@@ -40,7 +40,7 @@
 using namespace App;
 
 // returns a string which represent the object e.g. when printed in python
-std::string DocumentObjectPy::representation(void) const
+std::string DocumentObjectPy::representation() const
 {
     DocumentObject* object = this->getDocumentObjectPtr();
     std::stringstream str;
@@ -48,7 +48,7 @@ std::string DocumentObjectPy::representation(void) const
     return str.str();
 }
 
-Py::String DocumentObjectPy::getName(void) const
+Py::String DocumentObjectPy::getName() const
 {
     DocumentObject* object = this->getDocumentObjectPtr();
     const char* internal = object->getNameInDocument();
@@ -58,12 +58,12 @@ Py::String DocumentObjectPy::getName(void) const
     return Py::String(std::string(internal));
 }
 
-Py::String DocumentObjectPy::getFullName(void) const
+Py::String DocumentObjectPy::getFullName() const
 {
     return Py::String(getDocumentObjectPtr()->getFullName());
 }
 
-Py::Object DocumentObjectPy::getDocument(void) const
+Py::Object DocumentObjectPy::getDocument() const
 {
     DocumentObject* object = this->getDocumentObjectPtr();
     Document* doc = object->getDocument();
@@ -91,7 +91,7 @@ PyObject*  DocumentObjectPy::addProperty(PyObject *args)
     }
 
     getDocumentObjectPtr()->addDynamicProperty(sType,sName,sGroup,sDocStr.c_str(),attr,
-            PyObject_IsTrue(ro) ? true : false, PyObject_IsTrue(hd) ? true : false);
+            Base::asBoolean(ro), Base::asBoolean(hd));
 
     return Py::new_reference_to(this);
 }
@@ -135,7 +135,7 @@ PyObject*  DocumentObjectPy::touch(PyObject * args)
             Py_Return;
         }
         auto prop = getDocumentObjectPtr()->getPropertyByName(propName);
-        if(!prop) 
+        if(!prop)
             throw Py::RuntimeError("Property not found");
         prop->touch();
         Py_Return;
@@ -161,7 +161,7 @@ PyObject*  DocumentObjectPy::enforceRecompute(PyObject * args)
     Py_Return;
 }
 
-Py::List DocumentObjectPy::getState(void) const
+Py::List DocumentObjectPy::getState() const
 {
     DocumentObject* object = this->getDocumentObjectPtr();
     Py::List list;
@@ -200,7 +200,7 @@ Py::List DocumentObjectPy::getState(void) const
     return list;
 }
 
-Py::Object DocumentObjectPy::getViewObject(void) const
+Py::Object DocumentObjectPy::getViewObject() const
 {
     try {
         PyObject *dict = PySys_GetObject("modules");
@@ -248,7 +248,7 @@ Py::Object DocumentObjectPy::getViewObject(void) const
     }
 }
 
-Py::List DocumentObjectPy::getInList(void) const
+Py::List DocumentObjectPy::getInList() const
 {
     Py::List ret;
     std::vector<DocumentObject*> list = getDocumentObjectPtr()->getInList();
@@ -259,7 +259,7 @@ Py::List DocumentObjectPy::getInList(void) const
     return ret;
 }
 
-Py::List DocumentObjectPy::getInListRecursive(void) const
+Py::List DocumentObjectPy::getInListRecursive() const
 {
     Py::List ret;
     try {
@@ -267,15 +267,14 @@ Py::List DocumentObjectPy::getInListRecursive(void) const
 
         for (std::vector<DocumentObject*>::iterator It = list.begin(); It != list.end(); ++It)
             ret.append(Py::Object((*It)->getPyObject(), true));
- 
     }
     catch (const Base::Exception& e) {
         throw Py::IndexError(e.what());
     }
-    return ret;    
+    return ret;
 }
 
-Py::List DocumentObjectPy::getOutList(void) const
+Py::List DocumentObjectPy::getOutList() const
 {
     Py::List ret;
     std::vector<DocumentObject*> list = getDocumentObjectPtr()->getOutList();
@@ -286,7 +285,7 @@ Py::List DocumentObjectPy::getOutList(void) const
     return ret;
 }
 
-Py::List DocumentObjectPy::getOutListRecursive(void) const
+Py::List DocumentObjectPy::getOutListRecursive() const
 {
     Py::List ret;
     try {
@@ -374,12 +373,12 @@ PyObject*  DocumentObjectPy::evalExpression(PyObject *self, PyObject * args)
 
 PyObject*  DocumentObjectPy::recompute(PyObject *args)
 {
-    PyObject *recursive=Py_False;
-    if (!PyArg_ParseTuple(args, "|O",&recursive))
+    PyObject *recursive = Py_False;
+    if (!PyArg_ParseTuple(args, "|O!", &PyBool_Type, &recursive))
         return nullptr;
 
     try {
-        bool ok = getDocumentObjectPtr()->recomputeFeature(PyObject_IsTrue(recursive));
+        bool ok = getDocumentObjectPtr()->recomputeFeature(Base::asBoolean(recursive));
         return Py_BuildValue("O", (ok ? Py_True : Py_False));
     }
     catch (const Base::Exception& e) {
@@ -434,8 +433,8 @@ PyObject* DocumentObjectPy::getSubObject(PyObject *args, PyObject *keywds)
     short depth = 0;
 
     static char *kwlist[] = {"subname", "retType", "matrix", "transform", "depth", nullptr};
-    if (!PyArg_ParseTupleAndKeywords(args, keywds, "O|hO!Oh", kwlist,
-                                     &obj, &retType, &Base::MatrixPy::Type, &pyMat, &doTransform, &depth))
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "O|hO!O!h", kwlist,
+                                     &obj, &retType, &Base::MatrixPy::Type, &pyMat, &PyBool_Type, &doTransform, &depth))
         return nullptr;
 
     if (retType < 0 || retType > 6) {
@@ -448,7 +447,7 @@ PyObject* DocumentObjectPy::getSubObject(PyObject *args, PyObject *keywds)
     bool single = true;
 
     if (PyUnicode_Check(obj)) {
-        subs.push_back(PyUnicode_AsUTF8(obj));
+        subs.emplace_back(PyUnicode_AsUTF8(obj));
     }
     else if (PySequence_Check(obj)) {
         single = false;
@@ -456,7 +455,7 @@ PyObject* DocumentObjectPy::getSubObject(PyObject *args, PyObject *keywds)
         for (Py::Sequence::iterator it = shapeSeq.begin(); it != shapeSeq.end(); ++it) {
             PyObject* item = (*it).ptr();
             if (PyUnicode_Check(item)) {
-                subs.push_back(PyUnicode_AsUTF8(item));
+                subs.emplace_back(PyUnicode_AsUTF8(item));
             }
             else {
                 PyErr_SetString(PyExc_TypeError, "non-string object in sequence");
@@ -469,14 +468,14 @@ PyObject* DocumentObjectPy::getSubObject(PyObject *args, PyObject *keywds)
         return nullptr;
     }
 
-    bool transform = PyObject_IsTrue(doTransform);
+    bool transform = Base::asBoolean(doTransform);
 
     struct SubInfo {
         App::DocumentObject *sobj;
         Py::Object obj;
         Py::Object pyObj;
         Base::Matrix4D mat;
-        SubInfo(const Base::Matrix4D &mat) : sobj(nullptr), mat(mat){}
+        explicit SubInfo(const Base::Matrix4D &mat) : sobj(nullptr), mat(mat){}
     };
 
     Base::Matrix4D mat;
@@ -578,35 +577,34 @@ PyObject*  DocumentObjectPy::getLinkedObject(PyObject *args, PyObject *keywds)
     PyObject *transform = Py_True;
     short depth = 0;
     static char *kwlist[] = {"recursive","matrix","transform","depth", nullptr};
-    if (!PyArg_ParseTupleAndKeywords(args, keywds, "|OOOh", kwlist,
-                &recursive,&pyMat,&transform,&depth))
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "|O!OO!h", kwlist,
+                &PyBool_Type,&recursive,&pyMat,&PyBool_Type,&transform,&depth))
         return nullptr;
 
-    Base::Matrix4D _mat;
-    Base::Matrix4D *mat = nullptr;
-    if(pyMat!=Py_None) {
-        if(!PyObject_TypeCheck(pyMat,&Base::MatrixPy::Type)) {
-            PyErr_SetString(PyExc_TypeError, "expect argument 'matrix' to be of type Base.Matrix");
-            return nullptr;
-        }
-        _mat = *static_cast<Base::MatrixPy*>(pyMat)->getMatrixPtr();
-        mat = &_mat;
-    }
-
     PY_TRY {
+        Base::PyTypeCheck(&pyMat, &Base::MatrixPy::Type, "expect argument 'matrix' to be of type Base.Matrix");
+        Base::Matrix4D _mat;
+        Base::Matrix4D *mat = nullptr;
+        if (pyMat) {
+            _mat = *static_cast<Base::MatrixPy*>(pyMat)->getMatrixPtr();
+            mat = &_mat;
+        }
+
         auto linked = getDocumentObjectPtr()->getLinkedObject(
-                PyObject_IsTrue(recursive), mat, PyObject_IsTrue(transform),depth);
-        if(!linked)
+                Base::asBoolean(recursive), mat, Base::asBoolean(transform), depth);
+        if (!linked)
             linked = getDocumentObjectPtr();
         auto pyObj = Py::Object(linked->getPyObject(),true);
-        if(mat) {
+        if (mat) {
             Py::Tuple ret(2);
             ret.setItem(0,pyObj);
             ret.setItem(1,Py::asObject(new Base::MatrixPy(*mat)));
             return Py::new_reference_to(ret);
         }
+
         return Py::new_reference_to(pyObj);
-    } PY_CATCH;
+    }
+    PY_CATCH;
 }
 
 PyObject*  DocumentObjectPy::isElementVisible(PyObject *args)
@@ -623,10 +621,10 @@ PyObject*  DocumentObjectPy::setElementVisible(PyObject *args)
 {
     char *element = nullptr;
     PyObject *visible = Py_True;
-    if (!PyArg_ParseTuple(args, "s|O", &element,&visible))
+    if (!PyArg_ParseTuple(args, "s|O!", &element, &PyBool_Type, &visible))
         return nullptr;
     PY_TRY {
-        return Py_BuildValue("h", getDocumentObjectPtr()->setElementVisible(element,PyObject_IsTrue(visible)));
+        return Py_BuildValue("h", getDocumentObjectPtr()->setElementVisible(element, Base::asBoolean(visible)));
     } PY_CATCH;
 }
 
@@ -675,6 +673,24 @@ PyObject*  DocumentObjectPy::getParentGeoFeatureGroup(PyObject *args)
     }
 }
 
+PyObject*  DocumentObjectPy::getParent(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
+
+    try {
+        auto grp = getDocumentObjectPtr()->getFirstParent();
+        if(!grp) {
+            Py_INCREF(Py_None);
+            return Py_None;
+        }
+        return grp->getPyObject();
+    }
+    catch (const Base::Exception& e) {
+        throw Py::RuntimeError(e.what());
+    }
+}
+
 Py::Boolean DocumentObjectPy::getMustExecute() const
 {
     try {
@@ -696,7 +712,7 @@ PyObject*  DocumentObjectPy::getPathsByOutList(PyObject *args)
                 (o)->getDocumentObjectPtr();
         auto array = getDocumentObjectPtr()->getPathsByOutList(target);
         Py::List list;
-        for (auto it : array) {
+        for (const auto& it : array) {
             Py::List path;
             for (auto jt : it) {
                 path.append(Py::asObject(jt->getPyObject()));
@@ -710,87 +726,13 @@ PyObject*  DocumentObjectPy::getPathsByOutList(PyObject *args)
     }
 }
 
-PyObject *DocumentObjectPy::getCustomAttributes(const char* attr) const
+PyObject *DocumentObjectPy::getCustomAttributes(const char* ) const
 {
-    // Dynamic property is now directly supported in PropertyContainer. So we
-    // can comment out here and let PropertyContainerPy handle it.
-#if 1
-    (void)attr;
-#else
-    // search for dynamic property
-    Property* prop = getDocumentObjectPtr()->getDynamicPropertyByName(attr);
-    if (prop)
-        return prop->getPyObject();
-    else
-#endif
         return nullptr;
 }
-
-int DocumentObjectPy::setCustomAttributes(const char* attr, PyObject *obj)
+//remove
+int DocumentObjectPy::setCustomAttributes(const char* , PyObject *)
 {
-    // The following code is practically the same as in PropertyContainerPy,
-    // especially since now dynamic property is directly supported in
-    // PropertyContainer. So we can comment out here and let PropertyContainerPy
-    // handle it.
-#if 1
-    (void)attr;
-    (void)obj;
-#else
-    // explicitly search for dynamic property
-    try {
-        Property* prop = getDocumentObjectPtr()->getDynamicPropertyByName(attr);
-        if (prop) {
-            if(prop->testStatus(Property::Immutable)) {
-                std::stringstream s;
-                s << "'DocumentObject' attribute '" << attr << "' is read-only"; 
-                throw Py::AttributeError(s.str());
-            }
-            prop->setPyObject(obj);
-            return 1;
-        }
-    }
-    catch (Base::ValueError &exc) {
-        std::stringstream s;
-        s << "Property '" << attr << "': " << exc.what();
-        throw Py::ValueError(s.str());
-    }
-    catch (Base::Exception &exc) {
-        std::stringstream s;
-        s << "Attribute (Name: " << attr << ") error: '" << exc.what() << "' ";
-        throw Py::AttributeError(s.str());
-    }
-    catch (Py::AttributeError &) {
-        throw;
-    }catch (...) {
-        std::stringstream s;
-        s << "Unknown error in attribute " << attr;
-        throw Py::AttributeError(s.str());
-    }
-
-    // search in PropertyList
-    Property *prop = getDocumentObjectPtr()->getPropertyByName(attr);
-    if (prop) {
-        // Read-only attributes must not be set over its Python interface
-        if(prop->testStatus(Property::Immutable) ||
-           (getDocumentObjectPtr()->getPropertyType(prop) & Prop_ReadOnly))
-        {
-            std::stringstream s;
-            s << "'DocumentObject' attribute '" << attr << "' is read-only"; 
-            throw Py::AttributeError(s.str());
-        }
-
-        try {
-            prop->setPyObject(obj);
-        }
-        catch (const Base::TypeError& e) {
-            std::stringstream s;
-            s << "Property '" << prop->getName() << "': " << e.what();
-            throw Py::TypeError(s.str());
-        }
-        return 1;
-    } 
-#endif
-
     return 0;
 }
 
@@ -830,13 +772,13 @@ PyObject *DocumentObjectPy::resolveSubElement(PyObject *args)
     const char *subname;
     PyObject *append = Py_False;
     int type = 0;
-    if (!PyArg_ParseTuple(args, "s|Oi",&subname,&append,&type))
+    if (!PyArg_ParseTuple(args, "s|O!i",&subname,&PyBool_Type,&append,&type))
         return nullptr;
 
     PY_TRY {
         std::pair<std::string,std::string> elementName;
         auto obj = GeoFeature::resolveElement(getDocumentObjectPtr(), subname,elementName,
-                PyObject_IsTrue(append),(GeoFeature::ElementNameType)type);
+                Base::asBoolean(append), static_cast<GeoFeature::ElementNameType>(type));
         Py::Tuple ret(3);
         ret.setItem(0,obj?Py::Object(obj->getPyObject(),true):Py::None());
         ret.setItem(1,Py::String(elementName.first));
@@ -866,7 +808,7 @@ PyObject *DocumentObjectPy::adjustRelativeLinks(PyObject *args) {
         std::set<App::DocumentObject *> visited;
         return Py::new_reference_to(Py::Boolean(
                     getDocumentObjectPtr()->adjustRelativeLinks(inList,
-                        PyObject_IsTrue(recursive)?&visited:nullptr)));
+                        Base::asBoolean(recursive) ? &visited : nullptr)));
     }PY_CATCH
 }
 
