@@ -26,16 +26,15 @@
 # include <sstream>
 #endif
 
-
-#include <Base/Console.h>
+#include <App/DocumentObjectPy.h>
 #include <Base/Interpreter.h>
-#include <Base/Reader.h>
 #include <Base/MatrixPy.h>
 #include <Base/Tools.h>
-#include <App/DocumentObjectPy.h>
+
 #include "FeaturePython.h"
 #include "FeaturePythonPyImp.h"
 
+
 using namespace App;
 
 FeaturePythonImp::FeaturePythonImp(App::DocumentObject* o)
@@ -49,7 +48,12 @@ FeaturePythonImp::~FeaturePythonImp()
 #undef FC_PY_ELEMENT
 #define FC_PY_ELEMENT(_name) py_##_name = Py::None();
 
-    FC_PY_FEATURE_PYTHON
+    try {
+        FC_PY_FEATURE_PYTHON
+    }
+    catch (Py::Exception& e) {
+        e.clear();
+    }
 }
 
 void FeaturePythonImp::init(PyObject *pyobj) {
@@ -125,14 +129,14 @@ bool FeaturePythonImp::mustExecute() const
 
 void FeaturePythonImp::onBeforeChange(const Property* prop)
 {
-    if(py_onBeforeChange.isNone())
+    if (py_onBeforeChange.isNone())
         return;
 
     // Run the execute method of the proxy object.
     Base::PyGILStateLocker lock;
     try {
         const char *prop_name = object->getPropertyName(prop);
-        if(prop_name == 0)
+        if (!prop_name)
             return;
         if (has__object__) {
             Py::Tuple args(1);
@@ -180,13 +184,13 @@ bool FeaturePythonImp::onBeforeChangeLabel(std::string &newLabel)
 
 void FeaturePythonImp::onChanged(const Property* prop)
 {
-    if(py_onChanged.isNone())
+    if (py_onChanged.isNone())
         return;
     // Run the execute method of the proxy object.
     Base::PyGILStateLocker lock;
     try {
         const char *prop_name = object->getPropertyName(prop);
-        if(prop_name == 0)
+        if (!prop_name)
             return;
         if (has__object__) {
             Py::Tuple args(1);
@@ -228,6 +232,28 @@ void FeaturePythonImp::onDocumentRestored()
     }
 }
 
+void FeaturePythonImp::unsetupObject()
+{
+    _FC_PY_CALL_CHECK(unsetupObject, return);
+
+    // Run the execute method of the proxy object.
+    Base::PyGILStateLocker lock;
+    try {
+        if (has__object__) {
+            Base::pyCall(py_unsetupObject.ptr());
+        }
+        else {
+            Py::Tuple args(1);
+            args.setItem(0, Py::Object(object->getPyObject(), true));
+            Base::pyCall(py_unsetupObject.ptr(), args.ptr());
+        }
+    }
+    catch (Py::Exception&) {
+        Base::PyException e; // extract the Python error text
+        e.ReportException();
+    }
+}
+
 bool FeaturePythonImp::getSubObject(DocumentObject *&ret, const char *subname,
     PyObject **pyObj, Base::Matrix4D *_mat, bool transform, int depth) const
 {
@@ -247,7 +273,7 @@ bool FeaturePythonImp::getSubObject(DocumentObject *&ret, const char *subname,
 
         Py::Object res(Base::pyCall(py_getSubObject.ptr(),args.ptr()));
         if(res.isNone()) {
-            ret = 0;
+            ret = nullptr;
             return true;
         }
         if(!res.isTrue())
@@ -271,7 +297,7 @@ bool FeaturePythonImp::getSubObject(DocumentObject *&ret, const char *subname,
                 *pyObj = Py::new_reference_to(Py::None());
         }
         if(seq.getItem(0).isNone())
-            ret = 0;
+            ret = nullptr;
         else
             ret = static_cast<DocumentObjectPy*>(seq.getItem(0).ptr())->getDocumentObjectPtr();
         return true;
@@ -283,7 +309,7 @@ bool FeaturePythonImp::getSubObject(DocumentObject *&ret, const char *subname,
         }
         Base::PyException e; // extract the Python error text
         e.ReportException();
-        ret = 0;
+        ret = nullptr;
         return true;
     }
 }
@@ -365,12 +391,12 @@ bool FeaturePythonImp::getLinkedObject(DocumentObject *&ret, bool recurse,
         }
         Base::PyException e; // extract the Python error text
         e.ReportException();
-        ret = 0;
+        ret = nullptr;
         return true;
     }
 }
 
-PyObject *FeaturePythonImp::getPyObject(void)
+PyObject *FeaturePythonImp::getPyObject()
 {
     // ref counter is set to 1
     return new FeaturePythonPyT<DocumentObjectPy>(object);
@@ -554,14 +580,36 @@ FeaturePythonImp::redirectSubName(std::ostringstream &ss,
     }
 }
 
+bool FeaturePythonImp::editProperty(const char *name)
+{
+    _FC_PY_CALL_CHECK(editProperty,return false);
+    Base::PyGILStateLocker lock;
+    try {
+        Py::Tuple args(1);
+        args.setItem(0, Py::String(name));
+        Py::Object ret(Base::pyCall(py_editProperty.ptr(),args.ptr()));
+        return ret.isTrue();
+    }
+    catch (Py::Exception&) {
+        if (PyErr_ExceptionMatches(PyExc_NotImplementedError)) {
+            PyErr_Clear();
+            return false;
+        }
+
+        Base::PyException e; // extract the Python error text
+        e.ReportException();
+    }
+    return false;
+}
+
 // ---------------------------------------------------------
 
 namespace App {
 PROPERTY_SOURCE_TEMPLATE(App::FeaturePython, App::DocumentObject)
-template<> const char* App::FeaturePython::getViewProviderName(void) const {
+template<> const char* App::FeaturePython::getViewProviderName() const {
     return "Gui::ViewProviderPythonFeature";
 }
-template<> PyObject* App::FeaturePython::getPyObject(void) {
+template<> PyObject* App::FeaturePython::getPyObject() {
     if (PythonObject.is(Py::_None())) {
         // ref counter is set to 1
         PythonObject = Py::Object(new FeaturePythonPyT<DocumentObjectPy>(this),true);
@@ -576,7 +624,7 @@ template class AppExport FeaturePythonT<DocumentObject>;
 
 namespace App {
 PROPERTY_SOURCE_TEMPLATE(App::GeometryPython, App::GeoFeature)
-template<> const char* App::GeometryPython::getViewProviderName(void) const {
+template<> const char* App::GeometryPython::getViewProviderName() const {
     return "Gui::ViewProviderPythonGeometry";
 }
 // explicit template instantiation
