@@ -25,12 +25,13 @@
 
 #include <Base/BaseClass.h>
 #include <Base/Interpreter.h>
-#include <App/PropertyContainerPy.h>
+#include <Base/PyObjectBase.h>
 
 #if defined(__clang__)
 # pragma clang diagnostic push
 # pragma clang diagnostic ignored "-Wmissing-field-initializers"
 #elif defined(__GNUC__) || defined(__GNUG__)
+# pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wmissing-field-initializers"
 #endif
 
@@ -44,62 +45,25 @@
         virtual ~_class_(); \
     };
 
-#if PY_VERSION_HEX >= 0x03080000
-#define PYTHON_TYPE_IMP(_class_, _subclass_) \
-    PyTypeObject _class_::Type = { \
-        PyVarObject_HEAD_INIT(&PyType_Type, 0) \
-        ""#_class_"",  \
-        sizeof(_class_),  \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, \
-        Py_TPFLAGS_BASETYPE|Py_TPFLAGS_DEFAULT, \
-        ""#_class_"", \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, \
-        &_subclass_::Type, \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 \
-    }; \
-    _class_::_class_(Base::BaseClass *pcObject, PyTypeObject *T) \
-        : _subclass_(reinterpret_cast<_subclass_::PointerType>(pcObject), T) \
-    { \
-    } \
-    _class_::~_class_() \
-    { \
-    }
-
-#elif PY_MAJOR_VERSION >= 3
-#define PYTHON_TYPE_IMP(_class_, _subclass_) \
-    PyTypeObject _class_::Type = { \
-        PyVarObject_HEAD_INIT(&PyType_Type, 0) \
-        ""#_class_"",  \
-        sizeof(_class_),  \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, \
-        Py_TPFLAGS_BASETYPE|Py_TPFLAGS_DEFAULT, \
-        ""#_class_"", \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, \
-        &_subclass_::Type, \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 \
-    }; \
-    _class_::_class_(Base::BaseClass *pcObject, PyTypeObject *T) \
-        : _subclass_(reinterpret_cast<_subclass_::PointerType>(pcObject), T) \
-    { \
-    } \
-    _class_::~_class_() \
-    { \
-    }
-
+#if PY_VERSION_HEX >= 0x03090000
+#define PYTHON_TYPE_SLOTS 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
+#elif PY_VERSION_HEX >= 0x03080000
+#define PYTHON_TYPE_SLOTS 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 #else
+#define PYTHON_TYPE_SLOTS 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
+#endif \
 
 #define PYTHON_TYPE_IMP(_class_, _subclass_) \
     PyTypeObject _class_::Type = { \
-        PyObject_HEAD_INIT(&PyType_Type) \
-        0, \
+        PyVarObject_HEAD_INIT(&PyType_Type, 0) \
         ""#_class_"",  \
         sizeof(_class_),  \
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, \
-        Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_CLASS, \
+        Py_TPFLAGS_BASETYPE|Py_TPFLAGS_DEFAULT, \
         ""#_class_"", \
         0, 0, 0, 0, 0, 0, 0, 0, 0, \
         &_subclass_::Type, \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 \
+        PYTHON_TYPE_SLOTS \
     }; \
     _class_::_class_(Base::BaseClass *pcObject, PyTypeObject *T) \
         : _subclass_(reinterpret_cast<_subclass_::PointerType>(pcObject), T) \
@@ -109,11 +73,11 @@
     { \
     }
 
-#endif
-
 namespace App
 {
 
+class Property;
+
 /**
  * @author Werner Mayer
  */
@@ -124,7 +88,7 @@ public:
     static PyTypeObject   Type;
 
 public:
-    FeaturePythonPyT(Base::BaseClass *pcObject, PyTypeObject *T = &Type);
+    explicit FeaturePythonPyT(Base::BaseClass *pcObject, PyTypeObject *T = &Type);
     virtual ~FeaturePythonPyT();
 
     /** @name callbacks and implementers for the python object methods */
