@@ -36,14 +36,14 @@ namespace App
  */
 class AppExport GeoFeature : public App::DocumentObject
 {
-    PROPERTY_HEADER(App::GeoFeature);
+    PROPERTY_HEADER_WITH_OVERRIDE(App::GeoFeature);
 
 public:
     PropertyPlacement Placement;
 
     /// Constructor
-    GeoFeature(void);
-    virtual ~GeoFeature();
+    GeoFeature();
+    ~GeoFeature() override;
 
     /**
      * @brief transformPlacement applies transform to placement of this shape.
@@ -64,7 +64,7 @@ public:
      * @brief getPyObject returns the Python binding object
      * @return the Python binding object
      */
-    virtual PyObject* getPyObject(void);
+    PyObject* getPyObject() override;
 
     /// Specify the type of element name to return when calling getElementName() 
     enum ElementNameType {
