@@ -29,7 +29,7 @@
 #include <Base/Uuid.h>
 
 #include "Application.h"
-#include "ComplexGeoData.h"
+#include "ElementNamingUtils.h"
 #include "ComplexGeoDataPy.h"
 #include "Document.h"
 #include "DocumentObserver.h"
@@ -49,7 +49,7 @@ using namespace App;
 using namespace Base;
 namespace bp = boost::placeholders;
 
-typedef boost::iterator_range<const char*> CharRange;
+using CharRange = boost::iterator_range<const char*>;
 
 ////////////////////////////////////////////////////////////////////////
 
@@ -81,11 +81,11 @@ public:
     }
 
     // Auto generated code. See class document of LinkParams.
-    ~LinkParamsP() {
+    ~LinkParamsP() override {
     }
 
     // Auto generated code. See class document of LinkParams.
-    void OnChange(Base::Subject<const char*> &, const char* sReason) {
+    void OnChange(Base::Subject<const char*> &, const char* sReason) override {
         if(!sReason)
             return;
         auto it = funcs.find(sReason);
@@ -117,8 +117,8 @@ ParameterGrp::handle LinkParams::getHandle() {
 // Auto generated code. See class document of LinkParams.
 const char *LinkParams::docCopyOnChangeApplyToAll() {
     return QT_TRANSLATE_NOOP("LinkParams",
-"Stores the last user choice of whether to apply CopyOnChange setup to all link\n"
-"that links to the same configurable object");
+"Stores the last user choice of whether to apply CopyOnChange setup to all links\n"
+"that reference the same configurable object");
 }
 
 // Auto generated code. See class document of LinkParams.
@@ -128,7 +128,7 @@ const bool & LinkParams::getCopyOnChangeApplyToAll() {
 
 // Auto generated code. See class document of LinkParams.
 const bool & LinkParams::defaultCopyOnChangeApplyToAll() {
-    const static bool def = true;
+    static const bool def = true;
     return def;
 }
 
@@ -232,14 +232,14 @@ void LinkBaseExtension::setProperty(int idx, Property *prop) {
     case PropLinkMode: {
         static const char *linkModeEnums[] = {"None","Auto Delete","Auto Link","Auto Unlink",nullptr};
         auto propLinkMode = static_cast<PropertyEnumeration*>(prop);
-        if(!propLinkMode->getEnums())
+        if(!propLinkMode->hasEnums())
             propLinkMode->setEnums(linkModeEnums);
         break;
     }
     case PropLinkCopyOnChange: {
         static const char *enums[] = {"Disabled","Enabled","Owned","Tracking",nullptr};
         auto propEnum = static_cast<PropertyEnumeration*>(prop);
-        if(!propEnum->getEnums())
+        if(!propEnum->hasEnums())
             propEnum->setEnums(enums);
         break;
     }
@@ -256,24 +256,24 @@ void LinkBaseExtension::setProperty(int idx, Property *prop) {
            getPlacementProperty())
         {
             bool transform = getLinkTransformValue();
-            getPlacementProperty()->setStatus(Property::Hidden,transform);
-            getLinkPlacementProperty()->setStatus(Property::Hidden,!transform);
+            getPlacementProperty()->setStatus(Property::Hidden, transform);
+            getLinkPlacementProperty()->setStatus(Property::Hidden, !transform);
         }
         break;
     case PropElementList:
         getElementListProperty()->setScope(LinkScope::Global);
-        getElementListProperty()->setStatus(Property::Hidden,true);
+        getElementListProperty()->setStatus(Property::Hidden, true);
         // fall through
     case PropLinkedObject:
         // Make ElementList as read-only if we are not a group (i.e. having
         // LinkedObject property), because it is for holding array elements.
         if(getElementListProperty())
             getElementListProperty()->setStatus(
-                    Property::Immutable,getLinkedObjectProperty()!=nullptr);
+                Property::Immutable, getLinkedObjectProperty() != nullptr);
         break;
     case PropVisibilityList:
-        getVisibilityListProperty()->setStatus(Property::Immutable,true);
-        getVisibilityListProperty()->setStatus(Property::Hidden,true);
+        getVisibilityListProperty()->setStatus(Property::Immutable, true);
+        getVisibilityListProperty()->setStatus(Property::Hidden, true);
         break;
     }
 
@@ -328,7 +328,7 @@ App::DocumentObjectExecReturn *LinkBaseExtension::extensionExecute() {
         PropertyPythonObject *proxy = nullptr;
         if(getLinkExecuteProperty()
                 && !boost::iequals(getLinkExecuteValue(), "none")
-                && (!_LinkOwner.getValue() 
+                && (!_LinkOwner.getValue()
                     || !container->getDocument()->getObjectByID(_LinkOwner.getValue())))
         {
             // Check if this is an element link. Do not invoke appLinkExecute()
@@ -502,7 +502,7 @@ void LinkBaseExtension::syncCopyOnChange()
     auto parent = getContainer();
 
     auto linked = linkProp->getValue();
-    
+
     std::vector<App::DocumentObjectT> oldObjs;
     std::vector<App::DocumentObject*> objs;
 
@@ -540,7 +540,7 @@ void LinkBaseExtension::syncCopyOnChange()
     // Obtain the original linked object and its dependency in depending order.
     // The last being the original linked object.
     auto srcObjs = getOnChangeCopyObjects();
-    // Refresh signal connection to monitor changes 
+    // Refresh signal connection to monitor changes
     monitorOnChangeCopyObjects(srcObjs);
 
     // Copy the objects. Document::export/importObjects() (called by
@@ -656,7 +656,7 @@ void LinkBaseExtension::syncCopyOnChange()
     // Finally, remove all old copies. oldObjs stores type of DocumentObjectT
     // which stores the object name. Before removing, we need to make sure the
     // object exists, and it is not some new object with the same name, by
-    // checking objs which stores DocumentObject pointer. 
+    // checking objs which stores DocumentObject pointer.
     for (const auto &objT : oldObjs) {
         auto obj = objT.getObject();
         if (obj && std::binary_search(objs.begin(), objs.end(), obj))
@@ -811,8 +811,7 @@ bool LinkBaseExtension::setupCopyOnChange(DocumentObject *parent, DocumentObject
     return res;
 }
 
-void LinkBaseExtension::checkCopyOnChange(
-        App::DocumentObject *parent, const App::Property &prop) 
+void LinkBaseExtension::checkCopyOnChange(App::DocumentObject *parent, const App::Property &prop)
 {
     if(!parent || !parent->getDocument()
                || parent->getDocument()->isPerformingTransaction())
@@ -906,7 +905,7 @@ void LinkBaseExtension::monitorOnChangeCopyObjects(
         return;
     for(auto obj : objs) {
         obj->setStatus(App::ObjectStatus::TouchOnColorChange, true);
-        copyOnChangeSrcConns.push_back(obj->signalChanged.connect(
+        copyOnChangeSrcConns.emplace_back(obj->signalChanged.connect(
             [this](const DocumentObject &, const Property &) {
                 if (auto prop = this->getLinkCopyOnChangeTouchedProperty()) {
                     if (this->getLinkCopyOnChangeValue() != CopyOnChangeDisabled)
@@ -917,7 +916,7 @@ void LinkBaseExtension::monitorOnChangeCopyObjects(
 }
 
 App::GroupExtension *LinkBaseExtension::linkedPlainGroup() const {
-    if(mySubElements.size() && mySubElements[0].size())
+    if(!mySubElements.empty() && !mySubElements[0].empty())
         return nullptr;
     auto linked = getTrueLinkedObject(false);
     if(!linked)
@@ -970,7 +969,7 @@ int LinkBaseExtension::_getElementCountValue() const {
 }
 
 bool LinkBaseExtension::extensionHasChildElement() const {
-    if(_getElementListValue().size()
+    if(!_getElementListValue().empty()
             || (_getElementCountValue() && _getShowElementValue()))
         return true;
     if (getLinkClaimChildValue())
@@ -1044,7 +1043,7 @@ DocumentObject *LinkBaseExtension::getContainer(){
 }
 
 DocumentObject *LinkBaseExtension::getLink(int depth) const{
-    if (!GetApplication().checkLinkDepth(depth,true))
+    if (!GetApplication().checkLinkDepth(depth, MessageOption::Error))
         return nullptr;
     if(getLinkedObjectProperty())
         return getLinkedObjectValue();
@@ -1052,7 +1051,7 @@ DocumentObject *LinkBaseExtension::getLink(int depth) const{
 }
 
 int LinkBaseExtension::getArrayIndex(const char *subname, const char **psubname) {
-    if(!subname || Data::ComplexGeoData::isMappedElement(subname))
+    if(!subname || Data::isMappedElement(subname))
         return -1;
     const char *dot = strchr(subname,'.');
     if(!dot) dot= subname+strlen(subname);
@@ -1074,7 +1073,7 @@ int LinkBaseExtension::getArrayIndex(const char *subname, const char **psubname)
 }
 
 int LinkBaseExtension::getElementIndex(const char *subname, const char **psubname) const {
-    if(!subname || Data::ComplexGeoData::isMappedElement(subname))
+    if(!subname || Data::isMappedElement(subname))
         return -1;
     int idx = -1;
     const char *dot = strchr(subname,'.');
@@ -1247,7 +1246,7 @@ bool LinkBaseExtension::extensionGetSubObjects(std::vector<std::string> &ret, in
                 char index[30];
                 for(int i=0,count=_getElementCountValue();i<count;++i) {
                     snprintf(index,sizeof(index),"%d.",i);
-                    ret.push_back(index);
+                    ret.emplace_back(index);
                 }
             }
         }
@@ -1309,12 +1308,12 @@ bool LinkBaseExtension::extensionGetSubObject(DocumentObject *&ret, const char *
     int idx = getElementIndex(subname,&subname);
     if(idx>=0) {
         const auto &elements = _getElementListValue();
-        if(elements.size()) {
+        if(!elements.empty()) {
             if(idx>=(int)elements.size() || !elements[idx] || !elements[idx]->getNameInDocument())
                 return true;
             ret = elements[idx]->getSubObject(subname,pyObj,mat,true,depth+1);
             // do not resolve the link if this element is the last referenced object
-            if(!subname || Data::ComplexGeoData::isMappedElement(subname) || !strchr(subname,'.'))
+            if(!subname || Data::isMappedElement(subname) || !strchr(subname,'.'))
                 ret = elements[idx];
             return true;
         }
@@ -1382,7 +1381,7 @@ bool LinkBaseExtension::extensionGetSubObject(DocumentObject *&ret, const char *
     std::string postfix;
     if(ret) {
         // do not resolve the link if we are the last referenced object
-        if(subname && !Data::ComplexGeoData::isMappedElement(subname) && strchr(subname,'.')) {
+        if(subname && !Data::isMappedElement(subname) && strchr(subname,'.')) {
             if(mat)
                 *mat = matNext;
         }
@@ -1395,14 +1394,14 @@ bool LinkBaseExtension::extensionGetSubObject(DocumentObject *&ret, const char *
         }
         else {
             if(idx) {
-                postfix = Data::ComplexGeoData::indexPostfix();
+                postfix = Data::POSTFIX_INDEX;
                 postfix += std::to_string(idx);
             }
             if(mat)
                 *mat = matNext;
         }
     }
-    checkGeoElementMap(obj,linked,pyObj,postfix.size()?postfix.c_str():nullptr);
+    checkGeoElementMap(obj,linked,pyObj,!postfix.empty()?postfix.c_str():nullptr);
     return true;
 }
 
@@ -1489,20 +1488,20 @@ void LinkBaseExtension::parseSubName() const {
     }
     const auto &subs = xlink->getSubValues();
     auto subname = subs.front().c_str();
-    auto element = Data::ComplexGeoData::findElementName(subname);
+    auto element = Data::findElementName(subname);
     if(!element || !element[0]) {
         mySubName = subs[0];
         if(hasSubElement)
             mySubElements.emplace_back("");
         return;
     }
-    mySubElements.push_back(element);
+    mySubElements.emplace_back(element);
     mySubName = std::string(subname,element-subname);
     for(std::size_t i=1;i<subs.size();++i) {
         auto &sub = subs[i];
-        element = Data::ComplexGeoData::findElementName(sub.c_str());
+        element = Data::findElementName(sub.c_str());
         if(element && element[0] && boost::starts_with(sub,mySubName))
-            mySubElements.push_back(element);
+            mySubElements.emplace_back(element);
     }
 }
 
@@ -1531,7 +1530,7 @@ void LinkBaseExtension::updateGroup() {
         }
     }
     std::vector<App::DocumentObject*> children;
-    if(groups.size()) {
+    if(!groups.empty()) {
         children = getElementListValue();
         std::set<DocumentObject*> childSet(children.begin(),children.end());
         for(auto ext : groups) {
@@ -1624,16 +1623,16 @@ void LinkBaseExtension::update(App::DocumentObject *parent, const Property *prop
             }
             // touch the property again to make sure view provider has been
             // signaled before clearing the elements
-            getShowElementProperty()->setStatus(App::Property::User3,true);
+            getShowElementProperty()->setStatus(App::Property::User3, true);
             getShowElementProperty()->touch();
-            getShowElementProperty()->setStatus(App::Property::User3,false);
+            getShowElementProperty()->setStatus(App::Property::User3, false);
 
             getElementListProperty()->setValues(std::vector<App::DocumentObject*>());
 
             if(getPlacementListProperty()) {
-                getPlacementListProperty()->setStatus(Property::User3,getScaleListProperty()!=nullptr);
+                getPlacementListProperty()->setStatus(Property::User3, getScaleListProperty() != nullptr);
                 getPlacementListProperty()->setValue(placements);
-                getPlacementListProperty()->setStatus(Property::User3,false);
+                getPlacementListProperty()->setStatus(Property::User3, false);
             }
             if(getScaleListProperty())
                 getScaleListProperty()->setValue(scales);
@@ -1829,8 +1828,8 @@ void LinkBaseExtension::update(App::DocumentObject *parent, const Property *prop
                     if (src != &obj || getLinkCopyOnChangeValue()==CopyOnChangeDisabled)
                         return;
                     if (App::Document::isAnyRestoring()
-                            || obj.testStatus(ObjectStatus::NoTouch) 
-                            || (prop.getType() & Prop_Output) 
+                            || obj.testStatus(ObjectStatus::NoTouch)
+                            || (prop.getType() & Prop_Output)
                             || prop.testStatus(Property::Output))
                         return;
                     if (auto propTouch = getLinkCopyOnChangeTouchedProperty())
@@ -1884,34 +1883,33 @@ void LinkBaseExtension::syncElementList() {
     auto owner = getContainer();
     auto ownerID = owner?owner->getID():0;
     auto elements = getElementListValue();
-    for(size_t i=0;i<elements.size();++i) {
+    for (size_t i = 0; i < elements.size(); ++i) {
         auto element = freecad_dynamic_cast<LinkElement>(elements[i]);
-        if(!element
-                || (element->_LinkOwner.getValue()
-                    && element->_LinkOwner.getValue()!=ownerID))
+        if (!element
+            || (element->_LinkOwner.getValue()
+                && element->_LinkOwner.getValue() != ownerID))
             continue;
 
         element->_LinkOwner.setValue(ownerID);
 
-        element->LinkTransform.setStatus(Property::Hidden,transform!=nullptr);
-        element->LinkTransform.setStatus(Property::Immutable,transform!=nullptr);
-        if(transform && element->LinkTransform.getValue()!=transform->getValue())
+        element->LinkTransform.setStatus(Property::Hidden, transform != nullptr);
+        element->LinkTransform.setStatus(Property::Immutable, transform != nullptr);
+        if (transform && element->LinkTransform.getValue() != transform->getValue())
             element->LinkTransform.setValue(transform->getValue());
 
-        element->LinkedObject.setStatus(Property::Hidden,link!=nullptr);
-        element->LinkedObject.setStatus(Property::Immutable,link!=nullptr);
-        if(element->LinkCopyOnChange.getValue()==2)
+        element->LinkedObject.setStatus(Property::Hidden, link != nullptr);
+        element->LinkedObject.setStatus(Property::Immutable, link != nullptr);
+        if (element->LinkCopyOnChange.getValue() == 2)
             continue;
-        if(xlink) {
-            if(element->LinkedObject.getValue()!=xlink->getValue() ||
-               element->LinkedObject.getSubValues()!=xlink->getSubValues())
-            {
+        if (xlink) {
+            if (element->LinkedObject.getValue() != xlink->getValue()
+                || element->LinkedObject.getSubValues() != xlink->getSubValues()) {
                 element->LinkedObject.setValue(xlink->getValue(), xlink->getSubValues());
             }
-        } else if(element->LinkedObject.getValue()!=link->getValue() ||
-                  element->LinkedObject.getSubValues().size())
-        {
-            element->setLink(-1,link->getValue());
+        }
+        else if (element->LinkedObject.getValue() != link->getValue()
+                 || !element->LinkedObject.getSubValues().empty()) {
+            element->setLink(-1, link->getValue());
         }
     }
 }
@@ -1940,7 +1938,7 @@ void LinkBaseExtension::onExtendedDocumentRestored() {
         } else {
             std::set<std::string> subset(mySubElements.begin(),mySubElements.end());
             auto sub = xlink->getSubValues().front();
-            auto element = Data::ComplexGeoData::findElementName(sub.c_str());
+            auto element = Data::findElementName(sub.c_str());
             if(element && element[0]) {
                 subset.insert(element);
                 sub.resize(element - sub.c_str());
@@ -2037,7 +2035,7 @@ void LinkBaseExtension::setLink(int index, DocumentObject *obj,
             int idx = -1;
             if(getLinkModeValue()>=LinkModeAutoLink ||
                (subname && subname[0]) ||
-               subElements.size() ||
+               !subElements.empty() ||
                obj->getDocument()!=parent->getDocument() ||
                (getElementListProperty()->find(obj->getNameInDocument(),&idx) && idx!=index))
             {
@@ -2088,14 +2086,14 @@ void LinkBaseExtension::setLink(int index, DocumentObject *obj,
     }
 
     if(!xlink) {
-        if(subElements.size() || (subname && subname[0]))
+        if(!subElements.empty() || (subname && subname[0]))
             LINK_THROW(Base::RuntimeError,"SubName/SubElement link requires PropertyXLink");
         linkProp->setValue(obj);
         return;
     }
 
     std::vector<std::string> subs;
-    if(subElements.size()) {
+    if(!subElements.empty()) {
         subs.reserve(subElements.size());
         for(const auto &s : subElements) {
             subs.emplace_back(subname?subname:"");
@@ -2110,7 +2108,7 @@ void LinkBaseExtension::detachElements()
 {
     std::vector<App::DocumentObjectT> objs;
     for (auto obj : getElementListValue())
-        objs.push_back(obj);
+        objs.emplace_back(obj);
     getElementListProperty()->setValue();
     for(const auto &objT : objs)
         detachElement(objT.getObject());
