@@ -33,15 +33,15 @@
 using namespace App;
 
 // returns a string which represent the object e.g. when printed in python
-std::string LinkBaseExtensionPy::representation(void) const
+std::string LinkBaseExtensionPy::representation() const
 {
     std::ostringstream str;
     str << "<" << getLinkBaseExtensionPtr()->getExtensionClassTypeId().getName() << ">";
     return str.str();
 }
 
-typedef std::map<std::string, std::pair<int,Property*> > PropTmpMap;
-typedef std::map<std::string, Property*> PropMap;
+using PropTmpMap = std::map<std::string, std::pair<int,Property*> >;
+using PropMap = std::map<std::string, Property*>;
 
 static bool getProperty(PropTmpMap &props, const LinkBaseExtension::PropInfoMap &infoMap,
         const PropMap &propMap, PyObject *key, PyObject *value)
@@ -256,7 +256,7 @@ PyObject* LinkBaseExtensionPy::cacheChildLabel(PyObject *args) {
     if(!PyArg_ParseTuple(args,"|O",&enable))
         return nullptr;
     PY_TRY {
-        getLinkBaseExtensionPtr()->cacheChildLabel(PyObject_IsTrue(enable)?-1:0);
+        getLinkBaseExtensionPtr()->cacheChildLabel(Base::asBoolean(enable) ? -1 : 0);
         Py_Return;
     }PY_CATCH;
 }
