@@ -78,7 +78,7 @@ int MaterialPy::PyInit(PyObject* args, PyObject* kwds)
 }
 
 // returns a string which represents the object e.g. when printed in python
-std::string MaterialPy::representation(void) const
+std::string MaterialPy::representation() const
 {
     return std::string("<Material object>");
 }
@@ -94,7 +94,7 @@ PyObject* MaterialPy::set(PyObject * args)
     Py_Return;
 }
 
-Py::Tuple MaterialPy::getAmbientColor(void) const
+Py::Tuple MaterialPy::getAmbientColor() const
 {
     Py::Tuple tuple(4);
     tuple.setItem(0, Py::Float(getMaterialPtr()->ambientColor.r));
@@ -115,7 +115,7 @@ void MaterialPy::setAmbientColor(Py::Tuple arg)
     getMaterialPtr()->ambientColor = c;
 }
 
-Py::Tuple MaterialPy::getDiffuseColor(void) const
+Py::Tuple MaterialPy::getDiffuseColor() const
 {
     Py::Tuple tuple(4);
     tuple.setItem(0, Py::Float(getMaterialPtr()->diffuseColor.r));
@@ -136,7 +136,7 @@ void MaterialPy::setDiffuseColor(Py::Tuple arg)
     getMaterialPtr()->diffuseColor = c;
 }
 
-Py::Tuple MaterialPy::getEmissiveColor(void) const
+Py::Tuple MaterialPy::getEmissiveColor() const
 {
     Py::Tuple tuple(4);
     tuple.setItem(0, Py::Float(getMaterialPtr()->emissiveColor.r));
@@ -157,7 +157,7 @@ void MaterialPy::setEmissiveColor(Py::Tuple arg)
     getMaterialPtr()->emissiveColor = c;
 }
 
-Py::Tuple MaterialPy::getSpecularColor(void) const
+Py::Tuple MaterialPy::getSpecularColor() const
 {
     Py::Tuple tuple(4);
     tuple.setItem(0, Py::Float(getMaterialPtr()->specularColor.r));
@@ -178,7 +178,7 @@ void MaterialPy::setSpecularColor(Py::Tuple arg)
     getMaterialPtr()->specularColor = c;
 }
 
-Py::Float MaterialPy::getShininess(void) const
+Py::Float MaterialPy::getShininess() const
 {
     return Py::Float(getMaterialPtr()->shininess);
 }
@@ -188,7 +188,7 @@ void MaterialPy::setShininess(Py::Float arg)
     getMaterialPtr()->shininess = (float)arg;
 }
 
-Py::Float MaterialPy::getTransparency(void) const
+Py::Float MaterialPy::getTransparency() const
 {
     return Py::Float(getMaterialPtr()->transparency);
 }
