@@ -109,7 +109,7 @@ int Transaction::getLastID() {
     return _TransactionID;
 }
 
-unsigned int Transaction::getMemSize (void) const
+unsigned int Transaction::getMemSize () const
 {
     return 0;
 }
@@ -124,7 +124,7 @@ void Transaction::Restore(Base::XMLReader &/*reader*/)
     assert(0);
 }
 
-int Transaction::getID(void) const
+int Transaction::getID() const
 {
     return transID;
 }
@@ -182,7 +182,7 @@ void Transaction::apply(Document &Doc, bool forward)
     }catch(...) {
         errMsg = "Unknown exception";
     }
-    if(errMsg.size()) {
+    if(!errMsg.empty()) {
         FC_ERR("Exception on " << (forward?"redo":"undo") << " '" 
                 << Name << "':" << errMsg);
     }
@@ -313,7 +313,7 @@ void TransactionObject::applyChn(Document & /*Doc*/, TransactionalObject *pcObj,
             // been destroies. We must prepare for the case where user removed
             // a dynamic property but does not recordered as transaction.
             auto name = pcObj->getPropertyName(prop);
-            if(!name || (data.name.size() && data.name != name) || data.propertyType != prop->getTypeId()) {
+            if(!name || (!data.name.empty() && data.name != name) || data.propertyType != prop->getTypeId()) {
                 // Here means the original property is not found, probably removed
                 if(data.name.empty()) {
                     // not a dynamic property, nothing to do
@@ -383,7 +383,7 @@ void TransactionObject::addOrRemoveProperty(const Property* pcProp, bool add)
         return;
 
     auto &data = _PropChangeMap[pcProp->getID()];
-    if(data.name.size()) {
+    if(!data.name.empty()) {
         if(!add && !data.property) {
             // this means add and remove the same property inside a single
             // transaction, so they cancel each other out.
@@ -407,7 +407,7 @@ void TransactionObject::addOrRemoveProperty(const Property* pcProp, bool add)
     }
 }
 
-unsigned int TransactionObject::getMemSize (void) const
+unsigned int TransactionObject::getMemSize () const
 {
     return 0;
 }
@@ -436,17 +436,13 @@ TYPESYSTEM_SOURCE_ABSTRACT(App::TransactionDocumentObject, App::TransactionObjec
  * A constructor.
  * A more elaborate description of the constructor.
  */
-TransactionDocumentObject::TransactionDocumentObject()
-{
-}
+TransactionDocumentObject::TransactionDocumentObject() = default;
 
 /**
  * A destructor.
  * A more elaborate description of the destructor.
  */
-TransactionDocumentObject::~TransactionDocumentObject()
-{
-}
+TransactionDocumentObject::~TransactionDocumentObject() = default;
 
 void TransactionDocumentObject::applyDel(Document &Doc, TransactionalObject *pcObj)
 {
@@ -491,7 +487,7 @@ App::TransactionFactory* App::TransactionFactory::self = nullptr;
 
 TransactionFactory& TransactionFactory::instance()
 {
-    if (self == nullptr)
+    if (!self)
         self = new TransactionFactory;
     return *self;
 }
