@@ -43,8 +43,8 @@ class BoundBox3
     static bool isOnRayS(_Precision, _Precision, _Precision);
 
 public:
-    typedef _Precision num_type;
-    typedef float_traits<num_type> traits_type;
+    using num_type = _Precision;
+    using traits_type = float_traits<num_type>;
 
     /**  Public attributes */
     //@{
@@ -263,9 +263,7 @@ inline BoundBox3<_Precision>::BoundBox3 (const Vector3<_Precision> &rcVector, _P
 }
 
 template <class _Precision>
-inline BoundBox3<_Precision>::~BoundBox3 ()
-{
-}
+inline BoundBox3<_Precision>::~BoundBox3 () = default;
 
 template <class _Precision>
 inline  BoundBox3<_Precision>& BoundBox3<_Precision>::operator = (const BoundBox3<_Precision> &rcBound)
@@ -610,7 +608,7 @@ inline bool BoundBox3<_Precision>::IntersectionPoint (const Vector3<_Precision>
             rc = IntersectPlaneWithLine(i, rcVct, rcVctDir, cVctRes);
             if (!cCmpBound.IsInBox(cVctRes))
                 rc = false;
-            if (rc == true) {
+            if (rc) {
                 // does intersection point lie in desired direction
                 // or was found the opposing side?
                 // -> scalar product of both direction vectors > 0 (angle < 90)
@@ -773,7 +771,7 @@ inline typename BoundBox3<_Precision>::SIDE BoundBox3<_Precision>::GetSideFromRa
                                                                                    Vector3<_Precision>& rcInt) const
 {
     Vector3<_Precision> cP0, cP1;
-    if (IntersectWithLine(rclPt, rclDir, cP0, cP1) == false)
+    if (!IntersectWithLine(rclPt, rclDir, cP0, cP1))
         return INVALID;
 
     Vector3<_Precision>  cOut;
@@ -984,8 +982,8 @@ inline void BoundBox3<_Precision>::ScaleZ (_Precision f)
     MinZ *= f; MaxZ *= f;
 }
 
-typedef BoundBox3<float> BoundBox3f;
-typedef BoundBox3<double> BoundBox3d;
+using BoundBox3f = BoundBox3<float>;
+using BoundBox3d = BoundBox3<double>;
 
 } // namespace Base
 
