@@ -133,9 +133,7 @@ Vector2dPy::Vector2dPy(Py::PythonClassInstance *self, Py::Tuple &args, Py::Dict
     v.y = y;
 }
 
-Vector2dPy::~Vector2dPy()
-{
-}
+Vector2dPy::~Vector2dPy() = default;
 
 Py::Object Vector2dPy::repr()
 {
@@ -157,13 +155,7 @@ Py::Object Vector2dPy::getattro(const Py::String &name_)
     //
     std::string name( name_.as_std_string( "utf-8" ) );
 
-    if (name == "__members__") { // Py2
-        Py::List attr;
-        attr.append(Py::String("x"));
-        attr.append(Py::String("y"));
-        return attr;
-    }
-    else if (name == "__dict__") { // Py3
+    if (name == "__dict__") {
         Py::Dict attr;
         attr.setItem(Py::String("x"), Py::Float(v.x));
         attr.setItem(Py::String("y"), Py::Float(v.y));
@@ -227,11 +219,6 @@ Py::Object Vector2dPy::number_float()
     throw Py::TypeError("Not defined");
 }
 
-Py::Object Vector2dPy::number_long()
-{
-    throw Py::TypeError("Not defined");
-}
-
 Py::Object Vector2dPy::number_add( const Py::Object & py)
 {
     Vector2d u(Py::toVector2d(py));
@@ -392,7 +379,7 @@ Py::Object Vector2dPy::projectToLine(const Py::Tuple& args)
 }
 PYCXX_VARARGS_METHOD_DECL(Vector2dPy, projectToLine)
 
-void Vector2dPy::init_type(void)
+void Vector2dPy::init_type()
 {
     behaviors().name( "Vector2d" );
     behaviors().doc( "Vector2d class" );
