@@ -24,10 +24,10 @@
 #define BASE_IINPUTSOURCE_H
 
 #include <iosfwd>
+#include <memory>
 
 #include <xercesc/util/BinInputStream.hpp>
 #include <xercesc/sax/InputSource.hpp>
-#include <QTextCodec>
 #ifndef FC_GLOBAL_H
 #include <FCGlobal.h>
 #endif
@@ -45,19 +45,14 @@ class BaseExport StdInputStream : public XERCES_CPP_NAMESPACE_QUALIFIER BinInput
 {
 public :
   StdInputStream ( std::istream& Stream, XERCES_CPP_NAMESPACE_QUALIFIER MemoryManager* const manager = XERCES_CPP_NAMESPACE_QUALIFIER XMLPlatformUtils::fgMemoryManager );
-  virtual ~StdInputStream();
+  ~StdInputStream() override;
 
   // -----------------------------------------------------------------------
   //  Implementation of the input stream interface
   // -----------------------------------------------------------------------
-#if (XERCES_VERSION_MAJOR == 2)
-  virtual unsigned int curPos() const;
-  virtual unsigned int readBytes( XMLByte* const toFill, const unsigned int maxToRead );
-#else
-  virtual XMLFilePos curPos() const;
-  virtual XMLSize_t readBytes( XMLByte* const toFill, const XMLSize_t maxToRead );
-  virtual const XMLCh* getContentType() const {return nullptr;}
-#endif
+  XMLFilePos curPos() const override;
+  XMLSize_t readBytes( XMLByte* const toFill, const XMLSize_t maxToRead ) override;
+  const XMLCh* getContentType() const override {return nullptr;}
 
 private :
   // -----------------------------------------------------------------------
@@ -75,7 +70,8 @@ private :
   // -----------------------------------------------------------------------
   std::istream            &stream;
   XERCES_CPP_NAMESPACE_QUALIFIER MemoryManager* const    fMemoryManager;
-  QTextCodec::ConverterState state;
+  struct TextCodec;
+  std::unique_ptr<TextCodec> codec;
 };
 
 
@@ -83,9 +79,9 @@ class BaseExport StdInputSource : public XERCES_CPP_NAMESPACE_QUALIFIER InputSou
 {
 public :
   StdInputSource ( std::istream& Stream, const char* filePath, XERCES_CPP_NAMESPACE_QUALIFIER MemoryManager* const manager = XERCES_CPP_NAMESPACE_QUALIFIER XMLPlatformUtils::fgMemoryManager );
-   ~StdInputSource();
+   ~StdInputSource() override;
 
-  virtual XERCES_CPP_NAMESPACE_QUALIFIER BinInputStream* makeStream() const;
+  XERCES_CPP_NAMESPACE_QUALIFIER BinInputStream* makeStream() const override;
 
 private:
   StdInputSource(const StdInputSource&);
