@@ -29,10 +29,7 @@
 
 using namespace Base;
 
-Placement::Placement()
-{
-
-}
+Placement::Placement() = default;
 
 Placement::Placement(const Base::Matrix4D& matrix)
 {
@@ -100,6 +97,23 @@ bool Placement::isIdentity() const
     return none;
 }
 
+bool Placement::isIdentity(double tol) const
+{
+    return isSame(Placement(), tol);
+}
+
+bool Placement::isSame(const Placement& p) const
+{
+    return this->_rot.isSame(p._rot) &&
+           this->_pos.IsEqual(p._pos, 0);
+}
+
+bool Placement::isSame(const Placement& p, double tol) const
+{
+    return this->_rot.isSame(p._rot, tol) &&
+           this->_pos.IsEqual(p._pos, tol);
+}
+
 void Placement::invert()
 {
     this->_rot = this->_rot.inverse();
@@ -129,13 +143,15 @@ bool Placement::operator != (const Placement& that) const
     return !(*this == that);
 }
 
+/*!
+  Let this placement be right-multiplied by \a p. Returns reference to
+  self.
+
+  \sa multRight()
+*/
 Placement & Placement::operator*=(const Placement & p)
 {
-    Base::Vector3d tmp(p._pos);
-    this->_rot.multVec(tmp, tmp);
-    this->_pos += tmp;
-    this->_rot *= p._rot;
-    return *this;
+    return multRight(p);
 }
 
 Placement Placement::operator*(const Placement & p) const
@@ -157,12 +173,46 @@ Placement Placement::pow(double t, bool shorten) const
     return Placement::fromDualQuaternion(this->toDualQuaternion().pow(t, shorten));
 }
 
+/*!
+  Let this placement be right-multiplied by \a p. Returns reference to
+  self.
+
+  \sa multLeft()
+*/
+Placement& Placement::multRight(const Base::Placement& p)
+{
+    Base::Vector3d tmp(p._pos);
+    this->_rot.multVec(tmp, tmp);
+    this->_pos += tmp;
+    this->_rot.multRight(p._rot);
+    return *this;
+}
+
+/*!
+  Let this placement be left-multiplied by \a p. Returns reference to
+  self.
+
+  \sa multRight()
+*/
+Placement& Placement::multLeft(const Base::Placement& p)
+{
+    p.multVec(this->_pos, this->_pos);
+    this->_rot.multLeft(p._rot);
+    return *this;
+}
+
 void Placement::multVec(const Vector3d & src, Vector3d & dst) const
 {
     this->_rot.multVec(src, dst);
     dst += this->_pos;
 }
 
+void Placement::multVec(const Vector3f & src, Vector3f & dst) const
+{
+    this->_rot.multVec(src, dst);
+    dst += Base::toVector<float>(this->_pos);
+}
+
 Placement Placement::slerp(const Placement & p0, const Placement & p1, double t)
 {
     Rotation rot = Rotation::slerp(p0.getRotation(), p1.getRotation(), t);
