@@ -39,14 +39,14 @@ using namespace Base;
 // returns a string which represents the object e.g. when printed in python
 std::string PlacementPy::representation() const
 {
-    double A,B,C;
+    double yaw{}, pitch{}, roll{};
     PlacementPy::PointerType ptr = getPlacementPtr();
     std::stringstream str;
-    ptr->getRotation().getYawPitchRoll(A,B,C);
+    ptr->getRotation().getYawPitchRoll(yaw, pitch, roll);
 
     str << "Placement [Pos=(";
     str << ptr->getPosition().x << ","<< ptr->getPosition().y << "," << ptr->getPosition().z;
-    str << "), Yaw-Pitch-Roll=(" << A << "," << B << "," << C << ")]";
+    str << "), Yaw-Pitch-Roll=(" << yaw << "," << pitch << "," << roll << ")]";
 
     return str.str();
 }
@@ -67,9 +67,15 @@ int PlacementPy::PyInit(PyObject* args, PyObject* /*kwd*/)
 
     PyErr_Clear();
     if (PyArg_ParseTuple(args, "O!", &(Base::MatrixPy::Type), &o)) {
-        Base::Matrix4D mat = static_cast<Base::MatrixPy*>(o)->value();
-        getPlacementPtr()->fromMatrix(mat);
-        return 0;
+        try {
+            Base::Matrix4D mat = static_cast<Base::MatrixPy*>(o)->value();
+            getPlacementPtr()->fromMatrix(mat);
+            return 0;
+        }
+        catch (const Base::Exception& e) {
+            PyErr_SetString(e.getPyExceptionType(), e.what());
+            return -1;
+        }
     }
 
     PyErr_Clear();
@@ -163,22 +169,33 @@ PyObject* PlacementPy::translate(PyObject * args)
     return move(args);
 }
 
-PyObject* PlacementPy::rotate(PyObject *args) {
-    PyObject *obj1, *obj2;
+PyObject* PlacementPy::rotate(PyObject *args, PyObject *kwds)
+{
     double angle;
-    if (!PyArg_ParseTuple(args, "OOd", &obj1, &obj2, &angle))
+    char *keywords[] =  { "center", "axis", "angle", "comp", nullptr };
+    Vector3d center;
+    Vector3d axis;
+    PyObject* pyComp = Py_False;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "(ddd)(ddd)d|O!", keywords, &center.x, &center.y, &center.z,
+                                     &axis.x, &axis.y, &axis.z, &angle, &PyBool_Type, &pyComp))
         return nullptr;
 
     try {
-        Py::Sequence p1(obj1), p2(obj2);
-        Vector3d center((double)Py::Float(p1[0]),
-                        (double)Py::Float(p1[1]),
-                        (double)Py::Float(p1[2]));
-        Vector3d axis((double)Py::Float(p2[0]),
-                      (double)Py::Float(p2[1]),
-                      (double)Py::Float(p2[2]));
-        (*getPlacementPtr()) *= Placement(
-                Vector3d(),Rotation(axis,toRadians<double>(angle)),center);
+        /*
+         * if comp is False, we retain the original behaviour that - contrary to the (old) documentation - generates
+         * Placements different from TopoShape.rotate() to ensure compatibility for existing code
+         */
+        bool comp = Base::asBoolean(pyComp);
+
+        if (!comp) {
+            getPlacementPtr()->multRight(Placement(Vector3d(), Rotation(axis, toRadians<double>(angle)), center));
+        }
+        else {
+            // multiply new Placement the same way TopoShape.rotate() does
+            getPlacementPtr()->multLeft(Placement(Vector3d(), Rotation(axis, toRadians<double>(angle)), center));
+        }
+
         Py_Return;
     }
     catch (const Py::Exception&) {
@@ -234,7 +251,7 @@ PyObject* PlacementPy::pow(PyObject* args)
     PyObject* shorten = Py_True;
     if (!PyArg_ParseTuple(args, "d|O!", &t, &(PyBool_Type), &shorten))
         return nullptr;
-    Base::Placement ret = getPlacementPtr()->pow(t, PyObject_IsTrue(shorten));
+    Base::Placement ret = getPlacementPtr()->pow(t, Base::asBoolean(shorten));
     return new PlacementPy(new Placement(ret));
 }
 
@@ -247,7 +264,7 @@ PyObject* PlacementPy::sclerp(PyObject* args)
     if (!PyArg_ParseTuple(args, "O!d|O!", &(PlacementPy::Type), &pyplm2, &t, &(PyBool_Type), &shorten))
         return nullptr;
     Base::Placement plm2 = static_cast<Base::PlacementPy*>(pyplm2)->value();
-    Base::Placement ret = Base::Placement::sclerp(*getPlacementPtr(), plm2, t, PyObject_IsTrue(shorten));
+    Base::Placement ret = Base::Placement::sclerp(*getPlacementPtr(), plm2, t, Base::asBoolean(shorten));
     return new PlacementPy(new Placement(ret));
 }
 
@@ -264,12 +281,27 @@ PyObject* PlacementPy::slerp(PyObject* args)
 
 PyObject* PlacementPy::isIdentity(PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))
+    double tol = 0.0;
+    if (!PyArg_ParseTuple(args, "|d", &tol))
         return nullptr;
-    bool none = getPlacementPtr()->isIdentity();
+    bool none = tol > 0 ? getPlacementPtr()->isIdentity(tol)
+                        : getPlacementPtr()->isIdentity();
     return Py_BuildValue("O", (none ? Py_True : Py_False));
 }
 
+PyObject* PlacementPy::isSame(PyObject *args)
+{
+    PyObject* plm;
+    double tol = 0.0;
+    if (!PyArg_ParseTuple(args, "O!|d", &PlacementPy::Type, &plm, &tol))
+        return nullptr;
+
+    Base::Placement plm1 = * getPlacementPtr();
+    Base::Placement plm2 = * static_cast<PlacementPy*>(plm)->getPlacementPtr();
+    bool same = tol > 0.0 ? plm1.isSame(plm2, tol) : plm1.isSame(plm2);
+    return Py_BuildValue("O", (same ? Py_True : Py_False));
+}
+
 Py::Object PlacementPy::getBase() const
 {
     return Py::Vector(getPlacementPtr()->getPosition());
@@ -316,8 +348,13 @@ void PlacementPy::setMatrix(Py::Object arg)
     Py::Matrix mat;
     if (!mat.accepts(arg.ptr()))
         throw Py::TypeError("Expect type Matrix");
-    mat = arg;
-    getPlacementPtr()->fromMatrix(mat);
+    try {
+        mat = arg;
+        getPlacementPtr()->fromMatrix(mat);
+    }
+    catch (const Base::ValueError& e) {
+        throw Py::ValueError(e.what());
+    }
 }
 
 PyObject *PlacementPy::getCustomAttributes(const char* attr) const
