@@ -35,13 +35,14 @@
 #include <fcntl.h>
 #include <cstdio>
 #include <cassert>
-#include <time.h>
+#include <ctime>
 #include <cfloat>
 #ifdef FC_OS_WIN32
 #define _USE_MATH_DEFINES
 #endif // FC_OS_WIN32
 #include <cmath>
 #include <climits>
+#include <codecvt>
 
 #ifdef FC_OS_WIN32
 #include <direct.h>
@@ -55,10 +56,18 @@
 #include <Rpc.h>
 #endif
 
+#if defined (FC_OS_LINUX) || defined(FC_OS_CYGWIN) || defined(FC_OS_MACOSX) || defined(FC_OS_BSD)
+#include <dirent.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#endif
+
 // STL
 #include <string>
+#include <string_view>
 #include <list>
 #include <map>
+#include <unordered_map>
 #include <vector>
 #include <set>
 #include <stack>
@@ -77,9 +86,6 @@
 #include <xercesc/dom/DOM.hpp>
 #include <xercesc/dom/DOMImplementation.hpp>
 #include <xercesc/dom/DOMImplementationLS.hpp>
-#if (XERCES_VERSION_MAJOR == 2)
-#include <xercesc/dom/DOMWriter.hpp>
-#endif
 #include <xercesc/dom/DOMDocument.hpp>
 #include <xercesc/dom/DOMElement.hpp>
 #include <xercesc/dom/DOMText.hpp>
@@ -106,7 +112,11 @@
 #include <boost/filesystem/path.hpp>
 #include <boost/filesystem/operations.hpp>
 #include <boost/filesystem/exception.hpp>
+#include <boost/algorithm/string.hpp>
+#include <boost/algorithm/string/predicate.hpp>
+#include <boost/lexical_cast.hpp>
 #include <boost/regex.hpp>
+#include <boost/tokenizer.hpp>
 
 // QtCore
 #include <QBuffer>
