@@ -28,20 +28,21 @@
 
 #include "Rotation.h"
 #include "Matrix.h"
+#include "Precision.h"
 
 
 using namespace Base;
 
 Rotation::Rotation()
+    : quat{0.0,0.0,0.0,1.0}
+    , _axis{0.0,0.0,1.0}
+    , _angle{0.0}
 {
-    quat[0]=quat[1]=quat[2]=0.0;quat[3]=1.0;
-
-    _axis.Set(0.0, 0.0, 1.0);
-    _angle = 0.0;
 }
 
 /** Construct a rotation by rotation axis and angle */
 Rotation::Rotation(const Vector3d& axis, const double fAngle)
+    : Rotation()
 {
     // set to (0,0,1) as fallback in case the passed axis is the null vector
     _axis.Set(0.0, 0.0, 1.0);
@@ -49,6 +50,7 @@ Rotation::Rotation(const Vector3d& axis, const double fAngle)
 }
 
 Rotation::Rotation(const Matrix4D& matrix)
+    : Rotation()
 {
     this->setValue(matrix);
 }
@@ -58,6 +60,7 @@ Rotation::Rotation(const Matrix4D& matrix)
  * where the quaternion is specified by q=w+xi+yj+zk.
  */
 Rotation::Rotation(const double q[4])
+    : Rotation()
 {
     this->setValue(q);
 }
@@ -67,16 +70,19 @@ Rotation::Rotation(const double q[4])
  * where the quaternion is specified by q=w+xi+yj+zk.
  */
 Rotation::Rotation(const double q0, const double q1, const double q2, const double q3)
+    : Rotation()
 {
     this->setValue(q0, q1, q2, q3);
 }
 
 Rotation::Rotation(const Vector3d & rotateFrom, const Vector3d & rotateTo)
+    : Rotation()
 {
     this->setValue(rotateFrom, rotateTo);
 }
 
 Rotation::Rotation(const Rotation& rot)
+    : Rotation()
 {
     this->quat[0] = rot.quat[0];
     this->quat[1] = rot.quat[1];
@@ -214,32 +220,55 @@ void Rotation::setValue(const double q[4])
 
 void Rotation::setValue(const Matrix4D & m)
 {
-    double trace = (m[0][0] + m[1][1] + m[2][2]);
+    
+    auto type = m.hasScale();
+    if (type == Base::ScaleType::Other) {
+        THROWM(Base::ValueError, "setValue(matrix): Could not determine the rotation.");
+    }
+    Matrix4D mc(m);
+    if (type != Base::ScaleType::NoScaling) {
+        mc.setCol(3, Vector3d(0.0, 0.0, 0.0));
+        if (type == Base::ScaleType::NonUniformRight) {
+            mc.transpose();
+        }
+        double sx = 1.0 / mc.getRow(0).Length();
+        double sy = 1.0 / mc.getRow(1).Length();
+        double sz = 1.0 / mc.getRow(2).Length();
+        mc.scale(sx, sy, sz);
+        if (type == Base::ScaleType::NonUniformRight) {
+            mc.transpose();
+        }
+        if (mc.determinant3() < 0.0) {
+            mc.scale(-1.0, -1.0, -1.0);
+        }
+    }
+    // Extract quaternion
+    double trace = (mc[0][0] + mc[1][1] + mc[2][2]);
     if (trace > 0.0) {
         double s = sqrt(1.0+trace);
         this->quat[3] = 0.5 * s;
         s = 0.5 / s;
-        this->quat[0] = ((m[2][1] - m[1][2]) * s);
-        this->quat[1] = ((m[0][2] - m[2][0]) * s);
-        this->quat[2] = ((m[1][0] - m[0][1]) * s);
+        this->quat[0] = ((mc[2][1] - mc[1][2]) * s);
+        this->quat[1] = ((mc[0][2] - mc[2][0]) * s);
+        this->quat[2] = ((mc[1][0] - mc[0][1]) * s);
     }
     else {
         // Described in RotationIssues.pdf from <http://www.geometrictools.com>
         //
         // Get the max. element of the trace
         unsigned short i = 0;
-        if (m[1][1] > m[0][0]) i = 1;
-        if (m[2][2] > m[i][i]) i = 2;
+        if (mc[1][1] > mc[0][0]) i = 1;
+        if (mc[2][2] > mc[i][i]) i = 2;
 
         unsigned short j = (i+1)%3;
         unsigned short k = (i+2)%3;
 
-        double s = sqrt((m[i][i] - (m[j][j] + m[k][k])) + 1.0);
+        double s = sqrt((mc[i][i] - (mc[j][j] + mc[k][k])) + 1.0);
         this->quat[i] = s * 0.5;
         s = 0.5 / s;
-        this->quat[3] = ((m[k][j] - m[j][k]) * s);
-        this->quat[j] = ((m[j][i] + m[i][j]) * s);
-        this->quat[k] = ((m[k][i] + m[i][k]) * s);
+        this->quat[3] = ((mc[k][j] - mc[j][k]) * s);
+        this->quat[j] = ((mc[j][i] + mc[i][j]) * s);
+        this->quat[k] = ((mc[k][i] + mc[i][k]) * s);
     }
 
     this->evaluateVector();
@@ -345,7 +374,31 @@ Rotation Rotation::inverse() const
     return rot;
 }
 
+/*!
+  Let this rotation be right-multiplied by \a q. Returns reference to
+  self.
+
+  \sa multRight()
+*/
 Rotation & Rotation::operator*=(const Rotation & q)
+{
+    return multRight(q);
+}
+
+Rotation Rotation::operator*(const Rotation & q) const
+{
+    Rotation quat(*this);
+    quat *= q;
+    return quat;
+}
+
+/*!
+  Let this rotation be right-multiplied by \a q. Returns reference to
+  self.
+
+  \sa multLeft()
+*/
+Rotation& Rotation::multRight(const Base::Rotation& q)
 {
     // Taken from <http://de.wikipedia.org/wiki/Quaternionen>
     double x0, y0, z0, w0;
@@ -360,11 +413,25 @@ Rotation & Rotation::operator*=(const Rotation & q)
     return *this;
 }
 
-Rotation Rotation::operator*(const Rotation & q) const
+/*!
+  Let this rotation be left-multiplied by \a q. Returns reference to
+  self.
+
+  \sa multRight()
+*/
+Rotation& Rotation::multLeft(const Base::Rotation& q)
 {
-    Rotation quat(*this);
-    quat *= q;
-    return quat;
+    // Taken from <http://de.wikipedia.org/wiki/Quaternionen>
+    double x0, y0, z0, w0;
+    q.getValue(x0, y0, z0, w0);
+    double x1, y1, z1, w1;
+    this->getValue(x1, y1, z1, w1);
+
+    this->setValue(w0*x1 + x0*w1 + y0*z1 - z0*y1,
+                   w0*y1 - x0*z1 + y0*w1 + z0*x1,
+                   w0*z1 + x0*y1 - y0*x1 + z0*w1,
+                   w0*w1 - x0*x1 - y0*y1 - z0*z1);
+    return *this;
 }
 
 bool Rotation::operator==(const Rotation & q) const
@@ -386,33 +453,6 @@ bool Rotation::operator!=(const Rotation & q) const
     return !(*this == q);
 }
 
-bool Rotation::isSame(const Rotation& q) const
-{
-    if ((this->quat[0] == q.quat[0] &&
-         this->quat[1] == q.quat[1] &&
-         this->quat[2] == q.quat[2] &&
-         this->quat[3] == q.quat[3]) ||
-        (this->quat[0] == -q.quat[0] &&
-         this->quat[1] == -q.quat[1] &&
-         this->quat[2] == -q.quat[2] &&
-         this->quat[3] == -q.quat[3]))
-        return true;
-    return false;
-}
-
-bool Rotation::isSame(const Rotation& q, double tol) const
-{
-    // This follows the implementation of Coin3d where the norm
-    // (x1-y1)**2 + ... + (x4-y4)**2 is computed.
-    // This term can be simplified to
-    // 2 - 2*(x1*y1 + ... + x4*y4) so that for the equality we have to check
-    // 1 - tol/2 <= x1*y1 + ... + x4*y4
-    // Because a quaternion (x1,x2,x3,x4) is equal to (-x1,-x2,-x3,-x4) we use the
-    // absolute value of the scalar product
-    double dot = q.quat[0]*quat[0]+q.quat[1]*quat[1]+q.quat[2]*quat[2]+q.quat[3]*quat[3];
-    return fabs(dot) >= 1.0 - tol/2;
-}
-
 Vector3d Rotation::multVec(const Vector3d & src) const
 {
     Vector3d dst;
@@ -439,6 +479,20 @@ void Rotation::multVec(const Vector3d & src, Vector3d & dst) const
     dst.z = dz;
 }
 
+void Rotation::multVec(const Vector3f & src, Vector3f & dst) const
+{
+    Base::Vector3d srcd = Base::toVector<double>(src);
+    multVec(srcd, srcd);
+    dst = Base::toVector<float>(srcd);
+}
+
+Vector3f Rotation::multVec(const Vector3f & src) const
+{
+    Vector3f dst;
+    multVec(src,dst);
+    return dst;
+}
+
 void Rotation::scaleAngle(const double scaleFactor)
 {
     Vector3d axis;
@@ -491,7 +545,7 @@ Rotation Rotation::identity()
 
 Rotation Rotation::makeRotationByAxes(Vector3d xdir, Vector3d ydir, Vector3d zdir, const char* priorityOrder)
 {
-    const double tol = 1e-7; //equal to OCC Precision::Confusion
+    const double tol = Precision::Confusion();
     enum dirIndex {
         X,
         Y,
@@ -700,6 +754,35 @@ void Rotation::getYawPitchRoll(double& y, double& p, double& r) const
     r = (r/D_PI)*180;
 }
 
+bool Rotation::isSame(const Rotation& q) const
+{
+    if ((this->quat[0] == q.quat[0] &&
+         this->quat[1] == q.quat[1] &&
+         this->quat[2] == q.quat[2] &&
+         this->quat[3] == q.quat[3]) ||
+        (this->quat[0] == -q.quat[0] &&
+         this->quat[1] == -q.quat[1] &&
+         this->quat[2] == -q.quat[2] &&
+         this->quat[3] == -q.quat[3]))
+        return true;
+    return false;
+}
+
+bool Rotation::isSame(const Rotation& q, double tol) const
+{
+    // This follows the implementation of Coin3d where the norm
+    // (x1-y1)**2 + ... + (x4-y4)**2 is computed.
+    // This term can be simplified to
+    // 2 - 2*(x1*y1 + ... + x4*y4) so that for the equality we have to check
+    // 1 - tol/2 <= x1*y1 + ... + x4*y4
+    // This simplification only work if both quats are normalized
+    // Is it safe to assume that?
+    // Because a quaternion (x1,x2,x3,x4) is equal to (-x1,-x2,-x3,-x4) we use the
+    // absolute value of the scalar product
+    double dot = q.quat[0]*quat[0]+q.quat[1]*quat[1]+q.quat[2]*quat[2]+q.quat[3]*quat[3];
+    return fabs(dot) >= 1.0 - tol/2;
+}
+
 bool Rotation::isIdentity() const
 {
     return ((this->quat[0] == 0.0  &&
@@ -709,6 +792,11 @@ bool Rotation::isIdentity() const
              this->quat[3] == -1.0));
 }
 
+bool Rotation::isIdentity(double tol) const
+{
+    return isSame(Rotation(), tol);
+}
+
 bool Rotation::isNull() const
 {
     return (this->quat[0] == 0.0 &&
@@ -754,7 +842,7 @@ struct EulerSequence_Parameters
 
 EulerSequence_Parameters translateEulerSequence (const Rotation::EulerSequence theSeq)
 {
-    typedef EulerSequence_Parameters Params;
+    using Params = EulerSequence_Parameters;
     const bool F = false;
     const bool T = true;
 
@@ -863,7 +951,7 @@ Rotation::EulerSequence Rotation::eulerSequenceFromName(const char *name)
     if (name) {
         for (unsigned i=0; i<sizeof(EulerSequenceNames)/sizeof(EulerSequenceNames[0]); ++i) {
             if (boost::iequals(name, EulerSequenceNames[i]))
-                return (EulerSequence)(i+1);
+                return static_cast<EulerSequence>(i+1);
         }
     }
     return Invalid;
