@@ -24,9 +24,6 @@
 #ifndef BASE_SEQUENCER_H
 #define BASE_SEQUENCER_H
 
-#include <memory>
-#include <CXX/Extensions.hxx>
-
 #include "Exception.h"
 
 
@@ -269,15 +266,15 @@ public:
 
 protected:
     /** Starts the sequencer */
-    void startStep();
+    void startStep() override;
     /** Writes the current progress to the console window. */
-    void nextStep(bool canAbort);
+    void nextStep(bool canAbort) override;
 
 private:
     /** Puts text to the console window */
-    void setText (const char* pszTxt);
+    void setText (const char* pszTxt) override;
     /** Resets the sequencer */
-    void resetData();
+    void resetData() override;
 };
 
 /** The SequencerLauncher class is provided for convenience. It allows you to run an instance of the
@@ -384,27 +381,6 @@ inline SequencerBase& Sequencer ()
     return SequencerBase::Instance();
 }
 
-class BaseExport ProgressIndicatorPy : public Py::PythonExtension<ProgressIndicatorPy>
-{
-public:
-    static void init_type();    // announce properties and methods
-
-    ProgressIndicatorPy();
-    ~ProgressIndicatorPy();
-
-    Py::Object repr();
-
-    Py::Object start(const Py::Tuple&);
-    Py::Object next(const Py::Tuple&);
-    Py::Object stop(const Py::Tuple&);
-
-private:
-    static PyObject *PyMake(struct _typeobject *, PyObject *, PyObject *);
-
-private:
-    std::unique_ptr<SequencerLauncher> _seq;
-};
-
 } // namespace Base
 
 #endif // BASE_SEQUENCER_H
