@@ -229,15 +229,14 @@ private:
 // ----------------------------------------------------------------------------
 
 class ConnectionBlocker {
-    typedef boost::signals2::connection Connection;
-    typedef boost::signals2::shared_connection_block ConnectionBlock;
+    using Connection = boost::signals2::connection;
+    using ConnectionBlock = boost::signals2::shared_connection_block;
     ConnectionBlock blocker;
 
 public:
     ConnectionBlocker(Connection& c) : blocker(c) {
     }
-    ~ConnectionBlocker() {
-    }
+    ~ConnectionBlocker() = default;
 };
 
 // ----------------------------------------------------------------------------
@@ -275,6 +274,29 @@ struct BaseExport Tools
     static inline QString fromStdString(const std::string & s) {
         return QString::fromUtf8(s.c_str(), static_cast<int>(s.size()));
     }
+
+    /**
+     * @brief quoted Creates a quoted string.
+     * @param String to be quoted.
+     * @return A quoted std::string.
+     */
+    static std::string quoted(const char*);
+    /**
+     * @brief quoted Creates a quoted string.
+     * @param String to be quoted.
+     * @return A quoted std::string.
+     */
+    static std::string quoted(const std::string&);
+
+    /**
+     * @brief joinList
+     * Join the vector of strings \a vec using the separator \a sep
+     * @param vec
+     * @param sep
+     * @return
+     */
+    static std::string joinList(const std::vector<std::string>& vec,
+                                const std::string& sep = ", ");
 };
 
 
