@@ -100,7 +100,8 @@ PyObject* UnitsApi::sListSchemas(PyObject * /*self*/, PyObject *args)
         int num = static_cast<int>(UnitSystem::NumUnitSystemTypes);
         Py::Tuple tuple(num);
         for (int i=0; i<num; i++) {
-            tuple.setItem(i, Py::String(UnitsApi::getDescription(static_cast<UnitSystem>(i))));
+            const auto description {UnitsApi::getDescription(static_cast<UnitSystem>(i)).toStdString()};
+            tuple.setItem(i, Py::String(description.c_str()));
         }
 
         return Py::new_reference_to(tuple);
@@ -115,7 +116,8 @@ PyObject* UnitsApi::sListSchemas(PyObject * /*self*/, PyObject *args)
             return nullptr;
         }
 
-        return Py_BuildValue("s", UnitsApi::getDescription(static_cast<UnitSystem>(index)));
+        const auto description {UnitsApi::getDescription(static_cast<UnitSystem>(index)).toStdString()};
+        return Py_BuildValue("s", description.c_str());
     }
 
     PyErr_SetString(PyExc_TypeError, "int or empty argument list expected");
