@@ -51,9 +51,7 @@ Uuid::Uuid()
  * A destructor.
  * A more elaborate description of the destructor.
  */
-Uuid::~Uuid()
-{
-}
+Uuid::~Uuid() = default;
 
 //**************************************************************************
 //**************************************************************************
