@@ -27,6 +27,9 @@
 // Std. configurations
 
 #include <string>
+#ifndef FC_GLOBAL_H
+#include <FCGlobal.h>
+#endif
 
 namespace Base
 {
@@ -39,13 +42,18 @@ class BaseExport Uuid
 public:
     /// Construction
     Uuid();
+    Uuid(const Uuid&) = default;
+    Uuid& operator=(const Uuid&) = default;
     /// Destruction
     virtual ~Uuid();
 
     void setValue(const char* sString);
     void setValue(const std::string &sString);
-    const std::string& getValue(void) const;
-    static std::string createUuid(void);
+    const std::string& getValue() const;
+    static std::string createUuid();
+
+    bool operator==(const Uuid &other) const {return _uuid == other._uuid;}
+    bool operator<(const Uuid &other) const {return _uuid < other._uuid;}
 
 private:
     std::string _uuid;
