@@ -23,6 +23,8 @@
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <sstream>
+# include <QRegularExpression>
+# include <QRegularExpressionMatch>
 #endif
 
 #include "Command.h"
@@ -36,6 +38,7 @@
 // inclusion of the generated files (generated out of CommandPy.xml)
 #include "CommandPy.h"
 #include "CommandPy.cpp"
+#include "ShortcutManager.h"
 
 
 // returns a string which represents the object e.g. when printed in python
@@ -52,7 +55,7 @@ PyObject* CommandPy::get(PyObject *args)
 
     Command* cmd = Application::Instance->commandManager().getCommandByName(pName);
     if (cmd) {
-        CommandPy* cmdPy = new CommandPy(cmd);
+        auto cmdPy = new CommandPy(cmd);
         return cmdPy;
     }
 
@@ -76,8 +79,8 @@ PyObject* CommandPy::listAll(PyObject *args)
     std::vector <Command*> cmds = Application::Instance->commandManager().getAllCommands();
     PyObject* pyList = PyList_New(cmds.size());
     int i=0;
-    for ( std::vector<Command*>::iterator it = cmds.begin(); it != cmds.end(); ++it ) {
-        PyObject* str = PyUnicode_FromString((*it)->getName());
+    for (const auto & cmd : cmds) {
+        PyObject* str = PyUnicode_FromString(cmd->getName());
         PyList_SetItem(pyList, i++, str);
     }
     return pyList;
@@ -92,33 +95,32 @@ PyObject* CommandPy::listByShortcut(PyObject *args)
 
     std::vector <Command*> cmds = Application::Instance->commandManager().getAllCommands();
     std::vector <std::string> matches;
-    for (Command* c : cmds){
+    for (Command* c : cmds) {
         Action* action = c->getAction();
-        if (action){
+        if (action) {
             QString spc = QString::fromLatin1(" ");
-            if(PyObject_IsTrue(bIsRegularExp)){
-               QRegExp re = QRegExp(QString::fromLatin1(shortcut_to_find));
-               re.setCaseSensitivity(Qt::CaseInsensitive);
-               if (!re.isValid()){
+            if (Base::asBoolean(bIsRegularExp)) {
+               QRegularExpression re(QString::fromLatin1(shortcut_to_find), QRegularExpression::CaseInsensitiveOption);
+               if (!re.isValid()) {
                    std::stringstream str;
                    str << "Invalid regular expression:" << ' ' << shortcut_to_find;
                    throw Py::RuntimeError(str.str());
                }
 
-               if (re.indexIn(action->shortcut().toString().remove(spc).toUpper()) != -1) {
-                   matches.push_back(c->getName());
+               if (re.match(action->shortcut().toString().remove(spc).toUpper()).hasMatch()) {
+                   matches.emplace_back(c->getName());
                }
             }
             else if (action->shortcut().toString().remove(spc).toUpper() ==
                      QString::fromLatin1(shortcut_to_find).remove(spc).toUpper()) {
-                matches.push_back(c->getName());
+                matches.emplace_back(c->getName());
             }
         }
     }
 
     PyObject* pyList = PyList_New(matches.size());
     int i=0;
-    for (std::string match : matches) {
+    for (const std::string& match : matches) {
         PyObject* str = PyUnicode_FromString(match.c_str());
         PyList_SetItem(pyList, i++, str);
     }
@@ -187,33 +189,8 @@ PyObject* CommandPy::setShortcut(PyObject *args)
 
     Command* cmd = this->getCommandPtr();
     if (cmd) {
-        Action* action = cmd->getAction();
-        if (action) {
-            QKeySequence shortcut = QString::fromLatin1(pShortcut);
-            QString nativeText = shortcut.toString(QKeySequence::NativeText);
-            action->setShortcut(nativeText);
-            bool success = action->shortcut() == nativeText;
-            /**
-             * avoid cluttering parameters unnecessarily by saving only
-             * when new shortcut is not the default shortcut
-             * remove spaces to handle cases such as shortcut = "C,L" or "C, L"
-             */
-            QString default_shortcut = QString::fromLatin1(cmd->getAccel());
-            QString spc = QString::fromLatin1(" ");
-
-            ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("Shortcut");
-            const char* pName = cmd->getName();
-            if (success && default_shortcut.remove(spc).toUpper() != nativeText.remove(spc).toUpper()) {
-                hGrp->SetASCII(pName, pShortcut);
-            }
-            else {
-                hGrp->RemoveASCII(pName);
-            }
-            return Py::new_reference_to(Py::Boolean(success));
-        }
-        else {
-            return Py::new_reference_to(Py::Boolean(false));
-        }
+        ShortcutManager::instance()->setShortcut(cmd->getName(), pShortcut);
+        return Py::new_reference_to(Py::Boolean(true));
     }
     else {
         PyErr_Format(Base::PyExc_FC_GeneralError, "No such command");
@@ -229,24 +206,8 @@ PyObject* CommandPy::resetShortcut(PyObject *args)
 
     Command* cmd = this->getCommandPtr();
     if (cmd) {
-        Action* action = cmd->getAction();
-        if (action){
-            QString default_shortcut = QString::fromLatin1(cmd->getAccel());
-            action->setShortcut(default_shortcut);
-            ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("Shortcut");
-            hGrp->RemoveASCII(cmd->getName());
-            /** test to see if we successfully reset the shortcut by loading it back and comparing */
-            QString spc = QString::fromLatin1(" ");
-            QString new_shortcut = action->shortcut().toString();
-            if (default_shortcut.remove(spc).toUpper() == new_shortcut.remove(spc).toUpper()){
-                return Py::new_reference_to(Py::Boolean(true));
-            } else {
-                return Py::new_reference_to(Py::Boolean(false));
-            }
-        } else {
-            return Py::new_reference_to(Py::Boolean(false));
-        }
-
+        ShortcutManager::instance()->reset(cmd->getName());
+        return Py::new_reference_to(Py::Boolean(true));
     } else {
         PyErr_Format(Base::PyExc_FC_GeneralError, "No such command");
         return nullptr;
@@ -268,7 +229,7 @@ PyObject* CommandPy::getInfo(PyObject *args)
         const char* whatsThisTxt = cmd->getWhatsThis();
         const char* statustipTxt = cmd->getStatusTip();
         const char* pixMapTxt = cmd->getPixmap();
-        std::string shortcutTxt = "";
+        std::string shortcutTxt;
         if (action)
             shortcutTxt = action->shortcut().toString().toStdString();
 
@@ -302,14 +263,15 @@ PyObject* CommandPy::getAction(PyObject *args)
     Command* cmd = this->getCommandPtr();
     if (cmd) {
         Action* action = cmd->getAction();
-        ActionGroup* group = qobject_cast<ActionGroup*>(action);
+        auto* group = qobject_cast<ActionGroup*>(action);
 
         PythonWrapper wrap;
         wrap.loadWidgetsModule();
 
         Py::List list;
         if (group) {
-            for (auto a : group->actions())
+            const auto actions = group->actions();
+            for (auto a : actions)
                 list.append(wrap.fromQObject(a));
         }
         else if (action) {
@@ -341,10 +303,10 @@ PyObject* CommandPy::createCustomCommand(PyObject* args, PyObject* kw)
 
     auto name = Application::Instance->commandManager().newMacroName();
     CommandManager& commandManager = Application::Instance->commandManager();
-    MacroCommand* macro = new MacroCommand(name.c_str(), false);
+    auto macro = new MacroCommand(name.c_str(), false);
     commandManager.addCommand(macro);
 
-    macro->setScriptName(macroFile); 
+    macro->setScriptName(macroFile);
 
     if (menuTxt)
         macro->setMenuText(menuTxt);
@@ -376,8 +338,8 @@ PyObject* CommandPy::removeCustomCommand(PyObject* args)
     CommandManager& commandManager = Application::Instance->commandManager();
     std::vector<Command*> macros = commandManager.getGroupCommands("Macros");
 
-    auto action = std::find_if(macros.begin(), macros.end(), [actionName](const Command* c) { 
-        return std::string(c->getName()) == std::string(actionName); 
+    auto action = std::find_if(macros.begin(), macros.end(), [actionName](const Command* c) {
+        return std::string(c->getName()) == std::string(actionName);
     });
 
     if (action != macros.end()) {
