@@ -42,16 +42,19 @@ using namespace Gui::Dialog;
  *  true to construct a modal dialog.
  */
 DlgRunExternal::DlgRunExternal( QWidget* parent, Qt::WindowFlags fl )
-    : QDialog(parent, fl),process(this),advancedHidden(true)
+    : QDialog(parent, fl)
+    , process(this)
+    , advancedHidden(true)
+    , ui(new Ui_DlgRunExternal)
 {
-    ui = new Ui_DlgRunExternal();
     ui->setupUi(this);
-    connect(&process,SIGNAL(finished(int, QProcess::ExitStatus)),
-            this,SLOT(finished(int, QProcess::ExitStatus)));
-    connect(ui->buttonAccept,SIGNAL(clicked()),this,SLOT(accept()));
-    connect(ui->buttonDiscard,SIGNAL(clicked()),this,SLOT(reject()));
-    connect(ui->buttonAbort,SIGNAL(clicked()),this,SLOT(abort()));
-    connect(ui->buttonAdvanced,SIGNAL(clicked()),this,SLOT(advanced()));
+    connect(ui->chooseProgram, &QPushButton::clicked, this, &DlgRunExternal::onChooseProgramClicked);
+    connect(&process, qOverload<int, QProcess::ExitStatus>(&QProcess::finished),
+            this, qOverload<int, QProcess::ExitStatus>(&DlgRunExternal::finished));
+    connect(ui->buttonAccept, &QPushButton::clicked, this, &DlgRunExternal::accept);
+    connect(ui->buttonDiscard, &QPushButton::clicked, this, &DlgRunExternal::reject);
+    connect(ui->buttonAbort, &QPushButton::clicked, this, &DlgRunExternal::abort);
+    connect(ui->buttonAdvanced, &QPushButton::clicked, this, &DlgRunExternal::advanced);
 
     ui->gridLayout->setSizeConstraint(QLayout::SetFixedSize);
     ui->extensionWidget->hide();
@@ -62,11 +65,14 @@ DlgRunExternal::DlgRunExternal( QWidget* parent, Qt::WindowFlags fl )
  */
 DlgRunExternal::~DlgRunExternal()
 {
-    // no need to delete child widgets, Qt does it all for us
-    delete ui;
 }
 
-int DlgRunExternal::Do()
+void DlgRunExternal::addArgument(const QString& arg)
+{
+    arguments.append(arg);
+}
+
+int DlgRunExternal::runProcess()
 {
     QFileInfo ifo (ProcName);
 
@@ -116,7 +122,7 @@ void DlgRunExternal::finished (int exitCode, QProcess::ExitStatus exitStatus)
     ui->buttonAbort->setEnabled(false);
 }
 
-void DlgRunExternal::on_chooseProgram_clicked()
+void DlgRunExternal::onChooseProgramClicked()
 {
     QString fn;
     fn = QFileDialog::getOpenFileName(this, tr("Select a file"), ui->programPath->text());
