@@ -44,7 +44,7 @@ using namespace Gui::Dialog;
 UndoDialog::UndoDialog( QWidget* parent )
   : QMenu( parent )
 {
-    connect(this, SIGNAL(aboutToShow()), this, SLOT(onFetchInfo()));
+    connect(this, &QMenu::aboutToShow, this, &UndoDialog::onFetchInfo);
 }
 
 /**
@@ -66,17 +66,18 @@ void UndoDialog::onFetchInfo()
     MDIView* mdi =  getMainWindow()->activeWindow();
     if (mdi) {
         QStringList vecUndos = mdi->undoActions();
-        for (QStringList::Iterator i = vecUndos.begin(); i != vecUndos.end(); ++i)
-            addAction(*i, this, SLOT(onSelected()));
+        for (QStringList::Iterator i = vecUndos.begin(); i != vecUndos.end(); ++i) {
+            addAction(*i, this, &UndoDialog::onSelected);
+        }
     }
 }
 
 /** Closes the dialog and sends the message 'Undo' to the currently active MDI view. */
 void UndoDialog::onSelected()
 {
-    QAction* a = static_cast<QAction*>(sender());
+    auto a = static_cast<QAction*>(sender());
     QList<QAction*> acts = this->actions();
-    for (QList<QAction*>::ConstIterator it = acts.begin(); it != acts.end(); ++it) {
+    for (QList<QAction*>::Iterator it = acts.begin(); it != acts.end(); ++it) {
         Gui::Application::Instance->sendMsgToActiveView("Undo");
         if (*it == a)
             break;
@@ -92,7 +93,7 @@ void UndoDialog::onSelected()
 RedoDialog::RedoDialog( QWidget* parent )
   : QMenu( parent )
 {
-    connect(this, SIGNAL(aboutToShow()), this, SLOT(onFetchInfo()));
+    connect(this, &QMenu::aboutToShow, this, &RedoDialog::onFetchInfo);
 }
 
 /**
@@ -114,17 +115,18 @@ void RedoDialog::onFetchInfo()
     MDIView* mdi = getMainWindow()->activeWindow();
     if (mdi) {
         QStringList vecRedos = mdi->redoActions();
-        for (QStringList::Iterator i = vecRedos.begin(); i != vecRedos.end(); ++i)
-            addAction(*i, this, SLOT(onSelected()));
+        for (QStringList::Iterator i = vecRedos.begin(); i != vecRedos.end(); ++i) {
+            addAction(*i, this, &RedoDialog::onSelected);
+        }
     }
 }
 
 /** Closes the dialog and sends the message 'Redo' to the currently active MDI view. */
 void RedoDialog::onSelected()
 {
-    QAction* a = static_cast<QAction*>(sender());
+    auto a = static_cast<QAction*>(sender());
     QList<QAction*> acts = this->actions();
-    for (QList<QAction*>::ConstIterator it = acts.begin(); it != acts.end(); ++it) {
+    for (QList<QAction*>::Iterator it = acts.begin(); it != acts.end(); ++it) {
         Gui::Application::Instance->sendMsgToActiveView("Redo");
         if (*it == a)
             break;
