@@ -53,8 +53,6 @@ public:
     virtual bool apply();
     bool hasExpression() const;
 
-    QPixmap getIcon(const char *name, const QSize &size) const;
-
     //auto apply means that the python code is issued not only on apply() but
     //also on setExpression
     bool autoApply() const {return m_autoApply;}
@@ -65,22 +63,17 @@ protected:
     std::shared_ptr<App::Expression> getExpression() const;
     std::string getExpressionString(bool no_throw=true) const;
     std::string getEscapedExpressionString() const;
+    bool assignToProperty(const std::string & propName, double);
     virtual void setExpression(std::shared_ptr<App::Expression> expr);
 
     //gets called when the bound expression is changed, either by this binding or any external action
     virtual void onChange() {}
 
-    void makeLabel(QLineEdit* parent);
-
 private:
     App::ObjectIdentifier path;
     std::shared_ptr<App::Expression> lastExpression;
 
 protected:
-    ExpressionLabel* iconLabel;
-    QPalette defaultPalette;
-    int iconHeight;
-
     void expressionChange(const App::ObjectIdentifier& id);
     void objectDeleted(const App::DocumentObject&);
     boost::signals2::scoped_connection expressionchanged;
@@ -88,6 +81,21 @@ protected:
     bool m_autoApply;
 };
 
+class GuiExport ExpressionWidget : public ExpressionBinding
+{
+public:
+    ExpressionWidget();
+    QPixmap getIcon(const char *name, const QSize &size) const;
+
+protected:
+    void makeLabel(QLineEdit* parent);
+
+protected:
+    ExpressionLabel* iconLabel;
+    QPalette defaultPalette;
+    int iconHeight;
+};
+
 }
 
 #endif // EXPRESSIONBINDING_H
