@@ -32,6 +32,7 @@
 #include <FCGlobal.h>
 
 class QButtonGroup;
+class QDialogButtonBox;
 class QGridLayout;
 class QGroupBox;
 class QHBoxLayout;
@@ -76,10 +77,10 @@ public:
     static QString restoreLocation();
     static void saveLocation(const QString&);
 
-    FileDialog(QWidget * parent = nullptr);
-    ~FileDialog();
+    explicit FileDialog(QWidget * parent = nullptr);
+    ~FileDialog() override;
 
-    void accept();
+    void accept() override;
 
 private Q_SLOTS:
     void onSelectedFilter(const QString&);
@@ -108,9 +109,9 @@ public:
     };
 
     FileOptionsDialog ( QWidget* parent, Qt::WindowFlags );
-    virtual ~FileOptionsDialog();
+    ~FileOptionsDialog() override;
 
-    void accept();
+    void accept() override;
 
     void setOptionsWidget( ExtensionPosition pos , QWidget*, bool show = false );
     QWidget* getOptionsWidget() const;
@@ -135,11 +136,11 @@ class FileIconProvider : public QFileIconProvider
 {
 public:
     FileIconProvider();
-    ~FileIconProvider();
+    ~FileIconProvider() override;
 
-    QIcon icon(IconType type) const;
-    QIcon icon(const QFileInfo & info) const;
-    QString type(const QFileInfo & info) const;
+    QIcon icon(IconType type) const override;
+    QIcon icon(const QFileInfo & info) const override;
+    QString type(const QFileInfo & info) const override;
 };
 
 // ----------------------------------------------------------------------
@@ -153,20 +154,21 @@ class GuiExport FileChooser : public QWidget
 {
     Q_OBJECT
 
-    Q_ENUMS( Mode )
-    Q_PROPERTY( Mode mode READ mode WRITE setMode )
-    Q_ENUMS( AcceptMode )
-    Q_PROPERTY( AcceptMode acceptMode READ acceptMode WRITE setAcceptMode    )
-    Q_PROPERTY( QString  fileName  READ fileName      WRITE setFileName      )
-    Q_PROPERTY( QString  filter    READ filter        WRITE setFilter        )
-    Q_PROPERTY( QString  buttonText  READ buttonText  WRITE setButtonText    )
-
 public:
     enum Mode { File, Directory };
     enum AcceptMode { AcceptOpen, AcceptSave };
 
-    FileChooser ( QWidget * parent = nullptr );
-    virtual ~FileChooser();
+    Q_ENUM( Mode )
+    Q_PROPERTY(Mode mode READ mode WRITE setMode NOTIFY modeChanged)
+    Q_ENUM( AcceptMode )
+    Q_PROPERTY(AcceptMode acceptMode READ acceptMode WRITE setAcceptMode NOTIFY acceptModeChanged)
+    Q_PROPERTY(QString fileName READ fileName WRITE setFileName NOTIFY fileNameChanged)
+    Q_PROPERTY(QString filter READ filter WRITE setFilter NOTIFY filterChanged)
+    Q_PROPERTY(QString buttonText READ buttonText WRITE setButtonText NOTIFY buttonTextChanged)
+
+public:
+    explicit FileChooser ( QWidget * parent = nullptr );
+    ~FileChooser() override;
 
     /**
     * Returns the set filter.
@@ -192,9 +194,7 @@ public:
     /**
      * Sets the accept mode.
      */
-    void setAcceptMode(AcceptMode mode) {
-        accMode = mode;
-    }
+    void setAcceptMode(AcceptMode mode);
     /**
      * Returns the accept mode.
      */
@@ -204,20 +204,24 @@ public:
 
 public Q_SLOTS:
     virtual void setFileName( const QString &fn );
-    virtual void setMode( Mode m );
+    virtual void setMode( Gui::FileChooser::Mode m );
     virtual void setFilter ( const QString & );
     virtual void setButtonText ( const QString & );
 
 Q_SIGNALS:
     void fileNameChanged( const QString & );
     void fileNameSelected( const QString & );
+    void filterChanged(const QString&);
+    void buttonTextChanged(const QString&);
+    void modeChanged(Gui::FileChooser::Mode);
+    void acceptModeChanged(Gui::FileChooser::AcceptMode);
 
 private Q_SLOTS:
     void chooseFile();
     void editingFinished();
 
 protected:
-    void resizeEvent(QResizeEvent*);
+    void resizeEvent(QResizeEvent*) override;
 
 private:
     QLineEdit *lineEdit;
@@ -241,10 +245,10 @@ class GuiExport SelectModule : public QDialog
     Q_OBJECT
 
 public:
-    typedef QMap<QString, QString> Dict;
+    using Dict = QMap<QString, QString>;
 
     SelectModule (const QString& type, const Dict&, QWidget* parent);
-    virtual ~SelectModule();
+    ~SelectModule() override;
     QString getModule() const;
 
     /** @name Import/Export handler
@@ -253,20 +257,20 @@ public:
      * the file.
      */
     //@{
-    static Dict exportHandler(const QString& fn, const QString& filter=QString());
-    static Dict exportHandler(const QStringList& fn, const QString& filter=QString());
-    static Dict importHandler(const QString& fn, const QString& filter=QString());
-    static Dict importHandler(const QStringList& fn, const QString& filter=QString());
+    static Dict exportHandler(const QString& fileName, const QString& filter=QString());
+    static Dict exportHandler(const QStringList& fileNames, const QString& filter=QString());
+    static Dict importHandler(const QString& fileName, const QString& filter=QString());
+    static Dict importHandler(const QStringList& fileNames, const QString& filter=QString());
     //@}
 
-    void accept();
-    void reject();
+    void accept() override;
+    void reject() override;
 
 private Q_SLOTS:
     void onButtonClicked();
 
 private:
-    QPushButton *okButton;
+    QDialogButtonBox *buttonBox;
     QButtonGroup* group;
     QGridLayout *gridLayout;
     QHBoxLayout *hboxLayout;
