@@ -26,21 +26,23 @@
 # include <QContextMenuEvent>
 # include <QMenu>
 # include <QPixmapCache>
+# include <QRegularExpression>
+# include <QRegularExpressionMatch>
 #endif
 
-#include <Base/Console.h>
-#include <Base/Quantity.h>
-#include <Base/Exception.h>
-#include <Base/Tools.h>
 #include <App/Application.h>
-#include <App/PropertyUnits.h>
-#include <App/ExpressionParser.h>
 #include <App/DocumentObject.h>
-#include "ExpressionCompleter.h"
-#include "Command.h"
+#include <App/ExpressionParser.h>
+#include <App/PropertyUnits.h>
+#include <Base/Exception.h>
+#include <Base/Quantity.h>
+#include <Base/Tools.h>
+
 #include "InputField.h"
 #include "BitmapFactory.h"
-#include "propertyeditor/PropertyItem.h"
+#include "Command.h"
+#include "QuantitySpinBox_p.h"
+
 
 using namespace Gui;
 using namespace App;
@@ -52,11 +54,11 @@ namespace Gui {
 class InputValidator : public QValidator
 {
 public:
-    InputValidator(InputField* parent);
-    ~InputValidator();
+    explicit InputValidator(InputField* parent);
+    ~InputValidator() override;
 
-    void fixup(QString& input) const;
-    State validate(QString& input, int& pos) const;
+    void fixup(QString& input) const override;
+    State validate(QString& input, int& pos) const override;
 
 private:
     InputField* dptr;
@@ -67,7 +69,7 @@ private:
 
 InputField::InputField(QWidget * parent)
   : ExpressionLineEdit(parent),
-    ExpressionBinding(),
+    ExpressionWidget(),
     validInput(true),
     actUnitValue(0),
     Maximum(DOUBLE_MAX),
@@ -77,14 +79,19 @@ InputField::InputField(QWidget * parent)
     SaveSize(5)
 {
     setValidator(new InputValidator(this));
-    setFocusPolicy(Qt::WheelFocus);
-    iconLabel = new QLabel(this);
+    if (!App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/General")->GetBool("ComboBoxWheelEventFilter",false)) {
+        setFocusPolicy(Qt::WheelFocus);
+    }
+    else {
+        setFocusPolicy(Qt::StrongFocus);
+    }
+    iconLabel = new ExpressionLabel(this);
     iconLabel->setCursor(Qt::ArrowCursor);
     QPixmap pixmap = getValidationIcon(":/icons/button_valid.svg", QSize(sizeHint().height(),sizeHint().height()));
     iconLabel->setPixmap(pixmap);
     iconLabel->setStyleSheet(QString::fromLatin1("QLabel { border: none; padding: 0px; }"));
     iconLabel->hide();
-    connect(this, SIGNAL(textChanged(const QString&)), this, SLOT(updateIconLabel(const QString&)));
+    connect(this, &QLineEdit::textChanged, this, &InputField::updateIconLabel);
     int frameWidth = style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
     setStyleSheet(QString::fromLatin1("QLineEdit { padding-right: %1px } ").arg(iconLabel->sizeHint().width() + frameWidth + 1));
     QSize msz = minimumSizeHint();
@@ -93,8 +100,7 @@ InputField::InputField(QWidget * parent)
 
     this->setContextMenuPolicy(Qt::DefaultContextMenu);
 
-    QObject::connect(this, SIGNAL(textChanged(QString)),
-                     this, SLOT(newInput(QString)));
+    connect(this, &QLineEdit::textChanged, this, &InputField::newInput);
 }
 
 InputField::~InputField()
@@ -105,7 +111,7 @@ void InputField::bind(const App::ObjectIdentifier &_path)
 {
     ExpressionBinding::bind(_path);
 
-    PropertyQuantity * prop = freecad_dynamic_cast<PropertyQuantity>(getPath().getProperty());
+    auto * prop = freecad_dynamic_cast<PropertyQuantity>(getPath().getProperty());
 
     if (prop)
         actQuantity = Base::Quantity(prop->getValue());
@@ -113,7 +119,7 @@ void InputField::bind(const App::ObjectIdentifier &_path)
     DocumentObject * docObj = getPath().getDocumentObject();
 
     if (docObj) {
-        boost::shared_ptr<const Expression> expr(docObj->getExpression(getPath()).expression);
+        std::shared_ptr<const Expression> expr(docObj->getExpression(getPath()).expression);
 
         if (expr)
             newInput(Tools::fromStdString(expr->toString()));
@@ -157,7 +163,7 @@ QPixmap InputField::getValidationIcon(const char* name, const QSize& size) const
 void InputField::updateText(const Base::Quantity& quant)
 {
     if (isBound()) {
-        boost::shared_ptr<const Expression> e(getPath().getDocumentObject()->getExpression(getPath()).expression);
+        std::shared_ptr<const Expression> e(getPath().getDocumentObject()->getExpression(getPath()).expression);
 
         if (e) {
             setText(Tools::fromStdString(e->toString()));
@@ -189,7 +195,7 @@ void InputField::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu *editMenu = createStandardContextMenu();
     editMenu->setTitle(tr("Edit"));
-    QMenu* menu = new QMenu(QString::fromLatin1("InputFieldContextmenu"));
+    auto menu = new QMenu(QString::fromLatin1("InputFieldContextmenu"));
 
     menu->addMenu(editMenu);
     menu->addSeparator();
@@ -201,9 +207,9 @@ void InputField::contextMenuEvent(QContextMenuEvent *event)
     // add the history menu part...
     std::vector<QString> history = getHistory();
 
-    for(std::vector<QString>::const_iterator it = history.begin();it!= history.end();++it){
-        actions.push_back(menu->addAction(*it));
-        values.push_back(*it);
+    for(const auto & it : history){
+        actions.push_back(menu->addAction(it));
+        values.push_back(it);
     }
 
     // add the save value portion of the menu
@@ -211,9 +217,9 @@ void InputField::contextMenuEvent(QContextMenuEvent *event)
     QAction *SaveValueAction = menu->addAction(tr("Save value"));
     std::vector<QString> savedValues = getSavedValues();
 
-    for(std::vector<QString>::const_iterator it = savedValues.begin();it!= savedValues.end();++it){
-        actions.push_back(menu->addAction(*it));
-        values.push_back(*it);
+    for(const auto & savedValue : savedValues){
+        actions.push_back(menu->addAction(savedValue));
+        values.push_back(savedValue);
     }
 
     // call the menu and wait until its back
@@ -224,7 +230,7 @@ void InputField::contextMenuEvent(QContextMenuEvent *event)
         pushToSavedValues();
     else{
         int i=0;
-        for(std::vector<QAction *>::const_iterator it = actions.begin();it!=actions.end();++it,i++)
+        for(auto it = actions.begin();it!=actions.end();++it,i++)
             if(*it == saveAction)
                 this->setText(values[i]);
     }
@@ -240,13 +246,13 @@ void InputField::newInput(const QString & text)
         fixup(input);
 
         if (isBound()) {
-            boost::shared_ptr<Expression> e(ExpressionParser::parse(getPath().getDocumentObject(), input.toUtf8()));
+            std::shared_ptr<Expression> e(ExpressionParser::parse(getPath().getDocumentObject(), input.toUtf8()));
 
             setExpression(e);
 
             std::unique_ptr<Expression> evalRes(getExpression()->eval());
 
-            NumberExpression * value = freecad_dynamic_cast<NumberExpression>(evalRes.get());
+            auto * value = freecad_dynamic_cast<NumberExpression>(evalRes.get());
             if (value) {
                 res.setValue(value->getValue());
                 res.setUnit(value->getUnit());
@@ -259,7 +265,7 @@ void InputField::newInput(const QString & text)
         QString errorText = QString::fromLatin1(e.what());
         QPixmap pixmap = getValidationIcon(":/icons/button_invalid.svg", QSize(sizeHint().height(),sizeHint().height()));
         iconLabel->setPixmap(pixmap);
-        parseError(errorText);
+        Q_EMIT parseError(errorText);
         validInput = false;
         return;
     }
@@ -271,7 +277,7 @@ void InputField::newInput(const QString & text)
     if(!actUnit.isEmpty() && !res.getUnit().isEmpty() && actUnit != res.getUnit()){
         QPixmap pixmap = getValidationIcon(":/icons/button_invalid.svg", QSize(sizeHint().height(),sizeHint().height()));
         iconLabel->setPixmap(pixmap);
-        parseError(QString::fromLatin1("Wrong unit"));
+        Q_EMIT parseError(QString::fromLatin1("Wrong unit"));
         validInput = false;
         return;
     }
@@ -297,8 +303,8 @@ void InputField::newInput(const QString & text)
     actQuantity = res;
 
     // signaling
-    valueChanged(res);
-    valueChanged(res.getValue());
+    Q_EMIT valueChanged(res);
+    Q_EMIT valueChanged(res.getValue());
 }
 
 void InputField::pushToHistory(const QString &valueq)
@@ -311,8 +317,8 @@ void InputField::pushToHistory(const QString &valueq)
 
     // check if already in:
     std::vector<QString> hist = InputField::getHistory();
-    for(std::vector<QString>::const_iterator it = hist.begin();it!=hist.end();++it)
-        if( *it == val)
+    for(const auto & it : hist)
+        if( it == val)
             return;
 
     std::string value(val.toUtf8());
@@ -323,14 +329,14 @@ void InputField::pushToHistory(const QString &valueq)
             snprintf(hist1,20,"Hist%i",i+1);
             snprintf(hist0,20,"Hist%i",i);
             std::string tHist = _handle->GetASCII(hist0,"");
-            if(tHist != "")
+            if(!tHist.empty())
                 _handle->SetASCII(hist1,tHist.c_str());
         }
         _handle->SetASCII("Hist0",value.c_str());
     }
 }
 
-std::vector<QString> InputField::getHistory(void)
+std::vector<QString> InputField::getHistory()
 {
     std::vector<QString> res;
 
@@ -340,7 +346,7 @@ std::vector<QString> InputField::getHistory(void)
         for(int i = 0 ; i< HistorySize ;i++){
             snprintf(hist,20,"Hist%i",i);
             tmp = _handle->GetASCII(hist,"");
-            if( tmp != "")
+            if( !tmp.empty())
                 res.push_back(QString::fromUtf8(tmp.c_str()));
             else
                 break; // end of history reached
@@ -349,7 +355,7 @@ std::vector<QString> InputField::getHistory(void)
     return res;
 }
 
-void InputField::setToLastUsedValue(void)
+void InputField::setToLastUsedValue()
 {
     std::vector<QString> hist = getHistory();
     if(!hist.empty())
@@ -371,14 +377,14 @@ void InputField::pushToSavedValues(const QString &valueq)
             snprintf(hist1,20,"Save%i",i+1);
             snprintf(hist0,20,"Save%i",i);
             std::string tHist = _handle->GetASCII(hist0,"");
-            if(tHist != "")
+            if(!tHist.empty())
                 _handle->SetASCII(hist1,tHist.c_str());
         }
         _handle->SetASCII("Save0",value.c_str());
     }
 }
 
-std::vector<QString> InputField::getSavedValues(void)
+std::vector<QString> InputField::getSavedValues()
 {
     std::vector<QString> res;
 
@@ -388,7 +394,7 @@ std::vector<QString> InputField::getSavedValues(void)
         for(int i = 0 ; i< SaveSize ;i++){
             snprintf(hist,20,"Save%i",i);
             tmp = _handle->GetASCII(hist,"");
-            if( tmp != "")
+            if( !tmp.empty())
                 res.push_back(QString::fromUtf8(tmp.c_str()));
             else
                 break; // end of history reached
@@ -451,7 +457,7 @@ const Base::Unit& InputField::getUnit() const
 }
 
 /// get stored, valid quantity as a string
-QString InputField::getQuantityString(void) const
+QString InputField::getQuantityString() const
 {
     return actQuantity.getUserString();
 }
@@ -465,7 +471,7 @@ void InputField::setQuantityString(const QString& text)
 }
 
 /// return the quantity in C locale, i.e. decimal separator is a dot.
-QString InputField::rawText(void) const
+QString InputField::rawText() const
 {
     double  factor;
     QString unit;
@@ -484,7 +490,7 @@ void InputField::setRawText(const QString& text)
 }
 
 /// get the value of the singleStep property
-double InputField::singleStep(void)const
+double InputField::singleStep()const
 {
     return StepSize;
 }
@@ -496,7 +502,7 @@ void InputField::setSingleStep(double s)
 }
 
 /// get the value of the maximum property
-double InputField::maximum(void)const
+double InputField::maximum()const
 {
     return Maximum;
 }
@@ -512,7 +518,7 @@ void InputField::setMaximum(double m)
 }
 
 /// get the value of the minimum property
-double InputField::minimum(void)const
+double InputField::minimum()const
 {
     return Minimum;
 }
@@ -538,7 +544,7 @@ void InputField::setUnitText(const QString& str)
     }
 }
 
-QString InputField::getUnitText(void)
+QString InputField::getUnitText()
 {
     double dFactor;
     QString unitStr;
@@ -576,7 +582,7 @@ void InputField::setFormat(const QString& format)
 }
 
 // get the value of the minimum property
-int InputField::historySize(void)const
+int InputField::historySize()const
 {
     return HistorySize;
 }
@@ -590,32 +596,18 @@ void InputField::setHistorySize(int i)
     HistorySize = i;
 }
 
-void InputField::selectNumber(void)
+void InputField::selectNumber()
 {
-    QString str = text();
-    unsigned int i = 0;
-
-    QChar d = locale().decimalPoint();
-    QChar g = locale().groupSeparator();
-    QChar n = locale().negativeSign();
-    QChar e = locale().exponential();
-
-    for (QString::iterator it = str.begin(); it != str.end(); ++it) {
-        if (it->isDigit())
-            i++;
-        else if (*it == d)
-            i++;
-        else if (*it == g)
-            i++;
-        else if (*it == n)
-            i++;
-        else if (*it == e && actQuantity.getFormat().format != Base::QuantityFormat::Fixed)
-            i++;
-        else // any non-number character
-            break;
+    QString expr = QString::fromLatin1("^([%1%2]?[0-9\\%3]*)\\%4?([0-9]+(%5[%1%2]?[0-9]+)?)")
+                   .arg(locale().negativeSign())
+                   .arg(locale().positiveSign())
+                   .arg(locale().groupSeparator())
+                   .arg(locale().decimalPoint())
+                   .arg(locale().exponential());
+    auto rmatch = QRegularExpression(expr).match(text());
+    if (rmatch.hasMatch()) {
+        setSelection(0, rmatch.capturedLength());
     }
-
-    setSelection(0, i);
 }
 
 void InputField::showEvent(QShowEvent * event)
@@ -642,6 +634,19 @@ void InputField::focusInEvent(QFocusEvent *event)
 
 void InputField::focusOutEvent(QFocusEvent *event)
 {
+    try {
+        if (Quantity::parse(this->text()).getUnit().isEmpty()) {
+            // if user didn't enter a unit, we virtually compensate
+            // the multiplication factor induced by user unit system
+            double factor;
+            QString unitStr;
+            actQuantity.getUserString(factor, unitStr);
+            actQuantity = actQuantity * factor;
+        }
+    }
+    catch (const Base::ParserError&) {
+        // do nothing, let apply the last known good value
+    }
     this->setText(actQuantity.getUserString());
     QLineEdit::focusOutEvent(event);
 }
@@ -686,17 +691,16 @@ void InputField::keyPressEvent(QKeyEvent *event)
 
 void InputField::wheelEvent (QWheelEvent * event)
 {
+    if (!hasFocus())
+        return;
+
     if (isReadOnly()) {
         QLineEdit::wheelEvent(event);
         return;
     }
 
     double factor = event->modifiers() & Qt::ControlModifier ? 10 : 1;
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
     double step = event->angleDelta().y() > 0 ? StepSize : -StepSize;
-#else
-    double step = event->delta() > 0 ? StepSize : -StepSize;
-#endif
     double val = actUnitValue + factor * step;
     if (val > Maximum)
         val = Maximum;
@@ -715,10 +719,18 @@ void InputField::wheelEvent (QWheelEvent * event)
 void InputField::fixup(QString& input) const
 {
     input.remove(locale().groupSeparator());
-    if (locale().negativeSign() != QLatin1Char('-'))
-        input.replace(locale().negativeSign(), QLatin1Char('-'));
-    if (locale().positiveSign() != QLatin1Char('+'))
-        input.replace(locale().positiveSign(), QLatin1Char('+'));
+
+    QString asciiMinus(QStringLiteral("-"));
+    QString localeMinus(locale().negativeSign());
+    if (localeMinus != asciiMinus) {
+        input.replace(localeMinus, asciiMinus);
+    }
+
+    QString asciiPlus(QStringLiteral("+"));
+    QString localePlus(locale().positiveSign());
+    if (localePlus != asciiPlus) {
+        input.replace(localePlus, asciiPlus);
+    }
 }
 
 QValidator::State InputField::validate(QString& input, int& pos) const
