@@ -71,11 +71,11 @@ LocationWidget::LocationWidget (QWidget * parent)
     yValue->setUnit(Base::Unit::Length);
     zValue->setUnit(Base::Unit::Length);
 
-    QGridLayout* gridLayout = new QGridLayout(this);
+    auto gridLayout = new QGridLayout(this);
     gridLayout->addLayout(box, 0, 0, 1, 2);
 
-    connect(dValue, SIGNAL(activated(int)),
-            this, SLOT(on_direction_activated(int)));
+    connect(dValue, qOverload<int>(&QComboBox::activated),
+            this, &LocationWidget::onDirectionActivated);
     retranslateUi();
 }
 
@@ -151,7 +151,7 @@ void LocationWidget::setDirection(const Base::Vector3d& dir)
     for (int i=0; i<dValue->count()-1; i++) {
         QVariant data = dValue->itemData (i);
         if (data.canConvert<Base::Vector3d>()) {
-            const Base::Vector3d val = data.value<Base::Vector3d>();
+            const auto val = data.value<Base::Vector3d>();
             if (val == dir) {
                 dValue->setCurrentIndex(i);
                 return;
@@ -202,7 +202,7 @@ Base::Vector3d LocationWidget::getUserDirection(bool* ok) const
     return dir;
 }
 
-void LocationWidget::on_direction_activated(int index)
+void LocationWidget::onDirectionActivated(int index)
 {
     // last item is selected to define direction by user
     if (index+1 == dValue->count()) {
@@ -253,7 +253,7 @@ Base::Vector3d LocationDialog::getUserDirection(bool* ok) const
     return dir;
 }
 
-void LocationDialog::on_direction_activated(int index)
+void LocationDialog::onDirectionActivated(int index)
 {
     directionActivated(index);
 }
