@@ -25,9 +25,9 @@
 
 // Open Inventor
 #ifdef FC_OS_MACOSX
-#include <OpenGL/gl.h>
+# include <OpenGL/gl.h>
 #else
-#include <GL/gl.h>
+# include <GL/gl.h>
 #endif
 
 #include <Inventor/C/basic.h>
@@ -36,11 +36,13 @@
 #include <Inventor/SbBox2f.h>
 #include <Inventor/SbClip.h>
 #include <Inventor/SbColor.h>
+#include <Inventor/SbImage.h>
 #include <Inventor/SbLine.h>
 #include <Inventor/SbLinear.h>
 #include <Inventor/SbRotation.h>
 #include <Inventor/SbSphere.h>
 #include <Inventor/SbTesselator.h>
+#include <Inventor/SbTime.h>
 #include <Inventor/SbVec2s.h>
 #include <Inventor/SbViewportRegion.h>
 #include <Inventor/SoDB.h>
@@ -52,6 +54,7 @@
 #include <Inventor/SoPickedPoint.h>
 #include <Inventor/SoPrimitiveVertex.h>
 #include <Inventor/SoRenderManager.h>
+
 #include <Inventor/actions/SoAction.h>
 #include <Inventor/actions/SoBoxHighlightRenderAction.h>
 #include <Inventor/actions/SoCallbackAction.h>
@@ -66,30 +69,39 @@
 #include <Inventor/actions/SoSearchAction.h>
 #include <Inventor/actions/SoToVRML2Action.h>
 #include <Inventor/actions/SoWriteAction.h>
+
+#include <Inventor/annex/ForeignFiles/SoSTLFileKit.h>
 #include <Inventor/annex/HardCopy/SoVectorizeAction.h>
 #include <Inventor/annex/HardCopy/SoVectorizePSAction.h>
 #include <Inventor/annex/HardCopy/SoVectorOutput.h>
+
 #include <Inventor/bundles/SoMaterialBundle.h>
 #include <Inventor/bundles/SoTextureCoordinateBundle.h>
+
 #include <Inventor/caches/SoNormalCache.h>
+
 #include <Inventor/details/SoDetail.h>
 #include <Inventor/details/SoFaceDetail.h>
 #include <Inventor/details/SoLineDetail.h>
 #include <Inventor/details/SoPointDetail.h>
+
 #include <Inventor/draggers/SoCenterballDragger.h>
 #include <Inventor/draggers/SoDragger.h>
 #include <Inventor/draggers/SoTrackballDragger.h>
 #include <Inventor/draggers/SoTransformerDragger.h>
+
 #include <Inventor/elements/SoCacheElement.h>
 #include <Inventor/elements/SoComplexityElement.h>
 #include <Inventor/elements/SoComplexityTypeElement.h>
 #include <Inventor/elements/SoCoordinateElement.h>
 #include <Inventor/elements/SoCreaseAngleElement.h>
 #include <Inventor/elements/SoDrawStyleElement.h>
+#include <Inventor/elements/SoFocalDistanceElement.h>
 #include <Inventor/elements/SoFontNameElement.h>
 #include <Inventor/elements/SoFontSizeElement.h>
 #include <Inventor/elements/SoGLCacheContextElement.h>
 #include <Inventor/elements/SoGLCoordinateElement.h>
+#include <Inventor/elements/SoGLLazyElement.h>
 #include <Inventor/elements/SoLazyElement.h>
 #include <Inventor/elements/SoLightModelElement.h>
 #include <Inventor/elements/SoLineWidthElement.h>
@@ -98,6 +110,7 @@
 #include <Inventor/elements/SoNormalBindingElement.h>
 #include <Inventor/elements/SoNormalElement.h>
 #include <Inventor/elements/SoOverrideElement.h>
+#include <Inventor/elements/SoPointSizeElement.h>
 #include <Inventor/elements/SoProfileCoordinateElement.h>
 #include <Inventor/elements/SoProfileElement.h>
 #include <Inventor/elements/SoProjectionMatrixElement.h>
@@ -110,18 +123,24 @@
 #include <Inventor/elements/SoViewportRegionElement.h>
 #include <Inventor/elements/SoViewVolumeElement.h>
 #include <Inventor/elements/SoWindowElement.h>
+
+#include <Inventor/engines/SoCalculator.h>
 #include <Inventor/engines/SoComposeVec3f.h>
 #include <Inventor/engines/SoComposeRotationFromTo.h>
 #include <Inventor/engines/SoComposeRotation.h>
+#include <Inventor/engines/SoConcatenate.h>
+
 #include <Inventor/errors/SoDebugError.h>
 #include <Inventor/errors/SoError.h>
 #include <Inventor/errors/SoReadError.h>
+
 #include <Inventor/events/SoEvent.h>
 #include <Inventor/events/SoKeyboardEvent.h>
 #include <Inventor/events/SoLocation2Event.h>
 #include <Inventor/events/SoMotion3Event.h>
 #include <Inventor/events/SoMouseButtonEvent.h>
 #include <Inventor/events/SoSpaceballButtonEvent.h>
+
 #include <Inventor/fields/SoMFColor.h>
 #include <Inventor/fields/SoMFNode.h>
 #include <Inventor/fields/SoSFBool.h>
@@ -132,11 +151,16 @@
 #include <Inventor/fields/SoSFNode.h>
 #include <Inventor/fields/SoSFRotation.h>
 #include <Inventor/fields/SoSFVec3f.h>
+
 #include <Inventor/manips/SoCenterballManip.h>
 #include <Inventor/manips/SoClipPlaneManip.h>
+#include <Inventor/manips/SoTransformBoxManip.h>
 #include <Inventor/manips/SoTransformerManip.h>
+
 #include <Inventor/misc/SoChildList.h>
+#include <Inventor/misc/SoContextHandler.h>
 #include <Inventor/misc/SoState.h>
+
 #include <Inventor/nodes/SoAnnotation.h>
 #include <Inventor/nodes/SoAntiSquish.h>
 #include <Inventor/nodes/SoAsciiText.h>
@@ -149,6 +173,7 @@
 #include <Inventor/nodes/SoCoordinate4.h>
 #include <Inventor/nodes/SoCube.h>
 #include <Inventor/nodes/SoCylinder.h>
+#include <Inventor/nodes/SoDepthBuffer.h>
 #include <Inventor/nodes/SoDirectionalLight.h>
 #include <Inventor/nodes/SoDrawStyle.h>
 #include <Inventor/nodes/SoEnvironment.h>
@@ -162,6 +187,7 @@
 #include <Inventor/nodes/SoIndexedLineSet.h>
 #include <Inventor/nodes/SoIndexedPointSet.h>
 #include <Inventor/nodes/SoIndexedTriangleStripSet.h>
+#include <Inventor/nodes/SoInfo.h>
 #include <Inventor/nodes/SoLightModel.h>
 #include <Inventor/nodes/SoLineSet.h>
 #include <Inventor/nodes/SoLocateHighlight.h>
@@ -173,6 +199,7 @@
 #include <Inventor/nodes/SoNode.h>
 #include <Inventor/nodes/SoNormal.h>
 #include <Inventor/nodes/SoNormalBinding.h>
+#include <Inventor/nodes/SoNurbsCurve.h>
 #include <Inventor/nodes/SoNurbsSurface.h>
 #include <Inventor/nodes/SoOrthographicCamera.h>
 #include <Inventor/nodes/SoPerspectiveCamera.h>
@@ -183,6 +210,7 @@
 #include <Inventor/nodes/SoProfileCoordinate2.h>
 #include <Inventor/nodes/SoProfileCoordinate3.h>
 #include <Inventor/nodes/SoQuadMesh.h>
+#include <Inventor/nodes/SoResetTransform.h>
 #include <Inventor/nodes/SoRotation.h>
 #include <Inventor/nodes/SoRotationXYZ.h>
 #include <Inventor/nodes/SoSelection.h>
@@ -196,23 +224,31 @@
 #include <Inventor/nodes/SoText2.h>
 #include <Inventor/nodes/SoTexture2.h>
 #include <Inventor/nodes/SoTexture3.h>
+#include <Inventor/nodes/SoTextureCoordinate2.h>
 #include <Inventor/nodes/SoTextureCoordinate3.h>
 #include <Inventor/nodes/SoTransform.h>
 #include <Inventor/nodes/SoTransformation.h>
 #include <Inventor/nodes/SoTranslation.h>
 #include <Inventor/nodes/SoTransparencyType.h>
+#include <Inventor/nodes/SoVertexProperty.h>
+
 #include <Inventor/nodekits/SoShapeKit.h>
-#include <Inventor/manips/SoTransformBoxManip.h>
+
 #include <Inventor/projectors/SbLineProjector.h>
 #include <Inventor/projectors/SbPlaneProjector.h>
 #include <Inventor/projectors/SbSpherePlaneProjector.h>
 #include <Inventor/projectors/SbSphereSheetProjector.h>
+
 #include <Inventor/sensors/SoFieldSensor.h>
 #include <Inventor/sensors/SoIdleSensor.h>
 #include <Inventor/sensors/SoNodeSensor.h>
+#include <Inventor/sensors/SoSensor.h>
 #include <Inventor/sensors/SoTimerSensor.h>
+
 #include <Inventor/system/inttypes.h>
+
 #include <Inventor/threads/SbStorage.h>
+
 #include <Inventor/VRMLnodes/SoVRMLGroup.h>
 #include <Inventor/VRMLnodes/SoVRMLIndexedFaceSet.h>
 #include <Inventor/VRMLnodes/SoVRMLNormal.h>
