@@ -26,15 +26,17 @@
 #include <QObject>
 #include <list>
 #include <map>
+#include <memory>
 #include <string>
+#include <FCGlobal.h>
 
 
 class QDir;
 
 namespace Gui {
 
-typedef std::list<std::string> TStringList;
-typedef std::map<std::string, std::string> TStringMap;
+using TStringList = std::list<std::string>;
+using TStringMap = std::map<std::string, std::string>;
 
 /**
  * The Translator class uses Qt's QTranslator objects to change the language of the application
@@ -74,6 +76,12 @@ public:
     TStringMap supportedLocales() const;
     /** Adds a path where localization files can be found */
     void addPath(const QString& path);
+    /** eventFilter used to convert decimal separator **/
+    bool eventFilter(QObject* obj, QEvent* ev);
+    /** Enables/disables decimal separator conversion **/
+    void enableDecimalPointConversion(bool on);
+    /** Returns whether decimal separator conversion is enabled */
+    bool isEnabledDecimalPointConversion() const;
 
 private:
     Translator();
@@ -86,6 +94,7 @@ private:
 private:
     static Translator* _pcSingleton;
     TranslatorP* d;
+    std::unique_ptr<Translator, std::function<void(Translator*)>> decimalPointConverter;
 };
 
 } // namespace Gui
