@@ -55,10 +55,10 @@ class GuiExport UrlHandler : public QObject
     Q_OBJECT
 
 public:
-    UrlHandler(QObject* parent = nullptr)
+    explicit UrlHandler(QObject* parent = nullptr)
         : QObject(parent){
     }
-    virtual ~UrlHandler() {
+    ~UrlHandler() override {
     }
     virtual void openUrl(App::Document*, const QUrl&) {
     }
@@ -85,13 +85,13 @@ public:
      * Constructs an empty main window. For default \a parent is 0, as there usually is
      * no toplevel window there.
      */
-    MainWindow(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Window);
+    explicit MainWindow(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Window);
     /** Destroys the object and frees any allocated resources. */
-    ~MainWindow();
+    ~MainWindow() override;
     /**
      * Filters events if this object has been installed as an event filter for the watched object.
      */
-    bool eventFilter(QObject* o, QEvent* e);
+    bool eventFilter(QObject* o, QEvent* e) override;
     /**
      * Adds an MDI window \a view to the main window's workspace and adds a new tab
      * to the tab bar.
@@ -129,7 +129,7 @@ public:
     /**
      * Returns true that the context menu contains the 'Customize...' menu item.
      */
-    QMenu * createPopupMenu();
+    QMenu * createPopupMenu() override;
 
     /** @name Splasher and access methods */
     //@{
@@ -156,6 +156,17 @@ public:
     void saveWindowSettings();
     //@}
 
+    /** @name Menu
+     */
+    //@{
+    /// Set menu for dock windows.
+    void setDockWindowMenu(QMenu*);
+    /// Set menu for toolbars.
+    void setToolBarMenu(QMenu*);
+    /// Set menu for sub-windows
+    void setWindowsMenu(QMenu*);
+    //@}
+
     /** @name MIME data handling
      */
     //@{
@@ -190,10 +201,9 @@ public:
 
     void updateActions(bool delay = false);
 
-    enum StatusType {None, Err, Wrn, Pane, Msg, Log, Tmp};
+    enum StatusType {None, Err, Wrn, Pane, Msg, Log, Tmp, Critical};
     void showStatus(int type, const QString & message);
 
-
 public Q_SLOTS:
     /**
      * Updates the standard actions of a text editor such as Cut, Copy, Paste, Undo and Redo.
@@ -203,10 +213,6 @@ public Q_SLOTS:
      * Sets text to the pane in the status bar.
      */
     void setPaneText(int i, QString text);
-    /**
-     * Arranges all child windows in a horizontal tile pattern.
-     */
-    void arrangeIcons();
     /**
      * Arranges all child windows in a tile pattern.
      */
@@ -253,26 +259,38 @@ protected:
     /**
      * This method checks if the main window can be closed by checking all open documents and views.
      */
-    void closeEvent (QCloseEvent * e);
-    void showEvent  (QShowEvent  * e);
-    void hideEvent  (QHideEvent  * e);
-    void timerEvent (QTimerEvent *  ){ timeEvent();}
-    void customEvent(QEvent      * e);
-    bool event      (QEvent      * e);
+    void closeEvent (QCloseEvent * e) override;
+    void showEvent  (QShowEvent  * e) override;
+    void hideEvent  (QHideEvent  * e) override;
+    void timerEvent (QTimerEvent *  ) override {
+        Q_EMIT timeEvent();
+    }
+    void customEvent(QEvent      * e) override;
+    bool event      (QEvent      * e) override;
     /**
      * Try to interpret dropped elements.
      */
-    void dropEvent  (QDropEvent  * e);
+    void dropEvent  (QDropEvent  * e) override;
     /**
      * Checks if a mime source object can be interpreted.
      */
-    void dragEnterEvent(QDragEnterEvent * e);
+    void dragEnterEvent(QDragEnterEvent * e) override;
     /**
      * This method is called from the Qt framework automatically whenever a
      * QTranslator object has been installed. This allows to translate all
      * relevant user visible text.
      */
-    void changeEvent(QEvent *e);
+    void changeEvent(QEvent *e) override;
+
+private:
+    void setupDockWindows();
+    bool setupTreeView(const std::string&);
+    bool setupPropertyView(const std::string&);
+    bool setupSelectionView(const std::string&);
+    bool setupComboView(const std::string&, bool enable);
+    bool setupDAGView(const std::string&);
+    bool setupReportView(const std::string&);
+    bool setupPythonConsole(const std::string&);
 
 private Q_SLOTS:
     /**
@@ -318,7 +336,7 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void timeEvent();
-    void windowStateChanged(MDIView*);
+    void windowStateChanged(Gui::MDIView*);
     void workbenchActivated(const QString&);
     void mainWindowClosed();
 
@@ -347,19 +365,20 @@ class StatusBarObserver: public WindowParameter, public Base::ILogger
 {
 public:
     StatusBarObserver();
-    virtual ~StatusBarObserver();
+    ~StatusBarObserver() override;
 
     /** Observes its parameter group. */
     void OnChange(Base::Subject<const char*> &rCaller, const char * sReason) override;
 
-    void SendLog(const std::string& msg, Base::LogStyle level) override;
+    void SendLog(const std::string& notifiername, const std::string& msg, Base::LogStyle level,
+                 Base::IntendedRecipient recipient, Base::ContentType content) override;
 
     /// name of the observer
     const char *Name() override {return "StatusBar";}
 
     friend class MainWindow;
 private:
-    QString msg, wrn, err;
+    QString msg, wrn, err, critical;
 };
 
 // -------------------------------------------------------------
@@ -373,7 +392,7 @@ public:
     static int EventType;
     enum Style {Restore, Clear};
 
-    ActionStyleEvent(Style type);
+    explicit ActionStyleEvent(Style type);
     Style getType() const;
 
 private:
