@@ -28,6 +28,8 @@
 # include <QFocusEvent>
 # include <QFontMetrics>
 # include <QLineEdit>
+# include <QRegularExpression>
+# include <QRegularExpressionMatch>
 # include <QStyle>
 # include <QStyleOptionSpinBox>
 # include <QToolTip>
@@ -39,7 +41,6 @@
 #include <App/Document.h>
 #include <App/DocumentObject.h>
 #include <App/ExpressionParser.h>
-#include <App/PropertyGeo.h>
 #include <Base/Exception.h>
 #include <Base/UnitsApi.h>
 #include <Base/Tools.h>
@@ -63,6 +64,7 @@ public:
     QuantitySpinBoxPrivate(QuantitySpinBox *q) :
       validInput(true),
       pendingEmit(false),
+      checkRangeInExpression(false),
       unitValue(0),
       maximum(DOUBLE_MAX),
       minimum(-DOUBLE_MAX),
@@ -84,7 +86,7 @@ public:
         return text;
     }
 
-    bool validate(QString& input, Base::Quantity& result) const
+    bool validate(QString& input, Base::Quantity& result, const App::ObjectIdentifier& path) const
     {
         Q_Q(const QuantitySpinBox);
 
@@ -97,9 +99,8 @@ public:
         QString tmp = input;
 
         auto validateInput = [&](QString& tmp) -> QValidator::State {
-            int pos = 0;
             QValidator::State state;
-            Base::Quantity res = validateAndInterpret(tmp, pos, state);
+            Base::Quantity res = validateAndInterpret(tmp, state, path);
             res.setFormat(quantity.getFormat());
             if (state == QValidator::Acceptable) {
                 success = true;
@@ -110,189 +111,151 @@ public:
         };
 
         QValidator::State state = validateInput(tmp);
-        if (state == QValidator::Intermediate) {
-            if (!q->hasExpression()) {
-                tmp = tmp.trimmed();
-                tmp += QLatin1Char(' ');
-                tmp += unitStr;
-                validateInput(tmp);
-            }
-            else {
-                // Accept the expression as it is but try to add the right unit string
-                success = true;
+        if (state == QValidator::Intermediate && q->hasExpression()) {
+            // Accept the expression as it is but try to add the right unit string
+            success = true;
 
-                Base::Quantity quantity;
-                double value;
-                if (parseString(input, quantity, value)) {
-                    quantity.setUnit(unit);
-                    result = quantity;
+            Base::Quantity quantity;
+            double value;
+            if (parseString(input, quantity, value, path)) {
+                quantity.setUnit(unit);
+                result = quantity;
 
-                    // Now translate the quantity into its string representation using the user-defined unit system
-                    input = Base::UnitsApi::schemaTranslate(result);
-                }
+                // Now translate the quantity into its string representation using the user-defined unit system
+                input = Base::UnitsApi::schemaTranslate(result);
             }
         }
 
         return success;
     }
-    bool parseString(const QString& str, Base::Quantity& result, double& value) const
+    bool parseString(const QString& str, Base::Quantity& result, double& value, const App::ObjectIdentifier& path) const
     {
+        App::ObjectIdentifier pathtmp = path;
         try {
             QString copy = str;
             copy.remove(locale.groupSeparator());
 
-            result = Base::Quantity::parse(copy);
-            value = result.getValue();
-            return true;
+            //Expression parser
+            std::shared_ptr<Expression> expr(ExpressionParser::parse(path.getDocumentObject(), copy.toUtf8().constData()));
+            if (expr) {
+
+                std::unique_ptr<Expression> res(expr->eval());
+                NumberExpression * n = Base::freecad_dynamic_cast<NumberExpression>(res.get());
+                if (n){
+                    result = n->getQuantity();
+                    value = result.getValue();
+                    return true;
+                }
+            }
         }
-        catch (Base::ParserError&) {
+        catch (Base::Exception&) {
             return false;
         }
+        return false;
     }
-    Base::Quantity validateAndInterpret(QString& input, int& pos, QValidator::State& state) const
+    Base::Quantity validateAndInterpret(QString& input, QValidator::State& state, const App::ObjectIdentifier& path) const
     {
         Base::Quantity res;
         const double max = this->maximum;
         const double min = this->minimum;
 
         QString copy = input;
+        double value = min;
+        bool ok = false;
 
-        int len = copy.size();
+        QChar plus = QLatin1Char('+'), minus = QLatin1Char('-');
 
-        const bool plus = max >= 0;
-        const bool minus = min <= 0;
+        if (locale.negativeSign() != minus)
+            copy.replace(locale.negativeSign(), minus);
+        if (locale.positiveSign() != plus)
+            copy.replace(locale.positiveSign(), plus);
 
-        switch (len) {
-        case 0:
-            state = max != min ? QValidator::Intermediate : QValidator::Invalid;
-            goto end;
-        case 1:
-            if (copy.at(0) == locale.decimalPoint()) {
-                state = QValidator::Intermediate;
-                copy.prepend(QLatin1Char('0'));
-                pos++;
-                len++;
-                goto end;
+        QString reverseUnitStr = unitStr;
+        std::reverse(reverseUnitStr.begin(), reverseUnitStr.end());
+
+        //Prep for expression parser
+        //This regex matches chunks between +,-,$,^ accounting for matching parenthesis.
+        QRegularExpression chunkRe(QString::fromUtf8("(?<=^|[\\+\\-])((\\((?>[^()]|(?2))*\\))|[^\\+\\-\n])*(?=$|[\\+\\-])"));
+        QRegularExpressionMatchIterator expressionChunk = chunkRe.globalMatch(copy);
+        unsigned int lengthOffset = 0;
+        while (expressionChunk.hasNext()) {
+            QRegularExpressionMatch matchChunk = expressionChunk.next();
+            QString origionalChunk = matchChunk.captured(0);
+            QString copyChunk = origionalChunk;
+            std::reverse(copyChunk.begin(), copyChunk.end());
+
+            //Reused regex patterns
+            static const std::string regexUnits = "sAV|VC|lim|nim|im|hpm|[mf]?bl|°|ged|dar|nog|″|′|rroT[uµm]?|K[uµm]?|A[mkM]?|F[pnuµm]?|C|S[uµmkM]?|zH[kMGT]?|H[nuµm]?|mhO[kM]?|J[mk]?|Ve[kM]?|V[mk]?|hWk|sW|lack?|N[mkM]?|g[uµmk]?|lm?|(?<=\\b|[^a-zA-Z])m[nuµmcdk]?|uoht|ni|\"|'|dy|dc|bW|T|t|zo|ts|twc|Wk?|aP[kMG]?|is[pk]|h|G|M|tfc|tfqs|tf|s";
+            static const std::string regexUnitlessFunctions = "soca|nisa|2nata|nata|hsoc|hnis|hnat|soc|nat|nis|pxe|gol|01gol";
+            static const std::string regexConstants = "e|ip|lomm|lom";
+            static const std::string regexNumber = "\\d+\\s*\\.?\\s*\\d*|\\.\\s*\\d+";
+
+            // If expression does not contain /*() or ^, this regex will not find anything
+            if (copy.contains(QLatin1Char('/')) || copy.contains(QLatin1Char('*')) || copy.contains(QLatin1Char('(')) || copy.contains(QLatin1Char(')')) || copy.contains(QLatin1Char('^'))){
+                //Find units and replace 1/2mm -> 1/2*(1mm), 1^2mm -> 1^2*(1mm)
+                QRegularExpression fixUnits(QString::fromStdString("("+regexUnits+")(\\s*\\)|(?:\\*|(?:\\)(?:(?:\\s*(?:"+regexConstants+"|\\)(?:[^()]|(?R))*\\((?:"+regexUnitlessFunctions+")|"+regexNumber+"))|(?R))*\\(|(?:\\s*(?:"+regexConstants+"|\\)(?:[^()]|(?R))*\\((?:"+regexUnitlessFunctions+")|"+regexNumber+"))))+(?:[\\/\\^]|(.*$))(?!("+regexUnits+")))"));
+                QRegularExpressionMatch fixUnitsMatch = fixUnits.match(copyChunk);
+
+                //3rd capture group being filled indicates regex bailed out; no match.
+                if (fixUnitsMatch.lastCapturedIndex() == 2 || (fixUnitsMatch.lastCapturedIndex() == 3 && fixUnitsMatch.captured(3).isEmpty())){
+                    QString matchUnits = fixUnitsMatch.captured(1);
+                    QString matchNumbers = fixUnitsMatch.captured(2);
+                    copyChunk.replace(matchUnits+matchNumbers, QString::fromUtf8(")")+matchUnits+QString::fromUtf8("1(*")+matchNumbers);
+                }
             }
-            else if (copy.at(0) == QLatin1Char('+')) {
-                // the quantity parser doesn't allow numbers of the form '+1.0'
-                state = QValidator::Invalid;
-                goto end;
+
+            //Add default units to string if none are present
+            if (!copyChunk.contains(reverseUnitStr)){ // Fast check
+                QRegularExpression unitsRe(QString::fromStdString("(?<=\\b|[^a-zA-Z])("+regexUnits+")(?=\\b|[^a-zA-Z])|°|″|′|\"|'|\\p{L}\\.\\p{L}|\\[\\p{L}"));
+
+                QRegularExpressionMatch match = unitsRe.match(copyChunk);
+                if (!match.hasMatch() && !copyChunk.isEmpty()) //If no units are found, use default units
+                    copyChunk.prepend(QString::fromUtf8(")")+reverseUnitStr+QString::fromUtf8("1(*")); // Add units to the end of chunk *(1unit)
             }
-            else if (copy.at(0) == QLatin1Char('-')) {
-                if (minus)
-                    state = QValidator::Intermediate;
-                else
-                    state = QValidator::Invalid;
-                goto end;
-            }
-            break;
-        case 2:
-            if (copy.at(1) == locale.decimalPoint()
-                && (plus && copy.at(0) == QLatin1Char('+'))) {
-                state = QValidator::Intermediate;
-                goto end;
-            }
-            if (copy.at(1) == locale.decimalPoint()
-                && (minus && copy.at(0) == QLatin1Char('-'))) {
-                state = QValidator::Intermediate;
-                copy.insert(1, QLatin1Char('0'));
-                pos++;
-                len++;
-                goto end;
-            }
-            break;
-        default: break;
+
+            std::reverse(copyChunk.begin(), copyChunk.end());
+
+            copy.replace(matchChunk.capturedStart() + lengthOffset,
+                    matchChunk.capturedEnd() - matchChunk.capturedStart(), copyChunk);
+            lengthOffset += copyChunk.length() - origionalChunk.length();
         }
 
-        {
-            if (copy.at(0) == locale.groupSeparator()) {
-                state = QValidator::Invalid;
-                goto end;
-            }
-            else if (len > 1) {
-                bool decOccurred = false;
-                for (int i = 0; i<copy.size(); i++) {
-                    if (copy.at(i) == locale.decimalPoint()) {
-                        // Disallow multiple decimal points within the same numeric substring
-                        if (decOccurred) {
-                            state = QValidator::Invalid;
-                            goto end;
-                        }
-                        decOccurred = true;
-                    }
-                    // Reset decOcurred if non-numeric character found
-                    else if (!(copy.at(i) == locale.groupSeparator() || copy.at(i).isDigit())) {
-                        decOccurred = false;
-                    }
-                }
-            }
+        ok = parseString(copy, res, value, path);
 
-            if (locale.negativeSign() != QLatin1Char('-'))
-                copy.replace(locale.negativeSign(), QLatin1Char('-'));
-            if (locale.positiveSign() != QLatin1Char('+'))
-                copy.replace(locale.positiveSign(), QLatin1Char('+'));
+        // If result does not have unit: add default unit
+        if (res.getUnit().isEmpty()){
+            res.setUnit(unit);
+        }
 
-            double value = min;
-            bool ok = parseString(copy, res, value);
-
-            if (!ok) {
-                // input may not be finished
-                state = QValidator::Intermediate;
-            }
-            else if (value >= min && value <= max) {
-                if (copy.endsWith(locale.decimalPoint())) {
-                    // input shouldn't end with a decimal point
-                    state = QValidator::Intermediate;
-                }
-                else if (res.getUnit().isEmpty() && !this->unit.isEmpty()) {
-                    // if not dimensionless the input should have a dimension
-                    state = QValidator::Intermediate;
-                }
-                else if (res.getUnit() != this->unit) {
-                    // If the user input is of the form "number * unit", "number + unit"
-                    // or "number - unit" it's rejected by the quantity parser and it's
-                    // assumed that the user input is not complete yet (Intermediate).
-                    // However, if the user input is of the form "number / unit" it's accepted
-                    // by the parser but because the units mismatch it's considered as invalid
-                    // and the last valid input will be restored.
-                    // See #0004422: PartDesign value input does not accept trailing slash
-                    // To work around this issue of the quantity parser it's checked if the
-                    // inversed unit matches and if yes the input is also considered as not
-                    // complete.
-                    if (res.getUnit().pow(-1) == this->unit)
-                        state = QValidator::Intermediate;
-                    else
-                        state = QValidator::Invalid;
-                }
-                else {
-                    state = QValidator::Acceptable;
-                }
-            }
-            else if (max == min) { // when max and min is the same the only non-Invalid input is max (or min)
+        if (!ok) {
+            // input may not be finished
+            state = QValidator::Intermediate;
+        }
+        else if (value >= min && value <= max) {
+                state = QValidator::Acceptable;
+        }
+        else if (max == min) { // when max and min is the same the only non-Invalid input is max (or min)
+            state = QValidator::Invalid;
+        }
+        else {
+            if ((value >= 0 && value > max) || (value < 0 && value < min)) {
                 state = QValidator::Invalid;
             }
             else {
-                if ((value >= 0 && value > max) || (value < 0 && value < min)) {
-                    state = QValidator::Invalid;
-                }
-                else {
-                    state = QValidator::Intermediate;
-                }
+                state = QValidator::Intermediate;
             }
         }
-end:
         if (state != QValidator::Acceptable) {
             res.setValue(max > 0 ? min : max);
         }
 
-        input = copy;
         return res;
     }
 
     QLocale locale;
     bool validInput;
     bool pendingEmit;
+    bool checkRangeInExpression;
     QString validStr;
     Base::Quantity quantity;
     Base::Quantity cached;
@@ -315,16 +278,18 @@ QuantitySpinBox::QuantitySpinBox(QWidget *parent)
 {
     d_ptr->locale = locale();
     this->setContextMenuPolicy(Qt::DefaultContextMenu);
-    QObject::connect(lineEdit(), SIGNAL(textChanged(QString)),
-                     this, SLOT(userInput(QString)));
-    QObject::connect(this, SIGNAL(editingFinished()),
-                     this, SLOT(handlePendingEmit()));
+    connect(lineEdit(), &QLineEdit::textChanged,
+            this, &QuantitySpinBox::userInput);
+    connect(this, &QuantitySpinBox::editingFinished,
+            this, [&]{
+        this->handlePendingEmit(true);
+    });
 
     // When a style sheet is set the text margins for top/bottom must be set to avoid to squash the widget
 #ifndef Q_OS_MAC
     lineEdit()->setTextMargins(0, 2, 0, 2);
 #else
-    // https://forum.freecadweb.org/viewtopic.php?f=8&t=50615
+    // https://forum.freecad.org/viewtopic.php?f=8&t=50615
     lineEdit()->setTextMargins(0, 2, 0, 0);
 #endif
 }
@@ -335,8 +300,11 @@ QuantitySpinBox::~QuantitySpinBox()
 
 void QuantitySpinBox::bind(const App::ObjectIdentifier &_path)
 {
-    ExpressionBinding::bind(_path);
+    ExpressionSpinBox::bind(_path);
+}
 
+void QuantitySpinBox::showIcon()
+{
     iconLabel->show();
 }
 
@@ -387,8 +355,8 @@ void QuantitySpinBox::setBoundToByName(const QString &name)
         path.setDocumentName(std::string(doc->getName()), true);
         path.setDocumentObjectName(std::string(obj->getNameInDocument()), true);
 
-        for (QStringList::iterator it = list.begin(); it != list.end(); ++it) {
-            path << App::ObjectIdentifier::Component::SimpleComponent(it->toLatin1().constData());
+        for (const auto & it : list) {
+            path << App::ObjectIdentifier::Component::SimpleComponent(it.toLatin1().constData());
         }
 
         if (path.getProperty())
@@ -421,7 +389,7 @@ void QuantitySpinBox::evaluateExpression()
 
 void Gui::QuantitySpinBox::setNumberExpression(App::NumberExpression* expr)
 {
-    lineEdit()->setText(getUserString(expr->getQuantity()));
+    updateEdit(getUserString(expr->getQuantity()));
     handlePendingEmit();
 }
 
@@ -429,27 +397,10 @@ bool QuantitySpinBox::apply(const std::string & propName)
 {
     if (!ExpressionBinding::apply(propName)) {
         double dValue = value().getValue();
-        if (isBound()) {
-            const App::ObjectIdentifier & path = getPath();
-            const Property * prop = path.getProperty();
-
-            /* Skip update if property is bound and we know it is read-only */
-            if (prop && prop->isReadOnly())
-                return true;
-
-            if (prop && prop->getTypeId().isDerivedFrom(App::PropertyPlacement::getClassTypeId())) {
-                std::string p = path.getSubPathStr();
-                if (p == ".Rotation.Angle") {
-                    dValue = Base::toRadians(dValue);
-                }
-            }
-        }
-
-        Gui::Command::doCommand(Gui::Command::Doc, "%s = %f", propName.c_str(), dValue);
-        return true;
+        return assignToProperty(propName, dValue);
     }
-    else
-        return false;
+
+    return false;
 }
 
 void QuantitySpinBox::resizeEvent(QResizeEvent * event)
@@ -478,20 +429,41 @@ void QuantitySpinBox::updateText(const Quantity &quant)
     double dFactor;
     QString txt = getUserString(quant, dFactor, d->unitStr);
     d->unitValue = quant.getValue()/dFactor;
-    lineEdit()->setText(txt);
+    updateEdit(txt);
     handlePendingEmit();
 }
 
+void QuantitySpinBox::updateEdit(const QString& text)
+{
+    Q_D(QuantitySpinBox);
+
+    QLineEdit* edit = lineEdit();
+
+    bool empty = edit->text().isEmpty();
+    int cursor = edit->cursorPosition();
+    int selsize = edit->selectedText().size();
+
+    edit->setText(text);
+
+    cursor = qBound(0, cursor, edit->displayText().size() - d->unitStr.size());
+    if (selsize > 0) {
+        edit->setSelection(0, cursor);
+    }
+    else {
+        edit->setCursorPosition(empty ? 0 : cursor);
+    }
+}
+
 void QuantitySpinBox::validateInput()
 {
     Q_D(QuantitySpinBox);
 
-    int pos = 0;
     QValidator::State state;
     QString text = lineEdit()->text();
-    d->validateAndInterpret(text, pos, state);
+    const App::ObjectIdentifier & path = getPath();
+    d->validateAndInterpret(text, state, path);
     if (state != QValidator::Acceptable) {
-        lineEdit()->setText(d->validStr);
+        updateEdit(d->validStr);
     }
 
     handlePendingEmit();
@@ -545,7 +517,8 @@ void QuantitySpinBox::userInput(const QString & text)
 
     QString tmp = text;
     Base::Quantity res;
-    if (d->validate(tmp, res)) {
+    const App::ObjectIdentifier & path = getPath();
+    if (d->validate(tmp, res, path)) {
         d->validStr = tmp;
         d->validInput = true;
     }
@@ -568,7 +541,10 @@ void QuantitySpinBox::openFormulaDialog()
     Q_ASSERT(isBound());
 
     Q_D(const QuantitySpinBox);
-    Gui::Dialog::DlgExpressionInput* box = new Gui::Dialog::DlgExpressionInput(getPath(), getExpression(), d->unit, this);
+    auto box = new Gui::Dialog::DlgExpressionInput(getPath(), getExpression(), d->unit, this);
+    if (d->checkRangeInExpression) {
+        box->setRange(d->minimum, d->maximum);
+    }
     QObject::connect(box, &Gui::Dialog::DlgExpressionInput::finished, [=]() {
         if (box->result() == QDialog::Accepted)
             setExpression(box->getExpression());
@@ -606,9 +582,9 @@ void QuantitySpinBox::updateFromCache(bool notify, bool updateUnit /* = true */)
         // signaling
         if (notify) {
             d->pendingEmit = false;
-            valueChanged(res);
-            valueChanged(res.getValue());
-            textChanged(text);
+            Q_EMIT valueChanged(res);
+            Q_EMIT valueChanged(res.getValue());
+            Q_EMIT textChanged(text);
         }
     }
 }
@@ -690,6 +666,19 @@ void QuantitySpinBox::setRange(double minimum, double maximum)
     d->maximum = maximum;
 }
 
+void QuantitySpinBox::checkRangeInExpression(bool on)
+{
+    Q_D(QuantitySpinBox);
+    d->checkRangeInExpression = on;
+}
+
+bool QuantitySpinBox::isCheckedRangeInExpresion() const
+{
+    Q_D(const QuantitySpinBox);
+    return d->checkRangeInExpression;
+}
+
+
 int QuantitySpinBox::decimals() const
 {
     Q_D(const QuantitySpinBox);
@@ -745,15 +734,7 @@ QString QuantitySpinBox::getUserString(const Base::Quantity& val) const
 
 void QuantitySpinBox::setExpression(std::shared_ptr<Expression> expr)
 {
-    Q_ASSERT(isBound());
-
-    try {
-        ExpressionBinding::setExpression(expr);
-        validateInput();
-    }
-    catch (const Base::Exception & e) {
-        showInvalidExpression(QString::fromLatin1(e.what()));
-    }
+    ExpressionSpinBox::setExpression(expr);
 }
 
 QAbstractSpinBox::StepEnabled QuantitySpinBox::stepEnabled() const
@@ -804,8 +785,7 @@ QSize QuantitySpinBox::sizeForText(const QString& txt) const
     QStyleOptionSpinBox opt;
     initStyleOption(&opt);
     QSize hint(w, h);
-    QSize size = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, this)
-                        .expandedTo(QApplication::globalStrut());
+    QSize size = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, this);
     return size;
 }
 
@@ -834,8 +814,7 @@ QSize QuantitySpinBox::sizeHint() const
     QStyleOptionSpinBox opt;
     initStyleOption(&opt);
     QSize hint(w, h);
-    QSize size = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, this)
-                        .expandedTo(QApplication::globalStrut());
+    QSize size = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, this);
     return size;
 }
 
@@ -865,8 +844,7 @@ QSize QuantitySpinBox::minimumSizeHint() const
     initStyleOption(&opt);
     QSize hint(w, h);
 
-    QSize size = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, this)
-                               .expandedTo(QApplication::globalStrut());
+    QSize size = style()->sizeFromContents(QStyle::CT_SpinBox, &opt, hint, this);
     return size;
 }
 
@@ -896,27 +874,6 @@ void QuantitySpinBox::closeEvent(QCloseEvent * event)
 
 bool QuantitySpinBox::event(QEvent * event)
 {
-    // issue #0004059: Tooltips for Gui::QuantitySpinBox not showing
-    // Here we must not try to show the tooltip of the icon label
-    // because it would override a custom tooltip set to this widget.
-    //
-    // We could also check if the text of this tooltip is empty but
-    // it will fail in cases where the widget is embedded into the
-    // property editor and the corresponding item has set a tooltip.
-    // Instead of showing the item's tooltip it will again show the
-    // tooltip of the icon label.
-#if 0
-    if (event->type() == QEvent::ToolTip) {
-        if (isBound() && getExpression() && lineEdit()->isReadOnly()) {
-            QHelpEvent * helpEvent = static_cast<QHelpEvent*>(event);
-
-            QToolTip::showText( helpEvent->globalPos(), Base::Tools::fromStdString(getExpression()->toString()), this);
-            event->accept();
-            return true;
-        }
-    }
-#endif
-
     return QAbstractSpinBox::event(event);
 }
 
@@ -930,7 +887,7 @@ void QuantitySpinBox::focusInEvent(QFocusEvent * event)
         event->reason() == Qt::ShortcutFocusReason) {
 
         if (isBound() && getExpression() && lineEdit()->isReadOnly()) {
-            QHelpEvent * helpEvent = new QHelpEvent(QEvent::ToolTip, QPoint( 0, rect().height() ), mapToGlobal( QPoint( 0, rect().height() ) ));
+            auto helpEvent = new QHelpEvent(QEvent::ToolTip, QPoint( 0, rect().height() ), mapToGlobal( QPoint( 0, rect().height() ) ));
             QApplication::postEvent(this, helpEvent);
             lineEdit()->setSelection(0, 0);
         }
@@ -956,27 +913,16 @@ void QuantitySpinBox::clear()
 
 void QuantitySpinBox::selectNumber()
 {
-    QString str = lineEdit()->text();
-    unsigned int i = 0;
-
-    QChar d = locale().decimalPoint();
-    QChar g = locale().groupSeparator();
-    QChar n = locale().negativeSign();
-
-    for (QString::iterator it = str.begin(); it != str.end(); ++it) {
-        if (it->isDigit())
-            i++;
-        else if (*it == d)
-            i++;
-        else if (*it == g)
-            i++;
-        else if (*it == n)
-            i++;
-        else // any non-number character
-            break;
+    QString expr = QString::fromLatin1("^([%1%2]?[0-9\\%3]*)\\%4?([0-9]+(%5[%1%2]?[0-9]+)?)")
+                   .arg(locale().negativeSign())
+                   .arg(locale().positiveSign())
+                   .arg(locale().groupSeparator())
+                   .arg(locale().decimalPoint())
+                   .arg(locale().exponential());
+    auto rmatch = QRegularExpression(expr).match(lineEdit()->text());
+    if (rmatch.hasMatch()) {
+        lineEdit()->setSelection(0, rmatch.capturedLength());
     }
-
-    lineEdit()->setSelection(0, i);
 }
 
 QString QuantitySpinBox::textFromValue(const Base::Quantity& value) const
@@ -995,12 +941,12 @@ Base::Quantity QuantitySpinBox::valueFromText(const QString &text) const
     Q_D(const QuantitySpinBox);
 
     QString copy = text;
-    int pos = lineEdit()->cursorPosition();
     QValidator::State state = QValidator::Acceptable;
-    Base::Quantity quant = d->validateAndInterpret(copy, pos, state);
+    const App::ObjectIdentifier & path = getPath();
+    Base::Quantity quant = d->validateAndInterpret(copy, state, path);
     if (state != QValidator::Acceptable) {
         fixup(copy);
-        quant = d->validateAndInterpret(copy, pos, state);
+        quant = d->validateAndInterpret(copy, state, path);
     }
 
     return quant;
@@ -1009,9 +955,11 @@ Base::Quantity QuantitySpinBox::valueFromText(const QString &text) const
 QValidator::State QuantitySpinBox::validate(QString &text, int &pos) const
 {
     Q_D(const QuantitySpinBox);
+    Q_UNUSED(pos)
 
     QValidator::State state;
-    d->validateAndInterpret(text, pos, state);
+    const App::ObjectIdentifier & path = getPath();
+    d->validateAndInterpret(text, state, path);
     return state;
 }
 
