@@ -38,6 +38,7 @@
 #include "QuarterWidget.h"
 #include "eventhandlers/EventFilter.h"
 
+#include <QActionGroup>
 #include <QApplication>
 #include <QCursor>
 #include <QMenu>
@@ -136,7 +137,7 @@ QuarterWidgetP::getCacheContextId() const
 QuarterWidgetP_cachecontext *
 QuarterWidgetP::findCacheContext(QuarterWidget * widget, const QtGLWidget * sharewidget)
 {
-  if (cachecontext_list == nullptr) {
+  if (!cachecontext_list) {
     // FIXME: static memory leak
     cachecontext_list = new SbList <QuarterWidgetP_cachecontext*>;
   }
