@@ -47,6 +47,7 @@
 #include "MainWindow.h"
 #include "MDIView.h"
 #include "SelectionFilter.h"
+#include "SelectionObserverPython.h"
 #include "Tree.h"
 #include "ViewProviderDocumentObject.h"
 
@@ -68,9 +69,9 @@ SelectionGateFilterExternal::SelectionGateFilterExternal(const char *docName, co
 bool SelectionGateFilterExternal::allow(App::Document *doc ,App::DocumentObject *obj, const char*) {
     if(!doc || !obj)
         return true;
-    if(DocName.size() && doc->getName()!=DocName)
+    if(!DocName.empty() && doc->getName()!=DocName)
         notAllowedReason = "Cannot select external object";
-    else if(ObjName.size() && ObjName==obj->getNameInDocument())
+    else if(!ObjName.empty() && ObjName==obj->getNameInDocument())
         notAllowedReason = "Cannot select self";
     else
         return true;
@@ -133,7 +134,7 @@ void SelectionObserver::attachSelection()
         connectSelection = signal.connect(boost::bind
             (&SelectionObserver::_onSelectionChanged, this, bp::_1));
 
-        if (filterDocName.size()) {
+        if (!filterDocName.empty()) {
             Selection().addSelectionGate(
                     new SelectionGateFilterExternal(filterDocName.c_str(),filterObjName.c_str()));
         }
@@ -159,202 +160,13 @@ void SelectionObserver::detachSelection()
 {
     if (connectSelection.connected()) {
         connectSelection.disconnect();
-        if (filterDocName.size())
+        if (!filterDocName.empty())
             Selection().rmvSelectionGate();
     }
 }
 
 // -------------------------------------------
 
-std::vector<SelectionObserverPython*> SelectionObserverPython::_instances;
-
-SelectionObserverPython::SelectionObserverPython(const Py::Object& obj, ResolveMode resolve)
-    : SelectionObserver(true, resolve), inst(obj)
-{
-#undef FC_PY_ELEMENT
-#define FC_PY_ELEMENT(_name) FC_PY_GetCallable(obj.ptr(),#_name,py_##_name);
-    FC_PY_SEL_OBSERVER
-}
-
-SelectionObserverPython::~SelectionObserverPython()
-{
-}
-
-void SelectionObserverPython::addObserver(const Py::Object& obj, ResolveMode resolve)
-{
-    _instances.push_back(new SelectionObserverPython(obj, resolve));
-}
-
-void SelectionObserverPython::removeObserver(const Py::Object& obj)
-{
-    SelectionObserverPython* obs=nullptr;
-    for (std::vector<SelectionObserverPython*>::iterator it =
-        _instances.begin(); it != _instances.end(); ++it) {
-        if ((*it)->inst == obj) {
-            obs = *it;
-            _instances.erase(it);
-            break;
-        }
-    }
-
-    delete obs;
-}
-
-void SelectionObserverPython::onSelectionChanged(const SelectionChanges& msg)
-{
-    switch (msg.Type)
-    {
-    case SelectionChanges::AddSelection:
-        addSelection(msg);
-        break;
-    case SelectionChanges::RmvSelection:
-        removeSelection(msg);
-        break;
-    case SelectionChanges::SetSelection:
-        setSelection(msg);
-        break;
-    case SelectionChanges::ClrSelection:
-        clearSelection(msg);
-        break;
-    case SelectionChanges::SetPreselect:
-        setPreselection(msg);
-        break;
-    case SelectionChanges::RmvPreselect:
-        removePreselection(msg);
-        break;
-    case SelectionChanges::PickedListChanged:
-        pickedListChanged();
-        break;
-    default:
-        break;
-    }
-}
-
-void SelectionObserverPython::pickedListChanged()
-{
-    if(py_pickedListChanged.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Callable(py_pickedListChanged).apply(Py::Tuple());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-void SelectionObserverPython::addSelection(const SelectionChanges& msg)
-{
-    if(py_addSelection.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Tuple args(4);
-        args.setItem(0, Py::String(msg.pDocName ? msg.pDocName : ""));
-        args.setItem(1, Py::String(msg.pObjectName ? msg.pObjectName : ""));
-        args.setItem(2, Py::String(msg.pSubName ? msg.pSubName : ""));
-        Py::Tuple tuple(3);
-        tuple[0] = Py::Float(msg.x);
-        tuple[1] = Py::Float(msg.y);
-        tuple[2] = Py::Float(msg.z);
-        args.setItem(3, tuple);
-        Base::pyCall(py_addSelection.ptr(),args.ptr());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-void SelectionObserverPython::removeSelection(const SelectionChanges& msg)
-{
-    if(py_removeSelection.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Tuple args(3);
-        args.setItem(0, Py::String(msg.pDocName ? msg.pDocName : ""));
-        args.setItem(1, Py::String(msg.pObjectName ? msg.pObjectName : ""));
-        args.setItem(2, Py::String(msg.pSubName ? msg.pSubName : ""));
-        Base::pyCall(py_removeSelection.ptr(),args.ptr());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-void SelectionObserverPython::setSelection(const SelectionChanges& msg)
-{
-    if(py_setSelection.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Tuple args(1);
-        args.setItem(0, Py::String(msg.pDocName ? msg.pDocName : ""));
-        Base::pyCall(py_setSelection.ptr(),args.ptr());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-void SelectionObserverPython::clearSelection(const SelectionChanges& msg)
-{
-    if(py_clearSelection.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Tuple args(1);
-        args.setItem(0, Py::String(msg.pDocName ? msg.pDocName : ""));
-        Base::pyCall(py_clearSelection.ptr(),args.ptr());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-void SelectionObserverPython::setPreselection(const SelectionChanges& msg)
-{
-    if(py_setPreselection.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Tuple args(3);
-        args.setItem(0, Py::String(msg.pDocName ? msg.pDocName : ""));
-        args.setItem(1, Py::String(msg.pObjectName ? msg.pObjectName : ""));
-        args.setItem(2, Py::String(msg.pSubName ? msg.pSubName : ""));
-        Base::pyCall(py_setPreselection.ptr(),args.ptr());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-void SelectionObserverPython::removePreselection(const SelectionChanges& msg)
-{
-    if(py_removePreselection.isNone())
-        return;
-    Base::PyGILStateLocker lock;
-    try {
-        Py::Tuple args(3);
-        args.setItem(0, Py::String(msg.pDocName ? msg.pDocName : ""));
-        args.setItem(1, Py::String(msg.pObjectName ? msg.pObjectName : ""));
-        args.setItem(2, Py::String(msg.pSubName ? msg.pSubName : ""));
-        Base::pyCall(py_removePreselection.ptr(),args.ptr());
-    }
-    catch (Py::Exception&) {
-        Base::PyException e; // extract the Python error text
-        e.ReportException();
-    }
-}
-
-// -------------------------------------------
-
 bool SelectionSingleton::hasSelection() const
 {
     return !_SelList.empty();
@@ -397,7 +209,7 @@ std::vector<SelectionSingleton::SelObj> SelectionSingleton::getSelection(const c
         if (resolve != ResolveMode::NoResolve && !objMap[obj].insert(std::string(subelement ? subelement : "")).second)
             continue;
 
-        if (single && temp.size()) {
+        if (single && !temp.empty()) {
             temp.clear();
             break;
         }
@@ -536,19 +348,19 @@ std::vector<SelectionObject> SelectionSingleton::getObjectList(const char* pDocN
             if (subelement && *subelement) {
                 if (resolve != ResolveMode::NoResolve && !temp[it->second]._SubNameSet.insert(subelement).second)
                     continue;
-                temp[it->second].SubNames.push_back(subelement);
+                temp[it->second].SubNames.emplace_back(subelement);
                 temp[it->second].SelPoses.emplace_back(sel.x,sel.y,sel.z);
             }
         }
         else {
-            if (single && temp.size()) {
+            if (single && !temp.empty()) {
                 temp.clear();
                 break;
             }
             // create a new entry
             temp.emplace_back(obj);
             if (subelement && *subelement) {
-                temp.back().SubNames.push_back(subelement);
+                temp.back().SubNames.emplace_back(subelement);
                 temp.back().SelPoses.emplace_back(sel.x,sel.y,sel.z);
                 if (resolve != ResolveMode::NoResolve)
                     temp.back()._SubNameSet.insert(subelement);
@@ -582,7 +394,7 @@ void SelectionSingleton::notify(SelectionChanges &&Chng)
     }
     Base::FlagToggler<bool> flag(Notifying);
     NotificationQueue.push_back(std::move(Chng));
-    while(NotificationQueue.size()) {
+    while(!NotificationQueue.empty()) {
         const auto &msg = NotificationQueue.front();
         bool notify;
         switch(msg.Type) {
@@ -618,7 +430,7 @@ void SelectionSingleton::notify(SelectionChanges &&Chng)
 
 bool SelectionSingleton::hasPickedList() const
 {
-    return _PickedList.size();
+    return !_PickedList.empty();
 }
 
 int SelectionSingleton::getAsPropertyLinkSubList(App::PropertyLinkSubList &prop) const
@@ -626,20 +438,19 @@ int SelectionSingleton::getAsPropertyLinkSubList(App::PropertyLinkSubList &prop)
     std::vector<Gui::SelectionObject> sel = this->getSelectionEx();
     std::vector<App::DocumentObject*> objs; objs.reserve(sel.size() * 2);
     std::vector<std::string> subs; subs.reserve(sel.size()*2);
-    for (std::size_t iobj = 0; iobj < sel.size(); iobj++) {
-        Gui::SelectionObject &selitem = sel[iobj];
+    for (auto & selitem : sel) {
         App::DocumentObject* obj = selitem.getObject();
         const std::vector<std::string> &subnames = selitem.getSubNames();
 
         //whole object is selected
-        if (subnames.size() == 0){
+        if (subnames.empty()){
             objs.push_back(obj);
             subs.emplace_back();
         }
         else {
-            for (std::size_t isub = 0; isub < subnames.size(); isub++) {
+            for (const auto & subname : subnames) {
                 objs.push_back(obj);
-                subs.push_back(subnames[isub]);
+                subs.push_back(subname);
             }
         }
     }
@@ -657,7 +468,7 @@ App::DocumentObject *SelectionSingleton::getObjectOfType(_SelObj &sel, Base::Typ
     const char *subname = sel.SubName.c_str();
     if (resolve != ResolveMode::NoResolve) {
         obj = sel.pResolvedObject;
-        if (resolve == ResolveMode::NewStyleElement && sel.elementName.first.size())
+        if (resolve == ResolveMode::NewStyleElement && !sel.elementName.first.empty())
             subname = sel.elementName.first.c_str();
         else
             subname = sel.elementName.second.c_str();
@@ -742,7 +553,7 @@ void SelectionSingleton::slotSelectionChanged(const SelectionChanges& msg)
        msg.Type == SelectionChanges::HideSelection)
         return;
 
-    if(msg.Object.getSubName().size()) {
+    if(!msg.Object.getSubName().empty()) {
         auto pParent = msg.Object.getObject();
         if(!pParent)
             return;
@@ -754,7 +565,7 @@ void SelectionSingleton::slotSelectionChanged(const SelectionChanges& msg)
             return;
         SelectionChanges msg2(msg.Type,pObject->getDocument()->getName(),
                 pObject->getNameInDocument(),
-                newElementName.size()?newElementName.c_str():oldElementName.c_str(),
+                !newElementName.empty()?newElementName.c_str():oldElementName.c_str(),
                 pObject->getTypeId().getName(), msg.x,msg.y,msg.z);
 
         try {
@@ -792,18 +603,6 @@ int SelectionSingleton::setPreselect(const char* pDocName, const char* pObjectNa
     if (!pSubName) pSubName = "";
 
     if (DocName==pDocName && FeatName==pObjectName && SubName==pSubName) {
-        // MovePreselect is likely going to slow down large scene rendering.
-        // Disable it for now.
-#if 0
-        if(hx!=x || hy!=y || hz!=z) {
-            hx = x;
-            hy = y;
-            hz = z;
-            SelectionChanges Chng(SelectionChanges::MovePreselect,
-                    DocName,FeatName,SubName,std::string(),x,y,z);
-            notify(Chng);
-        }
-#endif
         return -1;
     }
 
@@ -826,7 +625,7 @@ int SelectionSingleton::setPreselect(const char* pDocName, const char* pObjectNa
             if (!pObject)
                 return 0;
             if (gateResolve > ResolveMode::OldStyleElement)
-                subelement = newElementName.size() ? newElementName.c_str() : oldElementName.c_str();
+                subelement = !newElementName.empty() ? newElementName.c_str() : oldElementName.c_str();
             else
                 subelement = oldElementName.c_str();
         }
@@ -876,7 +675,7 @@ int SelectionSingleton::setPreselect(const char* pDocName, const char* pObjectNa
 
     notify(Chng);
 
-    if (signal == SelectionChanges::MsgSource::Internal && DocName.size()) {
+    if (signal == SelectionChanges::MsgSource::Internal && !DocName.empty()) {
         FC_TRACE("preselect "<<DocName<<'#'<<FeatName<<'.'<<SubName);
         Chng.Type = SelectionChanges::SetPreselect;
         CurrentPreselection = Chng;
@@ -942,7 +741,7 @@ void SelectionSingleton::setPreselectCoord( float x, float y, float z)
 
 void SelectionSingleton::rmvPreselect(bool signal)
 {
-    if (DocName == "")
+    if (DocName.empty())
         return;
 
     if(signal) {
@@ -972,7 +771,6 @@ void SelectionSingleton::rmvPreselect(bool signal)
 
     // notify observing objects
     notify(std::move(Chng));
-
 }
 
 const SelectionChanges &SelectionSingleton::getPreselection() const
@@ -1044,8 +842,8 @@ void SelectionSingleton::_SelObj::log(bool remove, bool clearPreselect) {
     std::ostringstream ss;
     ss << "Gui.Selection." << (remove?"removeSelection":"addSelection")
         << "('" << DocName  << "','" << FeatName << "'";
-    if(SubName.size()) {
-        if(elementName.second.size() && elementName.first.size())
+    if(!SubName.empty()) {
+        if(!elementName.second.empty() && !elementName.first.empty())
             ss << ",'" << SubName.substr(0,SubName.size()-elementName.first.size())
                 << elementName.second << "'";
         else
@@ -1156,7 +954,7 @@ void SelectionSingleton::selStackPush(bool clearForward, bool overwrite) {
     SelStackItem item;
     for(auto &sel : _SelList)
         item.emplace(sel.DocName.c_str(),sel.FeatName.c_str(),sel.SubName.c_str());
-    if(_SelStackBack.size() && _SelStackBack.back()==item)
+    if(!_SelStackBack.empty() && _SelStackBack.back()==item)
         return;
     if(!overwrite || _SelStackBack.empty())
         _SelStackBack.emplace_back();
@@ -1168,7 +966,7 @@ void SelectionSingleton::selStackGoBack(int count) {
         count = _SelStackBack.size();
     if(count<=0)
         return;
-    if(_SelList.size()) {
+    if(!_SelList.empty()) {
         selStackPush(false,true);
         clearCompleteSelection();
     } else
@@ -1179,7 +977,7 @@ void SelectionSingleton::selStackGoBack(int count) {
     }
     std::deque<SelStackItem> tmpStack;
     _SelStackForward.swap(tmpStack);
-    while(_SelStackBack.size()) {
+    while(!_SelStackBack.empty()) {
         bool found = false;
         for(auto &sobjT : _SelStackBack.back()) {
             if(sobjT.getSubObject()) {
@@ -1203,7 +1001,7 @@ void SelectionSingleton::selStackGoForward(int count) {
         count = _SelStackForward.size();
     if(count<=0)
         return;
-    if(_SelList.size()) {
+    if(!_SelList.empty()) {
         selStackPush(false,true);
         clearCompleteSelection();
     }
@@ -1266,15 +1064,15 @@ std::vector<SelectionObject> SelectionSingleton::selStackGet(const char* pDocNam
 
 bool SelectionSingleton::addSelections(const char* pDocName, const char* pObjectName, const std::vector<std::string>& pSubNames)
 {
-    if(_PickedList.size()) {
+    if(!_PickedList.empty()) {
         _PickedList.clear();
         notify(SelectionChanges(SelectionChanges::PickedListChanged));
     }
 
     bool update = false;
-    for(std::vector<std::string>::const_iterator it = pSubNames.begin(); it != pSubNames.end(); ++it) {
+    for(const auto & pSubName : pSubNames) {
         _SelObj temp;
-        int ret = checkSelection(pDocName, pObjectName, it->c_str(), ResolveMode::NoResolve, temp);
+        int ret = checkSelection(pDocName, pObjectName, pSubName.c_str(), ResolveMode::NoResolve, temp);
         if (ret!=0)
             continue;
 
@@ -1397,7 +1195,7 @@ void SelectionSingleton::rmvSelection(const char* pDocName, const char* pObjectN
         if(It->DocName!=temp.DocName || It->FeatName!=temp.FeatName)
             continue;
         // if no subname is specified, remove all subobjects of the matching object
-        if(temp.SubName.size()) {
+        if(!temp.SubName.empty()) {
             // otherwise, match subojects with common prefix, separated by '.'
             if(!boost::starts_with(It->SubName,temp.SubName) ||
                (It->SubName.length()!=temp.SubName.length() && It->SubName[temp.SubName.length()-1]!='.'))
@@ -1418,7 +1216,7 @@ void SelectionSingleton::rmvSelection(const char* pDocName, const char* pObjectN
     // as this can invalidate the iterators and thus leads to undefined
     // behaviour.
     // So, the notification is done after the loop, see also #0003469
-    if(changes.size()) {
+    if(!changes.empty()) {
         for(auto &Chng : changes) {
             FC_LOG("Rmv Selection "<<Chng.pDocName<<'#'<<Chng.pObjectName<<'.'<<Chng.pSubName);
             notify(std::move(Chng));
@@ -1503,7 +1301,7 @@ void SelectionSingleton::setVisible(VisibleState vis) {
 
             // Fall back to direct object visibility setting
         }
-        if(!filter.insert(std::make_pair(obj,(App::DocumentObject*)nullptr)).second){
+        if(!filter.insert(std::make_pair(obj,static_cast<App::DocumentObject*>(nullptr))).second){
             continue;
         }
 
@@ -1534,7 +1332,7 @@ void SelectionSingleton::setSelection(const char* pDocName, const std::vector<Ap
     if (!pcDoc)
         return;
 
-    if(_PickedList.size()) {
+    if(!_PickedList.empty()) {
         _PickedList.clear();
         notify(SelectionChanges(SelectionChanges::PickedListChanged));
     }
@@ -1568,7 +1366,7 @@ void SelectionSingleton::clearSelection(const char* pDocName, bool clearPreSelec
         return;
     }
 
-    if (_PickedList.size()) {
+    if (!_PickedList.empty()) {
         _PickedList.clear();
         notify(SelectionChanges(SelectionChanges::PickedListChanged));
     }
@@ -1611,7 +1409,7 @@ void SelectionSingleton::clearSelection(const char* pDocName, bool clearPreSelec
 
 void SelectionSingleton::clearCompleteSelection(bool clearPreSelect)
 {
-    if(_PickedList.size()) {
+    if(!_PickedList.empty()) {
         _PickedList.clear();
         notify(SelectionChanges(SelectionChanges::PickedListChanged));
     }
@@ -1680,7 +1478,7 @@ int SelectionSingleton::checkSelection(const char *pDocName, const char *pObject
        sel.SubName = pSubName;
     if (resolve == ResolveMode::NoResolve)
         TreeWidget::checkTopParent(sel.pObject,sel.SubName);
-    pSubName = sel.SubName.size()?sel.SubName.c_str():nullptr;
+    pSubName = !sel.SubName.empty()?sel.SubName.c_str():nullptr;
     sel.FeatName = sel.pObject->getNameInDocument();
     sel.TypeName = sel.pObject->getTypeId().getName();
     const char *element = nullptr;
@@ -1697,7 +1495,7 @@ int SelectionSingleton::checkSelection(const char *pDocName, const char *pObject
     std::string prefix;
     if(pSubName && element) {
         prefix = std::string(pSubName, element-pSubName);
-        if(sel.elementName.first.size()) {
+        if(!sel.elementName.first.empty()) {
             // make sure the selected sub name is a new style if available
             subname = prefix + sel.elementName.first;
             pSubName = subname.c_str();
@@ -1724,7 +1522,7 @@ int SelectionSingleton::checkSelection(const char *pDocName, const char *pObject
                 continue;
             if(!pSubName[0])
                 return 1;
-            if (s.elementName.first.size()) {
+            if (!s.elementName.first.empty()) {
                 if (s.elementName.first == sel.elementName.first)
                     return 1;
             }
@@ -1773,7 +1571,7 @@ void SelectionSingleton::slotDeletedObject(const App::DocumentObject& Obj)
             _SelList.erase(it);
         }
     }
-    if(changes.size()) {
+    if(!changes.empty()) {
         for(auto &Chng : changes) {
             FC_LOG("Rmv Selection "<<Chng.pDocName<<'#'<<Chng.pObjectName<<'.'<<Chng.pSubName);
             notify(std::move(Chng));
@@ -1781,7 +1579,7 @@ void SelectionSingleton::slotDeletedObject(const App::DocumentObject& Obj)
         getMainWindow()->updateActions();
     }
 
-    if(_PickedList.size()) {
+    if(!_PickedList.empty()) {
         bool changed = false;
         for(auto it=_PickedList.begin(),itNext=it;it!=_PickedList.end();it=itNext) {
             ++itNext;
@@ -1831,14 +1629,14 @@ SelectionSingleton* SelectionSingleton::_pcSingleton = nullptr;
 
 SelectionSingleton& SelectionSingleton::instance()
 {
-    if (_pcSingleton == nullptr)
+    if (!_pcSingleton)
         _pcSingleton = new SelectionSingleton;
     return *_pcSingleton;
 }
 
 void SelectionSingleton::destruct ()
 {
-    if (_pcSingleton != nullptr)
+    if (_pcSingleton)
         delete _pcSingleton;
     _pcSingleton = nullptr;
 }
@@ -2072,7 +1870,7 @@ PyObject *SelectionSingleton::sAddSelection(PyObject * /*self*/, PyObject *args)
     float x = 0, y = 0, z = 0;
     if (PyArg_ParseTuple(args, "ss|sfffO!", &docname, &objname ,
                 &subname,&x,&y,&z,&PyBool_Type,&clearPreselect)) {
-        Selection().addSelection(docname,objname,subname,x,y,z,nullptr,PyObject_IsTrue(clearPreselect));
+        Selection().addSelection(docname, objname, subname, x, y, z, nullptr, Base::asBoolean(clearPreselect));
         Py_Return;
     }
 
@@ -2082,7 +1880,7 @@ PyObject *SelectionSingleton::sAddSelection(PyObject * /*self*/, PyObject *args)
     x = 0, y = 0, z = 0;
     if (PyArg_ParseTuple(args, "O!|sfffO!", &(App::DocumentObjectPy::Type),&object,
                 &subname,&x,&y,&z,&PyBool_Type,&clearPreselect)) {
-        App::DocumentObjectPy* docObjPy = static_cast<App::DocumentObjectPy*>(object);
+        auto docObjPy = static_cast<App::DocumentObjectPy*>(object);
         App::DocumentObject* docObj = docObjPy->getDocumentObjectPtr();
         if (!docObj || !docObj->getNameInDocument()) {
             PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot check invalid object");
@@ -2091,7 +1889,7 @@ PyObject *SelectionSingleton::sAddSelection(PyObject * /*self*/, PyObject *args)
 
         Selection().addSelection(docObj->getDocument()->getName(),
                                  docObj->getNameInDocument(),
-                                 subname,x,y,z,nullptr,PyObject_IsTrue(clearPreselect));
+                                 subname, x, y, z, nullptr, Base::asBoolean(clearPreselect));
         Py_Return;
     }
 
@@ -2100,7 +1898,7 @@ PyObject *SelectionSingleton::sAddSelection(PyObject * /*self*/, PyObject *args)
     if (PyArg_ParseTuple(args, "O!O|O!", &(App::DocumentObjectPy::Type),&object,
                 &sequence,&PyBool_Type,&clearPreselect))
     {
-        App::DocumentObjectPy* docObjPy = static_cast<App::DocumentObjectPy*>(object);
+        auto docObjPy = static_cast<App::DocumentObjectPy*>(object);
         App::DocumentObject* docObj = docObjPy->getDocumentObjectPtr();
         if (!docObj || !docObj->getNameInDocument()) {
             PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot check invalid object");
@@ -2114,9 +1912,8 @@ PyObject *SelectionSingleton::sAddSelection(PyObject * /*self*/, PyObject *args)
                     std::string subname = static_cast<std::string>(Py::String(*it));
                     Selection().addSelection(docObj->getDocument()->getName(),
                                              docObj->getNameInDocument(),
-                                             subname.c_str(),0,0,0,nullptr,PyObject_IsTrue(clearPreselect));
+                                             subname.c_str(), 0, 0, 0, nullptr, Base::asBoolean(clearPreselect));
                 }
-
                 Py_Return;
             }
         }
@@ -2139,14 +1936,14 @@ PyObject *SelectionSingleton::sUpdateSelection(PyObject * /*self*/, PyObject *ar
             &object, &subname))
         return nullptr;
 
-    App::DocumentObjectPy* docObjPy = static_cast<App::DocumentObjectPy*>(object);
+    auto docObjPy = static_cast<App::DocumentObjectPy*>(object);
     App::DocumentObject* docObj = docObjPy->getDocumentObjectPtr();
     if (!docObj || !docObj->getNameInDocument()) {
         PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot check invalid object");
         return nullptr;
     }
 
-    Selection().updateSelection(PyObject_IsTrue(show),
+    Selection().updateSelection(Base::asBoolean(show),
             docObj->getDocument()->getName(), docObj->getNameInDocument(), subname);
 
     Py_Return;
@@ -2169,7 +1966,7 @@ PyObject *SelectionSingleton::sRemoveSelection(PyObject * /*self*/, PyObject *ar
     if (!PyArg_ParseTuple(args, "O!|s", &(App::DocumentObjectPy::Type),&object,&subname))
         return nullptr;
 
-    App::DocumentObjectPy* docObjPy = static_cast<App::DocumentObjectPy*>(object);
+    auto docObjPy = static_cast<App::DocumentObjectPy*>(object);
     App::DocumentObject* docObj = docObjPy->getDocumentObjectPtr();
     if (!docObj || !docObj->getNameInDocument()) {
         PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot check invalid object");
@@ -2193,7 +1990,7 @@ PyObject *SelectionSingleton::sClearSelection(PyObject * /*self*/, PyObject *arg
         if (!PyArg_ParseTuple(args, "|sO!", &documentName, &PyBool_Type, &clearPreSelect))
             return nullptr;
     }
-    Selection().clearSelection(documentName,PyObject_IsTrue(clearPreSelect));
+    Selection().clearSelection(documentName, Base::asBoolean(clearPreSelect));
 
     Py_Return;
 }
@@ -2224,7 +2021,7 @@ PyObject *SelectionSingleton::sIsSelected(PyObject * /*self*/, PyObject *args)
         return nullptr;
 
     try {
-        App::DocumentObjectPy* docObj = static_cast<App::DocumentObjectPy*>(object);
+        auto docObj = static_cast<App::DocumentObjectPy*>(object);
         bool ok = Selection().isSelected(docObj->getDocumentObjectPtr(), subname, toEnum(resolve));
 
         return Py_BuildValue("O", (ok ? Py_True : Py_False));
@@ -2263,18 +2060,18 @@ PyObject *SelectionSingleton::sGetSelection(PyObject * /*self*/, PyObject *args)
 
     try {
         std::vector<SelectionSingleton::SelObj> sel;
-        sel = Selection().getSelection(documentName, toEnum(resolve), PyObject_IsTrue(single));
+        sel = Selection().getSelection(documentName, toEnum(resolve), Base::asBoolean(single));
 
         std::set<App::DocumentObject*> noduplicates;
         std::vector<App::DocumentObject*> selectedObjects; // keep the order of selection
         Py::List list;
-        for (std::vector<SelectionSingleton::SelObj>::iterator it = sel.begin(); it != sel.end(); ++it) {
-            if (noduplicates.insert(it->pObject).second) {
-                selectedObjects.push_back(it->pObject);
+        for (const auto & it : sel) {
+            if (noduplicates.insert(it.pObject).second) {
+                selectedObjects.push_back(it.pObject);
             }
         }
-        for (std::vector<App::DocumentObject*>::iterator it = selectedObjects.begin(); it != selectedObjects.end(); ++it) {
-            list.append(Py::asObject((*it)->getPyObject()));
+        for (const auto & selectedObject : selectedObjects) {
+            list.append(Py::asObject(selectedObject->getPyObject()));
         }
         return Py::new_reference_to(list);
     }
@@ -2293,7 +2090,7 @@ PyObject *SelectionSingleton::sEnablePickedList(PyObject * /*self*/, PyObject *a
     if (!PyArg_ParseTuple(args, "|O!", &PyBool_Type, &enable))
         return nullptr;
 
-    Selection().enablePickedList(PyObject_IsTrue(enable));
+    Selection().enablePickedList(Base::asBoolean(enable));
 
     Py_Return;
 }
@@ -2307,7 +2104,7 @@ PyObject *SelectionSingleton::sSetPreselection(PyObject * /*self*/, PyObject *ar
     static char *kwlist[] = {"obj","subname","x","y","z","tp",nullptr};
     if (PyArg_ParseTupleAndKeywords(args, kwd, "O!|sfffi", kwlist,
                 &(App::DocumentObjectPy::Type),&object,&subname,&x,&y,&z,&type)) {
-        App::DocumentObjectPy* docObjPy = static_cast<App::DocumentObjectPy*>(object);
+        auto docObjPy = static_cast<App::DocumentObjectPy*>(object);
         App::DocumentObject* docObj = docObjPy->getDocumentObjectPtr();
         if (!docObj || !docObj->getNameInDocument()) {
             PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot check invalid object");
@@ -2388,11 +2185,11 @@ PyObject *SelectionSingleton::sGetSelectionEx(PyObject * /*self*/, PyObject *arg
     try {
         std::vector<SelectionObject> sel;
         sel = Selection().getSelectionEx(documentName,
-                App::DocumentObject::getClassTypeId(), toEnum(resolve), PyObject_IsTrue(single));
+                App::DocumentObject::getClassTypeId(), toEnum(resolve), Base::asBoolean(single));
 
         Py::List list;
-        for (std::vector<SelectionObject>::iterator it = sel.begin(); it != sel.end(); ++it) {
-            list.append(Py::asObject(it->getPyObject()));
+        for (auto & it : sel) {
+            list.append(Py::asObject(it.getPyObject()));
         }
         return Py::new_reference_to(list);
     }
@@ -2416,8 +2213,8 @@ PyObject *SelectionSingleton::sGetPickedList(PyObject * /*self*/, PyObject *args
 
     try {
         Py::List list;
-        for (std::vector<SelectionObject>::iterator it = sel.begin(); it != sel.end(); ++it) {
-            list.append(Py::asObject(it->getPyObject()));
+        for (auto & it : sel) {
+            list.append(Py::asObject(it.getPyObject()));
         }
         return Py::new_reference_to(list);
     }
@@ -2544,17 +2341,10 @@ PyObject *SelectionSingleton::sSetVisible(PyObject * /*self*/, PyObject *args)
         return nullptr;
 
     PY_TRY {
-        VisibleState vis;
-        if(visible == Py_None) {
-            vis = VisToggle;
-        }
-        else if (PyBool_Check(visible)) {
+        VisibleState vis = VisToggle;
+        Base::PyTypeCheck(&visible, &PyBool_Type);
+        if (visible)
             vis = PyObject_IsTrue(visible) ? VisShow : VisHide;
-        }
-        else {
-            PyErr_SetString(PyExc_ValueError, "Argument is neither None nor Bool");
-            return nullptr;
-        }
 
         Selection().setVisible(vis);
         Py_Return;
@@ -2569,7 +2359,7 @@ PyObject *SelectionSingleton::sPushSelStack(PyObject * /*self*/, PyObject *args)
     if (!PyArg_ParseTuple(args, "|O!O!", &PyBool_Type, &clear, &PyBool_Type, &overwrite))
         return nullptr;
 
-    Selection().selStackPush(PyObject_IsTrue(clear), PyObject_IsTrue(overwrite));
+    Selection().selStackPush(Base::asBoolean(clear), Base::asBoolean(overwrite));
 
     Py_Return;
 }
@@ -2602,7 +2392,7 @@ PyObject *SelectionSingleton::sHasSubSelection(PyObject * /*self*/, PyObject *ar
 
     PY_TRY {
         return Py::new_reference_to(
-                Py::Boolean(Selection().hasSubSelection(doc,PyObject_IsTrue(subElement))));
+               Py::Boolean(Selection().hasSubSelection(doc, Base::asBoolean(subElement))));
     }
     PY_CATCH;
 }
