@@ -28,7 +28,6 @@
 #include <list>
 #include <string>
 #include <vector>
-#include <CXX/Objects.hxx>
 
 #include <App/DocumentObject.h>
 #include <App/DocumentObserver.h>
@@ -37,6 +36,8 @@
 #include "SelectionObject.h"
 
 
+using PyObject = struct _object;
+
 namespace App
 {
     class DocumentObject;
@@ -102,9 +103,10 @@ public:
         pDocName = Object.getDocumentName().c_str();
         pObjectName = Object.getObjectName().c_str();
         pSubName = Object.getSubName().c_str();
-        if(typeName) TypeName = typeName;
+        if (typeName)
+            TypeName = typeName;
         pTypeName = TypeName.c_str();
-    }
+    }//explicit bombs
 
     SelectionChanges(MsgType type,
                      const std::string &docName,
@@ -229,7 +231,7 @@ public:
      *                 1 resolve sub-object with old style element name
      *                 2 resolve sub-object with new style element name
      */
-    SelectionObserver(bool attach = true, ResolveMode resolve = ResolveMode::OldStyleElement);
+    explicit SelectionObserver(bool attach = true, ResolveMode resolve = ResolveMode::OldStyleElement);
     /** Constructor
      *
      * @param vp: filtering view object.
@@ -242,7 +244,7 @@ public:
      * Constructs an selection observer that receives only selection event of
      * objects within the same document as the input view object.
      */
-    SelectionObserver(const Gui::ViewProviderDocumentObject *vp, bool attach=true, ResolveMode resolve = ResolveMode::OldStyleElement);
+    explicit SelectionObserver(const Gui::ViewProviderDocumentObject *vp, bool attach=true, ResolveMode resolve = ResolveMode::OldStyleElement);
 
     virtual ~SelectionObserver();
     bool blockSelection(bool block);
@@ -259,7 +261,7 @@ private:
     void _onSelectionChanged(const SelectionChanges& msg);
 
 private:
-    typedef boost::signals2::connection Connection;
+    using Connection = boost::signals2::connection;
     Connection connectSelection;
     std::string filterDocName;
     std::string filterObjName;
@@ -267,55 +269,6 @@ private:
     bool blockedSelection;
 };
 
-/**
- * The SelectionObserverPython class implements a mechanism to register
- * a Python class instance implementing the required interface in order
- * to be notified on selection changes.
- *
- * @author Werner Mayer
- */
-class GuiExport SelectionObserverPython : public SelectionObserver
-{
-
-public:
-    /// Constructor
-    SelectionObserverPython(const Py::Object& obj, ResolveMode resolve = ResolveMode::OldStyleElement);
-    virtual ~SelectionObserverPython();
-
-    static void addObserver(const Py::Object& obj, ResolveMode resolve = ResolveMode::OldStyleElement);
-    static void removeObserver(const Py::Object& obj);
-
-private:
-    void onSelectionChanged(const SelectionChanges& msg);
-    void addSelection(const SelectionChanges&);
-    void removeSelection(const SelectionChanges&);
-    void setSelection(const SelectionChanges&);
-    void clearSelection(const SelectionChanges&);
-    void setPreselection(const SelectionChanges&);
-    void removePreselection(const SelectionChanges&);
-    void pickedListChanged();
-
-private:
-    Py::Object inst;
-
-#define FC_PY_SEL_OBSERVER \
-    FC_PY_ELEMENT(onSelectionChanged) \
-    FC_PY_ELEMENT(addSelection) \
-    FC_PY_ELEMENT(removeSelection) \
-    FC_PY_ELEMENT(setSelection) \
-    FC_PY_ELEMENT(clearSelection) \
-    FC_PY_ELEMENT(setPreselection) \
-    FC_PY_ELEMENT(removePreselection) \
-    FC_PY_ELEMENT(pickedListChanged)
-
-#undef FC_PY_ELEMENT
-#define FC_PY_ELEMENT(_name) Py::Object py_##_name;
-
-    FC_PY_SEL_OBSERVER
-
-    static std::vector<SelectionObserverPython*> _instances;
-};
-
 /** SelectionGate
  * The selection gate allows or disallows selection of certain types.
  * It has to be registered to the selection.
@@ -341,8 +294,8 @@ public:
 class GuiExport SelectionGateFilterExternal: public SelectionGate
 {
 public:
-    SelectionGateFilterExternal(const char *docName, const char *objName=nullptr);
-    virtual bool allow(App::Document*,App::DocumentObject*, const char*) override;
+    explicit SelectionGateFilterExternal(const char *docName, const char *objName=nullptr);
+    bool allow(App::Document*,App::DocumentObject*, const char*) override;
 private:
     std::string DocName;
     std::string ObjName;
@@ -680,7 +633,7 @@ protected:
     /// Construction
     SelectionSingleton();
     /// Destruction
-    virtual ~SelectionSingleton();
+    ~SelectionSingleton() override;
 
     /// Observer message from the App doc
     void slotDeletedObject(const App::DocumentObject&);
@@ -720,7 +673,7 @@ protected:
     mutable std::list<_SelObj> _PickedList;
     bool _needPickedList;
 
-    typedef std::set<App::SubObjectT> SelStackItem;
+    using SelStackItem = std::set<App::SubObjectT>;
     std::deque<SelStackItem> _SelStackBack;
     std::deque<SelStackItem> _SelStackForward;
 
@@ -755,7 +708,7 @@ inline std::vector<T*> SelectionSingleton::getObjectsOfType(const char* pDocName
     std::vector<T*> type;
     std::vector<App::DocumentObject*> obj = this->getObjectsOfType(T::getClassTypeId(), pDocName, resolve);
     type.reserve(obj.size());
-    for (std::vector<App::DocumentObject*>::iterator it = obj.begin(); it != obj.end(); ++it)
+    for (auto it = obj.begin(); it != obj.end(); ++it)
         type.push_back(static_cast<T*>(*it));
     return type;
 }
@@ -770,7 +723,7 @@ inline SelectionSingleton& Selection()
  */
 class GuiExport SelectionLogDisabler {
 public:
-    SelectionLogDisabler(bool silent=false) :silent(silent) {
+    explicit SelectionLogDisabler(bool silent=false) :silent(silent) {
         Selection().disableCommandLog();
     }
     ~SelectionLogDisabler() {
