@@ -26,6 +26,7 @@
 
 #include <Base/BaseClass.h>
 #include <Base/Vector3D.h>
+#include <FCGlobal.h>
 #include <string>
 
 namespace App {
@@ -41,20 +42,20 @@ class SelectionChanges;
  */
 class GuiExport SelectionObject : public Base::BaseClass
 {
-    TYPESYSTEM_HEADER();
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
     /** Constructs a SelectionObject object. */
     SelectionObject();
     /*! Constructs a SelectionObject from the SelectionChanges structure.
      */
-    SelectionObject(const SelectionChanges& msg);
+    explicit SelectionObject(const SelectionChanges& msg);
     explicit SelectionObject(App::DocumentObject*);
-    virtual ~SelectionObject();
+    ~SelectionObject() override;
     /**
      * The default implementation returns an instance of @ref SelectionObjectPy.
      */
-    PyObject* getPyObject();
+    PyObject* getPyObject() override;
 
     /// get the SubElement name of this SelectionObject
     inline const std::vector<std::string> &getSubNames() const { return SubNames; }
