@@ -90,6 +90,10 @@ TDragger::TDragger()
 {
     SO_KIT_CONSTRUCTOR(TDragger);
 
+#if defined(Q_OS_MAC)
+    this->ref();
+#endif
+
     SO_KIT_ADD_CATALOG_ENTRY(translatorSwitch, SoSwitch, TRUE, geomSeparator, "", TRUE);
     SO_KIT_ADD_CATALOG_ENTRY(translator, SoSeparator, TRUE, translatorSwitch, "", TRUE);
     SO_KIT_ADD_CATALOG_ENTRY(translatorActive, SoSeparator, TRUE, translatorSwitch, "", TRUE);
@@ -128,21 +132,27 @@ TDragger::TDragger()
 
 TDragger::~TDragger()
 {
+    fieldSensor.setData(nullptr);
+    fieldSensor.detach();
 
+    this->removeStartCallback(&TDragger::startCB);
+    this->removeMotionCallback(&TDragger::motionCB);
+    this->removeFinishCallback(&TDragger::finishCB);
+    removeValueChangedCallback(&TDragger::valueChangedCB);
 }
 
 void TDragger::buildFirstInstance()
 {
     SoGroup *geometryGroup = buildGeometry();
 
-    SoSeparator *localTranslator = new SoSeparator();
+    auto localTranslator = new SoSeparator();
     localTranslator->setName("CSysDynamics_TDragger_Translator");
     localTranslator->addChild(geometryGroup);
     SoFCDB::getStorage()->addChild(localTranslator);
 
-    SoSeparator *localTranslatorActive = new SoSeparator();
+    auto localTranslatorActive = new SoSeparator();
     localTranslatorActive->setName("CSysDynamics_TDragger_TranslatorActive");
-    SoBaseColor *colorActive = new SoBaseColor();
+    auto colorActive = new SoBaseColor();
     colorActive->rgb.setValue(1.0, 1.0, 0.0);
     localTranslatorActive->addChild(colorActive);
     localTranslatorActive->addChild(geometryGroup);
@@ -154,19 +164,19 @@ SoGroup* TDragger::buildGeometry()
     //this builds one leg in the Y+ direction because of default done direction.
     //the location anchor for shapes is the center of shape.
 
-    SoGroup *root = new SoGroup();
+    auto root = new SoGroup();
 
     //cylinder
     float cylinderHeight = 10.0;
     float cylinderRadius = 0.2f;
-    SoSeparator *cylinderSeparator = new SoSeparator();
+    auto cylinderSeparator = new SoSeparator();
     root->addChild(cylinderSeparator);
 
-    SoTranslation *cylinderTranslation = new SoTranslation();
+    auto cylinderTranslation = new SoTranslation();
     cylinderTranslation->translation.setValue(0.0, cylinderHeight / 2.0, 0.0);
     cylinderSeparator->addChild(cylinderTranslation);
 
-    SoCylinder *cylinder = new SoCylinder();
+    auto cylinder = new SoCylinder();
     cylinder->radius.setValue(cylinderRadius);
     cylinder->height.setValue(cylinderHeight);
     cylinderSeparator->addChild(cylinder);
@@ -174,19 +184,19 @@ SoGroup* TDragger::buildGeometry()
     //cone
     float coneBottomRadius = 1.0;
     float coneHeight = 2.0;
-    SoSeparator *coneSeparator = new SoSeparator();
+    auto coneSeparator = new SoSeparator();
     root->addChild(coneSeparator);
 
-    SoPickStyle *pickStyle = new SoPickStyle();
+    auto pickStyle = new SoPickStyle();
     pickStyle->style.setValue(SoPickStyle::SHAPE);
     pickStyle->setOverride(TRUE);
     coneSeparator->addChild(pickStyle);
 
-    SoTranslation *coneTranslation = new SoTranslation();
+    auto coneTranslation = new SoTranslation();
     coneTranslation->translation.setValue(0.0, cylinderHeight + coneHeight / 2.0, 0.0);
     coneSeparator->addChild(coneTranslation);
 
-    SoCone *cone = new SoCone();
+    auto cone = new SoCone();
     cone->bottomRadius.setValue(coneBottomRadius);
     cone->height.setValue(coneHeight);
     coneSeparator->addChild(cone);
@@ -196,36 +206,42 @@ SoGroup* TDragger::buildGeometry()
 
 void TDragger::startCB(void *, SoDragger *d)
 {
-    TDragger *sudoThis = static_cast<TDragger *>(d);
+    auto sudoThis = static_cast<TDragger *>(d);
+    assert(sudoThis);
     sudoThis->dragStart();
 }
 
 void TDragger::motionCB(void *, SoDragger *d)
 {
-    TDragger *sudoThis = static_cast<TDragger *>(d);
+    auto sudoThis = static_cast<TDragger *>(d);
+    assert(sudoThis);
     sudoThis->drag();
 }
 
 void TDragger::finishCB(void *, SoDragger *d)
 {
-    TDragger *sudoThis = static_cast<TDragger *>(d);
+    auto sudoThis = static_cast<TDragger *>(d);
+    assert(sudoThis);
     sudoThis->dragFinish();
 }
 
 void TDragger::fieldSensorCB(void *f, SoSensor *)
 {
-  TDragger *sudoThis = reinterpret_cast<TDragger *>(f);
+    auto sudoThis = static_cast<TDragger *>(f);
 
-  SbMatrix matrix = sudoThis->getMotionMatrix();
-  sudoThis->workFieldsIntoTransform(matrix);
-  sudoThis->setMotionMatrix(matrix);
+    if(!f)
+      return;
+
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
+    sudoThis->workFieldsIntoTransform(matrix);
+    sudoThis->setMotionMatrix(matrix);
 }
 
 void TDragger::valueChangedCB(void *, SoDragger *d)
 {
-    TDragger *sudoThis = dynamic_cast<TDragger *>(d);
+    auto sudoThis = dynamic_cast<TDragger *>(d);
     assert(sudoThis);
-    SbMatrix matrix = sudoThis->getMotionMatrix();
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
 
     //all this just to get the translation?
     SbVec3f trans, scaleDummy;
@@ -318,7 +334,7 @@ SbBool TDragger::setUpConnections(SbBool onoff, SbBool doitalways)
   }
   else
   {
-    if (this->fieldSensor.getAttachedField() != nullptr)
+    if (this->fieldSensor.getAttachedField())
       this->fieldSensor.detach();
     inherited::setUpConnections(onoff, doitalways);
   }
@@ -363,6 +379,10 @@ RDragger::RDragger()
 {
     SO_KIT_CONSTRUCTOR(RDragger);
 
+#if defined(Q_OS_MAC)
+    this->ref();
+#endif
+
     SO_KIT_ADD_CATALOG_ENTRY(rotatorSwitch, SoSwitch, TRUE, geomSeparator, "", TRUE);
     SO_KIT_ADD_CATALOG_ENTRY(rotator, SoSeparator, TRUE, rotatorSwitch, "", TRUE);
     SO_KIT_ADD_CATALOG_ENTRY(rotatorActive, SoSeparator, TRUE, rotatorSwitch, "", TRUE);
@@ -402,21 +422,27 @@ RDragger::RDragger()
 
 RDragger::~RDragger()
 {
+    fieldSensor.setData(nullptr);
+    fieldSensor.detach();
 
+    this->removeStartCallback(&RDragger::startCB);
+    this->removeMotionCallback(&RDragger::motionCB);
+    this->removeFinishCallback(&RDragger::finishCB);
+    removeValueChangedCallback(&RDragger::valueChangedCB);
 }
 
 void RDragger::buildFirstInstance()
 {
     SoGroup *geometryGroup = buildGeometry();
 
-    SoSeparator *localRotator = new SoSeparator();
+    auto localRotator = new SoSeparator();
     localRotator->setName("CSysDynamics_RDragger_Rotator");
     localRotator->addChild(geometryGroup);
     SoFCDB::getStorage()->addChild(localRotator);
 
-    SoSeparator *localRotatorActive = new SoSeparator();
+    auto localRotatorActive = new SoSeparator();
     localRotatorActive->setName("CSysDynamics_RDragger_RotatorActive");
-    SoBaseColor *colorActive = new SoBaseColor();
+    auto colorActive = new SoBaseColor();
     colorActive->rgb.setValue(1.0, 1.0, 0.0);
     localRotatorActive->addChild(colorActive);
     localRotatorActive->addChild(geometryGroup);
@@ -425,10 +451,10 @@ void RDragger::buildFirstInstance()
 
 SoGroup* RDragger::buildGeometry()
 {
-    SoGroup *root = new SoGroup();
+    auto root = new SoGroup();
 
     //arc
-    SoCoordinate3 *coordinates = new SoCoordinate3();
+    auto coordinates = new SoCoordinate3();
 
     unsigned int segments = 6;
 
@@ -442,11 +468,11 @@ SoGroup* RDragger::buildGeometry()
     }
     root->addChild(coordinates);
 
-    SoLineSet *lineSet = new SoLineSet();
+    auto lineSet = new SoLineSet();
     lineSet->numVertices.setValue(segments + 1);
     root->addChild(lineSet);
 
-    SoPickStyle *pickStyle = new SoPickStyle();
+    auto pickStyle = new SoPickStyle();
     pickStyle->style.setValue(SoPickStyle::SHAPE);
     pickStyle->setOverride(TRUE);
     root->addChild(pickStyle);
@@ -455,11 +481,11 @@ SoGroup* RDragger::buildGeometry()
     SbVec3f origin(1.0, 1.0, 0.0);
     origin.normalize();
     origin *= arcRadius;
-    SoTranslation *sphereTranslation = new SoTranslation();
+    auto sphereTranslation = new SoTranslation();
     sphereTranslation->translation.setValue(origin);
     root->addChild(sphereTranslation);
 
-    SoSphere *sphere = new SoSphere();
+    auto sphere = new SoSphere();
     sphere->radius.setValue(1.0);
     root->addChild(sphere);
 
@@ -468,36 +494,42 @@ SoGroup* RDragger::buildGeometry()
 
 void RDragger::startCB(void *, SoDragger *d)
 {
-    RDragger *sudoThis = static_cast<RDragger *>(d);
+    auto sudoThis = static_cast<RDragger *>(d);
+    assert(sudoThis);
     sudoThis->dragStart();
 }
 
 void RDragger::motionCB(void *, SoDragger *d)
 {
-    RDragger *sudoThis = static_cast<RDragger *>(d);
+    auto sudoThis = static_cast<RDragger *>(d);
+    assert(sudoThis);
     sudoThis->drag();
 }
 
 void RDragger::finishCB(void *, SoDragger *d)
 {
-    RDragger *sudoThis = static_cast<RDragger *>(d);
+    auto sudoThis = static_cast<RDragger *>(d);
+    assert(sudoThis);
     sudoThis->dragFinish();
 }
 
 void RDragger::fieldSensorCB(void *f, SoSensor *)
 {
-  RDragger *sudoThis = reinterpret_cast<RDragger *>(f);
+    auto sudoThis = static_cast<RDragger *>(f);
 
-  SbMatrix matrix = sudoThis->getMotionMatrix();
-  sudoThis->workFieldsIntoTransform(matrix);
-  sudoThis->setMotionMatrix(matrix);
+    if(!f)
+      return;
+
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
+    sudoThis->workFieldsIntoTransform(matrix);
+    sudoThis->setMotionMatrix(matrix);
 }
 
 void RDragger::valueChangedCB(void *, SoDragger *d)
 {
-    RDragger *sudoThis = dynamic_cast<RDragger *>(d);
+    auto sudoThis = dynamic_cast<RDragger *>(d);
     assert(sudoThis);
-    SbMatrix matrix = sudoThis->getMotionMatrix();
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
 
     //all this just to get the translation?
     SbVec3f translationDummy, scaleDummy;
@@ -603,7 +635,7 @@ SbBool RDragger::setUpConnections(SbBool onoff, SbBool doitalways)
   }
   else
   {
-    if (this->fieldSensor.getAttachedField() != nullptr)
+    if (this->fieldSensor.getAttachedField())
       this->fieldSensor.detach();
     inherited::setUpConnections(onoff, doitalways);
   }
@@ -615,7 +647,7 @@ int RDragger::roundIncrement(const float &radiansIn)
 {
     int rCount = 0;
 
-    float increment = static_cast<float>(rotationIncrement.getValue());
+    auto increment = static_cast<float>(rotationIncrement.getValue());
     if (fabs(radiansIn) > (increment / 2.0))
     {
         rCount = static_cast<int>(radiansIn / increment);
@@ -758,7 +790,7 @@ SoFCCSysDragger::SoFCCSysDragger()
 
     SoRotation *localRotation;
     SbRotation tempRotation;
-    float angle = static_cast<float>(M_PI / 2.0);
+    auto angle = static_cast<float>(M_PI / 2.0);
     localRotation = SO_GET_ANY_PART(this, "xTranslatorRotation", SoRotation);
     localRotation->rotation.setValue(SbVec3f(0.0, 0.0, -1.0), angle);
     localRotation = SO_GET_ANY_PART(this, "yTranslatorRotation", SoRotation);
@@ -781,7 +813,7 @@ SoFCCSysDragger::SoFCCSysDragger()
 
     //this is for non-autoscale mode. this will be disconnected for autoscale
     //and won't be used. see setUpAutoScale.
-    SoComposeVec3f *scaleEngine = new SoComposeVec3f(); //uses coin ref scheme.
+    auto scaleEngine = new SoComposeVec3f(); //uses coin ref scheme.
     scaleEngine->x.connectFrom(&draggerSize);
     scaleEngine->y.connectFrom(&draggerSize);
     scaleEngine->z.connectFrom(&draggerSize);
@@ -812,6 +844,17 @@ SoFCCSysDragger::SoFCCSysDragger()
 
 SoFCCSysDragger::~SoFCCSysDragger()
 {
+    translationSensor.setData(nullptr);
+    translationSensor.detach();
+    rotationSensor.setData(nullptr);
+    rotationSensor.detach();
+    cameraSensor.setData(nullptr);
+    cameraSensor.detach();
+    idleSensor.setData(nullptr);
+    idleSensor.unschedule();
+
+    removeValueChangedCallback(&SoFCCSysDragger::valueChangedCB);
+    removeFinishCallback(&SoFCCSysDragger::finishDragCB, this);
 }
 
 
@@ -857,10 +900,10 @@ SbBool SoFCCSysDragger::setUpConnections(SbBool onoff, SbBool doitalways)
 
         inherited::setUpConnections(onoff, doitalways);
 
-        if (this->translationSensor.getAttachedField() != nullptr)
+        if (this->translationSensor.getAttachedField())
           this->translationSensor.detach();
 
-        if (this->rotationSensor.getAttachedField() != nullptr)
+        if (this->rotationSensor.getAttachedField())
             this->rotationSensor.detach();
     }
     return !(this->connectionsSetUp = onoff);
@@ -868,27 +911,31 @@ SbBool SoFCCSysDragger::setUpConnections(SbBool onoff, SbBool doitalways)
 
 void SoFCCSysDragger::translationSensorCB(void *f, SoSensor *)
 {
-    SoFCCSysDragger *sudoThis = reinterpret_cast<SoFCCSysDragger *>(f);
+    auto sudoThis = static_cast<SoFCCSysDragger *>(f);
+    if(!f)
+      return;
 
-    SbMatrix matrix = sudoThis->getMotionMatrix();
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
     sudoThis->workFieldsIntoTransform(matrix);
     sudoThis->setMotionMatrix(matrix);
 }
 
 void SoFCCSysDragger::rotationSensorCB(void *f, SoSensor *)
 {
-    SoFCCSysDragger *sudoThis = reinterpret_cast<SoFCCSysDragger *>(f);
+    auto sudoThis = static_cast<SoFCCSysDragger *>(f);
+    if(!f)
+      return;
 
-    SbMatrix matrix = sudoThis->getMotionMatrix();
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
     sudoThis->workFieldsIntoTransform(matrix);
     sudoThis->setMotionMatrix(matrix);
 }
 
 void SoFCCSysDragger::valueChangedCB(void *, SoDragger *d)
 {
-    SoFCCSysDragger *sudoThis = dynamic_cast<SoFCCSysDragger *>(d);
+    auto sudoThis = dynamic_cast<SoFCCSysDragger *>(d);
     assert(sudoThis);
-    SbMatrix matrix = sudoThis->getMotionMatrix();
+    SbMatrix matrix = sudoThis->getMotionMatrix(); // clazy:exclude=rule-of-two-soft
 
     //all this just to get the translation?
     SbVec3f localTranslation, scaleDummy;
@@ -913,7 +960,7 @@ void SoFCCSysDragger::setUpAutoScale(SoCamera *cameraIn)
     //checking current attachment state.
     if (cameraIn->getTypeId() == SoOrthographicCamera::getClassTypeId())
     {
-        SoOrthographicCamera *localCamera = dynamic_cast<SoOrthographicCamera *>(cameraIn);
+        auto localCamera = dynamic_cast<SoOrthographicCamera *>(cameraIn);
         assert(localCamera);
         cameraSensor.attach(&localCamera->height);
         SoScale *localScaleNode = SO_GET_ANY_PART(this, "scaleNode", SoScale);
@@ -923,7 +970,7 @@ void SoFCCSysDragger::setUpAutoScale(SoCamera *cameraIn)
     }
     else if (cameraIn->getTypeId() == SoPerspectiveCamera::getClassTypeId())
     {
-        SoPerspectiveCamera *localCamera = dynamic_cast<SoPerspectiveCamera *>(cameraIn);
+        auto localCamera = dynamic_cast<SoPerspectiveCamera *>(cameraIn);
         assert(localCamera);
         cameraSensor.attach(&localCamera->position);
         SoScale *localScaleNode = SO_GET_ANY_PART(this, "scaleNode", SoScale);
@@ -935,7 +982,9 @@ void SoFCCSysDragger::setUpAutoScale(SoCamera *cameraIn)
 
 void SoFCCSysDragger::cameraCB(void *data, SoSensor *)
 {
-    SoFCCSysDragger *sudoThis = reinterpret_cast<SoFCCSysDragger *>(data);
+    auto sudoThis = static_cast<SoFCCSysDragger *>(data);
+    if (!sudoThis)
+      return;
     if (!sudoThis->idleSensor.isScheduled())
         sudoThis->idleSensor.schedule();
 }
@@ -980,11 +1029,13 @@ void SoFCCSysDragger::handleEvent(SoHandleEventAction * action)
 
 void SoFCCSysDragger::idleCB(void *data, SoSensor *)
 {
-    SoFCCSysDragger *sudoThis = reinterpret_cast<SoFCCSysDragger *>(data);
+    auto sudoThis = static_cast<SoFCCSysDragger *>(data);
+    if (!data)
+      return;
     SoField* field = sudoThis->cameraSensor.getAttachedField();
     if (field)
     {
-        SoCamera* camera = static_cast<SoCamera*>(field->getContainer());
+        auto camera = static_cast<SoCamera*>(field->getContainer());
         SbMatrix localToWorld = sudoThis->getLocalToWorldMatrix();
         SbVec3f origin;
         localToWorld.multVecMatrix(SbVec3f(0.0, 0.0, 0.0), origin);
@@ -1003,7 +1054,8 @@ void SoFCCSysDragger::idleCB(void *data, SoSensor *)
 
 void SoFCCSysDragger::finishDragCB(void *data, SoDragger *)
 {
-    SoFCCSysDragger *sudoThis = reinterpret_cast<SoFCCSysDragger *>(data);
+    auto sudoThis = static_cast<SoFCCSysDragger *>(data);
+    assert(sudoThis);
 
     // note: when creating a second view of the document and then closing
     // the first viewer it deletes the camera. However, the attached field
@@ -1011,7 +1063,7 @@ void SoFCCSysDragger::finishDragCB(void *data, SoDragger *)
     SoField* field = sudoThis->cameraSensor.getAttachedField();
     if (field)
     {
-        SoCamera* camera = static_cast<SoCamera*>(field->getContainer());
+        auto camera = static_cast<SoCamera*>(field->getContainer());
         if (camera->getTypeId() == SoPerspectiveCamera::getClassTypeId())
             cameraCB(sudoThis, nullptr);
     }
