@@ -62,8 +62,8 @@ public:
     SoSFFloat autoScaleResult; //!< set from parent dragger.
 
 protected:
-    virtual ~TDragger() override;
-    virtual SbBool setUpConnections(SbBool onoff, SbBool doitalways = FALSE) override;
+    ~TDragger() override;
+    SbBool setUpConnections(SbBool onoff, SbBool doitalways = FALSE) override;
 
     static void startCB(void *, SoDragger * d);
     static void motionCB(void *, SoDragger * d);
@@ -82,7 +82,7 @@ private:
     void buildFirstInstance();
     SbVec3f roundTranslation(const SbVec3f &vecIn, float incrementIn);
     SoGroup* buildGeometry();
-    typedef SoDragger inherited;
+    using inherited = SoDragger;
 };
 
 /*! @brief Rotation Dragger.
@@ -107,8 +107,8 @@ public:
     SoSFColor color; //!< set from outside. non-active color.
 
 protected:
-    virtual ~RDragger() override;
-    virtual SbBool setUpConnections(SbBool onoff, SbBool doitalways = FALSE) override;
+    ~RDragger() override;
+    SbBool setUpConnections(SbBool onoff, SbBool doitalways = FALSE) override;
 
     static void startCB(void *, SoDragger * d);
     static void motionCB(void *, SoDragger * d);
@@ -128,7 +128,7 @@ private:
     void buildFirstInstance();
     int roundIncrement(const float &radiansIn);
     SoGroup* buildGeometry();
-    typedef SoDragger inherited;
+    using inherited = SoDragger;
 };
 
 /*! @brief Coordinate System Dragger
@@ -267,7 +267,7 @@ private:
 
     void updateAxisScale();
 
-    typedef SoDragger inherited;
+    using inherited = SoDragger;
 };
 
 }
