@@ -57,7 +57,7 @@ namespace Gui {
  *  \author Jürgen Riegel
  */
 class GuiExport SoFCSelection : public SoGroup {
-    typedef SoGroup inherited;
+    using inherited = SoGroup;
 
     SO_NODE_HEADER(Gui::SoFCSelection);
 
@@ -99,25 +99,25 @@ public:
     SoSFString subElementName;
     SoSFBool useNewSelection;
 
-    virtual void doAction(SoAction *action);
-    virtual void GLRender(SoGLRenderAction * action);
+    void doAction(SoAction *action) override;
+    void GLRender(SoGLRenderAction * action) override;
 
-    virtual void handleEvent(SoHandleEventAction * action);
-    virtual void GLRenderBelowPath(SoGLRenderAction * action);
-    virtual void GLRenderInPath(SoGLRenderAction * action);
+    void handleEvent(SoHandleEventAction * action) override;
+    void GLRenderBelowPath(SoGLRenderAction * action) override;
+    void GLRenderInPath(SoGLRenderAction * action) override;
     static  void turnOffCurrentHighlight(SoGLRenderAction * action);
 
 protected:
-    virtual ~SoFCSelection();
+    ~SoFCSelection() override;
 
-    typedef SoFCSelectionContext SelContext;
-    typedef std::shared_ptr<SelContext> SelContextPtr;
+    using SelContext = SoFCSelectionContext;
+    using SelContextPtr = std::shared_ptr<SelContext>;
     SelContextPtr selContext;
     SelContextPtr selContext2;
 
     virtual void redrawHighlighted(SoAction * act, SbBool flag);
 
-    virtual SbBool readInstance(SoInput *  in, unsigned short  flags);
+    SbBool readInstance(SoInput *  in, unsigned short  flags) override;
 
 private:
     static int getPriority(const SoPickedPoint*);
