@@ -1008,10 +1008,10 @@ SoBoxSelectionRenderActionP::initBoxGraph()
     this->drawstyle->style = SoDrawStyleElement::LINES;
     this->basecolor = new SoBaseColor;
 
-    SoLightModel * lightmodel = new SoLightModel;
+    auto lightmodel = new SoLightModel;
     lightmodel->model = SoLightModel::BASE_COLOR;
 
-    SoComplexity * complexity = new SoComplexity;
+    auto complexity = new SoComplexity;
     complexity->textureQuality = 0.0f;
     complexity->type = SoComplexityTypeElement::BOUNDING_BOX;
 
@@ -1030,7 +1030,7 @@ SoBoxSelectionRenderActionP::initBoxGraph()
 void
 SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
 {
-    if (this->camerasearch == nullptr) {
+    if (!this->camerasearch) {
         this->camerasearch = new SoSearchAction;
     }
 
@@ -1038,7 +1038,7 @@ SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
     this->camerasearch->setFind(SoSearchAction::TYPE);
     this->camerasearch->setInterest(SoSearchAction::LAST);
     this->camerasearch->setType(SoCamera::getClassTypeId());
-    this->camerasearch->apply((SoPath*) path);
+    this->camerasearch->apply(const_cast<SoPath*>(path));
 
     if (!this->camerasearch->getPath()) {
         // if there is no camera there is no point rendering the bbox
@@ -1047,11 +1047,11 @@ SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
     this->localRoot->insertChild(this->camerasearch->getPath()->getTail(), 0);
     this->camerasearch->reset();
 
-    if (this->bboxaction == nullptr) {
+    if (!this->bboxaction) {
         this->bboxaction = new SoGetBoundingBoxAction(SbViewportRegion(100, 100));
     }
     this->bboxaction->setViewportRegion(PUBLIC(this)->getViewportRegion());
-    this->bboxaction->apply((SoPath*) path);
+    this->bboxaction->apply(const_cast<SoPath*>(path));
 
     SbXfBox3f & box = this->bboxaction->getXfBoundingBox();
 
@@ -1063,7 +1063,7 @@ SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
         this->cube->height  = y;
         this->cube->depth = z;
 
-        SbMatrix transform = box.getTransform();
+        SbMatrix transform = box.getTransform(); // clazy:exclude=rule-of-two-soft
 
         // get center (in the local bbox coordinate system)
         SbVec3f center = box.SbBox3f::getCenter();
@@ -1116,7 +1116,6 @@ SoBoxSelectionRenderAction::constructorCommon()
     // Initialize local variables
     PRIVATE(this)->initBoxGraph();
 
-    // this->hlVisible = true;
     this->hlVisible = false;
 
     PRIVATE(this)->basecolor->rgb.setValue(1.0f, 0.0f, 0.0f);
@@ -1154,7 +1153,7 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
 {
     SoGLRenderAction::apply(node);
     if (this->hlVisible) {
-        if (PRIVATE(this)->searchaction == nullptr) {
+        if (!PRIVATE(this)->searchaction) {
             PRIVATE(this)->searchaction = new SoSearchAction;
         }
         PRIVATE(this)->searchaction->setType(SoFCSelection::getClassTypeId());
@@ -1165,11 +1164,11 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
             for (int i = 0; i < pathlist.getLength(); i++ ) {
                 SoPath * path = pathlist[i];
                 assert(path);
-                SoFCSelection * selection = (SoFCSelection *) path->getTail();
+                auto selection = static_cast<SoFCSelection *>(path->getTail());
                 assert(selection->getTypeId().isDerivedFrom(SoFCSelection::getClassTypeId()));
                 if (selection->selected.getValue() && selection->style.getValue() == SoFCSelection::BOX) {
                     PRIVATE(this)->basecolor->rgb.setValue(selection->colorSelection.getValue());
-                    if (PRIVATE(this)->selectsearch == nullptr) {
+                    if (!PRIVATE(this)->selectsearch) {
                         PRIVATE(this)->selectsearch = new SoSearchAction;
                     }
                     PRIVATE(this)->selectsearch->setType(SoShape::getClassTypeId());
@@ -1188,8 +1187,8 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
                          selection->style.getValue() == SoFCSelection::BOX) {
                     PRIVATE(this)->basecolor->rgb.setValue(selection->colorHighlight.getValue());
 
-                    if (PRIVATE(this)->selectsearch == nullptr) {
-                      PRIVATE(this)->selectsearch = new SoSearchAction;
+                    if (!PRIVATE(this)->selectsearch) {
+                        PRIVATE(this)->selectsearch = new SoSearchAction;
                     }
                     PRIVATE(this)->selectsearch->setType(SoShape::getClassTypeId());
                     PRIVATE(this)->selectsearch->setInterest(SoSearchAction::FIRST);
@@ -1220,7 +1219,7 @@ SoBoxSelectionRenderAction::apply(SoPath * path)
     SoGLRenderAction::apply(path);
     SoNode* node = path->getTail();
     if (node && node->getTypeId() == SoFCSelection::getClassTypeId()) {
-        SoFCSelection * selection = (SoFCSelection *) node;
+        auto selection = static_cast<SoFCSelection *>(node);
 
         // This happens when dehighlighting the current shape
         if (PRIVATE(this)->highlightPath == path) {
@@ -1236,8 +1235,8 @@ SoBoxSelectionRenderAction::apply(SoPath * path)
                  selection->style.getValue() == SoFCSelection::BOX) {
             PRIVATE(this)->basecolor->rgb.setValue(selection->colorHighlight.getValue());
 
-            if (PRIVATE(this)->selectsearch == nullptr) {
-              PRIVATE(this)->selectsearch = new SoSearchAction;
+            if (!PRIVATE(this)->selectsearch) {
+                PRIVATE(this)->selectsearch = new SoSearchAction;
             }
             PRIVATE(this)->selectsearch->setType(SoShape::getClassTypeId());
             PRIVATE(this)->selectsearch->setInterest(SoSearchAction::FIRST);
@@ -1306,7 +1305,7 @@ void
 SoBoxSelectionRenderAction::drawBoxes(SoPath * pathtothis, const SoPathList * pathlist)
 {
     int i;
-    int thispos = ((SoFullPath *)pathtothis)->getLength()-1;
+    int thispos = static_cast<SoFullPath *>(pathtothis)->getLength()-1;
     assert(thispos >= 0);
     PRIVATE(this)->postprocpath->truncate(0); // reset
 
@@ -1322,7 +1321,7 @@ SoBoxSelectionRenderAction::drawBoxes(SoPath * pathtothis, const SoPathList * pa
     thestate->push();
 
     for (i = 0; i < pathlist->getLength(); i++) {
-        SoFullPath * path = (SoFullPath *)(*pathlist)[i];
+        auto path = static_cast<SoFullPath *>((*pathlist)[i]);
 
         for (int j = 0; j < path->getLength(); j++) {
             PRIVATE(this)->postprocpath->append(path->getNode(j));
