@@ -21,14 +21,20 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
+
 #ifndef _PreComp_
 # include <cstdlib>
 # include <QApplication>
 # include <QClipboard>
+# include <QFile>
+# include <QFileInfo>
 # include <QLocale>
 # include <QMutex>
 # include <QProcessEnvironment>
+# include <QRegularExpression>
+# include <QRegularExpressionMatch>
 # include <QScreen>
+# include <QSettings>
 # include <QSysInfo>
 # include <QTextBrowser>
 # include <QTextStream>
@@ -55,49 +61,114 @@ using namespace Gui::Dialog;
 namespace fs = boost::filesystem;
 
 namespace Gui {
+
+QString prettyProductInfoWrapper()
+{
+    auto productName = QSysInfo::prettyProductName();
+#if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
+#ifdef FC_OS_MACOSX
+    auto macosVersionFile = QString::fromUtf8("/System/Library/CoreServices/.SystemVersionPlatform.plist");
+    auto fi = QFileInfo (macosVersionFile);
+    if (fi.exists() && fi.isReadable()) {
+        auto plistFile = QFile(macosVersionFile);
+        plistFile.open(QIODevice::ReadOnly);
+        while (!plistFile.atEnd()) {
+            auto line = plistFile.readLine();
+            if (line.contains("ProductUserVisibleVersion")) {
+                auto nextLine = plistFile.readLine();
+                if (nextLine.contains("<string>")) {
+                    QRegularExpression re(QString::fromUtf8("\\s*<string>(.*)</string>"));
+                    auto matches = re.match(QString::fromUtf8(nextLine));
+                    if (matches.hasMatch()) {
+                        productName = QString::fromUtf8("macOS ") + matches.captured(1);
+                        break;
+                    }
+                }
+            }
+        }
+    }
+#endif
+#endif
+#ifdef FC_OS_WIN64
+    QSettings regKey {QString::fromUtf8("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion"), QSettings::NativeFormat};
+    if (regKey.contains(QString::fromUtf8("CurrentBuildNumber"))) {
+        auto buildNumber = regKey.value(QString::fromUtf8("CurrentBuildNumber")).toInt();
+        if (buildNumber > 0) {
+            if (buildNumber < 9200) {
+                productName = QString::fromUtf8("Windows 7 build %1").arg(buildNumber);
+            }
+            else if (buildNumber < 10240) {
+                productName = QString::fromUtf8("Windows 8 build %1").arg(buildNumber);
+            }
+            else if (buildNumber < 22000) {
+                productName = QString::fromUtf8("Windows 10 build %1").arg(buildNumber);
+            }
+            else {
+                productName = QString::fromUtf8("Windows 11 build %1").arg(buildNumber);
+            }
+        }
+    }
+#endif
+    return productName;
+}
+
 /** Displays all messages at startup inside the splash screen.
  * \author Werner Mayer
  */
 class SplashObserver : public Base::ILogger
 {
 public:
-    SplashObserver(QSplashScreen* splasher=nullptr)
-      : splash(splasher), alignment(Qt::AlignBottom|Qt::AlignLeft), textColor(Qt::black)
+    SplashObserver(const SplashObserver&) = delete;
+    SplashObserver(SplashObserver&&) = delete;
+    SplashObserver& operator= (const SplashObserver&) = delete;
+    SplashObserver& operator= (SplashObserver&&) = delete;
+
+    explicit SplashObserver(QSplashScreen* splasher=nullptr)
+      : splash(splasher)
+      , alignment(Qt::AlignBottom|Qt::AlignLeft)
+      , textColor(Qt::black)
     {
         Base::Console().AttachObserver(this);
 
         // allow to customize text position and color
-        const std::map<std::string,std::string>& cfg = App::GetApplication().Config();
-        std::map<std::string,std::string>::const_iterator al = cfg.find("SplashAlignment");
+        const std::map<std::string,std::string>& cfg = App::Application::Config();
+        auto al = cfg.find("SplashAlignment");
         if (al != cfg.end()) {
             QString alt = QString::fromLatin1(al->second.c_str());
             int align=0;
-            if (alt.startsWith(QLatin1String("VCenter")))
+            if (alt.startsWith(QLatin1String("VCenter"))) {
                 align = Qt::AlignVCenter;
-            else if (alt.startsWith(QLatin1String("Top")))
+            }
+            else if (alt.startsWith(QLatin1String("Top"))) {
                 align = Qt::AlignTop;
-            else
+            }
+            else {
                 align = Qt::AlignBottom;
+            }
 
-            if (alt.endsWith(QLatin1String("HCenter")))
+            if (alt.endsWith(QLatin1String("HCenter"))) {
                 align += Qt::AlignHCenter;
-            else if (alt.endsWith(QLatin1String("Right")))
+            }
+            else if (alt.endsWith(QLatin1String("Right"))) {
                 align += Qt::AlignRight;
-            else
+            }
+            else {
                 align += Qt::AlignLeft;
+            }
 
             alignment = align;
         }
 
         // choose text color
-        std::map<std::string,std::string>::const_iterator tc = cfg.find("SplashTextColor");
+        auto tc = cfg.find("SplashTextColor");
         if (tc != cfg.end()) {
             QColor col; col.setNamedColor(QString::fromLatin1(tc->second.c_str()));
-            if (col.isValid())
+            if (col.isValid()) {
                 textColor = col;
+            }
         }
     }
-    virtual ~SplashObserver()
+    ~SplashObserver() override
     {
         Base::Console().DetachObserver(this);
     }
@@ -105,8 +176,13 @@ public:
     {
         return "SplashObserver";
     }
-    void SendLog(const std::string& msg, Base::LogStyle level) override
+    void SendLog(const std::string& notifiername, const std::string& msg, Base::LogStyle level,
+                 Base::IntendedRecipient recipient, Base::ContentType content) override
     {
+        Q_UNUSED(notifiername)
+        Q_UNUSED(recipient)
+        Q_UNUSED(content)
+
 #ifdef FC_DEBUG
         Log(msg.c_str());
         Q_UNUSED(level)
@@ -116,21 +192,21 @@ public:
         }
 #endif
     }
-    void Log (const char * s)
+    void Log (const char * text)
     {
-        QString msg(QString::fromUtf8(s));
-        QRegExp rx;
+        QString msg(QString::fromUtf8(text));
+        QRegularExpression rx;
         // ignore 'Init:' and 'Mod:' prefixes
         rx.setPattern(QLatin1String("^\\s*(Init:|Mod:)\\s*"));
-        int pos = rx.indexIn(msg);
-        if (pos != -1) {
-            msg = msg.mid(rx.matchedLength());
+        auto match = rx.match(msg);
+        if (match.hasMatch()) {
+            msg = msg.mid(match.capturedLength());
         }
         else {
             // ignore activation of commands
             rx.setPattern(QLatin1String("^\\s*(\\+App::|Create|CmdC:|CmdG:|Act:)\\s*"));
-            pos = rx.indexIn(msg);
-            if (pos == 0)
+            match = rx.match(msg);
+            if (match.hasMatch() && match.capturedStart() == 0)
                 return;
         }
 
@@ -174,6 +250,14 @@ void SplashScreen::drawContents ( QPainter * painter )
     QSplashScreen::drawContents(painter);
 }
 
+void SplashScreen::setShowMessages(bool on)
+{
+    messages->bErr = on;
+    messages->bMsg = on;
+    messages->bLog = on;
+    messages->bWrn = on;
+}
+
 // ------------------------------------------------------------------------------
 
 AboutDialogFactory* AboutDialogFactory::factory = nullptr;
@@ -223,6 +307,8 @@ AboutDialog::AboutDialog(bool showLic, QWidget* parent)
 
     setModal(true);
     ui->setupUi(this);
+    connect(ui->copyButton, &QPushButton::clicked,
+            this, &AboutDialog::copyToClipboard);
 
     // remove the automatic help button in dialog title since we don't use it
     setWindowFlag(Qt::WindowContextHelpButtonHint, false);
@@ -311,7 +397,7 @@ void AboutDialog::setupLabels()
     ui->labelAuthor->setUrl(mturl);
 
     if (qApp->styleSheet().isEmpty()) {
-        ui->labelAuthor->setStyleSheet(QString::fromLatin1("Gui--UrlLabel {color: #0000FF;text-decoration: underline;font-weight: 600;font-family: MS Shell Dlg 2;}"));
+        ui->labelAuthor->setStyleSheet(QString::fromLatin1("Gui--UrlLabel {color: #0000FF;text-decoration: underline;font-weight: 600;}"));
     }
 
     QString version = ui->labelBuildVersion->text();
@@ -327,7 +413,7 @@ void AboutDialog::setupLabels()
     ui->labelBuildDate->setText(date);
 
     QString os = ui->labelBuildOS->text();
-    os.replace(QString::fromLatin1("Unknown"), QSysInfo::prettyProductName());
+    os.replace(QString::fromLatin1("Unknown"), prettyProductInfoWrapper());
     ui->labelBuildOS->setText(os);
 
     QString platform = ui->labelBuildPlatform->text();
@@ -377,9 +463,9 @@ void AboutDialog::setupLabels()
 class AboutDialog::LibraryInfo {
 public:
     QString name;
-    QString version;
     QString href;
     QString url;
+    QString version;
 };
 
 void AboutDialog::showCredits()
@@ -391,11 +477,11 @@ void AboutDialog::showCredits()
         return;
     }
 
-    QWidget* tab_credits = new QWidget();
+    auto tab_credits = new QWidget();
     tab_credits->setObjectName(QString::fromLatin1("tab_credits"));
     ui->tabWidget->addTab(tab_credits, tr("Credits"));
-    QVBoxLayout* hlayout = new QVBoxLayout(tab_credits);
-    QTextBrowser* textField = new QTextBrowser(tab_credits);
+    auto hlayout = new QVBoxLayout(tab_credits);
+    auto textField = new QTextBrowser(tab_credits);
     textField->setOpenExternalLinks(false);
     textField->setOpenLinks(false);
     hlayout->addWidget(textField);
@@ -411,7 +497,9 @@ void AboutDialog::showCredits()
     creditsHTML += QString::fromLatin1("</h2><ul>");
 
     QTextStream stream(&creditsFile);
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
     stream.setCodec("UTF-8");
+#endif
     QString line;
     while (stream.readLineInto(&line)) {
         if (!line.isEmpty()) {
@@ -443,11 +531,11 @@ void AboutDialog::showLicenseInformation()
 
         ui->tabWidget->removeTab(1); // Hide the license placeholder widget
 
-        QWidget* tab_license = new QWidget();
+        auto tab_license = new QWidget();
         tab_license->setObjectName(QString::fromLatin1("tab_license"));
         ui->tabWidget->addTab(tab_license, tr("License"));
-        QVBoxLayout* hlayout = new QVBoxLayout(tab_license);
-        QTextBrowser* textField = new QTextBrowser(tab_license);
+        auto hlayout = new QVBoxLayout(tab_license);
+        auto textField = new QTextBrowser(tab_license);
         textField->setOpenExternalLinks(true);
         textField->setOpenLinks(true);
         hlayout->addWidget(textField);
@@ -482,154 +570,175 @@ QString AboutDialog::getAdditionalLicenseInformation() const
 
 void AboutDialog::showLibraryInformation()
 {
-    QWidget *tab_library = new QWidget();
+    auto tab_library = new QWidget();
     tab_library->setObjectName(QString::fromLatin1("tab_library"));
     ui->tabWidget->addTab(tab_library, tr("Libraries"));
-    QVBoxLayout* hlayout = new QVBoxLayout(tab_library);
-    QTextBrowser* textField = new QTextBrowser(tab_library);
+    auto hlayout = new QVBoxLayout(tab_library);
+    auto textField = new QTextBrowser(tab_library);
     textField->setOpenExternalLinks(false);
     textField->setOpenLinks(false);
     hlayout->addWidget(textField);
 
     QList<LibraryInfo> libInfo;
-    LibraryInfo li;
     QString baseurl = QString::fromLatin1("file:///%1/ThirdPartyLibraries.html")
             .arg(QString::fromUtf8(App::Application::getHelpDir().c_str()));
 
     // Boost
-    li.name = QLatin1String("Boost");
-    li.href = baseurl + QLatin1String("#_TocBoost");
-    li.url = QLatin1String("https://www.boost.org");
-    li.version = QLatin1String(BOOST_LIB_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Boost"),
+        baseurl + QLatin1String("#_TocBoost"),
+        QLatin1String("https://www.boost.org"),
+        QLatin1String(BOOST_LIB_VERSION)
+    };
 
     // Coin3D
-    li.name = QLatin1String("Coin3D");
-    li.href = baseurl + QLatin1String("#_TocCoin3D");
-    li.url = QLatin1String("https://coin3d.github.io");
-    li.version = QLatin1String(COIN_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Coin3D"),
+        baseurl + QLatin1String("#_TocCoin3D"),
+        QLatin1String("https://coin3d.github.io"),
+        QLatin1String(COIN_VERSION)
+    };
 
     // Eigen3
-    li.name = QLatin1String("Eigen");
-    li.href = baseurl + QLatin1String("#_TocEigen");
-    li.url = QLatin1String("https://eigen.tuxfamily.org");
-    li.version = QString::fromLatin1(FC_EIGEN3_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Eigen"),
+        baseurl + QLatin1String("#_TocEigen"),
+        QLatin1String("https://eigen.tuxfamily.org"),
+        QString::fromLatin1(fcEigen3Version)
+    };
 
     // FreeType
-    li.name = QLatin1String("FreeType");
-    li.href = baseurl + QLatin1String("#_TocFreeType");
-    li.url = QLatin1String("https://freetype.org");
-    li.version = QString::fromLatin1(FC_FREETYPE_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("FreeType"),
+        baseurl + QLatin1String("#_TocFreeType"),
+        QLatin1String("https://freetype.org"),
+        QString::fromLatin1(fcFreetypeVersion)
+    };
 
     // KDL
-    li.name = QLatin1String("KDL");
-    li.href = baseurl + QLatin1String("#_TocKDL");
-    li.url = QLatin1String("https://www.orocos.org/kdl");
-    li.version.clear();
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("KDL"),
+        baseurl + QLatin1String("#_TocKDL"),
+        QLatin1String("https://www.orocos.org/kdl"),
+        QString()
+    };
 
     // libarea
-    li.name = QLatin1String("libarea");
-    li.href = baseurl + QLatin1String("#_TocLibArea");
-    li.url = QLatin1String("https://github.com/danielfalck/libarea");
-    li.version.clear();
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("libarea"),
+        baseurl + QLatin1String("#_TocLibArea"),
+        QLatin1String("https://github.com/danielfalck/libarea"),
+        QString()
+    };
 
     // OCCT
 #if defined(HAVE_OCC_VERSION)
-    li.name = QLatin1String("Open CASCADE Technology");
-    li.href = baseurl + QLatin1String("#_TocOCCT");
-    li.url = QLatin1String("https://www.opencascade.com/open-cascade-technology/");
-    li.version = QLatin1String(OCC_VERSION_STRING_EXT);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Open CASCADE Technology"),
+        baseurl + QLatin1String("#_TocOCCT"),
+        QLatin1String("https://www.opencascade.com/open-cascade-technology/"),
+        QLatin1String(OCC_VERSION_STRING_EXT)
+    };
 #endif
 
     // pcl
-    li.name = QLatin1String("Point Cloud Library");
-    li.href = baseurl + QLatin1String("#_TocPcl");
-    li.url = QLatin1String("https://www.pointclouds.org");
-    li.version = QString::fromLatin1(FC_PCL_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Point Cloud Library"),
+        baseurl + QLatin1String("#_TocPcl"),
+        QLatin1String("https://www.pointclouds.org"),
+        QString::fromLatin1(fcPclVersion)
+    };
 
     // PyCXX
-    li.name = QLatin1String("PyCXX");
-    li.href = baseurl + QLatin1String("#_TocPyCXX");
-    li.url = QLatin1String("http://cxx.sourceforge.net");
-    li.version = QString::fromLatin1(FC_PYCXX_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("PyCXX"),
+        baseurl + QLatin1String("#_TocPyCXX"),
+        QLatin1String("http://cxx.sourceforge.net"),
+        QString::fromLatin1(fcPycxxVersion)
+    };
 
     // Python
-    li.name = QLatin1String("Python");
-    li.href = baseurl + QLatin1String("#_TocPython");
-    li.url = QLatin1String("https://www.python.org");
-    li.version = QLatin1String(PY_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Python"),
+        baseurl + QLatin1String("#_TocPython"),
+        QLatin1String("https://www.python.org"),
+        QLatin1String(PY_VERSION)
+    };
 
     // PySide
-    li.name = QLatin1String("Qt for Python (PySide)");
-    li.href = baseurl + QLatin1String("#_TocPySide");
-    li.url = QLatin1String("https://wiki.qt.io/Qt_for_Python");
-    li.version = QString::fromLatin1(FC_PYSIDE_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Qt for Python (PySide)"),
+        baseurl + QLatin1String("#_TocPySide"),
+        QLatin1String("https://wiki.qt.io/Qt_for_Python"),
+        QString::fromLatin1(fcPysideVersion)
+    };
 
     // Qt
-    li.name = QLatin1String("Qt");
-    li.href = baseurl + QLatin1String("#_TocQt");
-    li.url = QLatin1String("https://www.qt.io");
-    li.version = QLatin1String(QT_VERSION_STR);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Qt"),
+        baseurl + QLatin1String("#_TocQt"),
+        QLatin1String("https://www.qt.io"),
+        QLatin1String(QT_VERSION_STR)
+    };
 
     // Salome SMESH
-    li.name = QLatin1String("Salome SMESH");
-    li.href = baseurl + QLatin1String("#_TocSalomeSMESH");
-    li.url = QLatin1String("https://salome-platform.org");
-    li.version.clear();
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Salome SMESH"),
+        baseurl + QLatin1String("#_TocSalomeSMESH"),
+        QLatin1String("https://salome-platform.org"),
+#ifdef SMESH_VERSION_STR
+        QLatin1String(SMESH_VERSION_STR)
+#else
+        QString()
+#endif
+    };
 
     // Shiboken
-    li.name = QLatin1String("Qt for Python (Shiboken)");
-    li.href = baseurl + QLatin1String("#_TocPySide");
-    li.url = QLatin1String("https://wiki.qt.io/Qt_for_Python");
-    li.version = QString::fromLatin1(FC_SHIBOKEN_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Qt for Python (Shiboken)"),
+        baseurl + QLatin1String("#_TocPySide"),
+        QLatin1String("https://wiki.qt.io/Qt_for_Python"),
+        QString::fromLatin1(fcShibokenVersion)
+    };
 
     // vtk
-    li.name = QLatin1String("vtk");
-    li.href = baseurl + QLatin1String("#_TocVtk");
-    li.url = QLatin1String("https://www.vtk.org");
-    li.version = QString::fromLatin1(FC_VTK_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("vtk"),
+        baseurl + QLatin1String("#_TocVtk"),
+        QLatin1String("https://www.vtk.org"),
+        QString::fromLatin1(fcVtkVersion)
+    };
 
     // Xerces-C
-    li.name = QLatin1String("Xerces-C");
-    li.href = baseurl + QLatin1String("#_TocXercesC");
-    li.url = QLatin1String("https://xerces.apache.org/xerces-c");
-    li.version = QString::fromLatin1(FC_XERCESC_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Xerces-C"),
+        baseurl + QLatin1String("#_TocXercesC"),
+        QLatin1String("https://xerces.apache.org/xerces-c"),
+        QString::fromLatin1(fcXercescVersion)
+    };
 
     // Zipios++
-    li.name = QLatin1String("Zipios++");
-    li.href = baseurl + QLatin1String("#_TocZipios");
-    li.url = QLatin1String("http://zipios.sourceforge.net");
-    li.version.clear();
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("Zipios++"),
+        baseurl + QLatin1String("#_TocZipios"),
+        QLatin1String("http://zipios.sourceforge.net"),
+        QString()
+    };
 
     // zlib
-    li.name = QLatin1String("zlib");
-    li.href = baseurl + QLatin1String("#_TocZlib");
-    li.url = QLatin1String("https://zlib.net");
-    li.version = QLatin1String(ZLIB_VERSION);
-    libInfo << li;
+    libInfo << LibraryInfo {
+        QLatin1String("zlib"),
+        baseurl + QLatin1String("#_TocZlib"),
+        QLatin1String("https://zlib.net"),
+        QLatin1String(ZLIB_VERSION)
+    };
 
 
     QString msg = tr("This software uses open source components whose copyright and other "
                      "proprietary rights belong to their respective owners:");
     QString html;
     QTextStream out(&html);
-    out << "<html><head/><body style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;\">"
+    out << "<html><head/><body style=\" font-size:8.25pt; font-weight:400; font-style:normal;\">"
         << "<p>" << msg << "<br/></p>\n<ul>\n";
     for (QList<LibraryInfo>::iterator it = libInfo.begin(); it != libInfo.end(); ++it) {
         out << "<li><p>" << it->name << " " << it->version << "</p>"
@@ -649,11 +758,11 @@ void AboutDialog::showCollectionInformation()
     if (!QFile::exists(path))
         return;
 
-    QWidget *tab_collection = new QWidget();
+    auto tab_collection = new QWidget();
     tab_collection->setObjectName(QString::fromLatin1("tab_collection"));
     ui->tabWidget->addTab(tab_collection, tr("Collection"));
-    QVBoxLayout* hlayout = new QVBoxLayout(tab_collection);
-    QTextBrowser* textField = new QTextBrowser(tab_collection);
+    auto hlayout = new QVBoxLayout(tab_collection);
+    auto textField = new QTextBrowser(tab_collection);
     textField->setOpenExternalLinks(true);
     hlayout->addWidget(textField);
     textField->setSource(path);
@@ -661,7 +770,7 @@ void AboutDialog::showCollectionInformation()
 
 void AboutDialog::linkActivated(const QUrl& link)
 {
-    LicenseView* licenseView = new LicenseView();
+    auto licenseView = new LicenseView();
     licenseView->setAttribute(Qt::WA_DeleteOnClose);
     licenseView->show();
     QString title = tr("License");
@@ -675,7 +784,7 @@ void AboutDialog::linkActivated(const QUrl& link)
     licenseView->setSource(link);
 }
 
-void AboutDialog::on_copyButton_clicked()
+void AboutDialog::copyToClipboard()
 {
     QString data;
     QTextStream str(&data);
@@ -688,9 +797,9 @@ void AboutDialog::on_copyButton_clicked()
     QString point  = QString::fromLatin1(config["BuildVersionPoint"].c_str());
     QString build  = QString::fromLatin1(config["BuildRevision"].c_str());
 
-    QString deskEnv = QProcessEnvironment::systemEnvironment().value(QStringLiteral("XDG_CURRENT_DESKTOP"),QStringLiteral(""));
-    QString deskSess = QProcessEnvironment::systemEnvironment().value(QStringLiteral("DESKTOP_SESSION"),QStringLiteral(""));
-    QString deskInfo = QStringLiteral("");
+    QString deskEnv = QProcessEnvironment::systemEnvironment().value(QStringLiteral("XDG_CURRENT_DESKTOP"), QString());
+    QString deskSess = QProcessEnvironment::systemEnvironment().value(QStringLiteral("DESKTOP_SESSION"), QString());
+    QString deskInfo;
 
     if ( !(deskEnv.isEmpty() && deskSess.isEmpty()) ) {
         if ( deskEnv.isEmpty() || deskSess.isEmpty() )
@@ -700,7 +809,7 @@ void AboutDialog::on_copyButton_clicked()
     }
 
     str << "[code]\n";
-    str << "OS: " << QSysInfo::prettyProductName() << deskInfo << '\n';
+    str << "OS: " << prettyProductInfoWrapper() << deskInfo << '\n';
     str << "Word size of " << exe << ": " << QSysInfo::WordSize << "-bit\n";
     str << "Version: " << major << "." << minor << "." << point << "." << build;
     char *appimage = getenv("APPIMAGE");
@@ -730,7 +839,7 @@ void AboutDialog::on_copyButton_clicked()
     str << "Python " << PY_VERSION << ", ";
     str << "Qt " << QT_VERSION_STR << ", ";
     str << "Coin " << COIN_VERSION << ", ";
-    str << "Vtk " << FC_VTK_VERSION << ", ";
+    str << "Vtk " << fcVtkVersion << ", ";
 #if defined(HAVE_OCC_VERSION)
     str << "OCC "
         << OCC_VERSION_MAJOR << "."
@@ -758,14 +867,14 @@ void AboutDialog::on_copyButton_clicked()
     bool firstMod = true;
     if (fs::exists(modDir) && fs::is_directory(modDir)) {
         for (const auto& mod : fs::directory_iterator(modDir)) {
-            auto dirName = mod.path().leaf().string();
+            auto dirName = mod.path().filename().string();
             if (dirName[0] == '.') // Ignore dot directories
                 continue;
             if (firstMod) {
                 firstMod = false;
                 str << "Installed mods: \n";
             }
-            str << "  * " << QString::fromStdString(mod.path().leaf().string());
+            str << "  * " << QString::fromStdString(mod.path().filename().string());
             auto metadataFile = mod.path() / "package.xml";
             if (fs::exists(metadataFile)) {
                 App::Metadata metadata(metadataFile);
