@@ -22,40 +22,32 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-#include <assert.h>
+#include <cassert>
 #include <limits>
 #include <QApplication>
+#include <QGridLayout>
 #endif
 
-#include <QGridLayout>
-#include <QFontMetrics>
-
-#include <Gui/TaskView/TaskView.h>
-#include "QuantitySpinBox.h"
-#include <Gui/Application.h>
-#include <Gui/Command.h>
-#include <Gui/Document.h>
-#include <Gui/BitmapFactory.h>
-#include <Gui/ViewProviderDragger.h>
-#include <Gui/SoFCCSysDragger.h>
-
+#include <App/Document.h>
+#include "Document.h" // must be before TaskCSysDragger.h
 #include "TaskCSysDragger.h"
+#include "Application.h"
+#include "BitmapFactory.h"
+#include "Command.h"
+#include "QuantitySpinBox.h"
+#include "SoFCCSysDragger.h"
+#include "ViewProviderDragger.h"
+#include "TaskView/TaskView.h"
+
 
 using namespace Gui;
 
 
-static double radiansToDegrees(const double &radiansIn)
-{
-  return radiansIn * (180.0 / M_PI);
-}
-
-static double degreesToRadains(const double &degreesIn)
+static double degreesToRadians(const double &degreesIn)
 {
   return degreesIn * (M_PI / 180.0);
 }
 
-static double lastTranslationIncrement = 1.0;
-static double lastRotationIncrement = degreesToRadains(15.0);
 
 TaskCSysDragger::TaskCSysDragger(Gui::ViewProviderDocumentObject* vpObjectIn, Gui::SoFCCSysDragger* draggerIn) :
   dragger(draggerIn)
@@ -75,19 +67,30 @@ TaskCSysDragger::~TaskCSysDragger()
   Gui::Application::Instance->commandManager().getCommandByName("Std_PerspectiveCamera")->setEnabled(true);
 }
 
+void TaskCSysDragger::dragStartCallback(void *, SoDragger *)
+{
+    // This is called when a manipulator is about to manipulating
+  if(firstDrag)
+    {
+       Gui::Application::Instance->activeDocument()->openCommand(QT_TRANSLATE_NOOP("Command", "Transform"));
+       firstDrag=false;
+    }
+}
+
 void TaskCSysDragger::setupGui()
 {
-  Gui::TaskView::TaskBox *incrementsBox = new Gui::TaskView::TaskBox(
+    auto incrementsBox = new Gui::TaskView::TaskBox(
       Gui::BitmapFactory().pixmap("button_valid"),
-      tr("Increments"), true, 0);
+      tr("Increments"), true, nullptr);
 
-  QGridLayout *gridLayout = new QGridLayout();
+    auto gridLayout = new QGridLayout();
   gridLayout->setColumnStretch(1, 1);
 
-  QLabel *tLabel = new QLabel(tr("Translation Increment:"), incrementsBox);
+  auto tLabel = new QLabel(tr("Translation Increment:"), incrementsBox);
   gridLayout->addWidget(tLabel, 0, 0, Qt::AlignRight);
 
-  int spinBoxWidth = QApplication::fontMetrics().averageCharWidth() * 20;
+  QFontMetrics metrics(QApplication::font());
+  int spinBoxWidth = metrics.averageCharWidth() * 20;
   tSpinBox = new QuantitySpinBox(incrementsBox);
   tSpinBox->setMinimum(0.0);
   tSpinBox->setMaximum(std::numeric_limits<double>::max());
@@ -95,7 +98,7 @@ void TaskCSysDragger::setupGui()
   tSpinBox->setMinimumWidth(spinBoxWidth);
   gridLayout->addWidget(tSpinBox, 0, 1, Qt::AlignLeft);
 
-  QLabel *rLabel = new QLabel(tr("Rotation Increment:"), incrementsBox);
+  auto rLabel = new QLabel(tr("Rotation Increment:"), incrementsBox);
   gridLayout->addWidget(rLabel, 1, 0, Qt::AlignRight);
 
   rSpinBox = new QuantitySpinBox(incrementsBox);
@@ -108,8 +111,8 @@ void TaskCSysDragger::setupGui()
   incrementsBox->groupLayout()->addLayout(gridLayout);
   Content.push_back(incrementsBox);
 
-  connect(tSpinBox, SIGNAL(valueChanged(double)), this, SLOT(onTIncrementSlot(double)));
-  connect(rSpinBox, SIGNAL(valueChanged(double)), this, SLOT(onRIncrementSlot(double)));
+  connect(tSpinBox, qOverload<double>(&QuantitySpinBox::valueChanged), this, &TaskCSysDragger::onTIncrementSlot);
+  connect(rSpinBox, qOverload<double>(&QuantitySpinBox::valueChanged), this, &TaskCSysDragger::onRIncrementSlot);
 }
 
 void TaskCSysDragger::onTIncrementSlot(double freshValue)
@@ -119,31 +122,37 @@ void TaskCSysDragger::onTIncrementSlot(double freshValue)
 
 void TaskCSysDragger::onRIncrementSlot(double freshValue)
 {
-  dragger->rotationIncrement.setValue(degreesToRadains(freshValue));
+  dragger->rotationIncrement.setValue(degreesToRadians(freshValue));
 }
 
 void TaskCSysDragger::open()
 {
+  dragger->addStartCallback(dragStartCallback, this);
   //we can't have user switching camera types while dragger is shown.
   Gui::Application::Instance->commandManager().getCommandByName("Std_OrthographicCamera")->setEnabled(false);
   Gui::Application::Instance->commandManager().getCommandByName("Std_PerspectiveCamera")->setEnabled(false);
 //   dragger->translationIncrement.setValue(lastTranslationIncrement);
 //   dragger->rotationIncrement.setValue(lastRotationIncrement);
+  ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/History/Dragger");
+  double lastTranslationIncrement = hGrp->GetFloat("LastTranslationIncrement", 1.0);
+  double lastRotationIncrement = hGrp->GetFloat("LastRotationIncrement", 15.0);
   tSpinBox->setValue(lastTranslationIncrement);
-  rSpinBox->setValue(radiansToDegrees(lastRotationIncrement));
+  rSpinBox->setValue(lastRotationIncrement);
 
   Gui::TaskView::TaskDialog::open();
 }
 
 bool TaskCSysDragger::accept()
 {
-  lastTranslationIncrement = dragger->translationIncrement.getValue();
-  lastRotationIncrement = dragger->rotationIncrement.getValue();
+  ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/History/Dragger");
+  hGrp->SetFloat("LastTranslationIncrement", tSpinBox->rawValue());
+  hGrp->SetFloat("LastRotationIncrement", rSpinBox->rawValue());
 
   App::DocumentObject* dObject = vpObject.getObject();
   if (dObject) {
     Gui::Document* document = Gui::Application::Instance->getDocument(dObject->getDocument());
     assert(document);
+    firstDrag = true;
     document->commitCommand();
     document->resetEdit();
     document->getDocument()->recompute();
@@ -151,4 +160,18 @@ bool TaskCSysDragger::accept()
   return Gui::TaskView::TaskDialog::accept();
 }
 
+bool TaskCSysDragger::reject()
+{
+  App::DocumentObject* dObject = vpObject.getObject();
+  if (dObject) {
+    Gui::Document* document = Gui::Application::Instance->getDocument(dObject->getDocument());
+    assert(document);
+    firstDrag = true;
+    document->abortCommand();
+    document->resetEdit();
+    document->getDocument()->recompute();
+  }
+  return Gui::TaskView::TaskDialog::reject();
+}
+
 #include "moc_TaskCSysDragger.cpp"
