@@ -23,8 +23,11 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <QApplication>
 # include <QKeyEvent>
 # include <QPainter>
+# include <QRegularExpression>
+# include <QRegularExpressionMatch>
 # include <QShortcut>
 # include <QTextCursor>
 #endif
@@ -32,6 +35,7 @@
 #include "TextEdit.h"
 #include "SyntaxHighlighter.h"
 #include "Tools.h"
+#include <App/Color.h>
 
 
 using namespace Gui;
@@ -44,25 +48,25 @@ TextEdit::TextEdit(QWidget* parent)
 {
     //Note: Set the correct context to this shortcut as we may use several instances of this
     //class at a time
-    QShortcut* shortcut = new QShortcut(this);
+    auto shortcut = new QShortcut(this);
     shortcut->setKey(QKeySequence(QString::fromLatin1("CTRL+Space")));
     shortcut->setContext(Qt::WidgetShortcut);
-    connect(shortcut, SIGNAL(activated()), this, SLOT(complete()));
+    connect(shortcut, &QShortcut::activated, this, &TextEdit::complete);
 
-    QShortcut* shortcutFind = new QShortcut(this);
+    auto shortcutFind = new QShortcut(this);
     shortcutFind->setKey(QKeySequence::Find);
     shortcutFind->setContext(Qt::WidgetShortcut);
-    connect(shortcutFind, SIGNAL(activated()), this, SIGNAL(showSearchBar()));
+    connect(shortcutFind, &QShortcut::activated, this, &TextEdit::showSearchBar);
 
-    QShortcut* shortcutNext = new QShortcut(this);
+    auto shortcutNext = new QShortcut(this);
     shortcutNext->setKey(QKeySequence::FindNext);
     shortcutNext->setContext(Qt::WidgetShortcut);
-    connect(shortcutNext, SIGNAL(activated()), this, SIGNAL(findNext()));
+    connect(shortcutNext, &QShortcut::activated, this, &TextEdit::findNext);
 
-    QShortcut* shortcutPrev = new QShortcut(this);
+    auto shortcutPrev = new QShortcut(this);
     shortcutPrev->setKey(QKeySequence::FindPrevious);
     shortcutPrev->setContext(Qt::WidgetShortcut);
-    connect(shortcutPrev, SIGNAL(activated()), this, SIGNAL(findPrevious()));
+    connect(shortcutPrev, &QShortcut::activated, this, &TextEdit::findPrevious);
 }
 
 /** Destroys the object and frees any allocated resources */
@@ -111,7 +115,7 @@ void TextEdit::complete()
     if (wordPrefix.isEmpty())
         return;
 
-    QStringList list = toPlainText().split(QRegExp(QLatin1String("\\W+")));
+    QStringList list = toPlainText().split(QRegularExpression(QLatin1String("\\W+")));
     QMap<QString, QString> map;
     QStringList::Iterator it = list.begin();
     while (it != list.end()) {
@@ -195,7 +199,7 @@ struct TextEditorP
     QMap<QString, QColor> colormap; // Color map
     TextEditorP()
     {
-        colormap[QLatin1String("Text")] = Qt::black;
+        colormap[QLatin1String("Text")] = qApp->palette().windowText().color();
         colormap[QLatin1String("Bookmark")] = Qt::cyan;
         colormap[QLatin1String("Breakpoint")] = Qt::red;
         colormap[QLatin1String("Keyword")] = Qt::blue;
@@ -233,12 +237,12 @@ TextEditor::TextEditor(QWidget* parent)
     // set colors and font
     hPrefGrp->NotifyAll();
 
-    connect(this, SIGNAL(cursorPositionChanged()),
-            this, SLOT(highlightCurrentLine()));
-    connect(this, SIGNAL(blockCountChanged(int)),
-            this, SLOT(updateLineNumberAreaWidth(int)));
-    connect(this, SIGNAL(updateRequest(const QRect &, int)),
-            this, SLOT(updateLineNumberArea(const QRect &, int)));
+    connect(this, &QPlainTextEdit::cursorPositionChanged,
+            this, &TextEditor::highlightCurrentLine);
+    connect(this, &QPlainTextEdit::blockCountChanged,
+            this, &TextEditor::updateLineNumberAreaWidth);
+    connect(this, &QPlainTextEdit::updateRequest,
+            this, &TextEditor::updateLineNumberArea);
 
     updateLineNumberAreaWidth(0);
     highlightCurrentLine();
@@ -288,9 +292,9 @@ void TextEditor::highlightCurrentLine()
     if (!isReadOnly()) {
         QTextEdit::ExtraSelection selection;
         QColor lineColor = d->colormap[QLatin1String("Current line highlight")];
-        unsigned int col = (lineColor.red() << 24) | (lineColor.green() << 16) | (lineColor.blue() << 8);
+        unsigned int col = App::Color::asPackedRGB<QColor>(lineColor);
         ParameterGrp::handle hPrefGrp = getWindowParameter();
-        unsigned long value = static_cast<unsigned long>(col);
+        auto value = static_cast<unsigned long>(col);
         value = hPrefGrp->GetUnsigned( "Current line highlight", value);
         col = static_cast<unsigned int>(value);
         lineColor.setRgb((col>>24)&0xff, (col>>16)&0xff, (col>>8)&0xff);
@@ -450,11 +454,11 @@ void TextEditor::OnChange(Base::Subject<const char*> &rCaller,const char* sReaso
         lineNumberArea->setFont(font);
     }
     else {
-        QMap<QString, QColor>::ConstIterator it = d->colormap.find(QString::fromLatin1(sReason));
+        QMap<QString, QColor>::Iterator it = d->colormap.find(QString::fromLatin1(sReason));
         if (it != d->colormap.end()) {
             QColor color = it.value();
-            unsigned int col = (color.red() << 24) | (color.green() << 16) | (color.blue() << 8);
-            unsigned long value = static_cast<unsigned long>(col);
+            unsigned int col = App::Color::asPackedRGB<QColor>(color);
+            auto value = static_cast<unsigned long>(col);
             value = hPrefGrp->GetUnsigned(sReason, value);
             col = static_cast<unsigned int>(value);
             color.setRgb((col>>24)&0xff, (col>>16)&0xff, (col>>8)&0xff);
@@ -532,8 +536,8 @@ CompletionList::CompletionList(QPlainTextEdit* parent)
     pal.setColor(QPalette::Inactive, QPalette::HighlightedText, pal.color(QPalette::Active, QPalette::HighlightedText));
     parent->setPalette( pal );
 
-    connect(this, SIGNAL(itemActivated(QListWidgetItem *)),
-            this, SLOT(completionItem(QListWidgetItem *)));
+    connect(this, &CompletionList::itemActivated,
+            this, &CompletionList::completionItem);
 }
 
 CompletionList::~CompletionList()
@@ -565,7 +569,7 @@ bool CompletionList::eventFilter(QObject * watched, QEvent * event)
             hide();
     } else if (isVisible() && watched == textEdit) {
         if (event->type() == QEvent::KeyPress) {
-            QKeyEvent* ke = (QKeyEvent*)event;
+            auto ke = static_cast<QKeyEvent*>(event);
             if (ke->key() == Qt::Key_Up || ke->key() == Qt::Key_Down) {
                 keyPressEvent(ke);
                 return true;
@@ -579,7 +583,7 @@ bool CompletionList::eventFilter(QObject * watched, QEvent * event)
                 hide();
                 return false;
             } else if (ke->key() == Qt::Key_Return || ke->key() == Qt::Key_Enter) {
-                itemActivated(currentItem());
+                Q_EMIT itemActivated(currentItem());
                 return true;
             }
         } else if (event->type() == QEvent::FocusOut) {
