@@ -73,7 +73,7 @@ unsigned int Thumbnail::getMemSize () const
 void Thumbnail::Save (Base::Writer &writer) const
 {
     // It's only possible to add extra information if force of XML is disabled
-    if (writer.isForceXML() == false)
+    if (!writer.isForceXML())
         writer.addFile("thumbnails/Thumbnail.png", this);
 }
 
@@ -88,24 +88,23 @@ void Thumbnail::SaveDocFile (Base::Writer &writer) const
     if (!this->viewer)
         return;
     QImage img;
-    if (this->viewer->isActiveWindow()) {
-        if (this->viewer->thread() != QThread::currentThread()) {
-            qWarning("Cannot create a thumbnail from non-GUI thread");
-            return;
-        }
-
-        QColor invalid;
-        this->viewer->imageFromFramebuffer(this->size, this->size, 0, invalid, img);
+    if (this->viewer->thread() != QThread::currentThread()) {
+        qWarning("Cannot create a thumbnail from non-GUI thread");
+        return;
     }
 
+    QColor invalid;
+    this->viewer->imageFromFramebuffer(this->size, this->size, 4, invalid, img);
+
     // Get app icon and resize to half size to insert in topbottom position over the current view snapshot
     QPixmap appIcon = Gui::BitmapFactory().pixmap(App::Application::Config()["AppIcon"].c_str());
     QPixmap px =  appIcon;
     if (!img.isNull()) {
+        // Create a small "Fc" Application icon in the bottom right of the thumbnail
         if (App::GetApplication().GetParameterGroupByPath
             ("User parameter:BaseApp/Preferences/Document")->GetBool("AddThumbnailLogo",true)) {
             // only scale app icon if an offscreen image could be created
-            appIcon =  appIcon.scaled(this->size / 4, this->size /4);
+            appIcon = appIcon.scaled(this->size / 4, this->size /4, Qt::KeepAspectRatio, Qt::SmoothTransformation);
             px = BitmapFactory().merge(QPixmap::fromImage(img), appIcon, BitmapFactoryInst::BottomRight);
         }
         else {
@@ -115,7 +114,7 @@ void Thumbnail::SaveDocFile (Base::Writer &writer) const
 
     if (!px.isNull()) {
         // according to specification add some meta-information to the image
-        uint mt = QDateTime::currentDateTime().toTime_t();
+        qint64 mt = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
         QString mtime = QString::fromLatin1("%1").arg(mt);
         img.setText(QLatin1String("Software"), qApp->applicationName());
         img.setText(QLatin1String("Thumb::Mimetype"), QLatin1String("application/x-extension-fcstd"));
