@@ -26,6 +26,7 @@
 # include <QApplication>
 # include <QToolBar>
 # include <QToolButton>
+# include <QPointer>
 #endif
 
 #include "ToolBarManager.h"
@@ -36,14 +37,15 @@
 
 using namespace Gui;
 
-ToolBarItem::ToolBarItem()
+ToolBarItem::ToolBarItem() : visibilityPolicy(DefaultVisibility::Visible)
 {
 }
 
-ToolBarItem::ToolBarItem(ToolBarItem* item)
+ToolBarItem::ToolBarItem(ToolBarItem* item, DefaultVisibility visibilityPolicy) : visibilityPolicy(visibilityPolicy)
 {
-    if ( item )
+    if (item) {
         item->appendItem(this);
+    }
 }
 
 ToolBarItem::~ToolBarItem()
@@ -56,7 +58,7 @@ void ToolBarItem::setCommand(const std::string& name)
     _name = name;
 }
 
-std::string ToolBarItem::command() const
+const std::string & ToolBarItem::command() const
 {
     return _name;
 }
@@ -70,11 +72,11 @@ ToolBarItem* ToolBarItem::findItem(const std::string& name)
 {
     if ( _name == name ) {
         return this;
-    } else {
-        for ( QList<ToolBarItem*>::ConstIterator it = _items.begin(); it != _items.end(); ++it ) {
-            if ( (*it)->_name == name ) {
-                return *it;
-            }
+    }
+
+    for (auto it : qAsConst(_items)) {
+        if (it->_name == name) {
+            return it;
         }
     }
 
@@ -83,12 +85,12 @@ ToolBarItem* ToolBarItem::findItem(const std::string& name)
 
 ToolBarItem* ToolBarItem::copy() const
 {
-    ToolBarItem* root = new ToolBarItem;
+    auto root = new ToolBarItem;
     root->setCommand( command() );
 
     QList<ToolBarItem*> items = getItems();
-    for ( QList<ToolBarItem*>::ConstIterator it = items.begin(); it != items.end(); ++it ) {
-        root->appendItem( (*it)->copy() );
+    for (auto it : items) {
+        root->appendItem(it->copy());
     }
 
     return root;
@@ -110,21 +112,23 @@ bool ToolBarItem::insertItem( ToolBarItem* before, ToolBarItem* item)
     if (pos != -1) {
         _items.insert(pos, item);
         return true;
-    } else
-        return false;
+    }
+
+    return false;
 }
 
 void ToolBarItem::removeItem(ToolBarItem* item)
 {
     int pos = _items.indexOf(item);
-    if (pos != -1)
+    if (pos != -1) {
         _items.removeAt(pos);
+    }
 }
 
 void ToolBarItem::clear()
 {
-    for ( QList<ToolBarItem*>::Iterator it = _items.begin(); it != _items.end(); ++it ) {
-        delete *it;
+    for (auto it : qAsConst(_items)) {
+        delete it;
     }
 
     _items.clear();
@@ -138,7 +142,7 @@ ToolBarItem& ToolBarItem::operator << (ToolBarItem* item)
 
 ToolBarItem& ToolBarItem::operator << (const std::string& command)
 {
-    ToolBarItem* item = new ToolBarItem(this);
+    auto item = new ToolBarItem(this);
     item->setCommand(command);
     return *this;
 }
@@ -173,11 +177,39 @@ ToolBarManager::~ToolBarManager()
 {
 }
 
+namespace {
+QPointer<QWidget> createActionWidget()
+{
+    static QPointer<QWidget> _ActionWidget;
+    if (!_ActionWidget) {
+        _ActionWidget = new QWidget(getMainWindow());
+        _ActionWidget->setObjectName(QStringLiteral("_fc_action_widget_"));
+        /* TODO This is a temporary hack until a longterm solution
+        is found, thanks to @realthunder for this pointer.
+        Although _ActionWidget has zero size, it somehow has a
+        'phantom' size without any visible content and will block the top
+        left tool buttons and menus of the application main window.
+        Therefore it is moved out of the way. */
+        _ActionWidget->move(QPoint(-100,-100));
+    }
+    else {
+        auto actions = _ActionWidget->actions();
+        for (auto action : actions) {
+            _ActionWidget->removeAction(action);
+        }
+    }
+
+    return _ActionWidget;
+}
+}
+
 void ToolBarManager::setup(ToolBarItem* toolBarItems)
 {
     if (!toolBarItems)
         return; // empty menu bar
 
+    QPointer<QWidget> _ActionWidget = createActionWidget();
+
     saveState();
     this->toolbarNames.clear();
 
@@ -190,13 +222,12 @@ void ToolBarManager::setup(ToolBarItem* toolBarItems)
             ->GetGroup("Preferences")->GetGroup("MainWindow")->GetBool("ToolBarNameAsToolTip",true);
     QList<ToolBarItem*> items = toolBarItems->getItems();
     QList<QToolBar*> toolbars = toolBars();
-    for (QList<ToolBarItem*>::ConstIterator it = items.begin(); it != items.end(); ++it) {
+    for (QList<ToolBarItem*>::Iterator it = items.begin(); it != items.end(); ++it) {
         // search for the toolbar
         QString name = QString::fromUtf8((*it)->command().c_str());
         this->toolbarNames << name;
         QToolBar* toolbar = findToolBar(toolbars, name);
         std::string toolbarName = (*it)->command();
-        bool visible = hPref->GetBool(toolbarName.c_str(), true);
         bool toolbar_added = false;
 
         if (!toolbar) {
@@ -210,18 +241,45 @@ void ToolBarManager::setup(ToolBarItem* toolBarItems)
                     + QChar::fromLatin1(']');
                 toolbar->setToolTip(tooltip);
             }
-            toolbar->setVisible(visible);
             toolbar_added = true;
         }
         else {
-            toolbar->setVisible(visible);
-            toolbar->toggleViewAction()->setVisible(true);
             int index = toolbars.indexOf(toolbar);
             toolbars.removeAt(index);
         }
 
+        bool visible = false;
+
+        // If visibility policy is custom, the toolbar is initialised as not visible, and the
+        // toggleViewAction to control its visibility is not visible either.
+        //
+        // Both are managed under the responsibility of the client code
+        if((*it)->visibilityPolicy != ToolBarItem::DefaultVisibility::Unavailable) {
+            bool defaultvisibility = (*it)->visibilityPolicy == ToolBarItem::DefaultVisibility::Visible;
+
+            visible = hPref->GetBool(toolbarName.c_str(), defaultvisibility);
+
+            // Enable automatic handling of visibility via, for example, (contextual) menu
+            toolbar->toggleViewAction()->setVisible(true);
+        }
+        else { // ToolBarItem::DefaultVisibility::Unavailable
+            // Prevent that the action to show/hide a toolbar appears on the (contextual) menus.
+            // This is also managed by the client code for a toolbar with custom policy
+            toolbar->toggleViewAction()->setVisible(false);
+        }
+
+        // Initialise toolbar item visibility
+        toolbar->setVisible(visible);
+
+        // Store item visibility policy within the action
+        toolbar->toggleViewAction()->setProperty("DefaultVisibility", static_cast<int>((*it)->visibilityPolicy));
+
         // setup the toolbar
         setup(*it, toolbar);
+        auto actions = toolbar->actions();
+        for (auto action : actions) {
+            _ActionWidget->addAction(action);
+        }
 
         // try to add some breaks to avoid to have all toolbars in one line
         if (toolbar_added) {
@@ -251,10 +309,10 @@ void ToolBarManager::setup(ToolBarItem* toolBarItems)
             fw = fw->parentWidget();
         }
         // ignore toolbars which do not belong to the previously active workbench
-        QByteArray toolbarName = (*it)->objectName().toUtf8();
+        //QByteArray toolbarName = (*it)->objectName().toUtf8();
         if (!(*it)->toggleViewAction()->isVisible())
             continue;
-        hPref->SetBool(toolbarName.constData(), (*it)->isVisible());
+        //hPref->SetBool(toolbarName.constData(), (*it)->isVisible());
         (*it)->hide();
         (*it)->toggleViewAction()->setVisible(false);
     }
@@ -270,21 +328,25 @@ void ToolBarManager::setup(ToolBarItem* item, QToolBar* toolbar) const
     CommandManager& mgr = Application::Instance->commandManager();
     QList<ToolBarItem*> items = item->getItems();
     QList<QAction*> actions = toolbar->actions();
-    for (QList<ToolBarItem*>::ConstIterator it = items.begin(); it != items.end(); ++it) {
+    for (QList<ToolBarItem*>::Iterator it = items.begin(); it != items.end(); ++it) {
         // search for the action item
         QAction* action = findAction(actions, QString::fromLatin1((*it)->command().c_str()));
         if (!action) {
             if ((*it)->command() == "Separator") {
                 action = toolbar->addSeparator();
-            } else {
+            }
+            else {
                 // Check if action was added successfully
                 if (mgr.addTo((*it)->command().c_str(), toolbar))
-                    action = toolbar->actions().last();
+                    action = toolbar->actions().constLast();
             }
 
             // set the tool button user data
-            if (action) action->setData(QString::fromLatin1((*it)->command().c_str()));
-        } else {
+            if (action) {
+                action->setData(QString::fromLatin1((*it)->command().c_str()));
+            }
+        }
+        else {
             // Note: For toolbars we do not remove and re-add the actions
             // because this causes flicker effects. So, it could happen that the order of
             // buttons doesn't match with the order of commands in the workbench.
@@ -301,6 +363,24 @@ void ToolBarManager::setup(ToolBarItem* item, QToolBar* toolbar) const
 
 void ToolBarManager::saveState() const
 {
+    auto ignoreSave = [](QAction* action) {
+        // If the toggle action is invisible then it's controlled by the application.
+        // In this case the current state is not saved.
+        if (!action->isVisible()) {
+            return true;
+        }
+
+        QVariant property = action->property("DefaultVisibility");
+        if (property.isNull()) {
+            return false;
+        }
+
+        // If DefaultVisibility is Unavailable then never save the state because it's
+        // always controlled by the client code.
+        auto value = static_cast<ToolBarItem::DefaultVisibility>(property.toInt());
+        return value == ToolBarItem::DefaultVisibility::Unavailable;
+    };
+
     ParameterGrp::handle hPref = App::GetApplication().GetUserParameter().GetGroup("BaseApp")
                                ->GetGroup("MainWindow")->GetGroup("Toolbars");
 
@@ -308,6 +388,10 @@ void ToolBarManager::saveState() const
     for (QStringList::ConstIterator it = this->toolbarNames.begin(); it != this->toolbarNames.end(); ++it) {
         QToolBar* toolbar = findToolBar(toolbars, *it);
         if (toolbar) {
+            if (ignoreSave(toolbar->toggleViewAction())) {
+                continue;
+            }
+
             QByteArray toolbarName = toolbar->objectName().toUtf8();
             hPref->SetBool(toolbarName.constData(), toolbar->isVisible());
         }
@@ -378,10 +462,99 @@ QList<QToolBar*> ToolBarManager::toolBars() const
     QWidget* mw = getMainWindow();
     QList<QToolBar*> tb;
     QList<QToolBar*> bars = getMainWindow()->findChildren<QToolBar*>();
-    for (QList<QToolBar*>::ConstIterator it = bars.begin(); it != bars.end(); ++it) {
+    for (QList<QToolBar*>::Iterator it = bars.begin(); it != bars.end(); ++it) {
         if ((*it)->parentWidget() == mw)
             tb.push_back(*it);
     }
 
     return tb;
 }
+
+ToolBarItem::DefaultVisibility ToolBarManager::getToolbarPolicy(const QToolBar* toolbar) const
+{
+    auto* action = toolbar->toggleViewAction();
+
+    QVariant property = action->property("DefaultVisibility");
+    if (property.isNull()) {
+        return ToolBarItem::DefaultVisibility::Visible;
+    }
+
+    return static_cast<ToolBarItem::DefaultVisibility>(property.toInt());
+}
+
+void ToolBarManager::setState(const QList<QString>& names, State state)
+{
+    for (auto& name : names) {
+        setState(name, state);
+    }
+}
+
+void ToolBarManager::setState(const QString& name, State state)
+{
+    ParameterGrp::handle hPref = App::GetApplication().GetUserParameter().GetGroup("BaseApp")->GetGroup("MainWindow")->GetGroup("Toolbars");
+
+    auto visibility = [hPref, name](bool defaultvalue) {
+        return hPref->GetBool(name.toStdString().c_str(), defaultvalue);
+    };
+
+    auto saveVisibility = [hPref, name](bool value) {
+        hPref->SetBool(name.toStdString().c_str(), value);
+    };
+
+    auto showhide = [visibility](QToolBar* toolbar, ToolBarItem::DefaultVisibility policy) {
+
+        auto show = visibility( policy == ToolBarItem::DefaultVisibility::Visible );
+
+        if(show) {
+            toolbar->show();
+        }
+        else {
+            toolbar->hide();
+        }
+    };
+
+    QToolBar* tb = findToolBar(toolBars(), name);
+    if (tb) {
+
+        if (state == State::RestoreDefault) {
+
+            auto policy = getToolbarPolicy(tb);
+
+            if(policy == ToolBarItem::DefaultVisibility::Unavailable) {
+                tb->hide();
+                tb->toggleViewAction()->setVisible(false);
+            }
+            else  {
+                tb->toggleViewAction()->setVisible(true);
+
+                showhide(tb, policy);
+            }
+        }
+        else if (state == State::ForceAvailable) {
+
+            auto policy = getToolbarPolicy(tb);
+
+            tb->toggleViewAction()->setVisible(true);
+
+            // Unavailable policy defaults to a Visible toolbars when made available
+            auto show = visibility( policy == ToolBarItem::DefaultVisibility::Visible ||
+                                    policy == ToolBarItem::DefaultVisibility::Unavailable);
+
+            if(show) {
+                tb->show();
+            }
+            else {
+                tb->hide();
+            }
+        }
+        else if (state == State::ForceHidden) {
+            tb->toggleViewAction()->setVisible(false); // not visible in context menus
+            tb->hide(); // toolbar not visible
+
+        }
+        else if (state == State::SaveState) {
+            auto show = tb->isVisible();
+            saveVisibility(show);
+        }
+    }
+}
