@@ -26,6 +26,7 @@
 
 #include <list>
 #include <map>
+#include <memory>
 #include <set>
 #include <vector>
 
@@ -40,6 +41,7 @@
 
 #include "Namespace.h"
 #include "Selection.h"
+#include "View3DInventorSelection.h"
 #include "Quarter/SoQTQuarterAdaptor.h"
 
 
@@ -79,7 +81,8 @@ class ViewerEventFilter;
  */
 class GuiExport View3DInventorViewer : public Quarter::SoQTQuarterAdaptor, public SelectionObserver
 {
-    typedef Quarter::SoQTQuarterAdaptor inherited;
+    using inherited = Quarter::SoQTQuarterAdaptor;
+    Q_OBJECT
 
 public:
     /// Pick modes for picking points in the scene
@@ -130,21 +133,29 @@ public:
     };
     //@}
 
-    View3DInventorViewer (QWidget *parent, const QtGLWidget* sharewidget = nullptr);
+    /** @name Background
+      */
+    //@{
+    enum Background {
+        NoGradient,
+        LinearGradient,
+        RadialGradient
+    };
+    //@}
+
+    explicit View3DInventorViewer (QWidget *parent, const QtGLWidget* sharewidget = nullptr);
     View3DInventorViewer (const QtGLFormat& format, QWidget *parent, const QtGLWidget* sharewidget = nullptr);
-    virtual ~View3DInventorViewer();
+    ~View3DInventorViewer() override;
 
     void init();
 
     /// Observer message from the Selection
-    virtual void onSelectionChanged(const SelectionChanges &Reason);
-    void checkGroupOnTop(const SelectionChanges &Reason);
-    void clearGroupOnTop();
+    void onSelectionChanged(const SelectionChanges &Reason) override;
 
     SoDirectionalLight* getBacklight() const;
     void setBacklight(SbBool on);
     SbBool isBacklight() const;
-    void setSceneGraph (SoNode *root);
+    void setSceneGraph (SoNode *root) override;
     SbBool searchNode(SoNode*) const;
 
     void setAnimationEnabled(const SbBool enable);
@@ -172,7 +183,7 @@ public:
     void imageFromFramebuffer(int width, int height, int samples,
                               const QColor& bgcolor, QImage& img);
 
-    virtual void setViewing(SbBool enable);
+    void setViewing(SbBool enable) override;
     virtual void setCursorEnabled(SbBool enable);
 
     void addGraphicsItem(GLGraphicsItem*);
@@ -210,11 +221,11 @@ public:
     /** Helper method to get picked entities while editing.
      * It's in the responsibility of the caller to delete the returned instance.
      */
-    SoPickedPoint* getPointOnRay(const SbVec2s& pos, ViewProvider* vp) const;
+    SoPickedPoint* getPointOnRay(const SbVec2s& pos, const ViewProvider* vp) const;
     /** Helper method to get picked entities while editing.
      * It's in the responsibility of the caller to delete the returned instance.
      */
-    SoPickedPoint* getPointOnRay(const SbVec3f& pos, const SbVec3f& dir, ViewProvider* vp) const;
+    SoPickedPoint* getPointOnRay(const SbVec3f& pos, const SbVec3f& dir, const ViewProvider* vp) const;
     /// display override mode
     void setOverrideMode(const std::string &mode);
     void updateOverrideMode(const std::string &mode);
@@ -294,27 +305,48 @@ public:
     void    setViewDirection(SbVec3f);
     /** Returns the up direction */
     SbVec3f getUpDirection() const;
+
     /** Returns the orientation of the camera. */
     SbRotation getCameraOrientation() const;
+
     /** Returns the 3d point on the focal plane to the given 2d point. */
     SbVec3f getPointOnFocalPlane(const SbVec2s&) const;
-    /** Returns the 2d coordinates on the screen to the given 3d point. */
-    SbVec2s getPointOnScreen(const SbVec3f&) const;
+
+    /** Returns the 2d coordinates on the viewport to the given 3d point. */
+    SbVec2s getPointOnViewport(const SbVec3f&) const;
+
+    /** Converts Inventor coordinates into Qt coordinates.
+     * The conversion takes the device pixel ratio into account.
+     */
+    QPoint toQPoint(const SbVec2s&) const;
+
+    /** Converts Qt coordinates into Inventor coordinates.
+     * The conversion takes the device pixel ratio into account.
+     */
+    SbVec2s fromQPoint(const QPoint&) const;
+
     /** Returns the near plane represented by its normal and base point. */
     void getNearPlane(SbVec3f& rcPt, SbVec3f& rcNormal) const;
+
     /** Returns the far plane represented by its normal and base point. */
     void getFarPlane(SbVec3f& rcPt, SbVec3f& rcNormal) const;
+
     /** Adds or remove a manipulator to/from the scenegraph. */
     void toggleClippingPlane(int toggle=-1, bool beforeEditing=false,
             bool noManip=false, const Base::Placement &pla = Base::Placement());
+
     /** Checks whether a clipping plane is set or not. */
     bool hasClippingPlane() const;
+
     /** Project the given normalized 2d point onto the near plane */
     SbVec3f projectOnNearPlane(const SbVec2f&) const;
+
     /** Project the given normalized 2d point onto the far plane */
     SbVec3f projectOnFarPlane(const SbVec2f&) const;
+
     /** Project the given 2d point to a line */
     void projectPointToLine(const SbVec2s&, SbVec3f& pt1, SbVec3f& pt2) const;
+
     /** Get the normalized position of the 2d point. */
     SbVec2f getNormalizedPosition(const SbVec2s&) const;
     //@}
@@ -342,7 +374,7 @@ public:
      * set.
      */
     void setCameraOrientation(const SbRotation& rot, SbBool moveTocenter=false);
-    void setCameraType(SoType t);
+    void setCameraType(SoType t) override;
     void moveCameraTo(const SbRotation& rot, const SbVec3f& pos, int steps, int ms);
     /**
      * Zooms the viewport to the size of the bounding box.
@@ -351,7 +383,7 @@ public:
     /**
      * Reposition the current camera so we can see the complete scene.
      */
-    void viewAll();
+    void viewAll() override;
     void viewAll(float factor);
 
     /// Breaks out a VR window for a Rift
@@ -369,8 +401,8 @@ public:
      */
     void viewSelection();
 
-    void setGradientBackground(bool b);
-    bool hasGradientBackground() const;
+    void setGradientBackground(Background);
+    Background getGradientBackground() const;
     void setGradientBackgroundColor(const SbColor& fromColor,
                                     const SbColor& toColor);
     void setGradientBackgroundColor(const SbColor& fromColor,
@@ -385,11 +417,15 @@ public:
     void setEnabledNaviCube(bool b);
     bool isEnabledNaviCube() const;
     void setNaviCubeCorner(int);
-    NaviCube* getNavigationCube() const;
+    NaviCube* getNaviCube() const;
     void setEnabledVBO(bool b);
     bool isEnabledVBO() const;
     void setRenderCache(int);
 
+    void getDimensions(float& fHeight, float& fWidth) const;
+    float getMaxDimension() const;
+    SbVec3f getCenterPointOnFocalPlane() const;
+
     NavigationStyle* navigationStyle() const;
 
     void setDocument(Gui::Document *pcDocument);
@@ -403,14 +439,14 @@ protected:
     void renderFramebuffer();
     void renderGLImage();
     void animatedViewAll(int steps, int ms);
-    virtual void actualRedraw();
-    virtual void setSeekMode(SbBool enable);
-    virtual void afterRealizeHook();
-    virtual bool processSoEvent(const SoEvent * ev);
-    void dropEvent (QDropEvent * e);
-    void dragEnterEvent (QDragEnterEvent * e);
-    void dragMoveEvent(QDragMoveEvent *e);
-    void dragLeaveEvent(QDragLeaveEvent *e);
+    void actualRedraw() override;
+    void setSeekMode(SbBool enable) override;
+    void afterRealizeHook() override;
+    bool processSoEvent(const SoEvent * ev) override;
+    void dropEvent (QDropEvent * e) override;
+    void dragEnterEvent (QDragEnterEvent * e) override;
+    void dragMoveEvent(QDragMoveEvent *e) override;
+    void dragLeaveEvent(QDragLeaveEvent *e) override;
     SbBool processSoEventBase(const SoEvent * const ev);
     void printDimension();
     void selectAll();
@@ -431,8 +467,9 @@ private:
     void initialize();
     void drawAxisCross();
     static void drawArrow();
+    void drawSingleBackground(const QColor&);
     void setCursorRepresentation(int mode);
-    void aboutToDestroyGLContext();
+    void aboutToDestroyGLContext() override;
     void createStandardCursors(double);
 
 private:
@@ -446,13 +483,12 @@ private:
     SoSeparator * foregroundroot;
     SoDirectionalLight* backlight;
 
+    // Scene graph root
     SoSeparator * pcViewProviderRoot;
+    // Child group in the scene graph that contains view providers related to the physical object
+    SoGroup* objectGroup;
 
-    SoGroup * pcGroupOnTop;
-    SoGroup * pcGroupOnTopSel;
-    SoGroup * pcGroupOnTopPreSel;
-    std::map<std::string,SoNode*> objectsOnTop;
-    std::map<std::string,SoNode*> objectsOnTopPreSel;
+    std::unique_ptr<View3DInventorSelection> inventorSelection;
 
     SoSeparator * pcEditingRoot;
     SoTransform * pcEditingTransform;
