@@ -44,12 +44,12 @@ class View3DInventorViewerPy : public Py::PythonExtension<View3DInventorViewerPy
 public:
     static void init_type();    // announce properties and methods
 
-    View3DInventorViewerPy(View3DInventorViewer *vi);
-    ~View3DInventorViewerPy();
+    explicit View3DInventorViewerPy(View3DInventorViewer *vi);
+    ~View3DInventorViewerPy() override;
 
-    Py::Object repr();
-    Py::Object getattr(const char *);
-    int setattr(const char *, const Py::Object &);
+    Py::Object repr() override;
+    Py::Object getattr(const char *) override;
+    int setattr(const char *, const Py::Object &) override;
 
     //exposed methods
     Py::Object getSoEventManager(const Py::Tuple&);
@@ -67,6 +67,8 @@ public:
     Py::Object setupEditingRoot(const Py::Tuple &args);
     Py::Object resetEditingRoot(const Py::Tuple &args);
 
+    Py::Object setGradientBackground(const Py::Tuple& args);
+    Py::Object setGradientBackgroundColor(const Py::Tuple& args);
     Py::Object setBackgroundColor(const Py::Tuple& args);
     Py::Object setRedirectToSceneGraph(const Py::Tuple& args);
     Py::Object isRedirectedToSceneGraph(const Py::Tuple& args);
@@ -78,7 +80,7 @@ public:
 
 
 private:
-    typedef PyObject* (*method_varargs_handler)(PyObject *_self, PyObject *_args);
+    using method_varargs_handler = PyObject* (*)(PyObject *_self, PyObject *_args);
     static method_varargs_handler pycxx_handler;
     static PyObject *method_varargs_ext_handler(PyObject *_self, PyObject *_args);
 
