@@ -35,6 +35,7 @@
 
 #include <App/Document.h>
 #include <App/OriginFeature.h>
+#include <App/Origin.h>
 
 #include "ViewProviderOriginFeature.h"
 #include "SoFCSelection.h"
@@ -49,7 +50,7 @@ ViewProviderOriginFeature::ViewProviderOriginFeature () {
     ADD_PROPERTY_TYPE ( Size, (ViewProviderOrigin::defaultSize()), 0, App::Prop_ReadOnly,
     QT_TRANSLATE_NOOP("App::Property", "Visual size of the feature"));
 
-    ShapeColor.setValue ( 50.f/255, 150.f/255, 250.f/255 ); // Set default color for origin (light-blue)
+    ShapeColor.setValue ( ViewProviderOrigin::defaultColor ); // Set default color for origin (light-blue)
     BoundingBox.setStatus(App::Property::Hidden, true); // Hide Boundingbox from the user due to it doesn't make sense
 
     // Create node for scaling the origin
@@ -82,13 +83,13 @@ void ViewProviderOriginFeature::attach(App::DocumentObject* pcObject)
     float sz = Size.getValue () / defaultSz;
 
     // Create an external separator
-    SoSeparator  *sep = new SoSeparator();
+    auto sep = new SoSeparator();
 
     // Add material from the base class
     sep->addChild(pcShapeMaterial);
 
     // Bind same material to all part
-    SoMaterialBinding* matBinding = new SoMaterialBinding;
+    auto matBinding = new SoMaterialBinding;
     matBinding->value = SoMaterialBinding::OVERALL;
     sep->addChild(matBinding);
 
@@ -97,12 +98,29 @@ void ViewProviderOriginFeature::attach(App::DocumentObject* pcObject)
     sep->addChild (pScale);
 
     // Setup font size
-    SoFont *font = new SoFont ();
-    font->size.setValue ( defaultSz/10.);
+    auto font = new SoFont ();
+    float fontRatio = 10.0f;
+    if ( pcObject->getTypeId() == App::Line::getClassTypeId() ) {
+        // keep font size on axes equal to font size on planes
+        fontRatio *= ViewProviderOrigin::axesScaling;
+        const char* axisName = pcObject->getNameInDocument();
+        auto axisRoles = App::Origin::AxisRoles;
+        if ( strncmp(axisName, axisRoles[0], strlen(axisRoles[0]) ) == 0 ) {
+            // X-axis: red
+            ShapeColor.setValue ( 0xFF0000FF );
+        } else if ( strncmp(axisName, axisRoles[1], strlen(axisRoles[1]) ) == 0 ) {
+            // Y-axis: green
+            ShapeColor.setValue ( 0x00FF00FF );
+        } else if ( strncmp(axisName, axisRoles[2], strlen(axisRoles[2]) ) == 0 ) {
+            // Z-axis: blue
+            ShapeColor.setValue ( 0x0000FFFF );
+        }
+    }
+    font->size.setValue ( defaultSz / fontRatio );
     sep->addChild ( font );
 
     // Create the selection node
-    SoFCSelection *highlight = new SoFCSelection ();
+    auto highlight = new SoFCSelection ();
     highlight->applySettings ();
     if ( !Selectable.getValue() ) {
         highlight->selectionMode = Gui::SoFCSelection::SEL_OFF;
@@ -112,7 +130,7 @@ void ViewProviderOriginFeature::attach(App::DocumentObject* pcObject)
     highlight->style = SoFCSelection::EMISSIVE_DIFFUSE;
 
     // Style for normal (visible) lines
-    SoDrawStyle* style = new SoDrawStyle ();
+    auto style = new SoDrawStyle ();
     style->lineWidth = 2.0f;
     highlight->addChild ( style );
 
@@ -120,7 +138,7 @@ void ViewProviderOriginFeature::attach(App::DocumentObject* pcObject)
     highlight->addChild ( pOriginFeatureRoot );
 
     // Hidden features
-    SoAnnotation *hidden = new SoAnnotation ();
+    auto hidden = new SoAnnotation ();
 
     // Style for hidden lines
     style = new SoDrawStyle ();
@@ -160,7 +178,7 @@ std::vector<std::string> ViewProviderOriginFeature::getDisplayModes () const
 {
     // add modes
     std::vector<std::string> StrList;
-    StrList.push_back("Base");
+    StrList.emplace_back("Base");
     return StrList;
 }
 
@@ -172,7 +190,7 @@ void ViewProviderOriginFeature::setDisplayMode (const char* ModeName)
 }
 
 bool ViewProviderOriginFeature::onDelete(const std::vector<std::string> &) {
-    App::OriginFeature *feat = static_cast <App::OriginFeature *> ( getObject() );
+    auto feat = static_cast <App::OriginFeature *> ( getObject() );
     // Forbid deletion if there is an origin this feature belongs to
 
     if ( feat->getOrigin () ) {
