@@ -185,7 +185,7 @@ private:
         FC_PY_VIEW_OBJECT
         FlagMax,
     };
-    typedef std::bitset<FlagMax> Flags;
+    using Flags = std::bitset<FlagMax>;
     mutable Flags _Flags;
 
 public:
@@ -227,21 +227,21 @@ public:
 
     /** @name Nodes */
     //@{
-    virtual SoSeparator* getRoot() const override {
+    SoSeparator* getRoot() const override {
         return ViewProviderT::getRoot();
     }
-    virtual SoSeparator* getFrontRoot() const override {
+    SoSeparator* getFrontRoot() const override {
         return ViewProviderT::getFrontRoot();
     }
     // returns the root node of the Provider (3D)
-    virtual SoSeparator* getBackRoot() const override {
+    SoSeparator* getBackRoot() const override {
         return ViewProviderT::getBackRoot();
     }
     //@}
 
     /** @name Selection handling */
     //@{
-    virtual bool useNewSelectionModel() const override {
+    bool useNewSelectionModel() const override {
         switch(imp->useNewSelectionModel()) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -251,7 +251,7 @@ public:
             return ViewProviderT::useNewSelectionModel();
         }
     }
-    virtual bool getElementPicked(const SoPickedPoint *pp, std::string &subname) const override {
+    bool getElementPicked(const SoPickedPoint *pp, std::string &subname) const override {
         auto ret = imp->getElementPicked(pp,subname);
         if(ret == ViewProviderPythonFeatureImp::NotImplemented)
             return ViewProviderT::getElementPicked(pp,subname);
@@ -259,44 +259,44 @@ public:
             return true;
         return false;
     }
-    virtual std::string getElement(const SoDetail *det) const override {
+    std::string getElement(const SoDetail *det) const override {
         std::string name;
         if(!imp->getElement(det,name))
             return ViewProviderT::getElement(det);
         return name;
     }
-    virtual SoDetail* getDetail(const char* name) const override {
+    SoDetail* getDetail(const char* name) const override {
         SoDetail *det = nullptr;
         if(imp->getDetail(name,det))
             return det;
         return ViewProviderT::getDetail(name);
     }
-    virtual bool getDetailPath(const char *name, SoFullPath *path, bool append,SoDetail *&det) const override {
+    bool getDetailPath(const char *name, SoFullPath *path, bool append,SoDetail *&det) const override {
         auto ret = imp->getDetailPath(name,path,append,det);
         if(ret == ViewProviderPythonFeatureImp::NotImplemented)
             return ViewProviderT::getDetailPath(name,path,append,det);
         return ret == ViewProviderPythonFeatureImp::Accepted;
     }
-    virtual std::vector<Base::Vector3d> getSelectionShape(const char* Element) const override {
+    std::vector<Base::Vector3d> getSelectionShape(const char* Element) const override {
         return ViewProviderT::getSelectionShape(Element);
     };
     //@}
 
     /** @name Update data methods*/
     //@{
-    virtual void attach(App::DocumentObject *obj) override {
+    void attach(App::DocumentObject *obj) override {
         // delay loading of the actual attach() method because the Python
         // view provider class is not attached yet
         ViewProviderT::pcObject = obj;
     }
-    virtual void updateData(const App::Property* prop) override {
+    void updateData(const App::Property* prop) override {
         imp->updateData(prop);
         ViewProviderT::updateData(prop);
     }
-    virtual void getTaskViewContent(std::vector<Gui::TaskView::TaskContent*>& c) const override {
+    void getTaskViewContent(std::vector<Gui::TaskView::TaskContent*>& c) const override {
         ViewProviderT::getTaskViewContent(c);
     }
-    virtual bool onDelete(const std::vector<std::string> & sub) override {
+    bool onDelete(const std::vector<std::string> & sub) override {
         switch(imp->onDelete(sub)) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -306,7 +306,7 @@ public:
             return ViewProviderT::onDelete(sub);
         }
     }
-    virtual bool canDelete(App::DocumentObject *obj) const override {
+    bool canDelete(App::DocumentObject *obj) const override {
         switch(imp->canDelete(obj)) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -320,11 +320,11 @@ public:
 
     /** @name Restoring view provider from document load */
     //@{
-    virtual void startRestoring() override {
+    void startRestoring() override {
         ViewProviderT::startRestoring();
         imp->startRestoring();
     }
-    virtual void finishRestoring() override {
+    void finishRestoring() override {
         imp->finishRestoring();
         ViewProviderT::finishRestoring();
     }
@@ -333,7 +333,7 @@ public:
     /** @name Drag and drop */
     //@{
     /// Returns true if the view provider generally supports dragging objects
-    virtual bool canDragObjects() const override {
+    bool canDragObjects() const override {
         switch (imp->canDragObjects()) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -344,7 +344,7 @@ public:
         }
     }
     /// Check whether the object can be removed from the view provider by drag and drop
-    virtual bool canDragObject(App::DocumentObject* obj) const override {
+    bool canDragObject(App::DocumentObject* obj) const override {
         switch (imp->canDragObject(obj)) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -355,7 +355,7 @@ public:
         }
     }
     /// Starts to drag the object
-    virtual void dragObject(App::DocumentObject* obj) override {
+    void dragObject(App::DocumentObject* obj) override {
         App::AutoTransaction committer;
         switch (imp->dragObject(obj)) {
         case ViewProviderPythonFeatureImp::Accepted:
@@ -366,7 +366,7 @@ public:
         }
     }
     /// Returns true if the view provider generally accepts dropping of objects
-    virtual bool canDropObjects() const override {
+    bool canDropObjects() const override {
         switch (imp->canDropObjects()) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -377,7 +377,7 @@ public:
         }
     }
     /// Check whether the object can be dropped to the view provider by drag and drop
-    virtual bool canDropObject(App::DocumentObject* obj) const override {
+    bool canDropObject(App::DocumentObject* obj) const override {
         switch (imp->canDropObject(obj)) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -388,7 +388,7 @@ public:
         }
     }
     /// If the dropped object type is accepted the object will be added as child
-    virtual void dropObject(App::DocumentObject* obj) override {
+    void dropObject(App::DocumentObject* obj) override {
         App::AutoTransaction committer;
         switch (imp->dropObject(obj)) {
         case ViewProviderPythonFeatureImp::Accepted:
@@ -399,7 +399,7 @@ public:
         }
     }
     /** Return false to force drop only operation for a give object*/
-    virtual bool canDragAndDropObject(App::DocumentObject *obj) const override {
+    bool canDragAndDropObject(App::DocumentObject *obj) const override {
         switch (imp->canDragAndDropObject(obj)) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -409,7 +409,7 @@ public:
             return ViewProviderT::canDragAndDropObject(obj);
         }
     }
-    virtual bool canDropObjectEx(App::DocumentObject *obj, App::DocumentObject *owner,
+    bool canDropObjectEx(App::DocumentObject *obj, App::DocumentObject *owner,
             const char *subname, const std::vector<std::string> &elements) const override
     {
         switch (imp->canDropObjectEx(obj,owner,subname,elements)) {
@@ -422,7 +422,7 @@ public:
         }
     }
     /** Add an object with full qualified name to the view provider by drag and drop */
-    virtual std::string dropObjectEx(App::DocumentObject *obj, App::DocumentObject *owner,
+    std::string dropObjectEx(App::DocumentObject *obj, App::DocumentObject *owner,
             const char *subname, const std::vector<std::string> &elements) override
     {
         App::AutoTransaction committer;
@@ -436,7 +436,7 @@ public:
     /** @name Display methods */
     //@{
     /// Returns true if the icon must always appear enabled in the tree view
-    virtual bool isShow() const override {
+    bool isShow() const override {
         switch(imp->isShow()) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -447,28 +447,28 @@ public:
         }
     }
     /// get the default display mode
-    virtual const char* getDefaultDisplayMode() const override {
+    const char* getDefaultDisplayMode() const override {
         defaultMode.clear();
         if(imp->getDefaultDisplayMode(defaultMode))
             return defaultMode.c_str();
         return ViewProviderT::getDefaultDisplayMode();
     }
     /// returns a list of all possible modes
-    virtual std::vector<std::string> getDisplayModes() const override {
+    std::vector<std::string> getDisplayModes() const override {
         std::vector<std::string> modes = ViewProviderT::getDisplayModes();
         std::vector<std::string> more_modes = imp->getDisplayModes();
         modes.insert(modes.end(), more_modes.begin(), more_modes.end());
         return modes;
     }
     /// set the display mode
-    virtual void setDisplayMode(const char* ModeName) override {
+    void setDisplayMode(const char* ModeName) override {
         std::string mask = imp->setDisplayMode(ModeName);
         ViewProviderT::setDisplayMaskMode(mask.c_str());
         ViewProviderT::setDisplayMode(ModeName);
     }
     //@}
 
-    virtual bool canRemoveChildrenFromRoot() const override {
+    bool canRemoveChildrenFromRoot() const override {
         switch(imp->canRemoveChildrenFromRoot()) {
         case ViewProviderPythonFeatureImp::NotImplemented:
             return ViewProviderT::canRemoveChildrenFromRoot();
@@ -483,7 +483,7 @@ public:
         return ViewProviderT::getPyObject();
     }
 
-    virtual bool canAddToSceneGraph() const override {
+    bool canAddToSceneGraph() const override {
         switch(imp->canAddToSceneGraph()) {
         case ViewProviderPythonFeatureImp::Accepted:
             return true;
@@ -495,7 +495,7 @@ public:
     }
 
 protected:
-    virtual void onChanged(const App::Property* prop) override {
+    void onChanged(const App::Property* prop) override {
         if (prop == &Proxy) {
             imp->init(Proxy.getValue().ptr());
             if (ViewProviderT::pcObject && !Proxy.getValue().is(Py::_None())) {
@@ -519,7 +519,7 @@ protected:
         ViewProviderT::onChanged(prop);
     }
     /// is called by the document when the provider goes in edit mode
-    virtual bool setEdit(int ModNum) override
+    bool setEdit(int ModNum) override
     {
         switch (imp->setEdit(ModNum)) {
         case ViewProviderPythonFeatureImp::Accepted:
@@ -531,7 +531,7 @@ protected:
         }
     }
     /// is called when you lose the edit mode
-    virtual void unsetEdit(int ModNum) override
+    void unsetEdit(int ModNum) override
     {
         switch (imp->unsetEdit(ModNum)) {
         case ViewProviderPythonFeatureImp::Accepted:
@@ -541,23 +541,23 @@ protected:
             return ViewProviderT::unsetEdit(ModNum);
         }
     }
-    virtual void setEditViewer(View3DInventorViewer *viewer, int ModNum) override {
+    void setEditViewer(View3DInventorViewer *viewer, int ModNum) override {
         if (imp->setEditViewer(viewer,ModNum) == ViewProviderPythonFeatureImp::NotImplemented)
             ViewProviderT::setEditViewer(viewer,ModNum);
     }
-    virtual void unsetEditViewer(View3DInventorViewer *viewer) override {
+    void unsetEditViewer(View3DInventorViewer *viewer) override {
         if (imp->unsetEditViewer(viewer) == ViewProviderPythonFeatureImp::NotImplemented)
             ViewProviderT::unsetEditViewer(viewer);
     }
 
-    virtual std::string getDropPrefix() const override {
+    std::string getDropPrefix() const override {
         std::string prefix;
         if(!imp->getDropPrefix(prefix))
             return ViewProviderT::getDropPrefix();
         return prefix;
     }
 
-    virtual int replaceObject(App::DocumentObject *oldObj, App::DocumentObject *newObj) override {
+    int replaceObject(App::DocumentObject *oldObj, App::DocumentObject *newObj) override {
         App::AutoTransaction committer;
         switch (imp->replaceObject(oldObj,newObj)) {
         case ViewProviderPythonFeatureImp::Accepted:
@@ -569,7 +569,7 @@ protected:
         }
     }
 
-    virtual ViewProviderDocumentObject *getLinkedViewProvider(
+    ViewProviderDocumentObject *getLinkedViewProvider(
             std::string *subname=nullptr, bool recursive=false) const override{
         ViewProviderDocumentObject *res = nullptr;
         if(!imp->getLinkedViewProvider(res, subname, recursive))
@@ -577,20 +577,20 @@ protected:
         return res;
     }
 
-    virtual void editProperty(const char *propName) override {
+    void editProperty(const char *propName) override {
         if (!imp->editProperty(propName))
             ViewProviderT::editProperty(propName);
     }
 
 public:
-    virtual void setupContextMenu(QMenu* menu, QObject* recipient, const char* member) override
+    void setupContextMenu(QMenu* menu, QObject* recipient, const char* member) override
     {
         if(!imp->setupContextMenu(menu))
             ViewProviderT::setupContextMenu(menu, recipient, member);
     }
 
 protected:
-    virtual bool doubleClicked() override
+    bool doubleClicked() override
     {
         App::AutoTransaction committer;
         switch (imp->doubleClicked()) {
@@ -602,12 +602,18 @@ protected:
             return ViewProviderT::doubleClicked();
         }
     }
-    virtual void setOverrideMode(const std::string &mode) override
+    void setOverrideMode(const std::string &mode) override
     {
         ViewProviderT::setOverrideMode(mode);
         viewerMode = mode;
     }
 
+public:
+    ViewProviderPythonFeatureT(const ViewProviderPythonFeatureT&) = delete;
+    ViewProviderPythonFeatureT(ViewProviderPythonFeatureT&&) = delete;
+    ViewProviderPythonFeatureT& operator= (const ViewProviderPythonFeatureT&) = delete;
+    ViewProviderPythonFeatureT& operator= (ViewProviderPythonFeatureT&&) = delete;
+
 private:
     ViewProviderPythonFeatureImp* imp;
     App::PropertyPythonObject Proxy;
@@ -617,8 +623,8 @@ private:
 };
 
 // Special Feature-Python classes
-typedef ViewProviderPythonFeatureT<ViewProviderDocumentObject> ViewProviderPythonFeature;
-typedef ViewProviderPythonFeatureT<ViewProviderGeometryObject> ViewProviderPythonGeometry;
+using ViewProviderPythonFeature  = ViewProviderPythonFeatureT<ViewProviderDocumentObject>;
+using ViewProviderPythonGeometry = ViewProviderPythonFeatureT<ViewProviderGeometryObject>;
 
 } // namespace Gui
 
