@@ -74,20 +74,23 @@ PropertyEditor::PropertyEditor(QWidget *parent)
     setRootIsDecorated(false);
     setExpandsOnDoubleClick(true);
 
-    QStyleOptionViewItem opt = viewOptions();
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+    QStyleOptionViewItem opt = PropertyEditor::viewOptions();
+#else
+    QStyleOptionViewItem opt;
+    initViewItemOption(&opt);
+#endif
     this->background = opt.palette.dark();
     this->groupColor = opt.palette.color(QPalette::BrightText);
 
     this->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
-    connect(this, SIGNAL(activated(const QModelIndex &)), this, SLOT(onItemActivated(const QModelIndex &)));
-    connect(this, SIGNAL(clicked(const QModelIndex &)), this, SLOT(onItemActivated(const QModelIndex &)));
-    connect(this, SIGNAL(expanded(const QModelIndex &)), this, SLOT(onItemExpanded(const QModelIndex &)));
-    connect(this, SIGNAL(collapsed(const QModelIndex &)), this, SLOT(onItemCollapsed(const QModelIndex &)));
-    connect(propertyModel, SIGNAL(rowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)),
-            this, SLOT(onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)));
-    connect(propertyModel, SIGNAL(rowsRemoved(const QModelIndex &, int, int)),
-            this, SLOT(onRowsRemoved(const QModelIndex &, int, int)));
+    connect(this, &QTreeView::activated, this, &PropertyEditor::onItemActivated);
+    connect(this, &QTreeView::clicked, this, &PropertyEditor::onItemActivated);
+    connect(this, &QTreeView::expanded, this, &PropertyEditor::onItemExpanded);
+    connect(this, &QTreeView::collapsed, this, &PropertyEditor::onItemCollapsed);
+    connect(propertyModel, &QAbstractItemModel::rowsMoved, this, &PropertyEditor::onRowsMoved);
+    connect(propertyModel, &QAbstractItemModel::rowsRemoved, this, &PropertyEditor::onRowsRemoved);
 }
 
 PropertyEditor::~PropertyEditor()
@@ -109,7 +112,7 @@ bool PropertyEditor::isAutomaticExpand(bool) const
 
 void PropertyEditor::onItemExpanded(const QModelIndex &index)
 {
-    PropertyItem* item = static_cast<PropertyItem*>(index.internalPointer());
+    auto item = static_cast<PropertyItem*>(index.internalPointer());
     item->setExpanded(true);
     for(int i=0, c=item->childCount(); i<c; ++i)
         setExpanded(propertyModel->index(i, 0, index), item->child(i)->isExpanded());
@@ -117,7 +120,7 @@ void PropertyEditor::onItemExpanded(const QModelIndex &index)
 
 void PropertyEditor::onItemCollapsed(const QModelIndex &index)
 {
-    PropertyItem* item = static_cast<PropertyItem*>(index.internalPointer());
+    auto item = static_cast<PropertyItem*>(index.internalPointer());
     item->setExpanded(false);
 }
 
@@ -151,17 +154,25 @@ void PropertyEditor::setGroupTextColor(const QColor& c)
     this->groupColor = c;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 QStyleOptionViewItem PropertyEditor::viewOptions() const
 {
     QStyleOptionViewItem option = QTreeView::viewOptions();
     option.showDecorationSelected = true;
     return option;
 }
+#else
+void PropertyEditor::initViewItemOption(QStyleOptionViewItem *option) const
+{
+    QTreeView::initViewItemOption(option);
+    option->showDecorationSelected = true;
+}
+#endif
 
 bool PropertyEditor::event(QEvent* event)
 {
     if (event->type() == QEvent::ShortcutOverride) {
-        QKeyEvent * kevent = static_cast<QKeyEvent*>(event);
+        auto kevent = static_cast<QKeyEvent*>(event);
         Qt::KeyboardModifiers ShiftKeypadModifier = Qt::ShiftModifier | Qt::KeypadModifier;
         if (kevent->modifiers() == Qt::NoModifier ||
             kevent->modifiers() == Qt::ShiftModifier ||
@@ -251,7 +262,7 @@ void PropertyEditor::openEditor(const QModelIndex &index)
         FC_LOG("editor already transacting " << app.getActiveTransaction());
         return;
     }
-    PropertyItem* item = static_cast<PropertyItem*>(editingIndex.internalPointer());
+    auto item = static_cast<PropertyItem*>(editingIndex.internalPointer());
     auto items = item->getPropertyData();
     for(auto propItem=item->parent();items.empty() && propItem;propItem=propItem->parent())
         items = propItem->getPropertyData();
@@ -392,7 +403,7 @@ void PropertyEditor::closeEditor (QWidget * editor, QAbstractItemDelegate::EndEd
         lastIndex = index;
         setCurrentIndex(propertyModel->buddy(index));
 
-        PropertyItem *item = static_cast<PropertyItem*>(index.internalPointer());
+        auto item = static_cast<PropertyItem*>(index.internalPointer());
         // Skip readonly item, because the editor will be disabled and hence
         // does not accept focus, and in turn break Tab/Backtab navigation.
         if (item && item->isReadOnly())
@@ -413,7 +424,7 @@ void PropertyEditor::reset()
     int numRows = propertyModel->rowCount(parent);
     for (int i=0; i<numRows; ++i) {
         QModelIndex index = propertyModel->index(i, 0, parent);
-        PropertyItem *item = static_cast<PropertyItem*>(index.internalPointer());
+        auto item = static_cast<PropertyItem*>(index.internalPointer());
         if (item->childCount() == 0) {
             if(item->isSeparator())
                 setRowHidden(i, parent, true);
@@ -427,7 +438,7 @@ void PropertyEditor::reset()
 void PropertyEditor::onRowsMoved(const QModelIndex &parent, int start, int end, const QModelIndex &dst, int)
 {
     if(parent != dst) {
-        PropertyItem *item = static_cast<PropertyItem*>(parent.internalPointer());
+        auto item = static_cast<PropertyItem*>(parent.internalPointer());
         if(item && item->isSeparator() && item->childCount()==0)
             setRowHidden(parent.row(), propertyModel->parent(parent), true);
         item = static_cast<PropertyItem*>(dst.internalPointer());
@@ -442,7 +453,7 @@ void PropertyEditor::rowsInserted (const QModelIndex & parent, int start, int en
 {
     QTreeView::rowsInserted(parent, start, end);
 
-    PropertyItem *item = static_cast<PropertyItem*>(parent.internalPointer());
+    auto item = static_cast<PropertyItem*>(parent.internalPointer());
     if (item && item->isSeparator() && item->childCount() == end-start+1) {
         setRowHidden(parent.row(), propertyModel->parent(parent), false);
         if(item->isExpanded())
@@ -451,7 +462,7 @@ void PropertyEditor::rowsInserted (const QModelIndex & parent, int start, int en
 
     for (int i=start; i<end; ++i) {
         QModelIndex index = propertyModel->index(i, 0, parent);
-        PropertyItem *child = static_cast<PropertyItem*>(index.internalPointer());
+        auto child = static_cast<PropertyItem*>(index.internalPointer());
         if(child->isSeparator()) {
             // Set group header rows to span all columns
             setFirstColumnSpanned(i, parent, true);
@@ -468,7 +479,7 @@ void PropertyEditor::rowsAboutToBeRemoved (const QModelIndex & parent, int start
 {
     QTreeView::rowsAboutToBeRemoved(parent, start, end);
 
-    PropertyItem *item = static_cast<PropertyItem*>(parent.internalPointer());
+    auto item = static_cast<PropertyItem*>(parent.internalPointer());
     if (item && item->isSeparator() && item->childCount() == end-start+1)
         setRowHidden(parent.row(), propertyModel->parent(parent), true);
 
@@ -498,8 +509,13 @@ void PropertyEditor::drawBranches(QPainter *painter, const QRect &rect, const QM
 {
     QTreeView::drawBranches(painter, rect, index);
 
-    QStyleOptionViewItem opt = viewOptions();
-    PropertyItem *property = static_cast<PropertyItem*>(index.internalPointer());
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+    //QStyleOptionViewItem opt = viewOptions();
+#else
+    //QStyleOptionViewItem opt;
+    //initViewItemOption(&opt);
+#endif
+    auto property = static_cast<PropertyItem*>(index.internalPointer());
     if (property && property->isSeparator()) {
         painter->fillRect(rect, this->background);
     //} else if (selectionModel()->isSelected(index)) {
@@ -568,7 +584,7 @@ void PropertyEditor::setEditorMode(const QModelIndex & parent, int start, int en
     int column = 1;
     for (int i=start; i<=end; i++) {
         QModelIndex item = propertyModel->index(i, column, parent);
-        PropertyItem* propItem = static_cast<PropertyItem*>(item.internalPointer());
+        auto propItem = static_cast<PropertyItem*>(item.internalPointer());
         if (!PropertyView::showAll() && propItem && propItem->testStatus(App::Property::Hidden)) {
             setRowHidden (i, parent, true);
         }
@@ -624,13 +640,14 @@ void PropertyEditor::contextMenuEvent(QContextMenuEvent *) {
     auto contextIndex = currentIndex();
 
     std::unordered_set<App::Property*> props;
-    for(auto index : selectedIndexes()) {
+    const auto indexes = selectedIndexes();
+    for(const auto& index : indexes) {
         auto item = static_cast<PropertyItem*>(index.internalPointer());
         if(item->isSeparator())
             continue;
         for(auto parent=item;parent;parent=parent->parent()) {
             const auto &ps = parent->getPropertyData();
-            if(ps.size()) {
+            if(!ps.empty()) {
                 props.insert(ps.begin(),ps.end());
                 break;
             }
@@ -654,7 +671,7 @@ void PropertyEditor::contextMenuEvent(QContextMenuEvent *) {
     }
 
     if(PropertyView::showAll()) {
-        if(props.size()) {
+        if(!props.empty()) {
             menu.addAction(tr("Add property"))->setData(QVariant(MA_AddProp));
             if (std::all_of(props.begin(), props.end(), [](auto prop) {
                     return prop->testStatus(App::Property::PropDynamic)
@@ -680,7 +697,7 @@ void PropertyEditor::contextMenuEvent(QContextMenuEvent *) {
         if(canRemove)
             menu.addAction(tr("Remove property"))->setData(QVariant(MA_RemoveProp));
 
-        if(props.size()) {
+        if(!props.empty()) {
             menu.addSeparator();
 
             QAction *action;
