@@ -69,7 +69,7 @@ QVariant PropertyModel::data ( const QModelIndex & index, int role ) const
     if (!index.isValid())
         return QVariant();
 
-    PropertyItem *item = static_cast<PropertyItem*>(index.internalPointer());
+    auto item = static_cast<PropertyItem*>(index.internalPointer());
     return item->data(index.column(), role);
 }
 
@@ -80,9 +80,9 @@ bool PropertyModel::setData(const QModelIndex& index, const QVariant & value, in
 
     // we check whether the data has really changed, otherwise we ignore it
     if (role == Qt::EditRole) {
-        PropertyItem *item = static_cast<PropertyItem*>(index.internalPointer());
+        auto item = static_cast<PropertyItem*>(index.internalPointer());
         QVariant data = item->data(index.column(), role);
-        if (data.type() == QVariant::Double && value.type() == QVariant::Double) {
+        if (data.userType() == QMetaType::Double && value.userType() == QMetaType::Double) {
             // since we store some properties as floats we get some round-off
             // errors here. Thus, we use an epsilon here.
             // NOTE: Since 0.14 PropertyFloat uses double precision, so this is maybe unnecessary now?
@@ -107,7 +107,7 @@ bool PropertyModel::setData(const QModelIndex& index, const QVariant & value, in
 
 Qt::ItemFlags PropertyModel::flags(const QModelIndex &index) const
 {
-    PropertyItem *item = static_cast<PropertyItem*>(index.internalPointer());
+    auto item = static_cast<PropertyItem*>(index.internalPointer());
     return item->flags(index.column());
 }
 
@@ -132,7 +132,7 @@ QModelIndex PropertyModel::parent ( const QModelIndex & index ) const
     if (!index.isValid())
         return QModelIndex();
 
-    PropertyItem *childItem = static_cast<PropertyItem*>(index.internalPointer());
+    auto childItem = static_cast<PropertyItem*>(index.internalPointer());
     PropertyItem *parentItem = childItem->parent();
 
     if (parentItem == rootItem)
@@ -176,7 +176,7 @@ QStringList PropertyModel::propertyPathFromIndex(const QModelIndex& index) const
 {
     QStringList path;
     if (index.isValid()) {
-        PropertyItem* item = static_cast<PropertyItem*>(index.internalPointer());
+        auto item = static_cast<PropertyItem*>(index.internalPointer());
         while (item && item != this->rootItem) {
             path.push_front(item->propertyName());
             item = item->parent();
@@ -245,7 +245,7 @@ static PropertyItem *createPropertyItem(App::Property *prop)
 PropertyModel::GroupInfo &PropertyModel::getGroupInfo(App::Property *prop)
 {
     const char* group = prop->getGroup();
-    bool isEmpty = (group == nullptr || group[0] == '\0');
+    bool isEmpty = (!group || group[0] == '\0');
     QString groupName = QString::fromLatin1(
             isEmpty ? QT_TRANSLATE_NOOP("App::Property", "Base") : group);
 
@@ -282,63 +282,93 @@ void PropertyModel::buildUp(const PropertyModel::PropertyList& props)
     // If props empty, then simply reset all property items, but keep the group
     // items.
     if (props.empty()) {
-        beginResetModel();
-        for(auto &v : groupItems) {
-            auto &groupInfo = v.second;
-            groupInfo.groupItem->reset();
-            groupInfo.children.clear();
-        }
-        itemMap.clear();
-        endResetModel();
+        resetGroups();
         return;
     }
 
     // First step, init group info
-    for (auto &v : groupItems) {
-        auto &groupInfo = v.second;
-        groupInfo.children.clear();
-    }
+    initGroups();
 
     // Second step, either find existing items or create new items for the given
     // properties. There is no signaling of model change at this stage. The
     // change information is kept pending in GroupInfo::children
-    for (auto jt = props.begin(); jt != props.end(); ++jt) {
-        App::Property* prop = jt->second.front();
+    findOrCreateChildren(props);
+
+    // Third step, signal item insertion and movement.
+    insertOrMoveChildren();
+
+
+    // Final step, signal item removal. This is separated from the above because
+    // of the possibility of moving items between groups.
+    removeChildren();
+}
+
+void PropertyModel::resetGroups()
+{
+    beginResetModel();
+    for(auto &v : groupItems) {
+        auto &groupInfo = v.second;
+        groupInfo.groupItem->reset();
+        groupInfo.children.clear();
+    }
+    itemMap.clear();
+    endResetModel();
+}
+
+void PropertyModel::initGroups()
+{
+    for (auto &v : groupItems) {
+        auto &groupInfo = v.second;
+        groupInfo.children.clear();
+    }
+}
+
+void PropertyModel::findOrCreateChildren(const PropertyModel::PropertyList& props)
+{
+    for (const auto & jt : props) {
+        App::Property* prop = jt.second.front();
 
         PropertyItem *item = nullptr;
-        for (auto prop : jt->second) {
+        for (auto prop : jt.second) {
             auto it = itemMap.find(prop);
-            if (it == itemMap.end() || !it->second)
+            if (it == itemMap.end() || !it->second) {
                 continue;
+            }
             item = it->second;
             break;
         }
 
         if (!item) {
             item = createPropertyItem(prop);
-            if (!item)
+            if (!item) {
                 continue;
+            }
         }
 
         GroupInfo &groupInfo = getGroupInfo(prop);
         groupInfo.children.push_back(item);
 
-        item->setLinked(boost::ends_with(jt->first,"*"));
+        item->setLinked(boost::ends_with(jt.first,"*"));
         setPropertyItemName(item, prop->getName(), groupInfo.groupItem->propertyName());
 
-        if (jt->second != item->getPropertyData()) {
-            for (auto prop : item->getPropertyData())
+        if (jt.second != item->getPropertyData()) {
+            for (auto prop : item->getPropertyData()) {
                 itemMap.erase(prop);
-            for (auto prop : jt->second)
+            }
+            for (auto prop : jt.second) {
                 itemMap[prop] = item;
+            }
             // TODO: is it necessary to make sure the item has no pending commit?
-            item->setPropertyData(jt->second);
+            item->setPropertyData(jt.second);
         }
-        else
+        else {
             item->updateData();
+        }
     }
+}
 
-    // Third step, signal item insertion and movement.
+void PropertyModel::insertOrMoveChildren()
+{
     for (auto &v : groupItems) {
         auto &groupInfo = v.second;
         int beginChange = -1;
@@ -375,10 +405,12 @@ void PropertyModel::buildUp(const PropertyModel::PropertyList& props)
             if (!item->parent()) {
                 flushChanges();
                 item->setParent(groupInfo.groupItem);
-                if (beginInsert < 0)
+                if (beginInsert < 0) {
                     beginInsert = row;
+                }
                 endInsert = row;
-            } else {
+            }
+            else {
                 flushInserts();
                 int oldRow = item->row();
                 // Dynamic property can rename group, so must check
@@ -388,12 +420,14 @@ void PropertyModel::buildUp(const PropertyModel::PropertyList& props)
                     if (beginChange < 0)
                         beginChange = row;
                     endChange = row;
-                } else {
+                }
+                else {
                     flushChanges();
-                    beginMoveRows(createIndex(groupItem->row(),0,groupItem),
-                            oldRow, oldRow, midx, row);
-                    if (groupItem == groupInfo.groupItem)
+                    beginMoveRows(createIndex(groupItem->row(), 0, groupItem),
+                                  oldRow, oldRow, midx, row);
+                    if (groupItem == groupInfo.groupItem) {
                         groupInfo.groupItem->moveChild(oldRow, row);
+                    }
                     else {
                         groupItem->takeChild(oldRow);
                         item->setParent(groupInfo.groupItem);
@@ -403,27 +437,37 @@ void PropertyModel::buildUp(const PropertyModel::PropertyList& props)
                 }
             }
         }
+
         flushChanges();
         flushInserts();
     }
+}
 
-    // Final step, signal item removal. This is separated from the above because
-    // of the possibility of moving items between groups.
+void PropertyModel::removeChildren()
+{
     for (auto &v : groupItems) {
         auto &groupInfo = v.second;
-        int last = groupInfo.groupItem->childCount();
-        int first = static_cast<int>(groupInfo.children.size());
+        int first, last;
+        getRange(groupInfo, first, last);
         if (last > first) {
-            QModelIndex midx = this->index(groupInfo.groupItem->_row,0,QModelIndex());
-            beginRemoveRows(midx, first, last-1);
-            groupInfo.groupItem->removeChildren(first, last-1);
+            QModelIndex midx = this->index(groupInfo.groupItem->_row, 0, QModelIndex());
+            // This can trigger a recursive call of PropertyView::onTimer()
+            beginRemoveRows(midx, first, last - 1);
+            groupInfo.groupItem->removeChildren(first, last - 1);
             endRemoveRows();
-        } else {
+        }
+        else {
             assert(last == first);
         }
     }
 }
 
+void PropertyModel::getRange(const PropertyModel::GroupInfo& groupInfo, int& first, int& last) const
+{
+    first = static_cast<int>(groupInfo.children.size());
+    last = groupInfo.groupItem->childCount();
+}
+
 void PropertyModel::updateProperty(const App::Property& prop)
 {
     auto it = itemMap.find(const_cast<App::Property*>(&prop));
@@ -436,7 +480,7 @@ void PropertyModel::updateProperty(const App::Property& prop)
     QModelIndex parent = this->index(item->parent()->row(), 0, QModelIndex());
     item->assignProperty(&prop);
     QModelIndex data = this->index(item->row(), column, parent);
-    dataChanged(data, data);
+    Q_EMIT dataChanged(data, data);
     updateChildren(item, column, data);
 }
 
@@ -492,16 +536,7 @@ void PropertyModel::updateChildren(PropertyItem* item, int column, const QModelI
     if (numChild > 0) {
         QModelIndex topLeft = this->index(0, column, parent);
         QModelIndex bottomRight = this->index(numChild, column, parent);
-        dataChanged(topLeft, bottomRight);
-#if 0 // It seems we don't have to inform grand children
-        for (int row=0; row<numChild; row++) {
-            PropertyItem* child = item->child(row);
-            QModelIndex data = this->index(row, column, parent);
-            if (data.isValid()) {
-                updateChildren(child, column, data);
-            }
-        }
-#endif
+        Q_EMIT dataChanged(topLeft, bottomRight);
     }
 }
 
