@@ -20,12 +20,15 @@
 #*                                                                         *
 #***************************************************************************
 
-
-from __future__ import print_function
-
-import FreeCAD, Part, DraftGeomUtils, WorkingPlane, DraftVecUtils, math
+import math
 from datetime import datetime
 
+import FreeCAD
+import DraftGeomUtils
+import DraftVecUtils
+import Part
+import WorkingPlane
+
 # This is roughly based on the no-fit polygon algorithm, used in
 # SvgNest: https://github.com/Jack000/SVGnest
 # Wikihouse plugin: https://github.com/tav/wikihouse-plugin/blob/master/wikihouse.rb
