@@ -122,7 +122,7 @@ class FreeCADGuiHandler(xml.sax.ContentHandler):
     # plus a GuiCameraSettings key that contains an iv repr of a coin camera
 
     def __init__(self):
-        
+
         super().__init__()
         self.guidata = {}
         self.current = None
@@ -188,7 +188,7 @@ class FreeCADGuiHandler(xml.sax.ContentHandler):
                 self.current = None
                 self.properties = {}
         elif tag == "Property":
-            if self.currentprop and (self.currentval != None):
+            if self.currentprop and (self.currentval is not None):
                 self.properties[self.currentprop] = {"type":self.currenttype,"value":self.currentval}
                 self.currentprop = None
                 self.currentval = None
@@ -216,7 +216,7 @@ def getGuiData(filename):
             for key,properties in guidata.items():
                 # open each diffusecolor files and retrieve values
                 # first 4 bytes are the array length, then each group of 4 bytes is abgr
-                # https://forum.freecadweb.org/viewtopic.php?t=29382
+                # https://forum.freecad.org/viewtopic.php?t=29382
                 if isinstance(properties,dict):
                     for propname in properties.keys():
                         if properties[propname]["type"] == "App::PropertyColorList":
@@ -225,10 +225,7 @@ def getGuiData(filename):
                             df.close()
                             cols = []
                             for i in range(1,int(len(buf)/4)):
-                                if sys.version_info.major < 3:
-                                    cols.append(ord(buf[i*4+3])/255.0,ord(buf[i*4+2])/255.0,ord(buf[i*4+1])/255.0,ord(buf[i*4])/255.0)
-                                else:
-                                    cols.append((buf[i*4+3]/255.0,buf[i*4+2]/255.0,buf[i*4+1]/255.0,buf[i*4]/255.0))
+                                cols.append((buf[i*4+3]/255.0,buf[i*4+2]/255.0,buf[i*4+1]/255.0,buf[i*4]/255.0))
                             guidata[key][propname]["value"] = cols
         zdoc.close()
         #print ("guidata:",guidata)
@@ -243,11 +240,7 @@ def saveDiffuseColor(colorlist):
     property. Returns the path to the created temp file"""
 
     def tochr(i):
-        #print("tochr:",i)
-        if sys.version_info.major < 3:
-            return chr(i)
-        else:
-            return bytes((i,))
+        return bytes((i,))
     # if too many colors, bail out and use only the first one for now...
     if len(colorlist) > 254:
         colorlist = colorlist[:1]
@@ -292,7 +285,7 @@ def getColors(filename,nodiffuse=False):
         if ("DiffuseColor" in v) and (not nodiffuse):
             if len(v["DiffuseColor"]["value"]) == 1:
                 # only one color in DiffuseColor: used for the whole object
-                 colors[k] = v["DiffuseColor"]["value"][0]
+                colors[k] = v["DiffuseColor"]["value"][0]
             else:
                 colors[k] = v["DiffuseColor"]["value"]
         elif "ShapeColor" in v:
@@ -623,7 +616,7 @@ def getUnsigned(color):
     # ensure everything is int otherwise bit ops below don't work
     color = (int(color[0]),int(color[1]),int(color[2]))
 
-    # https://forum.freecadweb.org/viewtopic.php?t=19074
+    # https://forum.freecad.org/viewtopic.php?t=19074
     return str(color[0] << 24 | color[1] << 16 | color[2] << 8)
 
 
@@ -639,7 +632,7 @@ def buildGuiDocumentFromColors(document,colors,camera=None):
 
     guidoc =  "<?xml version='1.0' encoding='utf-8'?>\n"
     guidoc += "<!--\n"
-    guidoc += " FreeCAD Document, see http://www.freecadweb.org for more information...\n"
+    guidoc += " FreeCAD Document, see http://www.freecad.org for more information...\n"
     guidoc += "-->\n"
     guidoc += "<Document SchemaVersion=\"1\">\n"
 
@@ -718,7 +711,7 @@ def buildGuiDocumentFromGuiData(document,guidata):
 
     guidoc =  "<?xml version='1.0' encoding='utf-8'?>\n"
     guidoc += "<!--\n"
-    guidoc += " FreeCAD Document, see http://www.freecadweb.org for more information...\n"
+    guidoc += " FreeCAD Document, see http://www.freecad.org for more information...\n"
     guidoc += "-->\n"
     guidoc += "<Document SchemaVersion=\"1\">\n"
 
