@@ -74,8 +74,8 @@ class TaskPanelPolarArray:
 
     See Also
     --------
-    * https://forum.freecadweb.org/viewtopic.php?f=10&t=40007
-    * https://forum.freecadweb.org/viewtopic.php?t=5374#p43038
+    * https://forum.freecad.org/viewtopic.php?f=10&t=40007
+    * https://forum.freecad.org/viewtopic.php?t=5374#p43038
     """
 
     def __init__(self):
@@ -156,10 +156,6 @@ class TaskPanelPolarArray:
         self.form.checkbox_fuse.stateChanged.connect(self.set_fuse)
         self.form.checkbox_link.stateChanged.connect(self.set_link)
 
-        # Old style for Qt4, avoid!
-        # QtCore.QObject.connect(self.form.button_reset,
-        #                        QtCore.SIGNAL("clicked()"),
-        #                        self.reset_point)
 
     def accept(self):
         """Execute when clicking the OK button or Enter key."""
