@@ -20,36 +20,29 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
 # include <sstream>
+
 # include <BRep_Builder.hxx>
 # include <Standard_Failure.hxx>
 # include <TopoDS_Compound.hxx>
 #endif
 
-
-#include <Base/Writer.h>
-#include <Base/Reader.h>
-#include <Base/Exception.h>
-#include <Base/FileInfo.h>
-
 #include "FeatureProjection.h"
 #include "ProjectionAlgos.h"
 
+
 using namespace Drawing;
 
-
 PROPERTY_SOURCE(Drawing::FeatureProjection, Part::Feature)
 
-
 FeatureProjection::FeatureProjection() 
 {
     static const char *group = "Projection";
     ADD_PROPERTY_TYPE(Source ,(nullptr),group,App::Prop_None,"Shape to project");
-    ADD_PROPERTY_TYPE(Direction ,(Base::Vector3d(0,0,1)),group,App::Prop_None,"Projection direction");
+    ADD_PROPERTY_TYPE(Direction, (Base::Vector3d(0, 0, 1)), group, App::Prop_None,
+                      "Projection direction");
     ADD_PROPERTY_TYPE(VCompound        ,(true),group,App::Prop_None,"Projection parameter");
     ADD_PROPERTY_TYPE(Rg1LineVCompound ,(true),group,App::Prop_None,"Projection parameter");
     ADD_PROPERTY_TYPE(RgNLineVCompound ,(true),group,App::Prop_None,"Projection parameter");
