@@ -20,24 +20,18 @@
  *                                                                         *
  ***************************************************************************/
 
- 
-
-
 #ifndef _FeatureView_h_
 #define _FeatureView_h_
 
-
 #include <App/DocumentObject.h>
-#include <App/PropertyStandard.h>
-#include <App/PropertyGeo.h>
 #include <App/FeaturePython.h>
+#include <App/PropertyStandard.h>
 #include <Mod/Drawing/DrawingGlobal.h>
 
 
 namespace Drawing
 {
 
-
 /** Base class of all View Features in the drawing module
  */
 class DrawingExport FeatureView : public App::DocumentObject
@@ -67,7 +61,7 @@ protected:
     //@}
 };
 
-typedef App::FeaturePythonT<FeatureView> FeatureViewPython;
+using FeatureViewPython = App::FeaturePythonT<FeatureView>;
 
 } //namespace Drawing
 
