@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef DRAWINGGUI_PRECOMPILED_H
 #define DRAWINGGUI_PRECOMPILED_H
 
@@ -32,31 +31,38 @@
 
 #ifdef _PreComp_
 
-// standard
-#include <iostream>
-#include <cassert>
-#include <cmath>
-
 // STL
+#include <cmath>
+#include <sstream>
 #include <vector>
-#include <map>
-#include <string>
-#include <list>
-#include <set>
-#include <algorithm>
-#include <stack>
-#include <queue>
-#include <bitset>
 
-#ifdef FC_OS_WIN32
-# include <windows.h>
-#endif
-
-
-// Qt Toolkit
-#ifndef __QtAll__
-# include <Gui/QtAll.h>
-#endif
+// Qt
+#include <QAction>
+#include <QApplication>
+#include <QCheckBox>
+#include <QContextMenuEvent>
+#include <QCoreApplication>
+#include <QDir>
+#include <QFile>
+#include <QFileDialog>
+#include <QFileInfo>
+#include <QGLWidget>
+#include <QGraphicsRectItem>
+#include <QGraphicsSvgItem>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QLineEdit>
+#include <QListWidget>
+#include <QMenu>
+#include <QMessageBox>
+#include <QPainter>
+#include <QPaintEvent>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <QPrintPreviewDialog>
+#include <QRegExp>
+#include <QTimer>
+#include <QWheelEvent>
 
 #endif //_PreComp_
 
