@@ -22,23 +22,19 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <QCheckBox>
 # include <QLineEdit>
 # include <QMenu>
 #endif
 
-#include "TaskOrthoViews.h"
-#include "ui_TaskOrthoViews.h"
-
 #include <App/Document.h>
 #include <Gui/Application.h>
 #include <Gui/BitmapFactory.h>
-#include <Gui/Command.h>
 #include <Gui/Control.h>
-#include <Mod/Part/App/PartFeature.h>
 #include <Mod/Drawing/App/FeaturePage.h>
+#include <Mod/Part/App/PartFeature.h>
 
-#include <boost_bind_bind.hpp>
+#include "TaskOrthoViews.h"
+#include "ui_TaskOrthoViews.h"
 
 
 using namespace Gui;
@@ -53,12 +49,7 @@ namespace bp = boost::placeholders;
 #endif
 
 
-#if _MSC_VER <= 1700
-// maybe in the c++ standard later, older compiler don't have round()
-double round(double r) {
-    return (r > 0.0) ? floor(r + 0.5) : ceil(r - 0.5);
-}
-#endif  // _MSC_VER < 1500
+
 
 void pagesize(string & page_template, int dims[4], int block[4])
 {
