@@ -32,11 +32,11 @@ namespace Fem
 
 class FemExport ConstraintContact : public Fem::Constraint
 {
-    PROPERTY_HEADER(Fem::ConstraintContact);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::ConstraintContact);
 
 public:
     /// Constructor
-    ConstraintContact(void);
+    ConstraintContact();
 
     // Read-only (calculated values). These trigger changes in the ViewProvider
     App::PropertyVectorList Points;
@@ -57,13 +57,13 @@ public:
 /* */
 
     /// recalculate the object
-    virtual App::DocumentObjectExecReturn *execute(void);
+    App::DocumentObjectExecReturn *execute() override;
 
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const;
+    const char* getViewProviderName() const override;
 
 protected:
-    virtual void onChanged(const App::Property* prop);
+    void onChanged(const App::Property* prop) override;
 
 };
 
