@@ -32,26 +32,26 @@ namespace Fem
 
 class FemExport ConstraintFixed : public Fem::Constraint
 {
-    PROPERTY_HEADER(Fem::ConstraintFixed);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::ConstraintFixed);
 
 public:
     /// Constructor
-    ConstraintFixed(void);
+    ConstraintFixed();
 
     // Read-only (calculated values). These trigger changes in the ViewProvider
     App::PropertyVectorList Points;
     App::PropertyVectorList Normals;
 
     /// recalculate the object
-    virtual App::DocumentObjectExecReturn *execute(void);
+    App::DocumentObjectExecReturn *execute() override;
 
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "FemGui::ViewProviderFemConstraintFixed";
     }
 
 protected:
-    virtual void onChanged(const App::Property* prop);
+    void onChanged(const App::Property* prop) override;
 };
 
 } //namespace Fem
