@@ -32,11 +32,11 @@ namespace Fem
 
 class FemExport ConstraintGear : public Fem::ConstraintBearing
 {
-    PROPERTY_HEADER(Fem::ConstraintGear);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::ConstraintGear);
 
 public:
     /// Constructor
-    ConstraintGear(void);
+    ConstraintGear();
 
     App::PropertyFloat Diameter;
     App::PropertyFloat Force;
@@ -47,15 +47,15 @@ public:
     App::PropertyVector DirectionVector;
 
     /// recalculate the object
-    virtual App::DocumentObjectExecReturn *execute(void);
+    App::DocumentObjectExecReturn *execute() override;
 
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "FemGui::ViewProviderFemConstraintGear";
     }
 
 protected:
-    virtual void onChanged(const App::Property* prop);
+    void onChanged(const App::Property* prop) override;
 
 private:
     Base::Vector3d naturalDirectionVector;
