@@ -34,28 +34,30 @@ namespace Fem
 
 class FemExport ConstraintInitialTemperature : public Fem::Constraint
 {
-    PROPERTY_HEADER(Fem::ConstraintInitialTemperature);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::ConstraintInitialTemperature);
 
 public:
     /// Constructor
-    ConstraintInitialTemperature(void);
+    ConstraintInitialTemperature();
 
     // Read-only (calculated values). These trigger changes in the ViewProvider
     App::PropertyVectorList Points;
     App::PropertyVectorList Normals;
 
     //Temperature parameters
-    App::PropertyFloat initialTemperature;
+    App::PropertyTemperature initialTemperature;
 
 
     /// recalculate the object
-    virtual App::DocumentObjectExecReturn *execute(void);
+    App::DocumentObjectExecReturn *execute() override;
 
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const;
+    const char* getViewProviderName() const override;
 
 protected:
-    virtual void onChanged(const App::Property* prop);
+    void handleChangedPropertyType(Base::XMLReader& reader, const char* TypeName,
+                                   App::Property* prop);
+    void onChanged(const App::Property* prop) override;
 
 };
 
