@@ -31,10 +31,10 @@ namespace Fem {
 
 class FemExport ConstraintPressure : public Fem::Constraint
 {
-    PROPERTY_HEADER(Fem::ConstraintPressure);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::ConstraintPressure);
 
 public:
-    ConstraintPressure(void);
+    ConstraintPressure();
 
     App::PropertyFloat Pressure;
     App::PropertyBool Reversed;
@@ -42,13 +42,13 @@ public:
     App::PropertyVectorList Normals;
 
     /// recalculate the object
-    virtual App::DocumentObjectExecReturn *execute(void);
+    App::DocumentObjectExecReturn *execute() override;
 
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const;
+    const char* getViewProviderName() const override;
 
 protected:
-    virtual void onChanged(const App::Property* prop);
+    void onChanged(const App::Property* prop) override;
 };
 
 }
