@@ -28,6 +28,7 @@
 # include <BRepBuilderAPI_Copy.hxx>
 # include <BRepTools.hxx>
 # include <SMESH_Gen.hxx>
+# include <SMESH_Mesh.hxx>
 # include <StdMeshers_MaxLength.hxx>
 # include <StdMeshers_LocalLength.hxx>
 # include <StdMeshers_MaxElementArea.hxx>
@@ -60,14 +61,16 @@ PROPERTY_SOURCE(Fem::FemMeshShapeObject, Fem::FemMeshObject)
 
 FemMeshShapeObject::FemMeshShapeObject()
 {
-    ADD_PROPERTY_TYPE(Shape,(nullptr), "FEM Mesh",Prop_None,"Geometry object, the mesh is made from. The geometry object has to have a Shape.");
+    ADD_PROPERTY_TYPE(
+        Shape, (nullptr), "FEM Mesh", Prop_None,
+        "Geometry object, the mesh is made from. The geometry object has to have a Shape.");
 }
 
 FemMeshShapeObject::~FemMeshShapeObject()
 {
 }
 
-App::DocumentObjectExecReturn *FemMeshShapeObject::execute(void)
+App::DocumentObjectExecReturn *FemMeshShapeObject::execute()
 {
     Fem::FemMesh newMesh;
 
@@ -211,21 +214,6 @@ App::DocumentObjectExecReturn *FemMeshShapeObject::execute(void)
     myNetGenMesher.Compute();
 #endif
 
-
-
-    //SMESHDS_Mesh* data = const_cast<SMESH_Mesh*>(newMesh.getSMesh())->GetMeshDS();
-    //const SMDS_MeshInfo& info = data->GetMeshInfo();
-    //int numNode = info.NbNodes();
-    //int numTria = info.NbTriangles();
-    //int numQuad = info.NbQuadrangles();
-    //int numPoly = info.NbPolygons();
-    //int numVolu = info.NbVolumes();
-    //int numTetr = info.NbTetras();
-    //int numHexa = info.NbHexas();
-    //int numPyrd = info.NbPyramids();
-    //int numPris = info.NbPrisms();
-    //int numHedr = info.NbPolyhedrons();
-
     // set the value to the object
     FemMesh.setValue(newMesh);
 
