@@ -36,22 +36,22 @@ namespace Fem
 
 class FemExport FemPostPipeline : public Fem::FemPostFilter
 {
-    PROPERTY_HEADER(Fem::FemPostPipeline);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::FemPostPipeline);
 
 public:
     /// Constructor
-    FemPostPipeline(void);
-    virtual ~FemPostPipeline();
+    FemPostPipeline();
+    ~FemPostPipeline() override;
 
     App::PropertyLinkList       Filter;
     App::PropertyLink           Functions;
     App::PropertyEnumeration    Mode;
 
-    short mustExecute(void) const;
-    virtual App::DocumentObjectExecReturn* execute(void);
-    PyObject* getPyObject();
+    short mustExecute() const override;
+    App::DocumentObjectExecReturn* execute() override;
+    PyObject* getPyObject() override;
 
-    virtual const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "FemGui::ViewProviderFemPostPipeline";
     }
 
@@ -69,7 +69,7 @@ public:
     bool holdsPostObject(FemPostObject *obj);
 
 protected:
-    virtual void onChanged(const App::Property *prop);
+    void onChanged(const App::Property *prop) override;
 
 private:
     static const char* ModeEnums[];
