@@ -33,24 +33,24 @@ namespace Fem
 
 class FemExport FemSetNodesObject : public FemSetObject
 {
-    PROPERTY_HEADER(Fem::FemSetNodesObject);
+    PROPERTY_HEADER_WITH_OVERRIDE(Fem::FemSetNodesObject);
 
 public:
     /// Constructor
-    FemSetNodesObject(void);
-    virtual ~FemSetNodesObject();
+    FemSetNodesObject();
+    ~FemSetNodesObject() override;
 
     App::PropertyIntegerSet Nodes;
 
     // returns the type name of the ViewProvider
-    virtual const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "FemGui::ViewProviderSetNodes";
     }
-    virtual App::DocumentObjectExecReturn *execute(void) {
+    App::DocumentObjectExecReturn *execute() override {
         return App::DocumentObject::StdReturn;
     }
-    virtual short mustExecute(void) const;
-    virtual PyObject *getPyObject(void);
+    short mustExecute() const override;
+    PyObject *getPyObject() override;
 
 
 };
