@@ -22,9 +22,13 @@
 
 #include "PreCompiled.h"
 
+// HypothesisPy.h must be included as first file to avoid compiler warning,
+// see: https://forum.freecad.org/viewtopic.php?p=633192#p633192
+#include "HypothesisPy.h"
+
 #ifndef _PreComp_
 # include <sstream>
-
+# include <SMESH_Version.h> // needed for SMESH_VERSION_MAJOR
 # include <StdMeshers_Arithmetic1D.hxx>
 # include <StdMeshers_AutomaticLength.hxx>
 # include <StdMeshers_CompositeSegment_1D.hxx>
@@ -64,7 +68,6 @@
 #include <Base/Interpreter.h>
 #include <Mod/Part/App/TopoShapePy.h>
 
-#include "HypothesisPy.h"
 #include "FemMeshPy.h"
 
 
@@ -134,7 +137,7 @@ Py::Object SMESH_HypothesisPy<T>::repr()
 template<class T>
 Py::Object SMESH_HypothesisPy<T>::setLibName(const Py::Tuple& args)
 {
-    std::string libName = (std::string)Py::String(args[0]);
+    std::string libName = static_cast<std::string>(Py::String(args[0]));
     hypothesis<SMESH_Hypothesis>()->SetLibName(libName.c_str());
     return Py::None();
 }
@@ -152,7 +155,7 @@ Py::Object SMESH_HypothesisPy<T>::getLibName(const Py::Tuple& args)
 template<class T>
 Py::Object SMESH_HypothesisPy<T>::setParameters(const Py::Tuple& args)
 {
-    std::string paramName = (std::string)Py::String(args[0]);
+    std::string paramName = static_cast<std::string>(Py::String(args[0]));
     hypothesis<SMESH_Hypothesis>()->SetParameters(paramName.c_str());
     return Py::None();
 }
@@ -170,7 +173,7 @@ Py::Object SMESH_HypothesisPy<T>::setLastParameters(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
-    std::string paramName = (std::string)Py::String(args[0]);
+    std::string paramName = static_cast<std::string>(Py::String(args[0]));
     hypothesis<SMESH_Hypothesis>()->SetLastParameters(paramName.c_str());
     return Py::None();
 }
@@ -317,8 +320,8 @@ Py::Object StdMeshers_AutomaticLengthPy::getFineness(const Py::Tuple& args)
 }
 
 namespace Py {
-    typedef ExtensionObject<Fem::FemMeshPy>         FemMesh;
-    typedef ExtensionObject<Part::TopoShapePy>      TopoShape;
+    using FemMesh = ExtensionObject<Fem::FemMeshPy>;
+    using TopoShape = ExtensionObject<Part::TopoShapePy>;
     template<> bool FemMesh::accepts (PyObject *pyob) const
     {
         return (pyob && PyObject_TypeCheck(pyob, &(Fem::FemMeshPy::Type)));
