@@ -23,21 +23,34 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
+#ifndef _PreComp_
+# include <QThread>
+# include <QMessageBox>
+#endif
+
+#include <App/Application.h>
 
 #include "DlgSettingsFemCcxImp.h"
 #include "ui_DlgSettingsFemCcx.h"
-#include <Gui/Application.h>
-#include <Gui/PrefWidgets.h>
+
 
 using namespace FemGui;
 
-DlgSettingsFemCcxImp::DlgSettingsFemCcxImp( QWidget* parent )
-  : PreferencePage( parent )
-  , ui(new Ui_DlgSettingsFemCcxImp)
+DlgSettingsFemCcxImp::DlgSettingsFemCcxImp(QWidget* parent)
+    : PreferencePage(parent)
+    , ui(new Ui_DlgSettingsFemCcxImp)
 {
     ui->setupUi(this);
+    // set ranges
+    ui->dsb_ccx_analysis_time->setMaximum(FLOAT_MAX);
+    ui->dsb_ccx_initial_time_step->setMaximum(FLOAT_MAX);
+    // determine number of CPU cores
+    int processor_count = QThread::idealThreadCount();
+    ui->sb_ccx_numcpu->setMaximum(processor_count);
+
+    connect(ui->fc_ccx_binary_path, &Gui::PrefFileChooser::fileNameChanged,
+            this, &DlgSettingsFemCcxImp::onfileNameChanged);
 }
 
 DlgSettingsFemCcxImp::~DlgSettingsFemCcxImp()
@@ -47,8 +60,8 @@ DlgSettingsFemCcxImp::~DlgSettingsFemCcxImp()
 
 void DlgSettingsFemCcxImp::saveSettings()
 {
-    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath
-        ("User parameter:BaseApp/Preferences/Mod/Fem/Ccx");
+    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath(
+        "User parameter:BaseApp/Preferences/Mod/Fem/Ccx");
     hGrp->SetInt("Solver", ui->cmb_solver->currentIndex());
     hGrp->SetInt("AnalysisType", ui->cb_analysis_type->currentIndex());
 
@@ -99,18 +112,20 @@ void DlgSettingsFemCcxImp::loadSettings()
     ui->fc_ccx_binary_path->onRestore();
     ui->cb_split_inp_writer->onRestore();
 
-    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath
-        ("User parameter:BaseApp/Preferences/Mod/Fem/Ccx");
-    int index =  hGrp->GetInt("Solver", 0);
-    if (index > -1) ui->cmb_solver->setCurrentIndex(index);
-    index =  hGrp->GetInt("AnalysisType", 0);
-    if (index > -1) ui->cb_analysis_type->setCurrentIndex(index);
+    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath(
+        "User parameter:BaseApp/Preferences/Mod/Fem/Ccx");
+    int index = hGrp->GetInt("Solver", 0);
+    if (index > -1)
+        ui->cmb_solver->setCurrentIndex(index);
+    index = hGrp->GetInt("AnalysisType", 0);
+    if (index > -1)
+        ui->cb_analysis_type->setCurrentIndex(index);
 }
 
 /**
  * Sets the strings of the subwidgets using the current language.
  */
-void DlgSettingsFemCcxImp::changeEvent(QEvent *e)
+void DlgSettingsFemCcxImp::changeEvent(QEvent* e)
 {
     if (e->type() == QEvent::LanguageChange) {
         int c_index = ui->cb_analysis_type->currentIndex();
@@ -122,4 +137,13 @@ void DlgSettingsFemCcxImp::changeEvent(QEvent *e)
     }
 }
 
+void DlgSettingsFemCcxImp::onfileNameChanged(QString FileName)
+{
+    if (!QFileInfo::exists(FileName)) {
+        QMessageBox::critical(this, tr("File does not exist"),
+                              tr("The specified executable \n'%1'\n does not exist!\n"
+                                 "Specify another file please.").arg(FileName));
+    }
+}
+
 #include "moc_DlgSettingsFemCcxImp.cpp"
