@@ -36,16 +36,16 @@ class DlgSettingsFemGmshImp : public Gui::Dialog::PreferencePage
     Q_OBJECT
 
 public:
-    DlgSettingsFemGmshImp( QWidget* parent = nullptr );
-    ~DlgSettingsFemGmshImp();
+    explicit DlgSettingsFemGmshImp( QWidget* parent = nullptr );
+    ~DlgSettingsFemGmshImp() override;
 
 protected Q_SLOTS:
     void onfileNameChanged(QString FileName);
 
 protected:
-    void saveSettings();
-    void loadSettings();
-    void changeEvent(QEvent *e);
+    void saveSettings() override;
+    void loadSettings() override;
+    void changeEvent(QEvent *e) override;
 
 private:
     std::unique_ptr<Ui_DlgSettingsFemGmshImp> ui;
