@@ -37,16 +37,16 @@ class DlgSettingsFemMystranImp : public Gui::Dialog::PreferencePage
     Q_OBJECT
 
 public:
-    DlgSettingsFemMystranImp( QWidget* parent = nullptr );
-    ~DlgSettingsFemMystranImp();
+    explicit DlgSettingsFemMystranImp( QWidget* parent = nullptr );
+    ~DlgSettingsFemMystranImp() override;
 
 protected Q_SLOTS:
     void onfileNameChanged(QString FileName);
 
 protected:
-    void saveSettings();
-    void loadSettings();
-    void changeEvent(QEvent *e);
+    void saveSettings() override;
+    void loadSettings() override;
+    void changeEvent(QEvent *e) override;
 
 private:
     std::unique_ptr<Ui_DlgSettingsFemMystranImp> ui;
