@@ -24,6 +24,7 @@
 #ifndef GUI_TASKVIEW_TaskFemConstraintForce_H
 #define GUI_TASKVIEW_TaskFemConstraintForce_H
 
+#include <memory>
 #include <QObject>
 
 #include "TaskFemConstraintOnBoundary.h"
@@ -48,33 +49,35 @@ class TaskFemConstraintForce : public TaskFemConstraintOnBoundary
     Q_OBJECT
 
 public:
-    TaskFemConstraintForce(ViewProviderFemConstraintForce *ConstraintView,QWidget *parent = nullptr);
-    virtual ~TaskFemConstraintForce();
-    double getForce(void) const;
-    const std::string getReferences() const;
-    const std::string getDirectionName(void) const;
-    const std::string getDirectionObject(void) const;
-    bool getReverse(void) const;
+    explicit TaskFemConstraintForce(ViewProviderFemConstraintForce* ConstraintView,
+                                    QWidget* parent = nullptr);
+    ~TaskFemConstraintForce() override;
+    double getForce() const;
+    const std::string getReferences() const override;
+    const std::string getDirectionName() const;
+    const std::string getDirectionObject() const;
+    bool getReverse() const;
 
 private Q_SLOTS:
-    void onReferenceDeleted(void);
+    void onReferenceDeleted();
     void onForceChanged(double);
     void onButtonDirection(const bool pressed = false);
     void onCheckReverse(bool);
-    void addToSelection();
-    void removeFromSelection();
+    void addToSelection() override;
+    void removeFromSelection() override;
 
 protected:
-    bool event(QEvent *e);
-    virtual void changeEvent(QEvent *e);
+    bool event(QEvent *e) override;
+    void changeEvent(QEvent *e) override;
     void clearButtons(const SelectionChangeModes notThis) override;
 
 private:
-    std::pair<App::DocumentObject*, std::string> getDirection(const std::vector<Gui::SelectionObject>&) const;
+    std::pair<App::DocumentObject*, std::string>
+    getDirection(const std::vector<Gui::SelectionObject>&) const;
     void updateUI();
 
 private:
-    Ui_TaskFemConstraintForce* ui;
+    std::unique_ptr<Ui_TaskFemConstraintForce> ui;
 };
 
 /// simulation dialog for the TaskView
@@ -83,13 +86,12 @@ class TaskDlgFemConstraintForce : public TaskDlgFemConstraint
     Q_OBJECT
 
 public:
-    TaskDlgFemConstraintForce(ViewProviderFemConstraintForce *ConstraintView);
+    explicit TaskDlgFemConstraintForce(ViewProviderFemConstraintForce *ConstraintView);
 
     /// is called by the framework if the dialog is accepted (Ok)
-    virtual void open();
-    virtual bool accept();
-    virtual bool reject();
-
+    void open() override;
+    bool accept() override;
+    bool reject() override;
 };
 
 } //namespace FemGui
