@@ -26,6 +26,7 @@
 #ifndef GUI_TASKVIEW_TaskFemConstraintPlaneRotation_H
 #define GUI_TASKVIEW_TaskFemConstraintPlaneRotation_H
 
+#include <memory>
 #include <QObject>
 
 #include "TaskFemConstraint.h"
@@ -40,23 +41,23 @@ class TaskFemConstraintPlaneRotation : public TaskFemConstraint
     Q_OBJECT
 
 public:
-    TaskFemConstraintPlaneRotation(ViewProviderFemConstraintPlaneRotation *ConstraintView,QWidget *parent = nullptr);
-    ~TaskFemConstraintPlaneRotation();
-    const std::string getReferences() const;
+    explicit TaskFemConstraintPlaneRotation(ViewProviderFemConstraintPlaneRotation* ConstraintView,
+                                            QWidget* parent = nullptr);
+    ~TaskFemConstraintPlaneRotation() override;
+    const std::string getReferences() const override;
 
 private Q_SLOTS:
-    void onReferenceDeleted(void);
+    void onReferenceDeleted();
     void addToSelection();
     void removeFromSelection();
 
 protected:
-    bool event(QEvent *e);
-    void changeEvent(QEvent *e);
+    bool event(QEvent *e) override;
+    void changeEvent(QEvent *e) override;
 
 private:
     void updateUI();
-    Ui_TaskFemConstraintPlaneRotation* ui;
-
+    std::unique_ptr<Ui_TaskFemConstraintPlaneRotation> ui;
 };
 
 class TaskDlgFemConstraintPlaneRotation : public TaskDlgFemConstraint
@@ -64,10 +65,11 @@ class TaskDlgFemConstraintPlaneRotation : public TaskDlgFemConstraint
     Q_OBJECT
 
 public:
-    TaskDlgFemConstraintPlaneRotation(ViewProviderFemConstraintPlaneRotation *ConstraintView);
-    void open();
-    bool accept();
-    bool reject();
+    explicit TaskDlgFemConstraintPlaneRotation(
+        ViewProviderFemConstraintPlaneRotation* ConstraintView);
+    void open() override;
+    bool accept() override;
+    bool reject() override;
 };
 
 } //namespace FemGui
