@@ -36,16 +36,13 @@
 using namespace FemGui;
 using namespace Gui;
 
-TaskTetParameter::TaskTetParameter(Fem::FemMeshShapeNetgenObject *pcObject,QWidget *parent)
-    : TaskBox(Gui::BitmapFactory().pixmap("FEM_CreateNodesSet"),
-      tr("Tet Parameter"),
-      true,
-      parent),
-      pcObject(pcObject)
+TaskTetParameter::TaskTetParameter(Fem::FemMeshShapeNetgenObject* pcObject, QWidget* parent)
+    : TaskBox(Gui::BitmapFactory().pixmap("FEM_CreateNodesSet"), tr("Tet Parameter"), true, parent),
+      pcObject(pcObject),
+      ui(new Ui_TaskTetParameter)
 {
     // we need a separate container widget to add all controls to
     proxy = new QWidget(this);
-    ui = new Ui_TaskTetParameter();
     ui->setupUi(proxy);
     QMetaObject::connectSlotsByName(this);
 
@@ -59,13 +56,20 @@ TaskTetParameter::TaskTetParameter(Fem::FemMeshShapeNetgenObject *pcObject,QWidg
     ui->spinBox_SegsPerRadius->setValue(pcObject->NbSegsPerRadius.getValue());
     ui->checkBox_Optimize->setChecked(pcObject->Optimize.getValue());
 
-    QObject::connect(ui->doubleSpinBox_MaxSize,SIGNAL(valueChanged(double)),this,SLOT(maxSizeValueChanged(double)));
-    QObject::connect(ui->comboBox_Fineness,SIGNAL(activated  (int)),this,SLOT(SwitchMethod(int)));
-    QObject::connect(ui->checkBox_SecondOrder,SIGNAL(stateChanged  (int)),this,SLOT(setQuadric(int)));
-    QObject::connect(ui->doubleSpinBox_GrowthRate,SIGNAL(valueChanged(double)),this,SLOT(setGrowthRate(double)));
-    QObject::connect(ui->spinBox_SegsPerEdge,SIGNAL(valueChanged (int)),this,SLOT(setSegsPerEdge(int)));
-    QObject::connect(ui->spinBox_SegsPerRadius,SIGNAL(valueChanged (int)),this,SLOT(setSegsPerRadius(int)));
-    QObject::connect(ui->checkBox_Optimize,SIGNAL(stateChanged  (int)),this,SLOT(setOptimize(int)));
+    QObject::connect(ui->doubleSpinBox_MaxSize, qOverload<double>(&QDoubleSpinBox::valueChanged),
+                     this, &TaskTetParameter::maxSizeValueChanged);
+    QObject::connect(ui->comboBox_Fineness, qOverload<int>(&QComboBox::activated),
+                     this, &TaskTetParameter::SwitchMethod);
+    QObject::connect(ui->checkBox_SecondOrder, &QCheckBox::stateChanged,
+                     this, &TaskTetParameter::setQuadric);
+    QObject::connect(ui->doubleSpinBox_GrowthRate, qOverload<double>(&QDoubleSpinBox::valueChanged),
+                     this, &TaskTetParameter::setGrowthRate);
+    QObject::connect(ui->spinBox_SegsPerEdge, qOverload<int>(&QSpinBox::valueChanged),
+                     this, &TaskTetParameter::setSegsPerEdge);
+    QObject::connect(ui->spinBox_SegsPerRadius, qOverload<int>(&QSpinBox::valueChanged),
+                     this, &TaskTetParameter::setSegsPerRadius);
+    QObject::connect(ui->checkBox_Optimize, &QCheckBox::stateChanged,
+                     this, &TaskTetParameter::setOptimize);
 
     if(pcObject->FemMesh.getValue().getInfo().numNode == 0)
         touched = true;
@@ -76,9 +80,7 @@ TaskTetParameter::TaskTetParameter(Fem::FemMeshShapeNetgenObject *pcObject,QWidg
 }
 
 TaskTetParameter::~TaskTetParameter()
-{
-    delete ui;
-}
+{}
 
 void TaskTetParameter::SwitchMethod(int Value)
 {
@@ -136,7 +138,7 @@ void TaskTetParameter::setOptimize(int v)
 }
 
 
-void TaskTetParameter::setInfo(void)
+void TaskTetParameter::setInfo()
 {
     Fem::FemMesh::FemMeshInfo info = pcObject->FemMesh.getValue().getInfo();
     //Base::BoundBox3d bndBox = pcObject->FemMesh.getValue().getBoundBox();
