@@ -32,15 +32,15 @@ namespace FemGui {
 
 class FemGuiExport ViewProviderFemConstraintDisplacement : public FemGui::ViewProviderFemConstraintOnBoundary
 {
-    PROPERTY_HEADER(FemGui::ViewProviderFemConstraintDisplacement);
+    PROPERTY_HEADER_WITH_OVERRIDE(FemGui::ViewProviderFemConstraintDisplacement);
 
 public:
     ViewProviderFemConstraintDisplacement();
-    virtual ~ViewProviderFemConstraintDisplacement();
-    virtual void updateData(const App::Property*);
+    ~ViewProviderFemConstraintDisplacement() override;
+    void updateData(const App::Property*) override;
 
 protected:
-    virtual bool setEdit(int ModNum);
+    bool setEdit(int ModNum) override;
 };
 
 }
