@@ -64,7 +64,7 @@ bool ViewProviderFemConstraintPulley::setEdit(int ModNum)
         if (dlg && !constrDlg) {
             // This case will occur in the ShaftWizard application
             checkForWizard();
-            if ((wizardWidget == nullptr) || (wizardSubLayout == nullptr)) {
+            if (!wizardWidget || !wizardSubLayout) {
                 // No shaft wizard is running
                 QMessageBox msgBox;
                 msgBox.setText(QObject::tr("A dialog is already open in the task panel"));
@@ -76,7 +76,7 @@ bool ViewProviderFemConstraintPulley::setEdit(int ModNum)
                     Gui::Control().reject();
                 else
                     return false;
-            } else if (constraintDialog != nullptr) {
+            } else if (constraintDialog) {
                 // Another FemConstraint* dialog is already open inside the Shaft Wizard
                 // Ignore the request to open another dialog
                 return false;
@@ -98,7 +98,7 @@ bool ViewProviderFemConstraintPulley::setEdit(int ModNum)
         return true;
     }
     else {
-        return ViewProviderDocumentObject::setEdit(ModNum);
+        return ViewProviderDocumentObject::setEdit(ModNum); // clazy:exclude=skipped-base-method
     }
 }
 
@@ -107,7 +107,7 @@ void ViewProviderFemConstraintPulley::updateData(const App::Property* prop)
     // Gets called whenever a property of the attached object changes
     Fem::ConstraintPulley* pcConstraint = static_cast<Fem::ConstraintPulley*>(this->getObject());
 
-    if (strcmp(prop->getName(), "BasePoint") == 0) {
+    if (prop == &pcConstraint->BasePoint) {
         if (pcConstraint->Height.getValue() > Precision::Confusion()) {
             // Remove and recreate the symbol
             Gui::coinRemoveAllChildren(pShapeSep);
@@ -157,7 +157,7 @@ void ViewProviderFemConstraintPulley::updateData(const App::Property* prop)
             pShapeSep->addChild(sep);// child 4
         }
     }
-    else if (strcmp(prop->getName(), "Diameter") == 0) {
+    else if (prop == &pcConstraint->Diameter) {
         if (pShapeSep->getNumChildren() > 0) {
             // Change the symbol
             double radius = pcConstraint->Radius.getValue();
@@ -198,8 +198,7 @@ void ViewProviderFemConstraintPulley::updateData(const App::Property* prop)
             updateArrow(subsep, 0, dia / 8 + dia / 2 * rat2, dia / 8);
         }
     }
-    else if ((strcmp(prop->getName(), "ForceAngle") == 0)
-             || (strcmp(prop->getName(), "BeltAngle") == 0)) {
+    else if ((prop == &pcConstraint->ForceAngle) || (prop == &pcConstraint->BeltAngle)) {
         if (pShapeSep->getNumChildren() > 0) {
             double radius = pcConstraint->Radius.getValue();
             double dia = pcConstraint->Diameter.getValue();
@@ -224,8 +223,7 @@ void ViewProviderFemConstraintPulley::updateData(const App::Property* prop)
                                                -cos(forceAngle - beltAngle - M_PI_2))));
         }
     }
-    else if ((strcmp(prop->getName(), "BeltForce1") == 0)
-             || (strcmp(prop->getName(), "BeltForce2") == 0)) {
+    else if ((prop == &pcConstraint->BeltForce1) || (prop == &pcConstraint->BeltForce2)) {
         if (pShapeSep->getNumChildren() > 0) {
             double radius = pcConstraint->Radius.getValue();
             double dia = pcConstraint->Diameter.getValue();
