@@ -32,15 +32,15 @@ namespace FemGui {
 
 class FemGuiExport ViewProviderFemConstraintTemperature : public FemGui::ViewProviderFemConstraintOnBoundary
 {
-    PROPERTY_HEADER(FemGui::ViewProviderFemConstraintTemperature);
+    PROPERTY_HEADER_WITH_OVERRIDE(FemGui::ViewProviderFemConstraintTemperature);
 
 public:
     ViewProviderFemConstraintTemperature();
-    virtual ~ViewProviderFemConstraintTemperature();
-    virtual void updateData(const App::Property*);
+    ~ViewProviderFemConstraintTemperature() override;
+    void updateData(const App::Property*) override;
 
 protected:
-    virtual bool setEdit(int ModNum);
+    bool setEdit(int ModNum) override;
 };
 
 }
