@@ -65,7 +65,7 @@ bool ViewProviderFemConstraintTransform::setEdit(int ModNum)
         if (constrDlg && constrDlg->getConstraintView() != this)
             constrDlg = nullptr; // another constraint left open its task panel
         if (dlg && !constrDlg) {
-            if (constraintDialog != nullptr) {
+            if (constraintDialog) {
                 // Ignore the request to open another dialog
                 return false;
             } else {
@@ -110,7 +110,7 @@ void ViewProviderFemConstraintTransform::updateData(const App::Property* prop)
     std::string transform_type = pcConstraint->TransformType.getValueAsString();
     if (transform_type == "Rectangular") {
 
-    if (strcmp(prop->getName(),"Points") == 0) {
+    if (prop == &pcConstraint->Points) {
         const std::vector<Base::Vector3d>& points = pcConstraint->Points.getValues();
         const std::vector<Base::Vector3d>& normals = pcConstraint->Normals.getValues();
         if (points.size() != normals.size())
@@ -262,7 +262,7 @@ void ViewProviderFemConstraintTransform::updateData(const App::Property* prop)
             return;
         std::vector<Base::Vector3d>::const_iterator n = normals.begin();
 
-        if (points.size() > 0) {
+        if (!points.empty()) {
             Base::Vector3d base = pcConstraint->BasePoint.getValue();
             Base::Vector3d axis = pcConstraint->Axis.getValue();
 
