@@ -33,21 +33,21 @@ namespace FemGui
 
 class FemGuiExport ViewProviderResult : public Gui::ViewProviderDocumentObject
 {
-    PROPERTY_HEADER(FemGui::ViewProviderResult);
+    PROPERTY_HEADER_WITH_OVERRIDE(FemGui::ViewProviderResult);
 
 public:
     /// constructor
     ViewProviderResult();
 
     /// destructor
-    virtual ~ViewProviderResult();
+    ~ViewProviderResult() override;
 
     // shows solid in the tree
-    virtual bool isShow(void) const
+    bool isShow() const override
     { return true; }
 };
 
-typedef Gui::ViewProviderPythonFeatureT<ViewProviderResult> ViewProviderResultPython;
+using ViewProviderResultPython = Gui::ViewProviderPythonFeatureT<ViewProviderResult>;
 
 } //namespace FemGui
 
