@@ -29,7 +29,7 @@ using namespace FemGui;
 
 PROPERTY_SOURCE(FemGui::ViewProviderSetGeometry, Gui::ViewProviderGeometryObject)
 
-bool ViewProviderSetGeometry::doubleClicked(void)
+bool ViewProviderSetGeometry::doubleClicked()
 {
     //Gui::TaskView::TaskDialog* dlg = new TaskDlgCreateNodeSet(dynamic_cast<Fem::FemSetNodesObject *>(getObject()));
     //Gui::Control().showDialog(dlg);
