@@ -22,13 +22,13 @@
 
 __title__ = "Tools for the work with Gmsh mesher"
 __author__ = "Bernd Hahnebach"
-__url__ = "https://www.freecadweb.org"
+__url__ = "https://www.freecad.org"
 
 ## \addtogroup FEM
 #  @{
 
+import os
 import subprocess
-import sys
 
 import FreeCAD
 from FreeCAD import Console
@@ -99,6 +99,8 @@ class GmshTools():
             self.algorithm2D = "7"
         elif algo2D == "DelQuad":
             self.algorithm2D = "8"
+        elif algo2D == "Packing Parallelograms":
+            self.algorithm2D = "9"
         else:
             self.algorithm2D = "2"
 
@@ -112,17 +114,43 @@ class GmshTools():
             self.algorithm3D = "2"
         elif algo3D == "Frontal":
             self.algorithm3D = "4"
-        elif algo3D == "Frontal Delaunay":
-            self.algorithm3D = "5"
-        elif algo3D == "Frontal Hex":
-            self.algorithm3D = "6"
         elif algo3D == "MMG3D":
             self.algorithm3D = "7"
         elif algo3D == "R-tree":
             self.algorithm3D = "9"
+        elif algo3D == "HXT":
+            self.algorithm3D = "10"
         else:
             self.algorithm3D = "1"
 
+        # RecombinationAlgorithm
+        algoRecombo = self.mesh_obj.RecombinationAlgorithm
+        if algoRecombo == "Simple":
+            self.RecombinationAlgorithm = "0"
+        elif algoRecombo == "Blossom":
+            self.RecombinationAlgorithm = "1"
+        elif algoRecombo == "Simple full-quad":
+            self.RecombinationAlgorithm = "2"
+        elif algoRecombo == "Blossom full-quad":
+            self.RecombinationAlgorithm = "3"
+        else:
+            self.algoRecombo = "0"
+
+        # HighOrderOptimize
+        optimizers = self.mesh_obj.HighOrderOptimize
+        if optimizers == "None":
+            self.HighOrderOptimize = "0"
+        elif optimizers == "Optimization":
+            self.HighOrderOptimize = "1"
+        elif optimizers == "Elastic+Optimization":
+            self.HighOrderOptimize = "2"
+        elif optimizers == "Elastic":
+            self.HighOrderOptimize = "3"
+        elif optimizers == "Fast Curving":
+            self.HighOrderOptimize = "4"
+        else:
+            self.HighOrderOptimize = "0"
+
         # mesh groups
         if self.mesh_obj.GroupsOfNodes is True:
             self.group_nodes_export = True
@@ -234,8 +262,7 @@ class GmshTools():
                         "but parameter to create it is set to True. "
                         "Dir will be created.\n".format(self.working_dir)
                     )
-                    from os import mkdir
-                    mkdir(param_working_dir)
+                    os.mkdir(param_working_dir)
                 else:
                     Console.PrintError(
                         "Dir given as parameter \'{}\' doesn't exist "
@@ -265,10 +292,12 @@ class GmshTools():
         # file paths
         _geometry_name = self.part_obj.Name + "_Geometry"
         self.mesh_name = self.part_obj.Name + "_Mesh"
-        from os.path import join
-        self.temp_file_geometry = join(self.working_dir, _geometry_name + ".brep")  # geometry file
-        self.temp_file_mesh = join(self.working_dir, self.mesh_name + ".unv")  # mesh file
-        self.temp_file_geo = join(self.working_dir, "shape2mesh.geo")  # Gmsh input file
+        # geometry file
+        self.temp_file_geometry = os.path.join(self.working_dir, _geometry_name + ".brep")
+        # mesh file
+        self.temp_file_mesh = os.path.join(self.working_dir, self.mesh_name + ".unv")
+        # Gmsh input file
+        self.temp_file_geo = os.path.join(self.working_dir, "shape2mesh.geo")
         Console.PrintMessage("  " + self.temp_file_geometry + "\n")
         Console.PrintMessage("  " + self.temp_file_mesh + "\n")
         Console.PrintMessage("  " + self.temp_file_geo + "\n")
@@ -289,8 +318,7 @@ class GmshTools():
                 p1 = subprocess.Popen(["which", "gmsh"], stdout=subprocess.PIPE)
                 if p1.wait() == 0:
                     output = p1.stdout.read()
-                    if sys.version_info.major >= 3:
-                        output = output.decode("utf-8")
+                    output = output.decode("utf-8")
                     gmsh_path = output.split("\n")[0]
                 elif p1.wait() == 1:
                     error_message = (
@@ -301,6 +329,13 @@ class GmshTools():
                     Console.PrintError(error_message)
                     raise GmshError(error_message)
                 self.gmsh_bin = gmsh_path
+            elif system() == "Darwin":
+                # https://forum.freecad.org/viewtopic.php?f=13&t=73041&p=642026#p642022
+                gmsh_path = "/Applications/Gmsh.app/Contents/MacOS/gmsh"
+                FreeCAD.ParamGet(
+                    "User parameter:BaseApp/Preferences/Mod/Fem/Gmsh"
+                ).SetString("gmshBinaryPath", gmsh_path)
+                self.gmsh_bin = gmsh_path
             else:
                 error_message = (
                     "No standard location implemented for your operating system. "
@@ -359,11 +394,52 @@ class GmshTools():
                     self.group_elements[ge] = new_group_elements[ge]
                 else:
                     Console.PrintError("  A group with this name exists already.\n")
-        else:
-            Console.PrintMessage("  No Group meshing for analysis.\n")
+        # else:
+        #    Console.PrintMessage("  No Group meshing for analysis.\n")
 
-        if self.group_elements:
-            Console.PrintMessage("  {}\n".format(self.group_elements))
+        # if self.group_elements:
+        #    Console.PrintMessage("  {}\n".format(self.group_elements))
+
+    def get_gmsh_version(self):
+        self.get_gmsh_command()
+        if os.path.exists(self.gmsh_bin):
+            found_message = "file found: " + self.gmsh_bin
+            Console.PrintMessage(found_message + "\n")
+        else:
+            found_message = "file not found: " + self.gmsh_bin
+            Console.PrintError(found_message + "\n")
+            return (None, None, None), found_message
+
+        command_list = [self.gmsh_bin, "--info"]
+        try:
+            p = subprocess.Popen(
+                command_list,
+                shell=False,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                universal_newlines=True
+            )
+        except Exception as e:
+            Console.PrintMessage(str(e) + "\n")
+            return (None, None, None), found_message + "\n\n" + "Error: " + str(e)
+
+        gmsh_stdout, gmsh_stderr = p.communicate()
+        Console.PrintMessage("Gmsh: StdOut:\n" + gmsh_stdout + "\n")
+        if gmsh_stderr:
+            Console.PrintError("Gmsh: StdErr:\n" + gmsh_stderr + "\n")
+
+        from re import search
+        # use raw string mode to get pep8 quiet
+        # https://stackoverflow.com/q/61497292
+        # https://github.com/MathSci/fecon236/issues/6
+        match = search(r"^Version\s*:\s*(\d+)\.(\d+)\.(\d+)", gmsh_stdout)
+        # return (major, minor, patch), fullmessage
+        if match:
+            mess = found_message + "\n\n" + gmsh_stdout
+            return match.group(1, 2, 3), mess
+        else:
+            mess = found_message + "\n\n" + "Warning: Output not recognized\n\n" + gmsh_stdout
+            return (None, None, None), mess
 
     def get_region_data(self):
         # mesh regions
@@ -371,11 +447,11 @@ class GmshTools():
             # print("  No mesh regions.")
             pass
         else:
-            Console.PrintMessage('  Mesh regions, we need to get the elements.\n')
+            # Console.PrintMessage("  Mesh regions, we need to get the elements.\n")
             # by the use of MeshRegion object and a BooleanSplitCompound
             # there could be problems with node numbers see
-            # http://forum.freecadweb.org/viewtopic.php?f=18&t=18780&start=40#p149467
-            # http://forum.freecadweb.org/viewtopic.php?f=18&t=18780&p=149520#p149520
+            # http://forum.freecad.org/viewtopic.php?f=18&t=18780&start=40#p149467
+            # http://forum.freecad.org/viewtopic.php?f=18&t=18780&p=149520#p149520
             part = self.part_obj
             if (
                 self.mesh_obj.MeshRegionList and part.Shape.ShapeType == "Compound"
@@ -385,17 +461,7 @@ class GmshTools():
                     or femutils.is_of_type(part, "FeatureXOR")
                 )
             ):
-                error_message = (
-                    "  The mesh to shape is a boolean split tools Compound "
-                    "and the mesh has mesh region list. "
-                    "Gmsh could return unexpected meshes in such circumstances. "
-                    "It is strongly recommended to extract the shape to mesh "
-                    "from the Compound and use this one."
-                )
-                Console.PrintError(error_message + "\n")
-                # TODO: no gui popup because FreeCAD will be in a endless output loop
-                #       as long as the pop up is on --> maybe find a better solution for
-                #       either of both --> thus the pop up is in task panel
+                self.outputCompoundWarning
             for mr_obj in self.mesh_obj.MeshRegionList:
                 # print(mr_obj.Name)
                 # print(mr_obj.CharacteristicLength)
@@ -464,8 +530,8 @@ class GmshTools():
                 ele_shape = geomtools.get_element(self.part_obj, eleml)
                 ele_vertexes = geomtools.get_vertexes_by_element(self.part_obj.Shape, ele_shape)
                 self.ele_node_map[eleml] = ele_vertexes
-            Console.PrintMessage("  {}\n".format(self.ele_length_map))
-            Console.PrintMessage("  {}\n".format(self.ele_node_map))
+            # Console.PrintMessage("  {}\n".format(self.ele_length_map))
+            # Console.PrintMessage("  {}\n".format(self.ele_node_map))
 
     def get_boundary_layer_data(self):
         # mesh boundary layer
@@ -477,16 +543,11 @@ class GmshTools():
             # print("  No mesh boundary layer setting document object.")
             pass
         else:
-            Console.PrintMessage("  Mesh boundary layers, we need to get the elements.\n")
+            # Console.PrintMessage("  Mesh boundary layers, we need to get the elements.\n")
             if self.part_obj.Shape.ShapeType == "Compound":
-                # see http://forum.freecadweb.org/viewtopic.php?f=18&t=18780&start=40#p149467 and
-                # http://forum.freecadweb.org/viewtopic.php?f=18&t=18780&p=149520#p149520
-                err = (
-                    "Gmsh could return unexpected meshes for a boolean split tools Compound. "
-                    "It is strongly recommended to extract the shape to mesh "
-                    "from the Compound and use this one."
-                )
-                Console.PrintError(err + "\n")
+                # see http://forum.freecad.org/viewtopic.php?f=18&t=18780&start=40#p149467 and
+                # http://forum.freecad.org/viewtopic.php?f=18&t=18780&p=149520#p149520
+                self.outputCompoundWarning
             for mr_obj in self.mesh_obj.MeshBoundaryLayerList:
                 if mr_obj.MinimumThickness and Units.Quantity(mr_obj.MinimumThickness).Value > 0:
                     if mr_obj.References:
@@ -659,12 +720,20 @@ class GmshTools():
         self.part_obj.Shape.exportBrep(self.temp_file_geometry)
 
     def write_geo(self):
+        temp_dir = os.path.dirname(self.temp_file_geo)
         geo = open(self.temp_file_geo, "w")
         geo.write("// geo file for meshing with Gmsh meshing software created by FreeCAD\n")
         geo.write("\n")
+
+        cpu_count = os.cpu_count()
+        if cpu_count is not None and cpu_count > 1:
+            geo.write("// enable multi-core processing\n")
+            geo.write(f"General.NumThreads = {cpu_count};\n")
+            geo.write("\n")
+
         geo.write("// open brep geometry\n")
         # explicit use double quotes in geo file
-        geo.write('Merge "{}";\n'.format(self.temp_file_geometry))
+        geo.write('Merge "{}";\n'.format(os.path.relpath(self.temp_file_geometry, temp_dir)))
         geo.write("\n")
 
         # groups
@@ -707,11 +776,27 @@ class GmshTools():
             geo.write("Mesh.CharacteristicLengthMin = " + str(0) + ";\n")
         else:
             geo.write("Mesh.CharacteristicLengthMin = " + str(self.clmin) + ";\n")
+        if hasattr(self.mesh_obj, "MeshSizeFromCurvature"):
+            geo.write(
+                "Mesh.MeshSizeFromCurvature = {}"
+                "; // number of elements per 2*pi radians, 0 to deactivate\n"
+                .format(self.mesh_obj.MeshSizeFromCurvature)
+            )
         geo.write("\n")
         if hasattr(self.mesh_obj, "RecombineAll") and self.mesh_obj.RecombineAll is True:
-            geo.write("// other mesh options\n")
+            geo.write("// recombination for surfaces\n")
             geo.write("Mesh.RecombineAll = 1;\n")
+        if hasattr(self.mesh_obj, "Recombine3DAll") and self.mesh_obj.Recombine3DAll is True:
+            geo.write("// recombination for volumes\n")
+            geo.write("Mesh.Recombine3DAll = 1;\n")
+        if (
+            (hasattr(self.mesh_obj, "RecombineAll") and self.mesh_obj.RecombineAll is True)
+            or (hasattr(self.mesh_obj, "Recombine3DAll") and self.mesh_obj.Recombine3DAll is True)
+        ):
+            geo.write("// recombination algorithm\n")
+            geo.write("Mesh.RecombinationAlgorithm = " + self.RecombinationAlgorithm + ";\n")
             geo.write("\n")
+
         geo.write("// optimize the mesh\n")
         # Gmsh tetra optimizer
         if hasattr(self.mesh_obj, "OptimizeStd") and self.mesh_obj.OptimizeStd is True:
@@ -724,17 +809,13 @@ class GmshTools():
         else:
             geo.write("Mesh.OptimizeNetgen = 0;\n")
         # higher order mesh optimizing
-        if hasattr(self.mesh_obj, "HighOrderOptimize") and self.mesh_obj.HighOrderOptimize is True:
-            geo.write(
-                "Mesh.HighOrderOptimize = 1;  // for more HighOrderOptimize "
-                "parameter check http://gmsh.info/doc/texinfo/gmsh.html\n"
-            )
-        else:
-            geo.write(
-                "Mesh.HighOrderOptimize = 0;  // for more HighOrderOptimize "
-                "parameter check http://gmsh.info/doc/texinfo/gmsh.html\n"
-            )
+        geo.write(
+            "// High-order meshes optimization (0=none, 1=optimization, 2=elastic+optimization, "
+            "3=elastic, 4=fast curving)\n"
+        )
+        geo.write("Mesh.HighOrderOptimize = " + self.HighOrderOptimize + ";\n")
         geo.write("\n")
+
         geo.write("// mesh order\n")
         geo.write("Mesh.ElementOrder = " + self.order + ";\n")
         if self.order == "2":
@@ -759,7 +840,7 @@ class GmshTools():
         )
         geo.write(
             "// 2D mesh algorithm (1=MeshAdapt, 2=Automatic, "
-            "5=Delaunay, 6=Frontal, 7=BAMG, 8=DelQuad)\n"
+            "5=Delaunay, 6=Frontal, 7=BAMG, 8=DelQuad, 9=Packing Parallelograms)\n"
         )
         if len(self.bl_setting_list) and self.dimension == 3:
             geo.write("Mesh.Algorithm = " + "DelQuad" + ";\n")  # Frontal/DelQuad are tested
@@ -767,14 +848,14 @@ class GmshTools():
             geo.write("Mesh.Algorithm = " + self.algorithm2D + ";\n")
         geo.write(
             "// 3D mesh algorithm (1=Delaunay, 2=New Delaunay, 4=Frontal, "
-            "5=Frontal Delaunay, 6=Frontal Hex, 7=MMG3D, 9=R-tree)\n"
+            "7=MMG3D, 9=R-tree, 10=HTX)\n"
         )
         geo.write("Mesh.Algorithm3D = " + self.algorithm3D + ";\n")
         geo.write("\n")
 
         geo.write("// meshing\n")
         # remove duplicate vertices
-        # see https://forum.freecadweb.org/viewtopic.php?f=18&t=21571&start=20#p179443
+        # see https://forum.freecad.org/viewtopic.php?f=18&t=21571&start=20#p179443
         if hasattr(self.mesh_obj, "CoherenceMesh") and self.mesh_obj.CoherenceMesh is True:
             geo.write(
                 "Geometry.Tolerance = {}; // set geometrical "
@@ -789,7 +870,6 @@ class GmshTools():
 
         # save mesh
         geo.write("// save\n")
-        geo.write("Mesh.Format = 2;\n")  # unv
         if self.group_elements and self.group_nodes_export:
             geo.write("// For each group save not only the elements but the nodes too.;\n")
             geo.write("Mesh.SaveGroupsOfNodes = 1;\n")
@@ -800,13 +880,13 @@ class GmshTools():
         geo.write("// Ignore Physical definitions and save all elements;\n")
         geo.write("Mesh.SaveAll = 1;\n")
         # explicit use double quotes in geo file
-        geo.write('Save "{}";\n'.format(self.temp_file_mesh))
+        geo.write('Save "{}";\n'.format(os.path.relpath(self.temp_file_mesh, temp_dir)))
         geo.write("\n\n")
 
         # some useful information
         geo.write("// " + "*" * 70 + "\n")
         geo.write("// Gmsh documentation:\n")
-        geo.write("// http://gmsh.info/doc/texinfo/gmsh.html#Mesh\n")
+        geo.write("// https://gmsh.info/doc/texinfo/gmsh.html#Mesh\n")
         geo.write("//\n")
         geo.write(
             "// We do not check if something went wrong, like negative "
@@ -821,31 +901,32 @@ class GmshTools():
         geo.close()
 
     def run_gmsh_with_geo(self):
-        comandlist = [self.gmsh_bin, "-", self.temp_file_geo]
-        # print(comandlist)
+        command_list = [self.gmsh_bin, "-", self.temp_file_geo]
+        # print(command_list)
         try:
             p = subprocess.Popen(
-                comandlist,
+                command_list,
                 shell=False,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE
             )
             output, error = p.communicate()
-            if sys.version_info.major >= 3:
-                # output = output.decode("utf-8")
-                error = error.decode("utf-8")
+            error = error.decode("utf-8")
             # stdout is still cut at some point
             # but the warnings are in stderr and thus printed :-)
             # print(output)
             # print(error)
         except Exception:
-            error = "Error executing: {}\n".format(" ".join(comandlist))
+            if os.path.exists(self.gmsh_bin):
+                error = "Error executing: {}\n".format(" ".join(command_list))
+            else:
+                error = "Gmsh executable not found: {}\n".format(self.gmsh_bin)
             Console.PrintError(error)
             self.error = True
 
         # workaround
         # filter useless gmsh warning in the regard of unknown element MSH type 15
-        # https://forum.freecadweb.org/viewtopic.php?f=18&t=33946
+        # https://forum.freecad.org/viewtopic.php?f=18&t=33946
         useless_warning = (
             "Warning : Unknown element type for UNV export "
             "(MSH type 15) - output file might be invalid"
@@ -864,6 +945,17 @@ class GmshTools():
         else:
             Console.PrintError("No mesh was created.\n")
 
+    def outputCompoundWarning(self):
+        error_message = (
+            "The mesh to shape is a Boolean Split Tools compound "
+            "and the mesh has mesh region list.\n"
+            "Gmsh could return unexpected meshes in such circumstances.\n"
+            "If this is the case, use the part workbench and "
+            "apply a Compound Filter on the compound.\n"
+            "Use the Compound Filter as input for the mesh."
+        )
+        Console.PrintWarning(error_message + "\n")
+
 ##  @}
 
 
@@ -925,7 +1017,7 @@ for len in max_mesh_sizes:
 """
 TODO
 class GmshTools should be splittet in two classes
-one class should only collect the mesh parameter from mesh object and his childs
+one class should only collect the mesh parameter from mesh object and its childs
 a second class only uses the collected parameter,
 writes the input file runs gmsh reads back the unv and returns a FemMesh
 gmsh binary will be collected in the second class
