@@ -23,7 +23,7 @@
 
 __title__ = "FreeCAD FEM solver equation base object"
 __author__ = "Markus Hovorka"
-__url__ = "https://www.freecadweb.org"
+__url__ = "https://www.freecad.org"
 
 ## \addtogroup FEM
 #  @{
@@ -69,14 +69,14 @@ class BaseViewProxy(object):
         return mode
 
 
-class HeatProxy(BaseProxy):
+class DeformationProxy(BaseProxy):
     pass
 
 
-class HeatViewProxy(BaseViewProxy):
+class DeformationViewProxy(BaseViewProxy):
 
     def getIcon(self):
-        return ":/icons/FEM_EquationHeat.svg"
+        return ":/icons/FEM_EquationDeformation.svg"
 
 
 class ElasticityProxy(BaseProxy):
@@ -89,23 +89,7 @@ class ElasticityViewProxy(BaseViewProxy):
         return ":/icons/FEM_EquationElasticity.svg"
 
 
-class ElectrostaticViewProxy(BaseViewProxy):
-
-    def getIcon(self):
-        return ":/icons/FEM_EquationElectrostatic.svg"
-
-
-class ElectrostaticProxy(BaseProxy):
-    pass
-
-
-class FluxViewProxy(BaseViewProxy):
-
-    def getIcon(self):
-        return ":/icons/FEM_EquationFlux.svg"
-
-
-class FluxProxy(BaseProxy):
+class ElectricforceProxy(BaseProxy):
     pass
 
 
@@ -115,10 +99,16 @@ class ElectricforceViewProxy(BaseViewProxy):
         return ":/icons/FEM_EquationElectricforce.svg"
 
 
-class ElectricforceProxy(BaseProxy):
+class ElectrostaticProxy(BaseProxy):
     pass
 
 
+class ElectrostaticViewProxy(BaseViewProxy):
+
+    def getIcon(self):
+        return ":/icons/FEM_EquationElectrostatic.svg"
+
+
 class FlowProxy(BaseProxy):
     pass
 
@@ -128,4 +118,45 @@ class FlowViewProxy(BaseViewProxy):
     def getIcon(self):
         return ":/icons/FEM_EquationFlow.svg"
 
+
+class FluxProxy(BaseProxy):
+    pass
+
+
+class FluxViewProxy(BaseViewProxy):
+
+    def getIcon(self):
+        return ":/icons/FEM_EquationFlux.svg"
+
+
+class HeatProxy(BaseProxy):
+    pass
+
+
+class HeatViewProxy(BaseViewProxy):
+
+    def getIcon(self):
+        return ":/icons/FEM_EquationHeat.svg"
+
+
+class MagnetodynamicProxy(BaseProxy):
+    pass
+
+
+class MagnetodynamicViewProxy(BaseViewProxy):
+
+    def getIcon(self):
+        return ":/icons/FEM_EquationMagnetodynamic.svg"
+
+
+class Magnetodynamic2DProxy(BaseProxy):
+    pass
+
+
+class Magnetodynamic2DViewProxy(BaseViewProxy):
+
+    def getIcon(self):
+        return ":/icons/FEM_EquationMagnetodynamic2D.svg"
+
+
 ##  @}
