@@ -44,7 +44,7 @@ new solver have a look at :class:`_SolverDlg`.
 
 __title__ = "FreeCAD FEM solver settings"
 __author__ = "Markus Hovorka, Bernd Hahnebach"
-__url__ = "https://www.freecadweb.org"
+__url__ = "https://www.freecad.org"
 
 
 import FreeCAD
@@ -81,7 +81,7 @@ _PARAM_PATH = "User parameter:BaseApp/Preferences/Mod/Fem/"
 _GENERAL_PARAM = _PARAM_PATH + "General"
 
 
-def get_binary(name):
+def get_binary(name, silent=False):
     """ Find binary of solver *name* honoring user settings.
 
     Return the specific path set by the user in FreeCADs settings/parameter
@@ -92,15 +92,31 @@ def get_binary(name):
     That check is done in DlgSettingsFem_Solver_Imp.cpp
 
     :param name: solver id as a ``str`` (see :mod:`femsolver.settings`)
+    :param silent: whether to output error if binary not found
     """
     if name in _SOLVER_PARAM:
-        binary = _SOLVER_PARAM[name].get_binary()
-        if binary is not None:
-            FreeCAD.Console.PrintMessage(
-                'Solver binary path: {} \n'.
-                format(binary)
-        )
+        binary = _SOLVER_PARAM[name].get_binary(silent)
         return binary
+    else:
+        if not silent:
+            FreeCAD.Console.PrintError(
+                "Settings solver name: {} not found in "
+                "solver settings modules _SOLVER_PARAM dirctionary.\n"
+                .format(name)
+            )
+        return None
+
+
+def get_cores(name):
+    """ Read number of CPU cores for solver *name* honoring user settings.
+
+    Returns number of CPU cores to be used for the solver run
+
+    :param name: solver id as a ``str`` (see :mod:`femsolver.settings`)
+    """
+    if name in _SOLVER_PARAM:
+        cores = _SOLVER_PARAM[name].get_cores()
+        return cores
     else:
         FreeCAD.Console.PrintError(
             "Settings solver name: {} not found in "
@@ -152,6 +168,22 @@ def get_dir_setting():
     return DirSetting.TEMPORARY
 
 
+def get_default_solver():
+    """ Return default solver name.
+    """
+    solver_map = {0: "None"}
+    if get_binary("Calculix", True):
+        solver_map[1] = "CalculixCcxTools"
+    if get_binary("ElmerSolver", True):
+        solver_map[len(solver_map)] = "Elmer"
+    if get_binary("Mystran", True):
+        solver_map[len(solver_map)] = "Mystran"
+    if get_binary("Z88", True):
+        solver_map[len(solver_map)] = "Z88"
+    param_group = FreeCAD.ParamGet(_GENERAL_PARAM)
+    return solver_map[param_group.GetInt("DefaultSolver", 0)]
+
+
 class _SolverDlg(object):
     """ Internal query logic for solver specific settings.
 
@@ -193,7 +225,7 @@ class _SolverDlg(object):
 
         self.param_group = FreeCAD.ParamGet(self.param_path)
 
-    def get_binary(self):
+    def get_binary(self, silent=False):
 
         # set the binary path to the FreeCAD defaults
         # ATM pure unix shell commands without path names are used as standard
@@ -212,9 +244,9 @@ class _SolverDlg(object):
         # get the whole binary path name for the given command or binary path and return it
         # None is returned if the binary has not been found
         # The user does not know what exactly has going wrong.
-        from distutils.spawn import find_executable as find_bin
+        from shutil import which as find_bin
         the_found_binary = find_bin(binary)
-        if the_found_binary is None:
+        if (the_found_binary is None) and (not silent):
             FreeCAD.Console.PrintError(
                 "The binary has not been found. Full binary search path: {}\n"
                 .format(binary)
@@ -223,6 +255,10 @@ class _SolverDlg(object):
             FreeCAD.Console.PrintLog("Found solver binary path: {}\n".format(the_found_binary))
         return the_found_binary
 
+    def get_cores(self):
+        cores = self.param_group.GetInt("UseNumberOfCores")
+        return cores
+
     def get_write_comments(self):
         return self.param_group.GetBool(self.WRITE_COMMENTS_PARAM, True)
 
