@@ -24,13 +24,12 @@
 
 __title__ = "FreeCAD result mechanical ViewProvider for the document object"
 __author__ = "Qingfeng Xia, Bernd Hahnebach"
-__url__ = "https://www.freecadweb.org"
+__url__ = "https://www.freecad.org"
 
 ## @package view_result_mechanical
 #  \ingroup FEM
 #  \brief view provider for mechanical ResultObjectPython
 
-import FreeCAD
 import FreeCADGui
 
 from PySide import QtGui
@@ -63,16 +62,24 @@ class VPResultMechanical(view_base_femconstraint.VPBaseFemConstraint):
 
     def onDelete(self, feature, subelements):
         children = self.claimChildren()
-        filtered = filter(lambda obj: not obj is None, children)
+        filtered = filter(lambda obj: obj is not None, children)
         children = list(filtered)
         if len(children) > 0:
             # issue a warning
-            bodyMessage = "The results object is not empty, therefore the\nfollowing referencing objects might be lost:\n"
+            bodyMessage = (
+                "The results object is not empty, therefore the\n"
+                "following referencing objects might be lost:\n"
+            )
             for obj in children:
                 bodyMessage += "\n" + obj.Label
             bodyMessage += "\n\nAre you sure you want to continue?"
-            reply = QtGui.QMessageBox.warning(None, "Object dependencies", bodyMessage,
-            QtGui.QMessageBox.Yes | QtGui.QMessageBox.No, QtGui.QMessageBox.No)
+            reply = QtGui.QMessageBox.warning(
+                None,
+                "Object dependencies",
+                bodyMessage,
+                QtGui.QMessageBox.Yes | QtGui.QMessageBox.No,
+                QtGui.QMessageBox.No
+            )
             if reply == QtGui.QMessageBox.Yes:
                 return True
             else:
