@@ -21,15 +21,14 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
 
 #include <Base/Console.h>
 #include <Base/Interpreter.h>
-#include "StepShapePy.h"
+
 #include "StepShape.h"
+#include "StepShapePy.h"
+
 
 namespace Import {
     extern PyObject* initModule();
@@ -50,8 +49,6 @@ PyMOD_INIT_FUNC(Import)
     // add mesh elements
     Base::Interpreter().addType(&Import::StepShapePy  ::Type, importModule, "StepShape");
 
-        // init Type system
-    //Import::StepShape       ::init();
 
     Base::Console().Log("Loading Import module... done\n");
     PyMOD_Return(importModule);
