@@ -19,20 +19,18 @@
  *   Suite 330, Boston, MA  02111-1307, USA                                *
  *                                                                         *
  ***************************************************************************/
-
  
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <fcntl.h>
-# include <TopTools_HSequenceOfShape.hxx>
-# include <STEPControl_Writer.hxx>
 # include <STEPControl_Reader.hxx>
 # include <TopoDS_Shape.hxx>
-# include <TFunction_Logbook.hxx>
+# include <TopTools_HSequenceOfShape.hxx>
 #endif
 
 #include <Base/Console.h>
 #include <Base/Sequencer.h>
+
 #include "FeatureImportStep.h"
 
 
@@ -40,27 +38,14 @@ using namespace Import;
 
 void FeatureImportStep::InitLabel(const TDF_Label &rcLabel)
 {
-	addProperty("String","FileName");
+    addProperty("String","FileName");
 
 }
 
-/*
-bool FeaturePartImportStep::MustExecute(void)
-{
-	Base::Console().Log("PartBoxFeature::MustExecute()\n");
-	return false;
-}
-*/
+
 Standard_Integer FeatureImportStep::Execute(void)
 {
-	Base::Console().Log("FeaturePartImportStep::Execute()\n");
-
-/*  cout << GetFloatProperty("x") << endl;
-  cout << GetFloatProperty("y") << endl;
-  cout << GetFloatProperty("z") << endl;
-  cout << GetFloatProperty("l") << endl;
-  cout << GetFloatProperty("h") << endl;
-  cout << GetFloatProperty("w") << endl;*/
+    Base::Console().Log("FeaturePartImportStep::Execute()\n");
 
   try{
 
@@ -73,13 +58,13 @@ Standard_Integer FeatureImportStep::Execute(void)
       return 1;
 
     int i=_open(FileName.c_str(),O_RDONLY);
-	  if( i != -1)
-	  {
-		  _close(i);
-	  }else{
+    if( i != -1)
+    {
+        _close(i);
+    }else{
       setError("File not readable");
-		  return 1;
-	  }
+      return 1;
+    }
 
     // just do show the wait cursor when the Gui is up
     Base::Sequencer().start("Load IGES", 1);
@@ -94,7 +79,7 @@ Standard_Integer FeatureImportStep::Execute(void)
   
     // Root transfers
     Standard_Integer nbr = aReader.NbRootsForTransfer();
-    //aReader.PrintCheckTransfer (failsonly, IFSelect_ItemsByEntity);
+
     for ( Standard_Integer n = 1; n<= nbr; n++)
     {
       printf("STEP: Transferring Root %d\n",n);
@@ -114,7 +99,7 @@ Standard_Integer FeatureImportStep::Execute(void)
       }
     }
 
-	  setShape(aShape);
+    setShape(aShape);
     Base::Sequencer().stop();
   }
   catch(...){
@@ -126,16 +111,3 @@ Standard_Integer FeatureImportStep::Execute(void)
   return 0;
 }
 
-/*
-void FeatureImportStep::Validate(void)
-{
-	Base::Console().Log("FeaturePartImportStep::Validate()\n");
- 
-  // We validate the object label ( Label() ), all the arguments and the results of the object:
-  log.SetValid(Label(), Standard_True);
-
-
-}
-*/
-
-
