@@ -23,38 +23,29 @@
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <algorithm>
-# include <memory>
 # include <map>
+# include <memory>
 #endif
 
-#include <CXX/Extensions.hxx>
-#include <CXX/Objects.hxx>
-
-#include <Base/Interpreter.h>
-#include <Base/FileInfo.h>
-#include <Base/Tools.h>
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObjectPy.h>
-#include <App/Property.h>
-#include <Base/PlacementPy.h>
-
 #include <Base/GeometryPyCXX.h>
+#include <Base/Interpreter.h>
+#include <Base/PlacementPy.h>
 #include <Base/VectorPy.h>
-
-#include "Core/MeshKernel.h"
-#include "Core/MeshIO.h"
+#include "Core/Approximation.h"
 #include "Core/Evaluation.h"
 #include "Core/Iterator.h"
-#include "Core/Approximation.h"
-
+#include "Core/MeshIO.h"
+#include "Core/MeshKernel.h"
 #include "WildMagic4/Wm4ContBox3.h"
 
-#include "Mesh.h"
+#include "MeshPy.h"
 #include "Exporter.h"
 #include "Importer.h"
-#include "FeatureMeshImport.h"
-#include <Mod/Mesh/App/MeshPy.h>
+#include "Mesh.h"
+
 
 using namespace Mesh;
 using namespace MeshCore;
@@ -138,10 +129,10 @@ public:
                    "\n");
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
-    virtual Py::Object invoke_method_varargs(void *method_def, const Py::Tuple &args)
+    Py::Object invoke_method_varargs(void *method_def, const Py::Tuple &args) override
     {
         try {
             return Py::ExtensionModule<Module>::invoke_method_varargs(method_def, args);
@@ -175,7 +166,7 @@ private:
         PyMem_Free(Name);
 
         // create new document and add Import feature
-        App::Document *pcDoc = App::GetApplication().newDocument("Unnamed");
+        App::Document *pcDoc = App::GetApplication().newDocument();
 
         Mesh::Importer import(pcDoc);
         import.load(EncodedName);
@@ -221,6 +212,7 @@ private:
         auto fTolerance( hGrp->GetFloat("MaxDeviationExport", 0.1f) );
 
         int exportAmfCompressed( hGrp->GetBool("ExportAmfCompressed", true) );
+        bool export3mfModel( hGrp->GetBool("Export3mfModel", true) );
 
         static char *kwList[] = {"objectList", "filename", "tolerance",
                                  "exportAmfCompressed", nullptr};
@@ -266,13 +258,18 @@ private:
             meta[App::Application::Config()["ExeName"] + "-buildRevisionHash"] =
                           App::Application::Config()["BuildRevisionHash"];
 
-            exporter.reset( new AmfExporter(outputFileName, meta, exportAmfCompressed) );
-
-        } else if (exportFormat != MeshIO::Undefined) {
+            exporter.reset( new ExporterAMF(outputFileName, meta, exportAmfCompressed) );
+        }
+        else if (exportFormat == MeshIO::ThreeMF) {
+            Extension3MFFactory::initialize();
+            exporter.reset( new Exporter3MF(outputFileName, Extension3MFFactory::createExtensions()) );
+            dynamic_cast<Exporter3MF*>(exporter.get())->setForceModel(export3mfModel);
+        }
+        else if (exportFormat != MeshIO::Undefined) {
             exporter.reset( new MergeExporter(outputFileName, exportFormat) );
-
-        } else {
-            std::string exStr("Can't determine mesh format from file name: '");
+        }
+        else {
+            std::string exStr("Can't determine mesh format from file name.\nPlease specify mesh format file extension: '");
             exStr += outputFileName + "'";
             throw Py::ValueError(exStr.c_str());
         }
@@ -280,6 +277,7 @@ private:
         for (auto it : objectList) {
             exporter->addObject(it, fTolerance);
         }
+
         exporter.reset();   // deletes Exporter, mesh file is written by destructor
 
         return Py::None();
@@ -345,7 +343,7 @@ private:
         if (!PyArg_ParseTuple(args.ptr(), "|fff",&x,&y,&z))
             throw Py::Exception();
 
-        if (y==0) 
+        if (y==0)
             y=x;
 
         float hx = x/2.0f;
