@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
@@ -29,19 +28,14 @@
 # include <queue>
 #endif
 
+#include <boost/math/special_functions/fpclassify.hpp>
+
 #include "Degeneration.h"
-#include "Definitions.h"
-#include "Iterator.h"
-#include "Helpers.h"
-#include "MeshKernel.h"
-#include "Algorithm.h"
-#include "Info.h"
 #include "Grid.h"
+#include "Iterator.h"
 #include "TopoAlgorithm.h"
 #include "Triangulation.h"
 
-#include <boost/math/special_functions/fpclassify.hpp>
-#include <Base/Sequencer.h>
 
 using namespace MeshCore;
 
@@ -95,7 +89,7 @@ bool MeshFixInvalids::Fixup()
 
 namespace MeshCore {
 
-typedef MeshPointArray::_TConstIterator VertexIterator;
+using VertexIterator = MeshPointArray::_TConstIterator;
 /*
  * When building up a mesh then usually the class MeshBuilder is used. This
  * class uses internally a std::set<MeshPoint> which uses the '<' operator of
@@ -222,7 +216,7 @@ bool MeshFixDuplicatePoints::Fixup()
     // remove invalid indices
     _rclMesh.DeletePoints(pointIndices);
     _rclMesh.RebuildNeighbours();
-    
+
     return true;
 }
 
@@ -263,7 +257,7 @@ bool MeshFixNaNPoints::Fixup()
     // remove invalid indices
     _rclMesh.DeletePoints(aInds);
     _rclMesh.RebuildNeighbours();
-    
+
     return true;
 }
 
@@ -271,13 +265,13 @@ bool MeshFixNaNPoints::Fixup()
 
 namespace MeshCore {
 
-typedef MeshFacetArray::_TConstIterator FaceIterator;
+using FaceIterator = MeshFacetArray::_TConstIterator;
 /*
  * The facet with the lowset index is regarded as 'less'.
  */
 struct MeshFacet_Less
 {
-    bool operator()(const FaceIterator& x, 
+    bool operator()(const FaceIterator& x,
                     const FaceIterator& y) const
     {
         PointIndex tmp;
@@ -329,7 +323,7 @@ struct MeshFacet_EqualTo
     {
         for (int i=0; i<3; i++ ) {
             if (x->_aulPoints[0] == y->_aulPoints[i]) {
-                if (x->_aulPoints[1] == y->_aulPoints[(i+1)%3] && 
+                if (x->_aulPoints[1] == y->_aulPoints[(i+1)%3] &&
                     x->_aulPoints[2] == y->_aulPoints[(i+2)%3])
                     return true;
                 else if (x->_aulPoints[1] == y->_aulPoints[(i+2)%3] &&
@@ -465,7 +459,7 @@ unsigned long MeshEvalDegeneratedFacets::CountEdgeTooSmall (float fMinEdgeLength
     MeshFacetIterator  clFIter(_rclMesh);
     unsigned long k = 0;
 
-    while (clFIter.EndReached() == false) {
+    while (!clFIter.EndReached()) {
         for (int i = 0; i < 3; i++) {
             if (Base::Distance(clFIter->_aclPoints[i], clFIter->_aclPoints[(i+1)%3]) < fMinEdgeLength)
                 k++;
@@ -509,8 +503,8 @@ bool MeshFixDegeneratedFacets::Fixup()
 
 bool MeshRemoveNeedles::Fixup()
 {
-    typedef std::pair<unsigned long, int> FaceEdge; // (face, edge) pair
-    typedef std::pair<float, FaceEdge> FaceEdgePriority;
+    using FaceEdge = std::pair<unsigned long, int>; // (face, edge) pair
+    using FaceEdgePriority = std::pair<float, FaceEdge>;
 
     MeshTopoAlgorithm topAlg(_rclMesh);
     MeshRefPointToFacets vf_it(_rclMesh);
@@ -609,8 +603,8 @@ bool MeshRemoveNeedles::Fixup()
 
 bool MeshFixCaps::Fixup()
 {
-    typedef std::pair<unsigned long, int> FaceVertex; // (face, vertex) pair
-    typedef std::pair<float, FaceVertex> FaceVertexPriority;
+    using FaceVertex = std::pair<unsigned long, int>; // (face, vertex) pair
+    using FaceVertexPriority = std::pair<float, FaceVertex>;
 
     MeshTopoAlgorithm topAlg(_rclMesh);
     const MeshFacetArray &rclFAry = _rclMesh.GetFacets();
