@@ -20,20 +20,19 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef MESH_ELEMENTS_H
 #define MESH_ELEMENTS_H
 
-#include <functional>
-#include <vector>
 #include <climits>
 #include <cstring>
+#include <functional>
+#include <vector>
+
+#include <Base/BoundBox.h>
+#include <Base/Matrix.h>
 
 #include "Definitions.h"
 
-#include <Base/BoundBox.h>
-#include <Base/Vector3D.h>
-#include <Base/Matrix.h>
 
 // Cannot use namespace Base in constructors of MeshPoint
 #ifdef _MSC_VER
@@ -46,7 +45,7 @@ class MeshHelpEdge;
 class MeshPoint;
 
 /**
- * Helper class providing an operator for comparison 
+ * Helper class providing an operator for comparison
  * of two edges. The class holds the point indices of the
  * underlying edge.
  */
@@ -54,7 +53,7 @@ class MeshExport MeshHelpEdge
 {
 public:
   inline bool operator == (const MeshHelpEdge &rclEdge) const;
-  unsigned long   _ulIndex[2];  // point indices
+  PointIndex   _ulIndex[2];  // point indices
 };
 
 /**
@@ -64,28 +63,28 @@ public:
 class MeshExport MeshIndexEdge
 {
 public:
-  unsigned long  _ulFacetIndex;  // Facet index
+  FacetIndex  _ulFacetIndex;  // Facet index
   unsigned short _ausCorner[2];  // corner point indices of the facet
 };
 
 /** MeshEdge just a pair of two point indices */
-typedef std::pair<unsigned long, unsigned long> MeshEdge;
+using MeshEdge = std::pair<PointIndex, PointIndex>;
 
 struct MeshExport EdgeCollapse
 {
-  unsigned long _fromPoint;
-  unsigned long _toPoint;
-  std::vector<unsigned long> _adjacentFrom; // adjacent points to _fromPoint
-  std::vector<unsigned long> _adjacentTo;   // adjacent points to _toPoint
-  std::vector<unsigned long> _removeFacets;
-  std::vector<unsigned long> _changeFacets;
+  PointIndex _fromPoint;
+  PointIndex _toPoint;
+  std::vector<PointIndex> _adjacentFrom; // adjacent points to _fromPoint
+  std::vector<PointIndex> _adjacentTo;   // adjacent points to _toPoint
+  std::vector<FacetIndex> _removeFacets;
+  std::vector<FacetIndex> _changeFacets;
 };
 
 struct MeshExport VertexCollapse
 {
-  unsigned long _point;
-  std::vector<unsigned long> _circumPoints;
-  std::vector<unsigned long> _circumFacets;
+  PointIndex _point;
+  std::vector<PointIndex> _circumPoints;
+  std::vector<FacetIndex> _circumFacets;
 };
 
 /**
@@ -108,11 +107,11 @@ public:
 
   /** @name Construction */
   //@{
-  MeshPoint (void) : _ucFlag(0), _ulProp(0) { }
+  MeshPoint () : _ucFlag(0), _ulProp(0) { }
   inline MeshPoint (float x, float y, float z);
-  inline MeshPoint (const Base::Vector3f &rclPt);
+  inline MeshPoint (const Base::Vector3f &rclPt);//explicit bombs
   inline MeshPoint (const MeshPoint &rclPt);
-  ~MeshPoint (void) { }
+  ~MeshPoint () { }
   //@}
 
 public:
@@ -121,19 +120,19 @@ public:
    */
   //@{
   void SetFlag (TFlagType tF) const
-  { const_cast<MeshPoint*>(this)->_ucFlag |= static_cast<unsigned char>(tF); }
+  { _ucFlag |= static_cast<unsigned char>(tF); }
   void ResetFlag (TFlagType tF) const
-  { const_cast<MeshPoint*>(this)->_ucFlag &= ~static_cast<unsigned char>(tF); }
+  { _ucFlag &= ~static_cast<unsigned char>(tF); }
   bool IsFlag (TFlagType tF) const
   { return (_ucFlag & static_cast<unsigned char>(tF)) == static_cast<unsigned char>(tF);  }
-  void ResetInvalid (void) const
+  void ResetInvalid () const
   { ResetFlag(INVALID); }
-  void  SetInvalid (void) const
+  void  SetInvalid () const
   { SetFlag(INVALID); }
-  bool IsValid (void) const
+  bool IsValid () const
   { return !IsFlag(INVALID); }
   void SetProperty(unsigned long uP) const
-  { const_cast<MeshPoint*>(this)->_ulProp = uP; }
+  { _ulProp = uP; }
   //@}
 
   // Assignment
@@ -145,18 +144,18 @@ public:
   inline bool operator < (const MeshPoint &rclPt) const;
 
 public:
-  unsigned char _ucFlag; /**< Flag member */
-  unsigned long _ulProp; /**< Free usable property */
+  mutable unsigned char _ucFlag; /**< Flag member */
+  mutable unsigned long _ulProp; /**< Free usable property */
 };
 
 /**
- * The MeshGeomEdge class is geometric counterpart to MeshEdge that holds the 
+ * The MeshGeomEdge class is geometric counterpart to MeshEdge that holds the
  * geometric data points of an edge.
  */
 class MeshExport MeshGeomEdge
 {
 public:
-  MeshGeomEdge (void) : _bBorder(false) {}
+  MeshGeomEdge () : _bBorder(false) {}
 
   /** Checks if the edge is inside the bounding box or intersects with it. */
   bool ContainedByOrIntersectBoundingBox (const Base::BoundBox3f &rclBB ) const;
@@ -168,6 +167,10 @@ public:
    * with the edge. The intersection must be inside the edge. If there is no intersection false is returned.
    */
   bool IntersectWithLine (const Base::Vector3f &rclPt, const Base::Vector3f &rclDir, Base::Vector3f &rclRes) const;
+  /** Calculates the intersection point of an edge with this edge.
+   * The intersection must be inside both edges. If there is no intersection false is returned.
+   */
+  bool IntersectWithEdge (const MeshGeomEdge &edge, Base::Vector3f &res) const;
   /** Calculates the intersection point of the plane defined by the base \a rclPt and the direction \a rclDir
    * with the edge. The intersection must be inside the edge. If there is no intersection false is returned.
    */
@@ -184,6 +187,26 @@ public:
    */
   void ClosestPointsToLine(const Base::Vector3f &linePt, const Base::Vector3f &lineDir,
                            Base::Vector3f& rclPnt1, Base::Vector3f& rclPnt2) const;
+  /**
+   * Checks if the point is part of the edge. A point is regarded as part
+   * of an edge if the distance is lower than \a fDistance to the projected point
+   * of \a rclPoint on the edge.
+   */
+  bool IsPointOf (const Base::Vector3f &rclPoint, float fDistance) const;
+  /**
+   * Checks if the projection point of \a point lies on the edge.
+   */
+  bool IsProjectionPointOf(const Base::Vector3f& point) const;
+  /**
+   * Checks if the two edges are parallel.
+   * \note Parallel edges could be collinear.
+   */
+  bool IsParallel(const MeshGeomEdge &edge) const;
+  /**
+   * Checks if the two edges are collinear.
+   * \note Collinear edges always are parallel.
+   */
+  bool IsCollinear(const MeshGeomEdge &edge) const;
 
 public:
   Base::Vector3f _aclPoints[2];  /**< Corner points */
@@ -194,12 +217,12 @@ public:
  * The MeshFacet class represent a triangle facet in the mesh data.structure. A facet indexes
  * three neighbour facets and also three corner points.
  * This class only keeps topologic information but no geometric information at all.
- * 
+ *
  * Here are the most important conventions concerning the facet's orientation:
  * \li neighbour or edge number of 0 is defined by corner 0 and 1
  * \li neighbour or edge number of 1 is defined by corner 1 and 2
  * \li neighbour or edge number of 2 is defined by corner 2 and 0
- * \li neighbour index is set to ULONG_MAX if there is no neighbour facet
+ * \li neighbour index is set to FACET_INDEX_MAX if there is no neighbour facet
  *
  * Note: The status flag SEGMENT mark a facet to be part of certain subset, a segment.
  * This flag must not be set by any algorithm unless it adds or removes facets to a segment.
@@ -215,10 +238,10 @@ public:
 public:
   /** @name Construction */
   //@{
-  inline MeshFacet (void);
+  inline MeshFacet ();
   inline MeshFacet(const MeshFacet &rclF);
-  inline MeshFacet(unsigned long p1,unsigned long p2,unsigned long p3,unsigned long n1=ULONG_MAX,unsigned long n2=ULONG_MAX,unsigned long n3=ULONG_MAX);
-  ~MeshFacet (void) { }
+  inline MeshFacet(PointIndex p1,PointIndex p2,PointIndex p3,FacetIndex n1=FACET_INDEX_MAX,FacetIndex n2=FACET_INDEX_MAX,FacetIndex n3=FACET_INDEX_MAX);
+  ~MeshFacet () { }
   //@}
 
   /** @name Flag state
@@ -226,51 +249,51 @@ public:
    */
   //@{
   void SetFlag (TFlagType tF) const
-  { const_cast<MeshFacet*>(this)->_ucFlag |= static_cast<unsigned char>(tF); }
+  { _ucFlag |= static_cast<unsigned char>(tF); }
   void ResetFlag (TFlagType tF) const
-  { const_cast<MeshFacet*>(this)->_ucFlag &= ~static_cast<unsigned char>(tF); }
+  { _ucFlag &= ~static_cast<unsigned char>(tF); }
   bool IsFlag (TFlagType tF) const
   { return (_ucFlag & static_cast<unsigned char>(tF)) == static_cast<unsigned char>(tF); }
-  void ResetInvalid (void) const
+  void ResetInvalid () const
   { ResetFlag(INVALID); }
   void SetProperty(unsigned long uP) const
-  { const_cast<MeshFacet*>(this)->_ulProp = uP; }
+  { _ulProp = uP; }
   /**
    * Marks a facet as invalid. Should be used only temporary from within an algorithm
    * (e.g. deletion of several facets) but must not be set permanently.
    * From outside the data-structure must not have invalid facets.
    */
-  void  SetInvalid (void) const
+  void  SetInvalid () const
   { SetFlag(INVALID); }
-  bool IsValid (void) const
+  bool IsValid () const
   { return !IsFlag(INVALID); }
   //@}
 
   // Assignment
   inline MeshFacet& operator = (const MeshFacet &rclF);
-  inline void SetVertices(unsigned long,unsigned long,unsigned long);
-  inline void SetNeighbours(unsigned long,unsigned long,unsigned long);
+  inline void SetVertices(PointIndex,PointIndex,PointIndex);
+  inline void SetNeighbours(FacetIndex,FacetIndex,FacetIndex);
 
   /**
-   * Returns the indices of the corner points of the given edge number. 
+   * Returns the indices of the corner points of the given edge number.
    */
   inline void GetEdge (unsigned short usSide, MeshHelpEdge &rclEdge) const;
   /**
-   * Returns the indices of the corner points of the given edge number. 
+   * Returns the indices of the corner points of the given edge number.
    */
-  inline std::pair<unsigned long, unsigned long> GetEdge (unsigned short usSide) const;
+  inline std::pair<PointIndex, PointIndex> GetEdge (unsigned short usSide) const;
   /**
    * Returns the edge-number to the given index of neighbour facet.
    * If \a ulNIndex is not a neighbour USHRT_MAX is returned.
    */
-  inline unsigned short Side (unsigned long ulNIndex) const;
+  inline unsigned short Side (FacetIndex ulNIndex) const;
   /**
    * Returns the edge-number defined by two points. If one point is
    * not a corner point USHRT_MAX is returned.
    */
-  inline unsigned short Side (unsigned long ulP0, unsigned long P1) const;
+  inline unsigned short Side (PointIndex ulP0, PointIndex P1) const;
   /**
-   * Returns the edge-number defined by the shared edge of both facets. If the facets don't 
+   * Returns the edge-number defined by the shared edge of both facets. If the facets don't
    * share a common edge USHRT_MAX is returned.
    */
   inline unsigned short Side (const MeshFacet& rcFace) const;
@@ -284,26 +307,32 @@ public:
    * by \a ulNew. If the facet does not have a corner point with this index
    * nothing happens.
    */
-  inline void Transpose (unsigned long ulOrig, unsigned long ulNew);
+  inline void Transpose (PointIndex ulOrig, PointIndex ulNew);
   /**
    * Decrement the index for each corner point that is higher than \a ulIndex.
    */
-  inline void Decrement (unsigned long ulIndex);
+  inline void Decrement (PointIndex ulIndex);
   /**
    * Checks if the facets references the given point index.
    */
-  inline bool HasPoint(unsigned long) const;
+  inline bool HasPoint(PointIndex) const;
   /**
    * Replaces the index of the neighbour facet that is equal to \a ulOrig
    * by \a ulNew. If the facet does not have a neighbourt with this index
    * nothing happens.
    */
-  inline void ReplaceNeighbour (unsigned long ulOrig, unsigned long ulNew);
+  inline void ReplaceNeighbour (FacetIndex ulOrig, FacetIndex ulNew);
   /**
    * Checks if the neighbour exists at the given edge-number.
    */
   bool HasNeighbour (unsigned short usSide) const
-  { return (_aulNeighbours[usSide] != ULONG_MAX); }
+  { return (_aulNeighbours[usSide] != FACET_INDEX_MAX); }
+  /**
+   * Checks if the given index is a neighbour facet.
+   */
+  bool IsNeighbour(FacetIndex index) const {
+      return Side(index) < 3;
+  }
   /** Counts the number of edges without neighbour. */
   inline unsigned short CountOpenEdges() const;
   /** Returns true if there is an edge without neighbour, otherwise false. */
@@ -315,34 +344,34 @@ public:
   /** Checks whether the facet is degenerated to a line of point. */
   inline bool IsDegenerated() const;
   /** Flips the orientation of the facet. */
-  void FlipNormal (void)
+  void FlipNormal ()
   {
     std::swap(_aulPoints[1], _aulPoints[2]);
     std::swap(_aulNeighbours[0], _aulNeighbours[2]);
   }
 
 public:
-  unsigned char _ucFlag; /**< Flag member. */
-  unsigned long _ulProp; /**< Free usable property. */
-  unsigned long _aulPoints[3];     /**< Indices of corner points. */
-  unsigned long _aulNeighbours[3]; /**< Indices of neighbour facets. */
+  mutable unsigned char _ucFlag; /**< Flag member. */
+  mutable unsigned long _ulProp; /**< Free usable property. */
+  PointIndex _aulPoints[3];     /**< Indices of corner points. */
+  FacetIndex _aulNeighbours[3]; /**< Indices of neighbour facets. */
 };
 
 /**
- * The MeshGeomFacet class is geometric counterpart to MeshFacet that holds the 
+ * The MeshGeomFacet class is geometric counterpart to MeshFacet that holds the
  * geometric data points of a triangle.
  */
-class MeshExport MeshGeomFacet 
+class MeshExport MeshGeomFacet
 {
 public:
   /** @name Construction */
   //@{
   /// default constructor
-  MeshGeomFacet (void); 
+  MeshGeomFacet ();
   /// Constructor with the corner points
   MeshGeomFacet (const Base::Vector3f &v1,const Base::Vector3f &v2,const Base::Vector3f &v3);
    /// Destruction
-  ~MeshGeomFacet (void) { }
+  ~MeshGeomFacet () { }
   //@}
 
 public:
@@ -358,15 +387,15 @@ public:
    * checked. This method is very efficient.
    */
   bool IsPointOf (const Base::Vector3f &rclPoint) const;
-  /** Checks whether the given point is inside the facet with tolerance \a fDistance. 
-   * This method does actually the same as IsPointOf() but this implementation 
+  /** Checks whether the given point is inside the facet with tolerance \a fDistance.
+   * This method does actually the same as IsPointOf() but this implementation
    * is done more effective through comparison of normals.
    */
   bool IsPointOfFace (const Base::Vector3f& rclP, float fDistance) const;
   /** Calculates the weights \a w1, ...,  \a w3 of the corners to get the point \a rclP, i.e.
    * rclP = w0*v0 + w1*v1 + w2*v2 (v0-v2 are the corners corners).
    * If w0+w1+w2==1.0 then the point rclP lies on the plane that is spanned by the facet, otherwise
-   * the point doesn't lie on the plane. 
+   * the point doesn't lie on the plane.
    * If the sum of wi is 1 and if each wi is between [0,1] than the point lies inside
    * the facet or on the border, respectively.
    *
@@ -403,7 +432,7 @@ public:
   /**
    * Calculates the facet normal for storing internally.
    */
-  inline void CalcNormal (void);
+  inline void CalcNormal () const;
   /**
    * Arrange the facet normal so the both vectors have the same orientation.
    */
@@ -411,9 +440,9 @@ public:
   /**
    * Adjusts the facet's orientation to its normal.
    */
-  inline void AdjustCirculationDirection (void);
+  inline void AdjustCirculationDirection ();
   /** Invalidate the normal. It will be recomputed when querying it. */
-  void NormalInvalid (void) { _bNormalCalculated = false; }
+  void NormalInvalid () { _bNormalCalculated = false; }
   /** Query the flag state of the facet. */
   bool IsFlag (MeshFacet::TFlagType tF) const
   { return (_ucFlag & static_cast<unsigned char>(tF)) == static_cast<unsigned char>(tF); }
@@ -424,13 +453,13 @@ public:
   void ResetFlag (MeshFacet::TFlagType tF)
   { _ucFlag &= ~static_cast<unsigned char>(tF); }
   /** Calculates the facet's gravity point. */
-  inline Base::Vector3f GetGravityPoint (void) const;
+  inline Base::Vector3f GetGravityPoint () const;
   /** Returns the normal of the facet. */
-  inline Base::Vector3f GetNormal (void) const;
+  inline Base::Vector3f GetNormal () const;
   /** Sets the facet's normal. */
   inline void SetNormal (const Base::Vector3f &rclNormal);
   /** Returns the wrapping bounding box. */
-  inline Base::BoundBox3f GetBoundBox (void) const;
+  inline Base::BoundBox3f GetBoundBox () const;
   /** Calculates the perimeter of the facet. */
   inline float Perimeter() const;
   /** Calculates the area of a facet. */
@@ -469,11 +498,11 @@ public:
   bool IntersectWithLine (const Base::Vector3f &rclPt, const Base::Vector3f &rclDir, Base::Vector3f &rclRes) const;
   /** Calculates the intersection point of the line defined by the base \a rclPt and the direction \a rclDir
    * with the facet. The intersection must be inside the facet. If there is no intersection false is returned.
-   * This does actually the same as IntersectWithLine() with one additionally constraint that the angle 
+   * This does actually the same as IntersectWithLine() with one additionally constraint that the angle
    * between the direction of the line and the normal of the plane must not exceed \a fMaxAngle.
    */
   bool Foraminate (const Base::Vector3f &rclPt, const Base::Vector3f &rclDir, Base::Vector3f &rclRes, float fMaxAngle = Mathf::PI) const;
-  /** Checks if the facet intersects with the plane defined by the base \a rclBase and the normal 
+  /** Checks if the facet intersects with the plane defined by the base \a rclBase and the normal
    * \a rclNormal and returns true if two points are found, false otherwise.
    */
   bool IntersectWithPlane (const Base::Vector3f &rclBase, const Base::Vector3f &rclNormal, Base::Vector3f &rclP1, Base::Vector3f &rclP2) const;
@@ -483,10 +512,10 @@ public:
    */
   inline bool IntersectWithPlane (const Base::Vector3f &rclBase, const Base::Vector3f &rclNormal) const;
   /** Checks if the plane defined by the facet \a rclFacet intersects with the line defined by the base
-   * \a rclBase and the direction \a rclNormal and returns the intersection point \a rclRes if possible. 
+   * \a rclBase and the direction \a rclNormal and returns the intersection point \a rclRes if possible.
    */
   bool IntersectPlaneWithLine (const Base::Vector3f &rclBase, const Base::Vector3f &rclNormal, Base::Vector3f &rclRes ) const;
-  /** Calculates the volume of the prism defined by two facets. 
+  /** Calculates the volume of the prism defined by two facets.
    * \note The two facets must not intersect.
    */
   float VolumeOfPrism (const MeshGeomFacet& rclF) const;
@@ -500,6 +529,8 @@ public:
   unsigned short NearestEdgeToPoint(const Base::Vector3f& rclPt) const;
   /** Returns the edge number \a side of the facet and the distance to the edge that is nearest to the point \a rclPt. */
   void NearestEdgeToPoint(const Base::Vector3f& rclPt, float& fDistance, unsigned short& side) const;
+  /** Returns the edge for \a side. */
+  MeshGeomEdge GetEdge(short side) const;
   /** The center and radius of the circum circle define a sphere in 3D. If the point \a rP is part of this sphere true is
    * returned, otherwise false.
    */
@@ -520,10 +551,14 @@ public:
   /** Apply a transformation on the triangle.
    */
   void Transform(const Base::Matrix4D&);
+  /**
+   * Checks if the two triangles are coplanar.
+   */
+  bool IsCoplanar(const MeshGeomFacet &facet) const;
 
 protected:
-  Base::Vector3f  _clNormal; /**< Normal of the facet. */
-  bool  _bNormalCalculated; /**< True if the normal is already calculated. */
+  mutable Base::Vector3f  _clNormal; /**< Normal of the facet. */
+  mutable bool  _bNormalCalculated; /**< True if the normal is already calculated. */
 
 public:
   Base::Vector3f  _aclPoints[3]; /**< Geometric corner points. */
@@ -531,7 +566,7 @@ public:
   unsigned long _ulProp; /**< Free usable property. */
 };
 
-typedef  std::vector<MeshPoint>  TMeshPointArray;
+using TMeshPointArray = std::vector<MeshPoint>;
 /**
  * Stores all data points of the mesh structure.
  */
@@ -539,19 +574,19 @@ class MeshExport MeshPointArray: public TMeshPointArray
 {
 public:
   // Iterator interface
-  typedef std::vector<MeshPoint>::iterator        _TIterator;
-  typedef std::vector<MeshPoint>::const_iterator  _TConstIterator;
+  using _TIterator = std::vector<MeshPoint>::iterator;
+  using _TConstIterator = std::vector<MeshPoint>::const_iterator;
 
   /** @name Construction */
   //@{
   // constructor
-  MeshPointArray (void) { }
+  MeshPointArray () { }
   // constructor
-  MeshPointArray (unsigned long ulSize) : TMeshPointArray(ulSize) { }
+  explicit MeshPointArray (PointIndex ulSize) : TMeshPointArray(ulSize) { }
   /// copy-constructor
   MeshPointArray (const MeshPointArray&);
   // Destructor
-  ~MeshPointArray (void) { }
+  ~MeshPointArray () { }
   //@}
 
   /** @name Flag state
@@ -563,7 +598,7 @@ public:
   /// Resets the flag for all points
   void ResetFlag (MeshPoint::TFlagType tF) const;
   /// Sets all points invalid
-  void ResetInvalid (void) const;
+  void ResetInvalid () const;
   /// Sets the property for all points
   void SetProperty (unsigned long ulVal) const;
   //@}
@@ -573,18 +608,18 @@ public:
   void Transform(const Base::Matrix4D&);
   /**
    * Searches for the first point index  Two points are equal if the distance is less
-   * than EPSILON. If no such points is found ULONG_MAX is returned. 
+   * than EPSILON. If no such points is found POINT_INDEX_MAX is returned.
    */
-  unsigned long Get (const MeshPoint &rclPoint);
+  PointIndex Get (const MeshPoint &rclPoint);
   /**
    * Searches for the first point index  Two points are equal if the distance is less
    * than EPSILON. If no such points is found the point is added to the array at end
-   * and its index is returned. 
+   * and its index is returned.
    */
-  unsigned long GetOrAddIndex (const MeshPoint &rclPoint);
+  PointIndex GetOrAddIndex (const MeshPoint &rclPoint);
 };
 
-typedef std::vector<MeshFacet>  TMeshFacetArray;
+using TMeshFacetArray = std::vector<MeshFacet>;
 
 /**
  * Stores all facets of the mesh data-structure.
@@ -593,19 +628,19 @@ class MeshExport MeshFacetArray: public TMeshFacetArray
 {
 public:
     // Iterator interface
-    typedef std::vector<MeshFacet>::iterator        _TIterator;
-    typedef std::vector<MeshFacet>::const_iterator  _TConstIterator;
+    using _TIterator = std::vector<MeshFacet>::iterator;
+    using _TConstIterator = std::vector<MeshFacet>::const_iterator;
 
     /** @name Construction */
     //@{
     /// constructor
-    MeshFacetArray (void) { }
+    MeshFacetArray () { }
     /// constructor
-    MeshFacetArray (unsigned long ulSize) : TMeshFacetArray(ulSize) { }
+    explicit MeshFacetArray (FacetIndex ulSize) : TMeshFacetArray(ulSize) { }
     /// copy-constructor
     MeshFacetArray (const MeshFacetArray&);
     /// destructor
-    ~MeshFacetArray (void) { }
+    ~MeshFacetArray () { }
     //@}
 
     /** @name Flag state
@@ -613,12 +648,12 @@ public:
     * of the object
     */
     //@{
-    /// Sets the flag for all facets. 
+    /// Sets the flag for all facets.
     void SetFlag (MeshFacet::TFlagType tF) const;
-    /// Resets the flag for all facets. 
+    /// Resets the flag for all facets.
     void ResetFlag (MeshFacet::TFlagType tF) const;
     /// Sets all facets invalid
-    void ResetInvalid (void) const;
+    void ResetInvalid () const;
     /// Sets the property for all facets
     void SetProperty (unsigned long ulVal) const;
     //@}
@@ -634,11 +669,11 @@ public:
     /**
      * Checks and flips the point indices if needed. @see MeshFacet::Transpose().
      */
-    void TransposeIndices (unsigned long ulOrig, unsigned long ulNew);
+    void TransposeIndices (PointIndex ulOrig, PointIndex ulNew);
     /**
      * Decrements all point indices that are higher than \a ulIndex.
      */
-    void DecrementIndices (unsigned long ulIndex);
+    void DecrementIndices (PointIndex ulIndex);
 };
 
 /**
@@ -648,7 +683,7 @@ public:
 class MeshExport MeshPointModifier
 {
 public:
-    MeshPointModifier(MeshPointArray& points)
+    explicit MeshPointModifier(MeshPointArray& points)
         : rPoints(points)
     {
     }
@@ -669,7 +704,7 @@ private:
 class MeshExport MeshFacetModifier
 {
 public:
-    MeshFacetModifier(MeshFacetArray& facets)
+    explicit MeshFacetModifier(MeshFacetArray& facets)
         : rFacets(facets)
     {
     }
@@ -684,7 +719,7 @@ public:
      * that is equal to \a old by \a now. If the facet does not have a corner
      * point with this index nothing happens.
      */
-    void Transpose(unsigned long pos, unsigned long old, unsigned long now)
+    void Transpose(PointIndex pos, PointIndex old, PointIndex now)
     {
         rFacets[pos].Transpose(old, now);
     }
@@ -765,17 +800,17 @@ inline float MeshGeomFacet::DistancePlaneToPoint (const Base::Vector3f &rclPoint
     return float(fabs(rclPoint.DistanceToPlane(_aclPoints[0], GetNormal())));
 }
 
-inline void MeshGeomFacet::CalcNormal (void)
+inline void MeshGeomFacet::CalcNormal () const
 {
     _clNormal = (_aclPoints[1] - _aclPoints[0]) % (_aclPoints[2] - _aclPoints[0]);
     _clNormal.Normalize();
     _bNormalCalculated = true;
 }
 
-inline Base::Vector3f MeshGeomFacet::GetNormal (void) const
+inline Base::Vector3f MeshGeomFacet::GetNormal () const
 {
-    if (_bNormalCalculated == false)
-        const_cast<MeshGeomFacet*>(this)->CalcNormal();
+    if (!_bNormalCalculated)
+        CalcNormal();
     return _clNormal;
 }
 
@@ -795,19 +830,19 @@ inline void MeshGeomFacet::ArrangeNormal (const Base::Vector3f &rclN)
         _clNormal = -_clNormal;
 }
 
-inline Base::Vector3f MeshGeomFacet::GetGravityPoint (void) const
+inline Base::Vector3f MeshGeomFacet::GetGravityPoint () const
 {
     return (1.0f / 3.0f) * (_aclPoints[0] + _aclPoints[1] + _aclPoints[2]);
 }
 
-inline void MeshGeomFacet::AdjustCirculationDirection (void)
+inline void MeshGeomFacet::AdjustCirculationDirection ()
 {
     Base::Vector3f clN = (_aclPoints[1] - _aclPoints[0]) % (_aclPoints[2] - _aclPoints[0]);
     if ((clN * _clNormal) < 0.0f)
         std::swap(_aclPoints[1], _aclPoints[2]);
 }
 
-inline Base::BoundBox3f MeshGeomFacet::GetBoundBox (void) const
+inline Base::BoundBox3f MeshGeomFacet::GetBoundBox () const
 {
     return Base::BoundBox3f(_aclPoints, 3);
 }
@@ -823,27 +858,27 @@ inline float MeshGeomFacet::Perimeter() const
 
 inline float MeshGeomFacet::Area () const
 {
-    return ((_aclPoints[1] - _aclPoints[0]) % 
+    return ((_aclPoints[1] - _aclPoints[0]) %
             (_aclPoints[2] - _aclPoints[0])).Length() / 2.0f;
 }
 
 inline bool MeshGeomFacet::ContainedByOrIntersectBoundingBox ( const Base::BoundBox3f &rclBB ) const
 {
-     // Test, ob alle Eckpunkte des Facets sich auf einer der 6 Seiten der BB befinden
-    if ((GetBoundBox() && rclBB) == false)
+     // Test, if all corner points of the facet are on one of the 6 sides of the BB
+    if (!(GetBoundBox() && rclBB))
         return false;
 
-    // Test, ob Facet-BB komplett in BB liegt
+    // Test, whether Facet-BB is completely within BB
     if (rclBB.IsInBox(GetBoundBox()))
         return true;
 
-    // Test, ob einer der Eckpunkte in BB liegt
+    // Test, whether one of the corner points is in BB
     for (int i=0;i<3;i++) {
         if (rclBB.IsInBox(_aclPoints[i]))
             return true;
     }
 
-    // "echter" Test auf Schnitt
+    // "real" test for cutting
     if (IntersectBoundingBox(rclBB))
         return true;
 
@@ -852,17 +887,17 @@ inline bool MeshGeomFacet::ContainedByOrIntersectBoundingBox ( const Base::Bound
 
 inline bool MeshGeomFacet::IntersectWithPlane (const Base::Vector3f &rclBase, const Base::Vector3f &rclNormal) const
 {
-    bool bD0 = (_aclPoints[0].DistanceToPlane(rclBase, rclNormal) > 0.0f); 
+    bool bD0 = (_aclPoints[0].DistanceToPlane(rclBase, rclNormal) > 0.0f);
     return !((bD0 == (_aclPoints[1].DistanceToPlane(rclBase, rclNormal) > 0.0f)) &&
              (bD0 == (_aclPoints[2].DistanceToPlane(rclBase, rclNormal) > 0.0f)));
 }
 
-inline MeshFacet::MeshFacet (void)
+inline MeshFacet::MeshFacet ()
 : _ucFlag(0),
   _ulProp(0)
 {
-    memset(_aulNeighbours, 0xff, sizeof(unsigned long) * 3);
-    memset(_aulPoints, 0xff, sizeof(unsigned long) * 3);
+    memset(_aulNeighbours, 0xff, sizeof(FacetIndex) * 3);
+    memset(_aulPoints, 0xff, sizeof(PointIndex) * 3);
 }
 
 inline MeshFacet::MeshFacet(const MeshFacet &rclF)
@@ -878,8 +913,8 @@ inline MeshFacet::MeshFacet(const MeshFacet &rclF)
     _aulNeighbours[2] = rclF._aulNeighbours[2];
 }
 
-inline MeshFacet::MeshFacet(unsigned long p1,unsigned long p2,unsigned long p3,
-                            unsigned long n1,unsigned long n2,unsigned long n3)
+inline MeshFacet::MeshFacet(PointIndex p1,PointIndex p2,PointIndex p3,
+                            FacetIndex n1,FacetIndex n2,FacetIndex n3)
 : _ucFlag(0),
   _ulProp(0)
 {
@@ -908,14 +943,14 @@ inline MeshFacet& MeshFacet::operator = (const MeshFacet &rclF)
     return *this;
 }
 
-void MeshFacet::SetVertices(unsigned long p1,unsigned long p2,unsigned long p3)
+void MeshFacet::SetVertices(PointIndex p1,PointIndex p2,PointIndex p3)
 {
     _aulPoints[0] = p1;
     _aulPoints[1] = p2;
     _aulPoints[2] = p3;
 }
 
-void MeshFacet::SetNeighbours(unsigned long n1,unsigned long n2,unsigned long n3)
+void MeshFacet::SetNeighbours(FacetIndex n1,FacetIndex n2,FacetIndex n3)
 {
     _aulNeighbours[0] = n1;
     _aulNeighbours[1] = n2;
@@ -928,12 +963,12 @@ inline void MeshFacet::GetEdge (unsigned short usSide, MeshHelpEdge &rclEdge) co
     rclEdge._ulIndex[1] = _aulPoints[(usSide+1) % 3];
 }
 
-inline std::pair<unsigned long, unsigned long> MeshFacet::GetEdge (unsigned short usSide) const
+inline std::pair<PointIndex, PointIndex> MeshFacet::GetEdge (unsigned short usSide) const
 {
-    return std::pair<unsigned long, unsigned long>(_aulPoints[usSide], _aulPoints[(usSide+1)%3]);
+    return std::pair<PointIndex, PointIndex>(_aulPoints[usSide], _aulPoints[(usSide+1)%3]);
 }
 
-inline void MeshFacet::Transpose (unsigned long ulOrig, unsigned long ulNew)
+inline void MeshFacet::Transpose (PointIndex ulOrig, PointIndex ulNew)
 {
     if (_aulPoints[0] == ulOrig)
         _aulPoints[0] = ulNew;
@@ -943,14 +978,14 @@ inline void MeshFacet::Transpose (unsigned long ulOrig, unsigned long ulNew)
         _aulPoints[2] = ulNew;
 }
 
-inline void MeshFacet::Decrement (unsigned long ulIndex)
+inline void MeshFacet::Decrement (PointIndex ulIndex)
 {
     if (_aulPoints[0] > ulIndex) _aulPoints[0]--;
     if (_aulPoints[1] > ulIndex) _aulPoints[1]--;
     if (_aulPoints[2] > ulIndex) _aulPoints[2]--;
 }
 
-inline bool MeshFacet::HasPoint(unsigned long ulIndex) const
+inline bool MeshFacet::HasPoint(PointIndex ulIndex) const
 {
     if (_aulPoints[0] == ulIndex)
         return true;
@@ -961,7 +996,7 @@ inline bool MeshFacet::HasPoint(unsigned long ulIndex) const
     return false;
 }
 
-inline void MeshFacet::ReplaceNeighbour (unsigned long ulOrig, unsigned long ulNew)
+inline void MeshFacet::ReplaceNeighbour (FacetIndex ulOrig, FacetIndex ulNew)
 {
     if (_aulNeighbours[0] == ulOrig)
         _aulNeighbours[0] = ulNew;
@@ -1011,7 +1046,7 @@ inline bool MeshFacet::IsDegenerated() const
     return false;
 }
 
-inline unsigned short MeshFacet::Side (unsigned long ulNIndex) const
+inline unsigned short MeshFacet::Side (FacetIndex ulNIndex) const
 {
     if (_aulNeighbours[0] == ulNIndex)
         return 0;
@@ -1023,25 +1058,25 @@ inline unsigned short MeshFacet::Side (unsigned long ulNIndex) const
         return USHRT_MAX;
 }
 
-inline unsigned short MeshFacet::Side (unsigned long ulP0, unsigned long ulP1) const
+inline unsigned short MeshFacet::Side (PointIndex ulP0, PointIndex ulP1) const
 {
     if (_aulPoints[0] == ulP0) {
         if (_aulPoints[1] == ulP1)
-            return 0;  // Kante 0-1 ==> 0
+            return 0;  // Edge 0-1 ==> 0
         else if (_aulPoints[2] == ulP1)
-            return 2;  // Kante 0-2 ==> 2
+            return 2;  // Edge 0-2 ==> 2
     }
     else if (_aulPoints[1] == ulP0) {
         if (_aulPoints[0] == ulP1)
-            return 0; // Kante 1-0 ==> 0
+            return 0; // Edge 1-0 ==> 0
         else if (_aulPoints[2] == ulP1)
-            return 1; // Kante 1-2 ==> 1
+            return 1; // Edge 1-2 ==> 1
     }
     else if (_aulPoints[2] == ulP0) {
         if (_aulPoints[0] == ulP1)
-            return 2; // Kante 2-0 ==> 2
+            return 2; // Edge 2-0 ==> 2
         else if (_aulPoints[1] == ulP1)
-            return 1; // Kante 2-1 ==> 1
+            return 1; // Edge 2-1 ==> 1
     }
 
     return USHRT_MAX;
@@ -1082,9 +1117,9 @@ template <class TCLASS>
 class MeshIsFlag
 {
 public:
-    typedef TCLASS first_argument_type;
-    typedef typename TCLASS::TFlagType second_argument_type;
-    typedef bool result_type;
+    using first_argument_type = TCLASS;
+    using second_argument_type = typename TCLASS::TFlagType;
+    using result_type = bool;
     bool operator () (const TCLASS& rclElem, typename TCLASS::TFlagType tFlag) const
     { return rclElem.IsFlag(tFlag); }
 };
@@ -1096,9 +1131,9 @@ template <class TCLASS>
 class MeshIsNotFlag
 {
 public:
-    typedef TCLASS first_argument_type;
-    typedef typename TCLASS::TFlagType second_argument_type;
-    typedef bool result_type;
+    using first_argument_type = TCLASS;
+    using second_argument_type = typename TCLASS::TFlagType;
+    using result_type = bool;
     bool operator () (const TCLASS& rclElem, typename TCLASS::TFlagType tFlag) const
     { return !rclElem.IsFlag(tFlag); }
 };
@@ -1110,9 +1145,9 @@ template <class TCLASS>
 class MeshSetFlag
 {
 public:
-    typedef TCLASS first_argument_type;
-    typedef typename TCLASS::TFlagType second_argument_type;
-    typedef bool result_type;
+    using first_argument_type = TCLASS;
+    using second_argument_type = typename TCLASS::TFlagType;
+    using result_type = bool;
     bool operator () (const TCLASS& rclElem, typename TCLASS::TFlagType tFlag) const
     { rclElem.SetFlag(tFlag); return true; }
 };
@@ -1124,13 +1159,13 @@ template <class TCLASS>
 class MeshResetFlag
 {
 public:
-    typedef TCLASS first_argument_type;
-    typedef typename TCLASS::TFlagType second_argument_type;
-    typedef bool result_type;
+    using first_argument_type = TCLASS;
+    using second_argument_type = typename TCLASS::TFlagType;
+    using result_type = bool;
     bool operator () (const TCLASS& rclElem, typename TCLASS::TFlagType tFlag) const
     { rclElem.ResetFlag(tFlag); return true; }
 };
 
 } // namespace MeshCore
 
-#endif // MESH_ELEMENTS_H 
+#endif // MESH_ELEMENTS_H
