@@ -20,30 +20,27 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
 # include <algorithm>
-# include <stdexcept>
 # include <map>
 # include <queue>
+# include <stdexcept>
 #endif
 
 #include <Base/Exception.h>
-#include <Base/Sequencer.h>
 #include <Base/Stream.h>
 #include <Base/Swap.h>
 
-#include "Algorithm.h"
-#include "Approximation.h"
-#include "Helpers.h"
 #include "MeshKernel.h"
-#include "Iterator.h"
-#include "Evaluation.h"
+#include "Algorithm.h"
 #include "Builder.h"
-#include "Smoothing.h"
+#include "Evaluation.h"
+#include "Iterator.h"
 #include "MeshIO.h"
+#include "Smoothing.h"
+
 
 using namespace MeshCore;
 
@@ -165,7 +162,7 @@ MeshKernel& MeshKernel::operator += (const std::vector<MeshGeomFacet> &rclFAry)
 void MeshKernel::AddFacets(const std::vector<MeshGeomFacet> &rclFAry)
 {
     // Create a temp. kernel to get the topology of the passed triangles
-    // and merge them with this kernel. This keeps properties and flags 
+    // and merge them with this kernel. This keeps properties and flags
     // of this mesh.
     MeshKernel tmp;
     tmp = rclFAry;
@@ -297,7 +294,7 @@ unsigned long MeshKernel::AddFacets(const std::vector<MeshFacet> &rclFAry,
         }
         else if (pE->second.size() == 2)  // normal facet with neighbour
         {
-            // we must check if both facets are part of the mesh now 
+            // we must check if both facets are part of the mesh now
             FacetIndex ulF0 = pE->second.front();
             if (ulF0 >= countFacets) {
                 ulF0 -= countFacets;
@@ -316,7 +313,7 @@ unsigned long MeshKernel::AddFacets(const std::vector<MeshFacet> &rclFAry,
                 else
                     ulF1 = FACET_INDEX_MAX;
             }
-            
+
             if (ulF0 != FACET_INDEX_MAX) {
                 unsigned short usSide = _aclFacetArray[ulF0].Side(ulP0, ulP1);
                 assert(usSide != USHRT_MAX);
@@ -381,7 +378,7 @@ void MeshKernel::Merge(const MeshPointArray& rPoints, const MeshFacetArray& rFac
     // Reserve the additional memory to append the new points
     PointIndex index = this->_aclPointArray.size();
     this->_aclPointArray.reserve(this->_aclPointArray.size() + countNewPoints);
-    
+
     // Now we can start inserting the points and adjust the point indices of the faces
     for (std::vector<unsigned long>::iterator it = increments.begin(); it != increments.end(); ++it) {
         if (*it > 0) {
@@ -433,7 +430,7 @@ bool MeshKernel::DeleteFacet (const MeshFacetIterator &rclIter)
         return false;
 
     // index of the facet to delete
-    ulInd = rclIter._clIter - _aclFacetArray.begin(); 
+    ulInd = rclIter._clIter - _aclFacetArray.begin();
 
     // invalidate neighbour indices of the neighbour facet to this facet
     for (int i = 0; i < 3; i++) {
@@ -520,12 +517,12 @@ bool MeshKernel::DeletePoint (PointIndex ulInd)
 bool MeshKernel::DeletePoint (const MeshPointIterator &rclIter)
 {
     MeshFacetIterator pFIter(*this), pFEnd(*this);
-    std::vector<MeshFacetIterator>  clToDel; 
+    std::vector<MeshFacetIterator>  clToDel;
     PointIndex ulInd;
 
     // index of the point to delete
-    ulInd = rclIter._clIter - _aclPointArray.begin(); 
- 
+    ulInd = rclIter._clIter - _aclPointArray.begin();
+
     pFIter.Begin();
     pFEnd.End();
 
@@ -544,7 +541,7 @@ bool MeshKernel::DeletePoint (const MeshPointIterator &rclIter)
     // delete each facet separately (from back to front to avoid to
     // invalidate the iterators)
     for (size_t i = clToDel.size(); i > 0; i--)
-        DeleteFacet(clToDel[i-1]); 
+        DeleteFacet(clToDel[i-1]);
     return true;
 }
 
@@ -561,7 +558,7 @@ void MeshKernel::DeletePoints (const std::vector<PointIndex> &raulPoints)
         MeshPoint &rclP1 = _aclPointArray[pF->_aulPoints[1]];
         MeshPoint &rclP2 = _aclPointArray[pF->_aulPoints[2]];
 
-        if ((rclP0.IsValid() == false) || (rclP1.IsValid() == false) || (rclP2.IsValid() == false)) {
+        if (!rclP0.IsValid() || !rclP1.IsValid() || !rclP2.IsValid()) {
             pF->SetInvalid();
         }
         else {
@@ -589,7 +586,7 @@ void MeshKernel::ErasePoint (PointIndex ulIndex, FacetIndex ulFacetIndex, bool b
     pFIter = _aclFacetArray.begin();
     pFNot  = _aclFacetArray.begin() + ulFacetIndex;
     pFEnd  = _aclFacetArray.end();
- 
+
     // check all facets
     while (pFIter < pFNot) {
         for (int i = 0; i < 3; i++) {
@@ -609,7 +606,7 @@ void MeshKernel::ErasePoint (PointIndex ulIndex, FacetIndex ulFacetIndex, bool b
     }
 
 
-    if (bOnlySetInvalid == false) {
+    if (!bOnlySetInvalid) {
         // completely remove point
         _aclPointArray.erase(_aclPointArray.begin() + ulIndex);
 
@@ -642,14 +639,14 @@ void MeshKernel::RemoveInvalids ()
     pPEnd  = _aclPointArray.end();
     for (pPIter = _aclPointArray.begin(); pPIter != pPEnd; ++pPIter) {
         *pDIter++ = ulDec;
-        if (pPIter->IsValid() == false)
+        if (!pPIter->IsValid())
             ulDec++;
     }
 
     // correct point indices of the facets
     pFEnd  = _aclFacetArray.end();
     for (pFIter = _aclFacetArray.begin(); pFIter != pFEnd; ++pFIter) {
-        if (pFIter->IsValid() == true) {
+        if (pFIter->IsValid()) {
             pFIter->_aulPoints[0] -= aulDecrements[pFIter->_aulPoints[0]];
             pFIter->_aulPoints[1] -= aulDecrements[pFIter->_aulPoints[1]];
             pFIter->_aulPoints[2] -= aulDecrements[pFIter->_aulPoints[2]];
@@ -664,7 +661,7 @@ void MeshKernel::RemoveInvalids ()
     MeshPointArray::_TIterator pPTemp = aclTempPt.begin();
     pPEnd = _aclPointArray.end();
     for (pPIter = _aclPointArray.begin(); pPIter != pPEnd; ++pPIter) {
-        if (pPIter->IsValid() == true)
+        if (pPIter->IsValid())
             *pPTemp++ = *pPIter;
     }
 
@@ -681,18 +678,18 @@ void MeshKernel::RemoveInvalids ()
     pFEnd  = _aclFacetArray.end();
     for (pFIter = _aclFacetArray.begin(); pFIter != pFEnd; ++pFIter, ++pDIter) {
         *pDIter = ulDec;
-        if (pFIter->IsValid() == false)
+        if (!pFIter->IsValid())
             ulDec++;
     }
 
     // correct neighbour indices of the facets
     pFEnd = _aclFacetArray.end();
     for (pFIter = _aclFacetArray.begin(); pFIter != pFEnd; ++pFIter) {
-        if (pFIter->IsValid() == true) {
+        if (pFIter->IsValid()) {
             for (int i = 0; i < 3; i++) {
                 FacetIndex k = pFIter->_aulNeighbours[i];
                 if (k != FACET_INDEX_MAX) {
-                    if (_aclFacetArray[k].IsValid() == true)
+                    if (_aclFacetArray[k].IsValid())
                         pFIter->_aulNeighbours[i] -= aulDecrements[k];
                     else
                         pFIter->_aulNeighbours[i] = FACET_INDEX_MAX;
@@ -705,10 +702,10 @@ void MeshKernel::RemoveInvalids ()
     unsigned long ulDelFacets = std::count_if(_aclFacetArray.begin(), _aclFacetArray.end(),
                                               [](const MeshFacet& f) { return f.IsValid(); });
     MeshFacetArray aclFArray(ulDelFacets);
-    MeshFacetArray::_TIterator pFTemp = aclFArray.begin();  
+    MeshFacetArray::_TIterator pFTemp = aclFArray.begin();
     pFEnd  = _aclFacetArray.end();
     for (pFIter = _aclFacetArray.begin(); pFIter != pFEnd; ++pFIter) {
-        if (pFIter->IsValid() == true)
+        if (pFIter->IsValid())
             *pFTemp++ = *pFIter;
     }
 
@@ -717,7 +714,7 @@ void MeshKernel::RemoveInvalids ()
     _aclFacetArray.swap(aclFArray);
 }
 
-void MeshKernel::CutFacets(const MeshFacetGrid& rclGrid, const Base::ViewProjMethod* pclProj, 
+void MeshKernel::CutFacets(const MeshFacetGrid& rclGrid, const Base::ViewProjMethod* pclProj,
                            const Base::Polygon2d& rclPoly, bool bCutInner, std::vector<MeshGeomFacet> &raclFacets)
 {
     std::vector<FacetIndex> aulFacets;
@@ -817,7 +814,7 @@ MeshFacetArray MeshKernel::GetFacets(const std::vector<FacetIndex>& indices) con
     return ary;
 }
 
-void MeshKernel::Write (std::ostream &rclOut) const 
+void MeshKernel::Write (std::ostream &rclOut) const
 {
     if (!rclOut || rclOut.bad())
         return;
@@ -897,7 +894,7 @@ void MeshKernel::Read (std::istream &rclIn)
             for (MeshPointArray::_TIterator it = pointArray.begin(); it != pointArray.end(); ++it) {
                 str >> it->x >> it->y >> it->z;
             }
-          
+
             MeshFacetArray facetArray;
             facetArray.resize(uCtFts);
 
