@@ -21,16 +21,20 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
-#include <algorithm>
+#ifndef _PreComp_
+# include <algorithm>
+#endif
+
+#include <Base/Sequencer.h>
 
 #include "Trim.h"
 #include "Grid.h"
 #include "Iterator.h"
-#include <Base/Sequencer.h>
+
 
 using namespace MeshCore;
 
-MeshTrimming::MeshTrimming(MeshKernel &rclM, const Base::ViewProjMethod* pclProj, 
+MeshTrimming::MeshTrimming(MeshKernel &rclM, const Base::ViewProjMethod* pclProj,
                            const Base::Polygon2d& rclPoly)
   : myMesh(rclM), myInner(true), myProj(pclProj), myPoly(rclPoly)
 {
@@ -53,16 +57,16 @@ void MeshTrimming::SetInnerOrOuter(TMode tMode)
     }
 }
 
-void MeshTrimming::CheckFacets(const MeshFacetGrid& rclGrid, std::vector<unsigned long> &raulFacets) const
+void MeshTrimming::CheckFacets(const MeshFacetGrid& rclGrid, std::vector<FacetIndex> &raulFacets) const
 {
-    std::vector<unsigned long>::iterator it;
+    std::vector<FacetIndex>::iterator it;
     MeshFacetIterator clIter(myMesh, 0);
 
     // cut inner: use grid to accelerate search
     if (myInner) {
         Base::BoundBox3f clBBox3d;
         Base::BoundBox2d clViewBBox, clPolyBBox;
-        std::vector<unsigned long> aulAllElements;
+        std::vector<FacetIndex> aulAllElements;
 
         // BBox of polygon
         clPolyBBox = myPoly.CalcBoundBox();
@@ -72,12 +76,12 @@ void MeshTrimming::CheckFacets(const MeshFacetGrid& rclGrid, std::vector<unsigne
             clBBox3d = clGridIter.GetBoundBox();
             clViewBBox = clBBox3d.ProjectBox(myProj);
             if (clViewBBox.Intersect(clPolyBBox)) {
-                // save all elements in AllElements 
+                // save all elements in AllElements
                 clGridIter.GetElements(aulAllElements);
             }
         }
-    
-        // remove double elements 
+
+        // remove double elements
         std::sort(aulAllElements.begin(), aulAllElements.end());
         aulAllElements.erase(std::unique(aulAllElements.begin(), aulAllElements.end()), aulAllElements.end());
 
@@ -103,13 +107,11 @@ void MeshTrimming::CheckFacets(const MeshFacetGrid& rclGrid, std::vector<unsigne
 
 bool MeshTrimming::HasIntersection(const MeshGeomFacet& rclFacet) const
 {
-    size_t i;
-    unsigned long j;
     Base::Polygon2d clPoly;
     Base::Line2d clFacLine, clPolyLine;
     Base::Vector2d S;
     // is corner of facet inside the polygon
-    for (i=0; i<3; i++) {
+    for (size_t i=0; i<3; i++) {
         Base::Vector3f clPt2d = myProj->operator ()(rclFacet._aclPoints[i]);
         if (myPoly.Contains(Base::Vector2d(clPt2d.x, clPt2d.y)) == myInner)
             return true;
@@ -118,17 +120,17 @@ bool MeshTrimming::HasIntersection(const MeshGeomFacet& rclFacet) const
     }
 
     // is corner of polygon inside the facet
-    for (j=0; j<myPoly.GetCtVectors(); j++) {
+    for (size_t j=0; j<myPoly.GetCtVectors(); j++) {
         if (clPoly.Contains(myPoly[j]))
             return true;
     }
-  
+
     // check for other intersections
-    for (j=0; j<myPoly.GetCtVectors(); j++) {
+    for (size_t j=0; j<myPoly.GetCtVectors(); j++) {
         clPolyLine.clV1 = myPoly[j];
         clPolyLine.clV2 = myPoly[(j+1)%myPoly.GetCtVectors()];
 
-        for (i=0; i<3; i++) {
+        for (size_t i=0; i<3; i++) {
             clFacLine.clV1 = clPoly[i];
             clFacLine.clV2 = clPoly[(i+1)%3];
 
@@ -141,7 +143,7 @@ bool MeshTrimming::HasIntersection(const MeshGeomFacet& rclFacet) const
     return false;
 }
 
-bool MeshTrimming::PolygonContainsCompleteFacet(bool bInner, unsigned long ulIndex) const
+bool MeshTrimming::PolygonContainsCompleteFacet(bool bInner, FacetIndex ulIndex) const
 {
     const MeshFacet &rclFacet = myMesh._aclFacetArray[ulIndex];
     for (int i=0; i<3; i++) {
@@ -154,13 +156,13 @@ bool MeshTrimming::PolygonContainsCompleteFacet(bool bInner, unsigned long ulInd
     return true;
 }
 
-bool MeshTrimming::IsPolygonPointInFacet(unsigned long ulIndex, Base::Vector3f& clPoint)
+bool MeshTrimming::IsPolygonPointInFacet(FacetIndex ulIndex, Base::Vector3f& clPoint)
 {
     Base::Vector2d A, B, C, P;
     float u,v,w, fDetPAC, fDetPBC, fDetPAB, fDetABC;
     Base::Polygon2d clFacPoly;
     const MeshGeomFacet &rclFacet = myMesh.GetFacet(ulIndex);
-  
+
     for (int i=0; i<3; i++) {
         Base::Vector3f clPt = (*myProj)(rclFacet._aclPoints[i]);
         clFacPoly.Add(Base::Vector2d(clPt.x, clPt.y));
@@ -171,7 +173,7 @@ bool MeshTrimming::IsPolygonPointInFacet(unsigned long ulIndex, Base::Vector3f&
     C = clFacPoly[2];
     fDetABC = static_cast<float>(A.x*B.y+A.y*C.x+B.x*C.y-(B.y*C.x+A.y*B.x+A.x*C.y));
 
-    for (unsigned long j=0; j<myPoly.GetCtVectors(); j++) {
+    for (size_t j=0; j<myPoly.GetCtVectors(); j++) {
         // facet contains a polygon point -> calculate the corresponding 3d-point
         if (clFacPoly.Contains(myPoly[j])) {
             P = myPoly[j];
@@ -181,7 +183,7 @@ bool MeshTrimming::IsPolygonPointInFacet(unsigned long ulIndex, Base::Vector3f&
             u = fDetPBC / fDetABC;
             v = fDetPAC / fDetABC;
             w = fDetPAB / fDetABC;
-      
+
             // point is on edge or no valid convex combination
             if (u == 0.0f || v == 0.0f || w == 0.0f || fabs(u+v+w-1.0f) >= 0.001f)
                 return false;
@@ -195,7 +197,7 @@ bool MeshTrimming::IsPolygonPointInFacet(unsigned long ulIndex, Base::Vector3f&
     return false;
 }
 
-bool MeshTrimming::GetIntersectionPointsOfPolygonAndFacet(unsigned long ulIndex, int& iSide, std::vector<Base::Vector3f>& raclPoints) const
+bool MeshTrimming::GetIntersectionPointsOfPolygonAndFacet(FacetIndex ulIndex, int& iSide, std::vector<Base::Vector3f>& raclPoints) const
 {
     MeshGeomFacet clFac(myMesh.GetFacet(ulIndex));
     Base::Vector2d S;
@@ -206,7 +208,7 @@ bool MeshTrimming::GetIntersectionPointsOfPolygonAndFacet(unsigned long ulIndex,
     // Edge with no intersection
     iSide = -1;
 
-    for (unsigned long i=0; i<myPoly.GetCtVectors(); i++) {
+    for (size_t i=0; i<myPoly.GetCtVectors(); i++) {
         // totally only four intersections allowed
         if (iIntersections == 4)
             break;
@@ -216,7 +218,7 @@ bool MeshTrimming::GetIntersectionPointsOfPolygonAndFacet(unsigned long ulIndex,
         clPolyLine.clV2 = P4;
 
         for (int j=0; j<3; j++) {
-            Base::Vector3f clP1((*myProj)(clFac._aclPoints[j])); 
+            Base::Vector3f clP1((*myProj)(clFac._aclPoints[j]));
             Base::Vector3f clP2((*myProj)(clFac._aclPoints[(j+1)%3]));
             Base::Vector2d P1(clP1.x, clP1.y);
             Base::Vector2d P2(clP2.x, clP2.y);
@@ -246,7 +248,7 @@ bool MeshTrimming::GetIntersectionPointsOfPolygonAndFacet(unsigned long ulIndex,
 
                 float r = fSP3 / fP3P4;
                 float s = fSP4 / fP3P4;
- 
+
                 // is intersection point convex combination?
                 if ((fabs(l+m-1.0f) < 0.001f) && (fabs(r+s-1.0f) < 0.001f)) {
                     Base::Vector3f clIntersection(m*clFac._aclPoints[j]+l*clFac._aclPoints[(j+1)%3]);
@@ -273,7 +275,7 @@ bool MeshTrimming::GetIntersectionPointsOfPolygonAndFacet(unsigned long ulIndex,
                             iIntsctWithEdge2++;
                     }
 
-                    if (bPushBack == true)
+                    if (bPushBack)
                         raclPoints.push_back(clIntersection);
                 }
             }
@@ -335,7 +337,7 @@ void MeshTrimming::AdjustFacet(MeshFacet& facet, int iInd)
     }
 }
 
-bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::vector<Base::Vector3f>& raclPoints, std::vector<MeshGeomFacet>& aclNewFacets)
+bool MeshTrimming::CreateFacets(FacetIndex ulFacetPos, int iSide, const std::vector<Base::Vector3f>& raclPoints, std::vector<MeshGeomFacet>& aclNewFacets)
 {
     MeshGeomFacet clFac;
 
@@ -344,7 +346,7 @@ bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::
         return false;
 
     // no intersection point found => triangle is only touched at a corner point
-    if (raclPoints.size() == 0) {
+    if (raclPoints.empty()) {
         MeshFacet& facet = myMesh._aclFacetArray[ulFacetPos];
         int iCtPtsIn=0;
         int iCtPtsOn=0;
@@ -373,7 +375,7 @@ bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::
         // determine the edge containing the intersection point
         Base::Line2d clFacLine;
         for (int j=0; j<3; j++) {
-            Base::Vector3f clP1((*myProj)(clFac._aclPoints[j])); 
+            Base::Vector3f clP1((*myProj)(clFac._aclPoints[j]));
             Base::Vector3f clP2((*myProj)(clFac._aclPoints[(j+1)%3]));
             Base::Vector2d P1(clP1.x, clP1.y);
             Base::Vector2d P2(clP2.x, clP2.y);
@@ -405,7 +407,7 @@ bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::
         MeshFacet& facet = myMesh._aclFacetArray[ulFacetPos];
         AdjustFacet(facet, iSide);
         Base::Vector3f clP1(raclPoints[0]), clP2(raclPoints[1]);
-    
+
         if (iSide == 1) {
             // swap P1 and P2
             clP1 = raclPoints[1];
@@ -495,48 +497,48 @@ bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::
                 MeshGeomFacet clTmpFac; clTmpFac._aclPoints[0] = clFac._aclPoints[1];
                 clTmpFac._aclPoints[1] = clP2; clTmpFac._aclPoints[2] = clP1;
                 if (clTmpFac.GetNormal() * clNormal > 0) {
-                    Base::Vector3f tmp(clP1); 
-                    clP1 = clP2; 
+                    Base::Vector3f tmp(clP1);
+                    clP1 = clP2;
                     clP2 = tmp;
                 }
                 else {
-                    Base::Vector3f tmp(clP1); 
-                    clP1 = clP4; 
-                    clP4 = clP2; 
-                    clP2 = clP3; 
+                    Base::Vector3f tmp(clP1);
+                    clP1 = clP4;
+                    clP4 = clP2;
+                    clP2 = clP3;
                     clP3 = tmp;
                 }
             }
             else if (iSide == 1) {
                 if ((clP2-clFac._aclPoints[1]).Length() > (clP4-clFac._aclPoints[1]).Length()) {
-                    Base::Vector3f tmp(clP1); 
-                    clP1 = clP4; 
+                    Base::Vector3f tmp(clP1);
+                    clP1 = clP4;
                     clP4 = tmp;
-                    tmp = clP2;          
-                    clP2 = clP3; 
+                    tmp = clP2;
+                    clP2 = clP3;
                     clP3 = tmp;
                 }
                 else {
-                    Base::Vector3f tmp(clP1); 
-                    clP1 = clP2; 
+                    Base::Vector3f tmp(clP1);
+                    clP1 = clP2;
                     clP2 = tmp;
-                    tmp = clP3;          
-                    clP3 = clP4; 
+                    tmp = clP3;
+                    clP3 = clP4;
                     clP4 = tmp;
                 }
             }
             else {
                 if ((clP1-clFac._aclPoints[1]).Length() > (clP3-clFac._aclPoints[1]).Length()) {
-                    Base::Vector3f tmp(clP1); 
-                    clP1 = clP3; 
+                    Base::Vector3f tmp(clP1);
+                    clP1 = clP3;
                     clP3 = tmp;
-                    tmp = clP2;          
-                    clP2 = clP4; 
+                    tmp = clP2;
+                    clP2 = clP4;
                     clP4 = tmp;
                 }
             }
         }
-  
+
         // now create the new facets
         if (iCtPts == 0) {
             // insert first facet
@@ -603,7 +605,7 @@ bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::
     return true;
 }
 
-bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::vector<Base::Vector3f>& raclPoints, Base::Vector3f& clP3,
+bool MeshTrimming::CreateFacets(FacetIndex ulFacetPos, int iSide, const std::vector<Base::Vector3f>& raclPoints, Base::Vector3f& clP3,
                                 std::vector<MeshGeomFacet>& aclNewFacets)
 {
     // no valid triangulation possible
@@ -716,18 +718,18 @@ bool MeshTrimming::CreateFacets(unsigned long ulFacetPos, int iSide, const std::
     return true;
 }
 
-void MeshTrimming::TrimFacets(const std::vector<unsigned long>& raulFacets, std::vector<MeshGeomFacet>& aclNewFacets)
+void MeshTrimming::TrimFacets(const std::vector<FacetIndex>& raulFacets, std::vector<MeshGeomFacet>& aclNewFacets)
 {
     Base::Vector3f clP;
     std::vector<Base::Vector3f> clIntsct;
     int iSide;
 
     Base::SequencerLauncher seq("trimming facets...", raulFacets.size());
-    for (std::vector<unsigned long>::const_iterator it=raulFacets.begin(); it!=raulFacets.end(); ++it) {
+    for (std::vector<FacetIndex>::const_iterator it=raulFacets.begin(); it!=raulFacets.end(); ++it) {
         clIntsct.clear();
-        if (IsPolygonPointInFacet(*it, clP) == false) {
+        if (!IsPolygonPointInFacet(*it, clP)) {
             // facet must be trimmed
-            if (PolygonContainsCompleteFacet(myInner, *it) == false) {
+            if (!PolygonContainsCompleteFacet(myInner, *it)) {
                 // generate new facets
                 if (GetIntersectionPointsOfPolygonAndFacet(*it, iSide, clIntsct))
                     CreateFacets(*it, iSide, clIntsct, myTriangles);
