@@ -20,19 +20,11 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
 
-#include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/Sequencer.h>
 #include "FeatureMeshExport.h"
 #include "MeshFeature.h"
 
-#include "Core/MeshIO.h"
-
 
 using namespace Mesh;
 using namespace MeshCore;
@@ -41,9 +33,9 @@ PROPERTY_SOURCE(Mesh::Export, App::DocumentObject)
 
 Export::Export()
 {
-    ADD_PROPERTY(Source  ,(nullptr));
-    ADD_PROPERTY(FileName,(""));
-    ADD_PROPERTY(Format  ,(""));
+    ADD_PROPERTY(Source, (nullptr));
+    ADD_PROPERTY(FileName, (""));
+    ADD_PROPERTY(Format, (""));
 }
 
 short Export::mustExecute() const
