@@ -20,21 +20,9 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
 
-#include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/Sequencer.h>
-
-#include "Core/MeshKernel.h"
-#include "Core/Algorithm.h"
-#include "Core/Evaluation.h"
 #include "Core/Iterator.h"
-#include "Core/Visitor.h"
-
 #include "Core/SetOperations.h"
 
 #include "FeatureMeshSetOperations.h"
@@ -48,8 +36,8 @@ PROPERTY_SOURCE(Mesh::SetOperations, Mesh::Feature)
 
 SetOperations::SetOperations()
 {
-    ADD_PROPERTY(Source1  ,(nullptr));
-    ADD_PROPERTY(Source2  ,(nullptr));
+    ADD_PROPERTY(Source1, (nullptr));
+    ADD_PROPERTY(Source2, (nullptr));
     ADD_PROPERTY(OperationType, ("union"));
 }
 
@@ -72,7 +60,7 @@ App::DocumentObjectExecReturn *SetOperations::execute()
     Mesh::Feature *mesh1  = dynamic_cast<Mesh::Feature*>(Source1.getValue());
     Mesh::Feature *mesh2  = dynamic_cast<Mesh::Feature*>(Source2.getValue());
 
-    if ((mesh1 != nullptr) && (mesh2 != nullptr)) {
+    if (mesh1 && mesh2) {
         const MeshObject& meshKernel1 = mesh1->Mesh.getValue();
         const MeshObject& meshKernel2 = mesh2->Mesh.getValue();
 
@@ -94,7 +82,7 @@ App::DocumentObjectExecReturn *SetOperations::execute()
             throw Base::ValueError("Operation type must either be 'union' or 'intersection'"
                                    " or 'difference' or 'inner' or 'outer'");
 
-        MeshCore::SetOperations setOp(meshKernel1.getKernel(), meshKernel2.getKernel(), 
+        MeshCore::SetOperations setOp(meshKernel1.getKernel(), meshKernel2.getKernel(),
             pcKernel->getKernel(), type, 1.0e-5f);
         setOp.Do();
         Mesh.setValuePtr(pcKernel.release());
