@@ -20,23 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
 
-#include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/Interpreter.h>
 #include <App/Document.h>
 
 #include "FeatureMeshSolid.h"
-#include "Mesh.h"
 
 
 namespace Mesh {
-    const App::PropertyIntegerConstraint::Constraints intSampling = {0,INT_MAX,1};
-    const App::PropertyLength::Constraints floatRange = {0.0,FLT_MAX,1.0};
+    const App::PropertyIntegerConstraint::Constraints intSampling = {0, INT_MAX, 1};
+    const App::PropertyLength::Constraints floatRange = {0.0, FLT_MAX, 1.0};
 }
 
 using namespace Mesh;
@@ -46,8 +39,8 @@ PROPERTY_SOURCE(Mesh::Sphere, Mesh::Feature)
 
 Sphere::Sphere()
 {
-    ADD_PROPERTY(Radius  ,(5.0));
-    ADD_PROPERTY(Sampling  ,(50));
+    ADD_PROPERTY(Radius, (5.0));
+    ADD_PROPERTY(Sampling, (50));
     Radius.setConstraints(&floatRange);
     Sampling.setConstraints(&intSampling);
 }
@@ -100,8 +93,8 @@ Ellipsoid::Ellipsoid()
 
 short Ellipsoid::mustExecute() const
 {
-    if (Radius1.isTouched() || 
-        Radius2.isTouched() || 
+    if (Radius1.isTouched() ||
+        Radius2.isTouched() ||
         Sampling.isTouched())
         return 1;
     return Feature::mustExecute();
@@ -152,7 +145,7 @@ Cylinder::Cylinder()
 
 short Cylinder::mustExecute() const
 {
-    if (Radius.isTouched() || 
+    if (Radius.isTouched() ||
         Length.isTouched() ||
         EdgeLength.isTouched() ||
         Closed.isTouched() ||
@@ -209,8 +202,8 @@ Cone::Cone()
 
 short Cone::mustExecute() const
 {
-    if (Radius1.isTouched() || 
-        Radius2.isTouched() || 
+    if (Radius1.isTouched() ||
+        Radius2.isTouched() ||
         Length.isTouched()  ||
         EdgeLength.isTouched() ||
         Closed.isTouched()  ||
@@ -262,8 +255,8 @@ Torus::Torus()
 
 short Torus::mustExecute() const
 {
-    if (Radius1.isTouched() || 
-        Radius2.isTouched() || 
+    if (Radius1.isTouched() ||
+        Radius2.isTouched() ||
         Sampling.isTouched())
         return 1;
     return Feature::mustExecute();
@@ -311,8 +304,8 @@ Cube::Cube()
 
 short Cube::mustExecute() const
 {
-    if (Length.isTouched() || 
-        Width.isTouched() || 
+    if (Length.isTouched() ||
+        Width.isTouched() ||
         Height.isTouched())
         return 1;
     return Feature::mustExecute();
