@@ -20,15 +20,12 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef FEATURE_MESH_TRANSFORM_DEMOLDING_H
 #define FEATURE_MESH_TRANSFORM_DEMOLDING_H
 
-#include "FeatureMeshTransform.h"
-
 #include <App/PropertyLinks.h>
-#include <App/PropertyGeo.h>
-#include <App/PropertyStandard.h>
+
+#include "FeatureMeshTransform.h"
 
 
 namespace Mesh
@@ -39,7 +36,7 @@ namespace Mesh
  */
 class TransformDemolding : public Transform
 {
-    PROPERTY_HEADER(Mesh::TransformDemolding);
+    PROPERTY_HEADER_WITH_OVERRIDE(Mesh::TransformDemolding);
 
 public:
     TransformDemolding();
@@ -51,9 +48,9 @@ public:
     /** @name methods override Feature */
     //@{
     /// recalculate the Feature
-    virtual App::DocumentObjectExecReturn *execute();
+    App::DocumentObjectExecReturn *execute() override;
     /// returns the type name of the ViewProvider
-    virtual const char* getViewProviderName() const {
+    const char* getViewProviderName() const override {
         return "MeshGui::ViewProviderMeshTransformDemolding";
     }
     //@}
@@ -61,4 +58,4 @@ public:
 
 }
 
-#endif // FEATURE_MESH_TRANSFORM_H 
+#endif // FEATURE_MESH_TRANSFORM_H
