@@ -20,24 +20,14 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-#endif
-
-#include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/Reader.h>
-#include <Base/Writer.h>
 #include <App/FeaturePythonPyImp.h>
 
-#include "Core/MeshIO.h"
-
 #include "MeshFeature.h"
 #include "MeshFeaturePy.h"
 
+
 using namespace Mesh;
 
 
@@ -68,29 +58,32 @@ PyObject *Feature::getPyObject()
         // ref counter is set to 1
         PythonObject = Py::Object(new MeshFeaturePy(this),true);
     }
-    return Py::new_reference_to(PythonObject); 
+    return Py::new_reference_to(PythonObject);
 }
 
 void Feature::onChanged(const App::Property* prop)
 {
     // if the placement has changed apply the change to the mesh data as well
     if (prop == &this->Placement) {
-        MeshObject& mesh = const_cast<MeshObject&>(this->Mesh.getValue());
-        mesh.setTransform(this->Placement.getValue().toMatrix());
+        this->Mesh.setTransform(this->Placement.getValue().toMatrix());
     }
     // if the mesh data has changed check and adjust the transformation as well
     else if (prop == &this->Mesh) {
-        Base::Placement p;
-        p.fromMatrix(this->Mesh.getValue().getTransform());
-        if (p != this->Placement.getValue())
-            this->Placement.setValue(p);
+        try {
+            Base::Placement p;
+            p.fromMatrix(this->Mesh.getTransform());
+            if (p != this->Placement.getValue())
+                this->Placement.setValue(p);
+        }
+        catch (const Base::ValueError&) {
+        }
     }
 
     // Note: If the Mesh property has changed the property and this object are marked as 'touched'
     // but no recomputation of this objects needs to be done because the Mesh property is regarded
-    // as output of a previous recomputation The mustExecute() method returns 0 in that case. 
+    // as output of a previous recomputation The mustExecute() method returns 0 in that case.
     // However, objects that reference this object the Mesh property can be an input parameter.
-    // As this object and the property are touched such objects can check this and return a value 1 
+    // As this object and the property are touched such objects can check this and return a value 1
     // (or -1) in their mustExecute() to be recomputed the next time the document recomputes itself.
     DocumentObject::onChanged(prop);
 }
