@@ -22,17 +22,13 @@
 
 #include "PreCompiled.h"
 
-#include <Base/Console.h>
-#include <Base/Handle.h>
-
-#include "Core/Evaluation.h"
 #include "MeshFeature.h"
-
 // inclusion of the generated files (generated out of MeshFeaturePy.xml)
 #include <Mod/Mesh/App/MeshPy.h>
 #include <Mod/Mesh/App/MeshFeaturePy.h>
 #include <Mod/Mesh/App/MeshFeaturePy.cpp>
 
+
 using namespace Mesh;
 
 
@@ -47,12 +43,12 @@ std::string MeshFeaturePy::representation() const
 
 PyObject*  MeshFeaturePy::countPoints(PyObject * /*args*/)
 {
-    return Py_BuildValue("i",getFeaturePtr()->Mesh.getValue().countPoints()); 
+    return Py_BuildValue("i",getFeaturePtr()->Mesh.getValue().countPoints());
 }
 
 PyObject*  MeshFeaturePy::countFacets(PyObject * /*args*/)
 {
-    return Py_BuildValue("i",getFeaturePtr()->Mesh.getValue().countFacets()); 
+    return Py_BuildValue("i",getFeaturePtr()->Mesh.getValue().countFacets());
 }
 
 PyObject*  MeshFeaturePy::harmonizeNormals(PyObject *args)
@@ -66,7 +62,7 @@ PyObject*  MeshFeaturePy::harmonizeNormals(PyObject *args)
         getFeaturePtr()->Mesh.finishEditing();
     } PY_CATCH;
 
-    Py_Return; 
+    Py_Return;
 }
 
 PyObject*  MeshFeaturePy::smooth(PyObject *args)
@@ -83,7 +79,7 @@ PyObject*  MeshFeaturePy::smooth(PyObject *args)
         obj->Mesh.finishEditing();
     } PY_CATCH;
 
-    Py_Return; 
+    Py_Return;
 }
 
 PyObject*  MeshFeaturePy::removeNonManifolds(PyObject *args)
@@ -120,7 +116,7 @@ PyObject*  MeshFeaturePy::fixIndices(PyObject *args)
         obj->Mesh.finishEditing();
     } PY_CATCH;
 
-    Py_Return; 
+    Py_Return;
 }
 
 PyObject*  MeshFeaturePy::fixDegenerations(PyObject *args)
@@ -136,7 +132,7 @@ PyObject*  MeshFeaturePy::fixDegenerations(PyObject *args)
         obj->Mesh.finishEditing();
     } PY_CATCH;
 
-    Py_Return; 
+    Py_Return;
 }
 
 PyObject*  MeshFeaturePy::removeDuplicatedFacets(PyObject *args)
@@ -151,7 +147,7 @@ PyObject*  MeshFeaturePy::removeDuplicatedFacets(PyObject *args)
         obj->Mesh.finishEditing();
     } PY_CATCH;
 
-    Py_Return; 
+    Py_Return;
 }
 
 PyObject*  MeshFeaturePy::removeDuplicatedPoints(PyObject *args)
@@ -166,7 +162,7 @@ PyObject*  MeshFeaturePy::removeDuplicatedPoints(PyObject *args)
         obj->Mesh.finishEditing();
     } PY_CATCH;
 
-    Py_Return; 
+    Py_Return;
 }
 
 PyObject*  MeshFeaturePy::fixSelfIntersections(PyObject *args)
@@ -227,5 +223,5 @@ PyObject *MeshFeaturePy::getCustomAttributes(const char* /*attr*/) const
 
 int MeshFeaturePy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
 {
-    return 0; 
+    return 0;
 }
