@@ -20,16 +20,15 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef MESH_MESHPOINT_H
 #define MESH_MESHPOINT_H
 
 #include <climits>
-#include <Base/Matrix.h>
+
 #include <Base/Vector3D.h>
-#include <Base/Handle.h>
+
 #ifndef MESH_GLOBAL_H
-#include <Mod/Mesh/MeshGlobal.h>
+# include <Mod/Mesh/MeshGlobal.h>
 #endif
 
 using Base::Vector3d;
@@ -49,14 +48,14 @@ class MeshExport MeshPoint : public Vector3d
 
 public:
     /// simple constructor
-    MeshPoint(const Vector3d& vec = Vector3d(),MeshObject* obj = nullptr, unsigned int index = UINT_MAX)
+    explicit MeshPoint(const Vector3d& vec = Vector3d(), const MeshObject* obj = nullptr, unsigned int index = UINT_MAX)
         :Vector3d(vec),Index(index),Mesh(obj)
     {}
 
     bool isBound() const {return Index != UINT_MAX;}
 
     unsigned int Index;
-    Base::Reference<MeshObject> Mesh;
+    Base::Reference<const MeshObject> Mesh;
 };
 
 } // namespace Mesh
