@@ -20,24 +20,21 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef MESH_MESHPROPERTIES_H
 #define MESH_MESHPROPERTIES_H
 
-#include <vector>
 #include <list>
+#include <map>
 #include <set>
 #include <string>
-#include <map>
+#include <vector>
 
 #include <Base/Handle.h>
 #include <Base/Matrix.h>
-#include <Base/Vector3D.h>
 
-#include <App/PropertyStandard.h>
-#include <App/PropertyGeo.h>
+#include <Mod/Mesh/App/Core/MeshIO.h>
+#include <Mod/Mesh/App/Core/MeshKernel.h>
 
-#include "Core/MeshKernel.h"
 #include "Mesh.h"
 
 
@@ -52,14 +49,14 @@ class MeshPy;
  */
 class MeshExport PropertyNormalList: public App::PropertyLists
 {
-    TYPESYSTEM_HEADER();
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
     PropertyNormalList();
-    ~PropertyNormalList();
+    ~PropertyNormalList() override;
 
-    virtual void setSize(int newSize);
-    virtual int getSize() const;
+    void setSize(int newSize) override;
+    int getSize() const override;
 
     void setValue(const Base::Vector3f&);
     void setValue(float x, float y, float z);
@@ -78,19 +75,19 @@ public:
         return _lValueList;
     }
 
-    virtual PyObject *getPyObject();
-    virtual void setPyObject(PyObject *);
+    PyObject *getPyObject() override;
+    void setPyObject(PyObject *) override;
 
-    virtual void Save (Base::Writer &writer) const;
-    virtual void Restore(Base::XMLReader &reader);
+    void Save (Base::Writer &writer) const override;
+    void Restore(Base::XMLReader &reader) override;
 
-    virtual void SaveDocFile (Base::Writer &writer) const;
-    virtual void RestoreDocFile(Base::Reader &reader);
+    void SaveDocFile (Base::Writer &writer) const override;
+    void RestoreDocFile(Base::Reader &reader) override;
 
-    virtual App::Property *Copy() const;
-    virtual void Paste(const App::Property &from);
+    App::Property *Copy() const override;
+    void Paste(const App::Property &from) override;
 
-    virtual unsigned int getMemSize () const;
+    unsigned int getMemSize () const override;
 
     void transformGeometry(const Base::Matrix4D &rclMat);
 
@@ -110,23 +107,23 @@ struct MeshExport CurvatureInfo
  */
 class MeshExport PropertyCurvatureList: public App::PropertyLists
 {
-    TYPESYSTEM_HEADER();
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
-    enum { 
+    enum {
         MeanCurvature  = 0,  /**< Mean curvature */
         GaussCurvature = 1,  /**< Gaussian curvature */
-        MaxCurvature   = 2,  /**< Maximum curvature */ 
+        MaxCurvature   = 2,  /**< Maximum curvature */
         MinCurvature   = 3,  /**< Minimum curvature */
         AbsCurvature   = 4   /**< Absolute curvature */
     };
 
 public:
     PropertyCurvatureList();
-    ~PropertyCurvatureList();
+    ~PropertyCurvatureList() override;
 
-    void setSize(int newSize){_lValueList.resize(newSize);}
-    int getSize() const {return _lValueList.size();}
+    void setSize(int newSize) override{_lValueList.resize(newSize);}
+    int getSize() const override {return _lValueList.size();}
     std::vector<float> getCurvature( int tMode) const;
     void setValue(const CurvatureInfo&);
     void setValues(const std::vector<CurvatureInfo>&);
@@ -143,37 +140,88 @@ public:
     }
     void transformGeometry(const Base::Matrix4D &rclMat);
 
-    void Save (Base::Writer &writer) const;
-    void Restore(Base::XMLReader &reader);
+    void Save (Base::Writer &writer) const override;
+    void Restore(Base::XMLReader &reader) override;
 
-    void SaveDocFile (Base::Writer &writer) const;
-    void RestoreDocFile(Base::Reader &reader);
+    void SaveDocFile (Base::Writer &writer) const override;
+    void RestoreDocFile(Base::Reader &reader) override;
 
     /** @name Python interface */
     //@{
-    PyObject* getPyObject();
-    void setPyObject(PyObject *value);
+    PyObject* getPyObject() override;
+    void setPyObject(PyObject *value) override;
     //@}
 
-    App::Property *Copy() const;
-    void Paste(const App::Property &from);
+    App::Property *Copy() const override;
+    void Paste(const App::Property &from) override;
 
-    virtual unsigned int getMemSize () const{return _lValueList.size() * sizeof(CurvatureInfo);}
+    unsigned int getMemSize () const override{return _lValueList.size() * sizeof(CurvatureInfo);}
 
 private:
     std::vector<CurvatureInfo> _lValueList;
 };
 
+/** Mesh material properties
+ */
+class MeshExport PropertyMaterial : public App::Property
+{
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
+
+public:
+    PropertyMaterial() = default;
+    ~PropertyMaterial() override = default;
+
+    /** Sets the property
+     */
+    void setValue(const MeshCore::Material &mat);
+    void setAmbientColor(const std::vector<App::Color>& col);
+    void setDiffuseColor(const std::vector<App::Color>& col);
+    void setSpecularColor(const std::vector<App::Color>& col);
+    void setEmissiveColor(const std::vector<App::Color>& col);
+    void setShininess(const std::vector<float>&);
+    void setTransparency(const std::vector<float>&);
+    void setBinding(MeshCore::MeshIO::Binding);
+
+    const MeshCore::Material& getValue() const;
+    const std::vector<App::Color>& getAmbientColor() const;
+    const std::vector<App::Color>& getDiffuseColor() const;
+    const std::vector<App::Color>& getSpecularColor() const;
+    const std::vector<App::Color>& getEmissiveColor() const;
+    const std::vector<float>& getShininess() const;
+    const std::vector<float>& getTransparency() const;
+    MeshCore::MeshIO::Binding getBinding() const;
+
+    PyObject* getPyObject() override;
+    void setPyObject(PyObject*) override;
+
+    void Save (Base::Writer& writer) const override;
+    void Restore(Base::XMLReader& reader) override;
+
+    void SaveDocFile(Base::Writer& writer) const override;
+    void RestoreDocFile(Base::Reader& reader) override;
+
+    const char* getEditorName() const override;
+
+    Property* Copy() const override;
+    void Paste(const Property& from) override;
+
+    unsigned int getMemSize() const override;
+    bool isSame(const Property& other) const override;
+
+private:
+    MeshCore::Material _material;
+};
+
 /** The mesh kernel property class.
  * @author Werner Mayer
  */
 class MeshExport PropertyMeshKernel : public App::PropertyComplexGeoData
 {
-    TYPESYSTEM_HEADER();
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
     PropertyMeshKernel();
-    ~PropertyMeshKernel();
+    ~PropertyMeshKernel() override;
 
     /** @name Getter/setter */
     //@{
@@ -194,19 +242,19 @@ public:
     void swapMesh(MeshObject&);
     /** Swaps the mesh data structure. */
     void swapMesh(MeshCore::MeshKernel&);
-    /** Returns a the attached mesh object by reference. It cannot be modified 
+    /** Returns a the attached mesh object by reference. It cannot be modified
      * from outside.
      */
     const MeshObject &getValue() const;
     const MeshObject *getValuePtr() const;
-    virtual unsigned int getMemSize () const;
+    unsigned int getMemSize () const override;
     //@}
 
     /** @name Getting basic geometric entities */
     //@{
-    const Data::ComplexGeoData* getComplexData() const;
+    const Data::ComplexGeoData* getComplexData() const override;
     /** Returns the bounding box around the underlying mesh kernel */
-    Base::BoundBox3d getBoundingBox() const;
+    Base::BoundBox3d getBoundingBox() const override;
     //@}
 
     /** @name Modification */
@@ -214,39 +262,41 @@ public:
     MeshObject* startEditing();
     void finishEditing();
     /// Transform the real mesh data
-    void transformGeometry(const Base::Matrix4D &rclMat);
+    void transformGeometry(const Base::Matrix4D &rclMat) override;
     void setPointIndices( const std::vector<std::pair<PointIndex, Base::Vector3f> >& );
+    void setTransform(const Base::Matrix4D& rclTrf) override;
+    Base::Matrix4D getTransform() const override;
     //@}
 
     /** @name Python interface */
     //@{
-    /** Returns a Python wrapper for the referenced mesh object. It does NOT 
+    /** Returns a Python wrapper for the referenced mesh object. It does NOT
      * create a copy. However, the Python wrapper is marked as \a immutable so
      * that the mesh object cannot be modified from outside.
      */
-    PyObject* getPyObject();
-    /** This method copies the content, hence creates an new mesh object 
+    PyObject* getPyObject() override;
+    /** This method copies the content, hence creates an new mesh object
      * to copy the data. The passed argument can be an instance of the Python
      * wrapper for the mesh object or simply a list of triangles, i.e. a list
      * of lists of three floats.
      */
-    void setPyObject(PyObject *value);
+    void setPyObject(PyObject *value) override;
     //@}
 
-    const char* getEditorName() const {
+    const char* getEditorName() const override {
         return "MeshGui::PropertyMeshKernelItem";
     }
 
     /** @name Save/restore */
     //@{
-    void Save (Base::Writer &writer) const;
-    void Restore(Base::XMLReader &reader);
+    void Save (Base::Writer &writer) const override;
+    void Restore(Base::XMLReader &reader) override;
 
-    void SaveDocFile (Base::Writer &writer) const;
-    void RestoreDocFile(Base::Reader &reader);
+    void SaveDocFile (Base::Writer &writer) const override;
+    void RestoreDocFile(Base::Reader &reader) override;
 
-    App::Property *Copy() const;
-    void Paste(const App::Property &from);
+    App::Property *Copy() const override;
+    void Paste(const App::Property &from) override;
     //@}
 
 private:
