@@ -20,13 +20,11 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
 
 #include "MeshTexture.h"
 
+
 using namespace Mesh;
 
 MeshTexture::MeshTexture(const Mesh::MeshObject& mesh, const MeshCore::Material &material)
