@@ -20,205 +20,63 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # ifdef FC_OS_WIN32
-# include <windows.h>
+#  include <windows.h>
 # endif
+# include <map>
+
 # include <QApplication>
-# include <qaction.h>
-# include <qdir.h>
 # include <qfileinfo.h>
 # include <qinputdialog.h>
 # include <qmessagebox.h>
 # include <QPointer>
 # include <qstringlist.h>
-//# include <gts.h>
-# include <map>
 #endif
 
 #ifndef __InventorAll__
 # include <Gui/InventorAll.h>
 #endif
 
-#include <Mod/Mesh/App/Core/Smoothing.h>
-#include <Mod/Mesh/App/MeshFeature.h>
-#include <Mod/Mesh/App/FeatureMeshCurvature.h>
-
-#include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/Interpreter.h>
-#include <Base/Tools.h>
-#include <App/Document.h>
 #include <App/DocumentObjectGroup.h>
 #include <App/DocumentObject.h>
+#include <Base/Console.h>
+#include <Base/Tools.h>
 #include <Gui/Application.h>
 #include <Gui/BitmapFactory.h>
-#include <Gui/MainWindow.h>
 #include <Gui/Command.h>
 #include <Gui/Control.h>
 #include <Gui/Document.h>
 #include <Gui/FileDialog.h>
-#include <Gui/Selection.h>
+#include <Gui/MainWindow.h>
 #include <Gui/MouseSelection.h>
-#include <Gui/ViewProvider.h>
+#include <Gui/NavigationStyle.h>
+#include <Gui/Selection.h>
 #include <Gui/View3DInventor.h>
 #include <Gui/View3DInventorViewer.h>
-#include <Gui/NavigationStyle.h>
 #include <Gui/WaitCursor.h>
-#include <CXX/Objects.hxx>
 
+#include <Mod/Mesh/App/FeatureMeshCurvature.h>
+#include <Mod/Mesh/App/MeshFeature.h>
+#include <Mod/Mesh/App/Core/Smoothing.h>
+
+#include "DlgDecimating.h"
 #include "DlgEvaluateMeshImp.h"
 #include "DlgRegularSolidImp.h"
-#include "RemoveComponents.h"
-#include "RemeshGmsh.h"
 #include "DlgSmoothing.h"
-#include "DlgDecimating.h"
-#include "ViewProviderMeshFaceSet.h"
-#include "ViewProviderCurvature.h"
 #include "MeshEditor.h"
+#include "RemeshGmsh.h"
+#include "RemoveComponents.h"
 #include "Segmentation.h"
 #include "SegmentationBestFit.h"
+#include "ViewProviderCurvature.h"
+#include "ViewProviderMeshFaceSet.h"
+
 
 using namespace Mesh;
 
-// deprecated
-#if 0
-DEF_STD_CMD_A(CmdMeshTransform)
 
-CmdMeshTransform::CmdMeshTransform()
-  :Command("Mesh_Transform")
-{
-  sAppModule    = "Mesh";
-  sGroup        = QT_TR_NOOP("Mesh");
-  sMenuText     = QT_TR_NOOP("Transform mesh");
-  sToolTipText  = QT_TR_NOOP("Rotate or move a mesh");
-  sWhatsThis    = "Mesh_Transform";
-  sStatusTip    = QT_TR_NOOP("Rotate or move a mesh");
-  sPixmap       = "Std_Tool1";
-}
-
-void CmdMeshTransform::activated(int)
-{
-  unsigned int n = getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId());
-  if ( n!=1 )
-      return;
-
-  std::string fName = getUniqueObjectName("Move");
-  std::vector<Gui::SelectionSingleton::SelObj> cSel = getSelection().getSelection();
-
-  openCommand(QT_TRANSLATE_NOOP("Command", "Mesh Create"));
-  doCommand(Doc,"App.activeDocument().addObject(\"Mesh::Transform\",\"%s\")",fName.c_str());
-  doCommand(Doc,"App.activeDocument().%s.Source = App.activeDocument().%s",fName.c_str(),cSel[0].FeatName);
-  doCommand(Gui,"Gui.hide(\"%s\")",cSel[0].FeatName);
-  commitCommand(); 
- 
-  updateActive();
-}
-
-bool CmdMeshTransform::isActive(void)
-{
-  //return true;
-  return getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) == 1;
-}
-
-//--------------------------------------------------------------------------------------
-
-DEF_STD_CMD_A(CmdMeshDemolding)
-
-CmdMeshDemolding::CmdMeshDemolding()
-  :Command("Mesh_Demolding")
-{
-  sAppModule    = "Mesh";
-  sGroup        = QT_TR_NOOP("Mesh");
-  sMenuText     = QT_TR_NOOP("Interactive demolding direction");
-  sToolTipText  = sMenuText;
-  sWhatsThis    = "Mesh_Demolding";
-  sStatusTip    = sMenuText;
-  sPixmap       = "Std_Tool1";
-}
-
-void CmdMeshDemolding::activated(int)
-{
-  unsigned int n = getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId());
-  if ( n!=1 )
-      return;
-
-  std::string fName = getUniqueObjectName("Demolding");
-  std::vector<Gui::SelectionSingleton::SelObj> cSel = getSelection().getSelection();
-
-  openCommand(QT_TRANSLATE_NOOP("Command", "Mesh Create"));
-  doCommand(Doc,"App.activeDocument().addObject(\"Mesh::TransformDemolding\",\"%s\")",fName.c_str());
-  doCommand(Doc,"App.activeDocument().%s.Source = App.activeDocument().%s",fName.c_str(),cSel[0].FeatName);
-  doCommand(Gui,"Gui.hide(\"%s\")",cSel[0].FeatName);
-  commitCommand(); 
- 
-  updateActive();
-}
-
-bool CmdMeshDemolding::isActive(void)
-{
-  //return true;
-  return getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) == 1;
-}
-
-//--------------------------------------------------------------------------------------
-
-DEF_STD_CMD_A(CmdMeshToolMesh)
-
-CmdMeshToolMesh::CmdMeshToolMesh()
-  :Command("Mesh_ToolMesh")
-{
-  sAppModule    = "Mesh";
-  sGroup        = QT_TR_NOOP("Mesh");
-  sMenuText     = QT_TR_NOOP("Segment by tool mesh");
-  sToolTipText  = QT_TR_NOOP("Creates a segment from a given tool mesh");
-  sWhatsThis    = "Mesh_ToolMesh";
-  sStatusTip    = QT_TR_NOOP("Creates a segment from a given tool mesh");
-}
-
-void CmdMeshToolMesh::activated(int)
-{
-  std::vector<App::DocumentObject*> fea = Gui::Selection().getObjectsOfType(Mesh::Feature::getClassTypeId());
-  if ( fea.size() == 2 )
-  {
-    std::string fName = getUniqueObjectName("MeshSegment");
-    App::DocumentObject* mesh = fea.front();
-    App::DocumentObject* tool = fea.back();
-
-    openCommand(QT_TRANSLATE_NOOP("Command", "Segment by tool mesh"));
-    doCommand(Doc, "import Mesh");
-    doCommand(Gui, "import MeshGui");
-    doCommand(Doc,
-      "App.activeDocument().addObject(\"Mesh::SegmentByMesh\",\"%s\")\n"
-      "App.activeDocument().%s.Source = App.activeDocument().%s\n"
-      "App.activeDocument().%s.Tool = App.activeDocument().%s\n",
-      fName.c_str(), fName.c_str(),  mesh->getNameInDocument(), fName.c_str(), tool->getNameInDocument() );
-
-    commitCommand();
-    updateActive();
-
-    App::Document* pDoc = getDocument();
-    App::DocumentObject * pObj = pDoc->getObject( fName.c_str() );
-
-    if ( pObj )
-    {
-      doCommand(Gui,"Gui.hide(\"%s\")", mesh->getNameInDocument());
-      doCommand(Gui,"Gui.hide(\"%s\")", tool->getNameInDocument());
-      getSelection().clearSelection();
-    }
-  }
-}
-
-bool CmdMeshToolMesh::isActive(void)
-{
-  // Check for the selected mesh feature (all Mesh types)
-  return getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) == 2;
-}
-#endif
-
-//--------------------------------------------------------------------------------------
 
 DEF_STD_CMD_A(CmdMeshUnion)
 
@@ -787,60 +645,6 @@ bool CmdMeshPolySegm::isActive()
     return false;
 }
 
-//--------------------------------------------------------------------------------------
-#if 0
-DEF_STD_CMD_A(CmdMeshPolySelect)
-
-CmdMeshPolySelect::CmdMeshPolySelect()
-  : Command("Mesh_PolySelect")
-{
-    sAppModule    = "Mesh";
-    sGroup        = QT_TR_NOOP("Mesh");
-    sMenuText     = QT_TR_NOOP("Select mesh");
-    sToolTipText  = QT_TR_NOOP("Select an area of the mesh");
-    sWhatsThis    = "Mesh_PolySelect";
-    sStatusTip    = QT_TR_NOOP("Select an area of the mesh");
-}
-
-void CmdMeshPolySelect::activated(int)
-{
-    std::vector<App::DocumentObject*> docObj = Gui::Selection().getObjectsOfType(Mesh::Feature::getClassTypeId());
-    for (std::vector<App::DocumentObject*>::iterator it = docObj.begin(); it != docObj.end(); ++it) {
-        if (it == docObj.begin()) {
-            Gui::Document* doc = getActiveGuiDocument();
-            Gui::MDIView* view = doc->getActiveView();
-            if (view->getTypeId().isDerivedFrom(Gui::View3DInventor::getClassTypeId())) {
-                Gui::View3DInventorViewer* viewer = ((Gui::View3DInventor*)view)->getViewer();
-                viewer->setEditing(true);
-                viewer->startSelection(Gui::View3DInventorViewer::Rectangle);
-                viewer->addEventCallback(SoMouseButtonEvent::getClassTypeId(), MeshGui::ViewProviderMeshFaceSet::selectGLCallback);
-            }
-            else {
-                return;
-            }
-        }
-
-        Gui::ViewProvider* pVP = getActiveGuiDocument()->getViewProvider(*it);
-        pVP->startEditing();
-    }
-}
-
-bool CmdMeshPolySelect::isActive(void)
-{
-    // Check for the selected mesh feature (all Mesh types)
-    if (getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) == 0)
-        return false;
-
-    Gui::MDIView* view = Gui::getMainWindow()->activeWindow();
-    if (view && view->isDerivedFrom(Gui::View3DInventor::getClassTypeId())) {
-        Gui::View3DInventorViewer* viewer = static_cast<Gui::View3DInventor*>(view)->getViewer();
-        return !viewer->isEditing();
-    }
-
-    return false;
-}
-#endif
-//--------------------------------------------------------------------------------------
 
 DEF_STD_CMD_A(CmdMeshAddFacet)
 
@@ -1411,48 +1215,13 @@ CmdMeshSmoothing::CmdMeshSmoothing()
 
 void CmdMeshSmoothing::activated(int)
 {
-#if 0
-    MeshGui::SmoothingDialog dlg(Gui::getMainWindow());
-    if (dlg.exec() == QDialog::Accepted) {
-        Gui::WaitCursor wc;
-        openCommand(QT_TRANSLATE_NOOP("Command", "Mesh Smoothing"));
-        std::vector<App::DocumentObject*> meshes = getSelection().getObjectsOfType(Mesh::Feature::getClassTypeId());
-        for (std::vector<App::DocumentObject*>::const_iterator it = meshes.begin(); it != meshes.end(); ++it) {
-            Mesh::Feature* mesh = (Mesh::Feature*)*it;
-            Mesh::MeshObject* mm = mesh->Mesh.startEditing();
-            switch (dlg.method()) {
-                case MeshGui::DlgSmoothing::Taubin:
-                    {
-                        MeshCore::TaubinSmoothing s(mm->getKernel());
-                        s.SetLambda(dlg.lambdaStep());
-                        s.SetMicro(dlg.microStep());
-                        s.Smooth(dlg.iterations());
-                    }   break;
-                case MeshGui::DlgSmoothing::Laplace:
-                    {
-                        MeshCore::LaplaceSmoothing s(mm->getKernel());
-                        s.SetLambda(dlg.lambdaStep());
-                        s.Smooth(dlg.iterations());
-                    }   break;
-                default:
-                    break;
-            }
-            mesh->Mesh.finishEditing();
-        }
-        commitCommand();
-    }
-#else
     Gui::Control().showDialog(new MeshGui::TaskSmoothing());
-#endif
 }
 
 bool CmdMeshSmoothing::isActive()
 {
-#if 1
     if (Gui::Control().activeDialog())
         return false;
-#endif
-    // Check for the selected mesh feature (all Mesh types)
     return getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) > 0;
 }
 
@@ -1922,9 +1691,6 @@ bool CmdMeshScale::isActive()
 void CreateMeshCommands()
 {
     Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
-  //rcCmdMgr.addCommand(new CmdMeshDemolding());
-  //rcCmdMgr.addCommand(new CmdMeshToolMesh());
-  //rcCmdMgr.addCommand(new CmdMeshTransform());
     rcCmdMgr.addCommand(new CmdMeshImport());
     rcCmdMgr.addCommand(new CmdMeshExport());
     rcCmdMgr.addCommand(new CmdMeshVertexCurvature());
@@ -1933,7 +1699,6 @@ void CreateMeshCommands()
     rcCmdMgr.addCommand(new CmdMeshDifference());
     rcCmdMgr.addCommand(new CmdMeshIntersection());
     rcCmdMgr.addCommand(new CmdMeshPolySegm());
-  //rcCmdMgr.addCommand(new CmdMeshPolySelect());
     rcCmdMgr.addCommand(new CmdMeshAddFacet());
     rcCmdMgr.addCommand(new CmdMeshPolyCut());
     rcCmdMgr.addCommand(new CmdMeshPolySplit());
