@@ -20,16 +20,19 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef MESHGUI_SEGMENTATIONBESTFIT_H
 #define MESHGUI_SEGMENTATIONBESTFIT_H
 
-#include <QDialog>
 #include <list>
+#include <QDialog>
+
 #include <Gui/TaskView/TaskDialog.h>
 #include <Gui/TaskView/TaskView.h>
+
+#include <Mod/Mesh/MeshGlobal.h>
 #include "MeshSelection.h"
 
+
 class QDoubleSpinBox;
 
 // forward declarations
@@ -49,7 +52,7 @@ public:
     virtual std::vector<float> getParameter(Points) const = 0;
 };
 
-typedef std::list<std::pair<QString, float> > ParameterList;
+using ParameterList = std::list<std::pair<QString, float> >;
 class ParametersDialog : public QDialog
 {
     Q_OBJECT
@@ -58,15 +61,15 @@ public:
     ParametersDialog(std::vector<float>&, FitParameter*,
                      ParameterList, Mesh::Feature* mesh,
                      QWidget* parent=nullptr);
-    ~ParametersDialog();
-    void accept();
-    void reject();
+    ~ParametersDialog() override;
+    void accept() override;
+    void reject() override;
 
-private Q_SLOTS:
-    void on_region_clicked();
-    void on_single_clicked();
-    void on_clear_clicked();
-    void on_compute_clicked();
+private:
+    void onRegionClicked();
+    void onSingleClicked();
+    void onClearClicked();
+    void onComputeClicked();
 
 private:
     std::vector<float>& values;
@@ -82,17 +85,18 @@ class MeshGuiExport SegmentationBestFit : public QWidget
     Q_OBJECT
 
 public:
-    SegmentationBestFit(Mesh::Feature* mesh, QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
-    ~SegmentationBestFit();
+    explicit SegmentationBestFit(Mesh::Feature* mesh, QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
+    ~SegmentationBestFit() override;
     void accept();
 
 protected:
-    void changeEvent(QEvent *e);
+    void changeEvent(QEvent *e) override;
 
-private Q_SLOTS:
-    void on_planeParameters_clicked();
-    void on_cylinderParameters_clicked();
-    void on_sphereParameters_clicked();
+private:
+    void setupConnections();
+    void onPlaneParametersClicked();
+    void onCylinderParametersClicked();
+    void onSphereParametersClicked();
 
 private:
     std::vector<float> planeParameter;
@@ -109,13 +113,13 @@ private:
 class TaskSegmentationBestFit : public Gui::TaskView::TaskDialog
 {
 public:
-    TaskSegmentationBestFit(Mesh::Feature* mesh);
-    ~TaskSegmentationBestFit();
+    explicit TaskSegmentationBestFit(Mesh::Feature* mesh);
+    ~TaskSegmentationBestFit() override;
 
 public:
-    bool accept();
+    bool accept() override;
 
-    virtual QDialogButtonBox::StandardButtons getStandardButtons() const
+    QDialogButtonBox::StandardButtons getStandardButtons() const override
     { return QDialogButtonBox::Ok | QDialogButtonBox::Cancel; }
 
 private:
