@@ -20,21 +20,19 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
 # include <algorithm>
 # include <climits>
 # ifdef FC_OS_WIN32
-# include <windows.h>
+#  include <windows.h>
 # endif
 # ifdef FC_OS_MACOSX
-# include <OpenGL/gl.h>
-# include <OpenGL/glu.h>
+#  include <OpenGL/gl.h>
+#  include <OpenGL/glu.h>
 # else
-# include <GL/gl.h>
-# include <GL/glu.h>
+#  include <GL/gl.h>
+#  include <GL/glu.h>
 # endif
 # include <Inventor/SbLine.h>
 # include <Inventor/SoPickedPoint.h>
@@ -45,37 +43,35 @@
 # include <Inventor/actions/SoGLRenderAction.h>
 # include <Inventor/actions/SoPickAction.h>
 # include <Inventor/actions/SoSearchAction.h>
-# include <Inventor/actions/SoWriteAction.h>
 # include <Inventor/bundles/SoMaterialBundle.h>
 # include <Inventor/bundles/SoTextureCoordinateBundle.h>
 # include <Inventor/details/SoFaceDetail.h>
 # include <Inventor/details/SoLineDetail.h>
-# include <Inventor/errors/SoReadError.h>
 # include <Inventor/misc/SoState.h>
 #endif
 
-#include "SoFCMeshObject.h"
 #include <Base/Console.h>
 #include <Base/Exception.h>
 #include <Gui/SoFCInteractiveElement.h>
 #include <Gui/SoFCSelectionAction.h>
 #include <Mod/Mesh/App/Core/Algorithm.h>
-#include <Mod/Mesh/App/Core/MeshIO.h>
-#include <Mod/Mesh/App/Core/MeshKernel.h>
 #include <Mod/Mesh/App/Core/Elements.h>
 #include <Mod/Mesh/App/Core/Grid.h>
+#include <Mod/Mesh/App/Core/MeshKernel.h>
+
+#include "SoFCMeshObject.h"
+
 
 using namespace MeshGui;
 
-
 class SoOutputStreambuf : public std::streambuf
 {
 public:
-    SoOutputStreambuf(SoOutput* o) : out(o)
+    explicit SoOutputStreambuf(SoOutput* o) : out(o)
     {
     }
 protected:
-    int overflow(int c = EOF)
+    int overflow(int c = EOF) override
     {
         if (c != EOF) {
             char z = static_cast<char>(c);
@@ -83,7 +79,7 @@ protected:
         }
         return c;
     }
-    std::streamsize xsputn (const char* s, std::streamsize num)
+    std::streamsize xsputn (const char* s, std::streamsize num) override
     {
         out->write(s);
         return num;
@@ -96,7 +92,7 @@ private:
 class SoOutputStream : public std::ostream
 {
 public:
-    SoOutputStream(SoOutput* o) : std::ostream(nullptr), buf(o)
+    explicit SoOutputStream(SoOutput* o) : std::ostream(nullptr), buf(o)
     {
         this->rdbuf(&buf);
     }
@@ -107,14 +103,14 @@ private:
 class SoInputStreambuf : public std::streambuf
 {
 public:
-    SoInputStreambuf(SoInput* o) : inp(o)
+    explicit SoInputStreambuf(SoInput* o) : inp(o)
     {
         setg (buffer+pbSize,
               buffer+pbSize,
               buffer+pbSize);
     }
 protected:
-    int underflow()
+    int underflow() override
     {
         if (gptr() < egptr()) {
             return *gptr();
@@ -160,11 +156,11 @@ private:
 class SoInputStream : public std::istream
 {
 public:
-    SoInputStream(SoInput* o) : std::istream(nullptr), buf(o)
+    explicit SoInputStream(SoInput* o) : std::istream(nullptr), buf(o)
     {
         this->rdbuf(&buf);
     }
-    ~SoInputStream()
+    ~SoInputStream() override
     {
     }
 
@@ -563,11 +559,11 @@ void SoFCMeshObjectNode::getPrimitiveCount(SoGetPrimitiveCountAction * action)
 }
 
 // Helper functions: draw vertices
-inline void glVertex(const MeshCore::MeshPoint& _v)  
+inline void glVertex(const MeshCore::MeshPoint& _v)
 {
     float v[3];
     v[0]=_v.x; v[1]=_v.y;v[2]=_v.z;
-    glVertex3fv(v); 
+    glVertex3fv(v);
 }
 
 // Helper functions: draw normal
@@ -575,19 +571,19 @@ inline void glNormal(const Base::Vector3f& _n)
 {
     float n[3];
     n[0]=_n.x; n[1]=_n.y;n[2]=_n.z;
-    glNormal3fv(n); 
+    glNormal3fv(n);
 }
 
 // Helper functions: draw normal
 inline void glNormal(float* n)
 {
-    glNormal3fv(n); 
+    glNormal3fv(n);
 }
 
 // Helper function: convert Vec to SbVec3f
 inline SbVec3f sbvec3f(const Base::Vector3f& _v)
 {
-    return SbVec3f(_v.x, _v.y, _v.z); 
+    return SbVec3f(_v.x, _v.y, _v.z);
 }
 
 SO_NODE_SOURCE(SoFCMeshObjectShape)
@@ -644,12 +640,12 @@ void SoFCMeshObjectShape::GLRender(SoGLRenderAction *action)
 
         SbBool needNormals = !mb.isColorOnly()/* || tb.isFunction()*/;
         mb.sendFirst();  // make sure we have the correct material
-    
+
         SbBool ccw = true;
-        if (SoShapeHintsElement::getVertexOrdering(state) == SoShapeHintsElement::CLOCKWISE) 
+        if (SoShapeHintsElement::getVertexOrdering(state) == SoShapeHintsElement::CLOCKWISE)
             ccw = false;
 
-        if (mode == false || mesh->countFacets() <= this->renderTriangleLimit) {
+        if (!mode || mesh->countFacets() <= this->renderTriangleLimit) {
             if (mbind != OVERALL) {
                 drawFaces(mesh, &mb, mbind, needNormals, ccw);
             }
@@ -672,9 +668,6 @@ void SoFCMeshObjectShape::GLRender(SoGLRenderAction *action)
             drawPoints(mesh, needNormals, ccw);
 #endif
         }
-
-        // Disable caching for this node
-        //SoGLCacheContextElement::shouldAutoCache(state, SoGLCacheContextElement::DONT_AUTO_CACHE);
     }
 }
 
@@ -739,7 +732,7 @@ void SoFCMeshObjectShape::drawFaces(const Mesh::MeshObject * mesh, SoMaterialBun
                 n[0] = (v1.y-v0.y)*(v2.z-v0.z)-(v1.z-v0.z)*(v2.y-v0.y);
                 n[1] = (v1.z-v0.z)*(v2.x-v0.x)-(v1.x-v0.x)*(v2.z-v0.z);
                 n[2] = (v1.x-v0.x)*(v2.y-v0.y)-(v1.y-v0.y)*(v2.x-v0.x);
-    
+
                 if(perFace)
                 mb->send(it-rFacets.begin(), true);
                 glNormal(n);
@@ -841,7 +834,7 @@ void SoFCMeshObjectShape::drawPoints(const Mesh::MeshObject * mesh, SbBool needN
                     n[0] = -((v1.y-v0.y)*(v2.z-v0.z)-(v1.z-v0.z)*(v2.y-v0.y));
                     n[1] = -((v1.z-v0.z)*(v2.x-v0.x)-(v1.x-v0.x)*(v2.z-v0.z));
                     n[2] = -((v1.x-v0.x)*(v2.y-v0.y)-(v1.y-v0.y)*(v2.x-v0.x));
-      
+
                     // Calculate the center point p=(v0+v1+v2)/3
                     float p[3];
                     p[0] = (v0.x+v1.x+v2.x)/3.0f;
@@ -889,32 +882,6 @@ void SoFCMeshObjectShape::generateGLArrays(SoState * state)
     const MeshCore::MeshPointArray& cP = kernel.GetPoints();
     const MeshCore::MeshFacetArray& cF = kernel.GetFacets();
 
-#if 0
-    // Smooth shading
-    face_vertices.resize(cP.size() * 6);
-    face_indices.resize(3 * cF.size());
-
-    int indexed = 0;
-    for (MeshCore::MeshPointArray::const_iterator it = cP.begin(); it != cP.end(); ++it) {
-        face_vertices[indexed * 6 + 3] += it->x;
-        face_vertices[indexed * 6 + 4] += it->y;
-        face_vertices[indexed * 6 + 5] += it->z;
-        indexed++;
-    }
-
-    indexed = 0;
-    for (MeshCore::MeshFacetArray::const_iterator it = cF.begin(); it != cF.end(); ++it) {
-        Base::Vector3f n = kernel.GetFacet(*it).GetNormal();
-        for (int i=0; i<3; i++) {
-            int32_t idx = it->_aulPoints[i];
-            face_vertices[idx * 6 + 0] += n.x;
-            face_vertices[idx * 6 + 1] += n.y;
-            face_vertices[idx * 6 + 2] += n.z;
-
-            face_indices[indexed++] = idx;
-        }
-    }
-#else
     // Flat shading
     face_vertices.reserve(3 * cF.size() * 6); // duplicate each vertex
     face_indices.resize(3 * cF.size());
@@ -935,8 +902,6 @@ void SoFCMeshObjectShape::generateGLArrays(SoState * state)
             indexed++;
         }
     }
-#endif
-
     this->index_array.swap(face_indices);
     this->vertex_array.swap(face_vertices);
 }
@@ -1020,15 +985,11 @@ void SoFCMeshObjectShape::startSelection(SoAction * action, const Mesh::MeshObje
     glInitNames();
     glPushName(-1);
 
-    //double mp[16];
     GLint viewport[4];
     glGetIntegerv(GL_VIEWPORT,viewport);
     glMatrixMode(GL_PROJECTION);
-    //glGetDoublev(GL_PROJECTION_MATRIX ,mp);
     glPushMatrix();
     glLoadIdentity();
-    // See https://www.opengl.org/discussion_boards/showthread.php/184308-gluPickMatrix-Implementation?p=1259884&viewfull=1#post1259884
-    //gluPickMatrix(x, y, w, h, viewport);
     if (w > 0 && h > 0) {
         glTranslatef((viewport[2] - 2 * (x - viewport[0])) / w, (viewport[3] - 2 * (y - viewport[1])) / h, 0);
         glScalef(viewport[2] / w, viewport[3] / h, 1.0);
@@ -1091,13 +1052,6 @@ void SoFCMeshObjectShape::renderSelectionGeometry(const Mesh::MeshObject* mesh)
     }
 }
 
-// test bbox intersection
-//static SbBool
-//SoFCMeshObjectShape_ray_intersect(SoRayPickAction * action, const SbBox3f & box)
-//{
-//    if (box.isEmpty()) return false;
-//    return action->intersect(box, true);
-//}
 
 /**
  * Calculates picked point based on primitives generated by subclasses.
@@ -1105,15 +1059,6 @@ void SoFCMeshObjectShape::renderSelectionGeometry(const Mesh::MeshObject* mesh)
 void
 SoFCMeshObjectShape::rayPick(SoRayPickAction * action)
 {
-    //if (this->shouldRayPick(action)) {
-    //    this->computeObjectSpaceRay(action);
-
-    //    const SoBoundingBoxCache* bboxcache = getBoundingBoxCache();
-    //    if (!bboxcache || !bboxcache->isValid(action->getState()) ||
-    //        SoFCMeshObjectShape_ray_intersect(action, bboxcache->getProjectedBox())) {
-    //        this->generatePrimitives(action);
-    //    }
-    //}
     inherited::rayPick(action);
 }
 
@@ -1132,7 +1077,7 @@ void SoFCMeshObjectShape::generatePrimitives(SoAction* action)
     const MeshCore::MeshFacetArray & rFacets = mesh->getKernel().GetFacets();
     if (rPoints.size() < 3)
         return;
-    if (rFacets.size() < 1)
+    if (rFacets.empty())
         return;
 
     // get material binding
@@ -1146,7 +1091,7 @@ void SoFCMeshObjectShape::generatePrimitives(SoAction* action)
     vertex.setDetail(&pointDetail);
 
     beginShape(action, TRIANGLES, &faceDetail);
-    try 
+    try
     {
         for (MeshCore::MeshFacetArray::_TConstIterator it = rFacets.begin(); it != rFacets.end(); ++it)
         {
@@ -1298,12 +1243,12 @@ void SoFCMeshSegmentShape::GLRender(SoGLRenderAction *action)
 
         SbBool needNormals = !mb.isColorOnly()/* || tb.isFunction()*/;
         mb.sendFirst();  // make sure we have the correct material
-    
+
         SbBool ccw = true;
-        if (SoShapeHintsElement::getVertexOrdering(state) == SoShapeHintsElement::CLOCKWISE) 
+        if (SoShapeHintsElement::getVertexOrdering(state) == SoShapeHintsElement::CLOCKWISE)
             ccw = false;
 
-        if (mode == false || mesh->countFacets() <= this->renderTriangleLimit) {
+        if (!mode || mesh->countFacets() <= this->renderTriangleLimit) {
             if (mbind != OVERALL)
                 drawFaces(mesh, &mb, mbind, needNormals, ccw);
             else
@@ -1312,9 +1257,6 @@ void SoFCMeshSegmentShape::GLRender(SoGLRenderAction *action)
         else {
             drawPoints(mesh, needNormals, ccw);
         }
-
-        // Disable caching for this node
-        //SoGLCacheContextElement::shouldAutoCache(state, SoGLCacheContextElement::DONT_AUTO_CACHE);
     }
 }
 
@@ -1384,7 +1326,7 @@ void SoFCMeshSegmentShape::drawFaces(const Mesh::MeshObject * mesh, SoMaterialBu
                 n[0] = (v1.y-v0.y)*(v2.z-v0.z)-(v1.z-v0.z)*(v2.y-v0.y);
                 n[1] = (v1.z-v0.z)*(v2.x-v0.x)-(v1.x-v0.x)*(v2.z-v0.z);
                 n[2] = (v1.x-v0.x)*(v2.y-v0.y)-(v1.y-v0.y)*(v2.x-v0.x);
-    
+
                 if(perFace)
                 mb->send(*it, true);
                 glNormal(n);
@@ -1494,7 +1436,7 @@ void SoFCMeshSegmentShape::drawPoints(const Mesh::MeshObject * mesh, SbBool need
                     n[0] = -((v1.y-v0.y)*(v2.z-v0.z)-(v1.z-v0.z)*(v2.y-v0.y));
                     n[1] = -((v1.z-v0.z)*(v2.x-v0.x)-(v1.x-v0.x)*(v2.z-v0.z));
                     n[2] = -((v1.x-v0.x)*(v2.y-v0.y)-(v1.y-v0.y)*(v2.x-v0.x));
-      
+
                     // Calculate the center point p=(v0+v1+v2)/3
                     float p[3];
                     p[0] = (v0.x+v1.x+v2.x)/3.0f;
@@ -1544,7 +1486,7 @@ void SoFCMeshSegmentShape::generatePrimitives(SoAction* action)
     const MeshCore::MeshFacetArray & rFacets = mesh->getKernel().GetFacets();
     if (rPoints.size() < 3)
         return;
-    if (rFacets.size() < 1)
+    if (rFacets.empty())
         return;
     if (mesh->countSegments() <= this->index.getValue())
         return;
@@ -1562,7 +1504,7 @@ void SoFCMeshSegmentShape::generatePrimitives(SoAction* action)
     vertex.setDetail(&pointDetail);
 
     beginShape(action, TRIANGLES, &faceDetail);
-    try 
+    try
     {
         for (std::vector<Mesh::FacetIndex>::const_iterator it = rSegm.begin(); it != rSegm.end(); ++it)
         {
@@ -1643,7 +1585,7 @@ void SoFCMeshSegmentShape::computeBBox(SoAction *action, SbBox3f &box, SbVec3f &
                     cBox.Add(rPoint[face._aulPoints[1]]);
                     cBox.Add(rPoint[face._aulPoints[2]]);
             }
-            
+
             box.setBounds(SbVec3f(cBox.MinX,cBox.MinY,cBox.MinZ),
                           SbVec3f(cBox.MaxX,cBox.MaxY,cBox.MaxZ));
             Base::Vector3f mid = cBox.GetCenter();
@@ -1699,9 +1641,6 @@ void SoFCMeshObjectBoundary::GLRender(SoGLRenderAction *action)
         mb.sendFirst();  // make sure we have the correct material
 
         drawLines(mesh);
-
-        // Disable caching for this node
-        //SoGLCacheContextElement::shouldAutoCache(state, SoGLCacheContextElement::DONT_AUTO_CACHE);
     }
 }
 
@@ -1713,7 +1652,7 @@ void SoFCMeshObjectBoundary::drawLines(const Mesh::MeshObject * mesh) const
     const MeshCore::MeshPointArray & rPoints = mesh->getKernel().GetPoints();
     const MeshCore::MeshFacetArray & rFacets = mesh->getKernel().GetFacets();
 
-    // When rendering open edges use the given line width * 3 
+    // When rendering open edges use the given line width * 3
     GLfloat lineWidth;
     glGetFloatv(GL_LINE_WIDTH, &lineWidth);
     glLineWidth(3.0f*lineWidth);
@@ -1788,7 +1727,7 @@ void SoFCMeshObjectBoundary::computeBBox(SoAction *action, SbBox3f &box, SbVec3f
     if (!mesh)
         return;
     const MeshCore::MeshPointArray & rPoints = mesh->getKernel().GetPoints();
-    if (rPoints.size() > 0) {
+    if (!rPoints.empty()) {
         Base::BoundBox3f cBox;
         for (MeshCore::MeshPointArray::_TConstIterator it = rPoints.begin(); it != rPoints.end(); ++it)
             cBox.Add(*it);
