@@ -20,24 +20,22 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
-# include <qobject.h>
 # include <QGroupBox>
 # include <QLabel>
 #endif
 
-#include "Workbench.h"
 #include <Gui/Application.h>
 #include <Gui/Command.h>
 #include <Gui/MenuManager.h>
-#include <Gui/ToolBarManager.h>
 #include <Gui/Selection.h>
+#include <Gui/ToolBarManager.h>
 #include <Gui/TaskView/TaskView.h>
+#include <Mod/Mesh/App/MeshFeature.h>
+
+#include "Workbench.h"
 
-#include "../App/MeshFeature.h"
 
 using namespace MeshGui;
 
@@ -107,11 +105,11 @@ public:
         taskbox->groupLayout()->addWidget(box);
         Content.push_back(taskbox);
     }
-    bool shouldShow(void)
+    bool shouldShow(void) override
     {
         return true;
     }
-    void onSelectionChanged(const Gui::SelectionChanges&)
+    void onSelectionChanged(const Gui::SelectionChanges&) override
     {
         Base::BoundBox3d bbox;
         unsigned long countPoints=0, countFacets=0;
@@ -184,7 +182,7 @@ Gui::MenuItem* Workbench::setupMenuBar() const
     // analyze
     Gui::MenuItem* analyze = new Gui::MenuItem;
     analyze->setCommand("Analyze");
-    *analyze << "Mesh_Evaluation" << "Mesh_EvaluateFacet" << "Mesh_CurvatureInfo" << "Separator" 
+    *analyze << "Mesh_Evaluation" << "Mesh_EvaluateFacet" << "Mesh_CurvatureInfo" << "Separator"
              << "Mesh_EvaluateSolid" << "Mesh_BoundingBox";
 
     // boolean
@@ -245,17 +243,17 @@ Gui::MenuItem* Workbench::setupMenuBar() const
 Gui::ToolBarItem* Workbench::setupToolBars() const
 {
     Gui::ToolBarItem* root = StdWorkbench::setupToolBars();
-    
+
     Gui::ToolBarItem* mesh = new Gui::ToolBarItem(root);
     mesh->setCommand("Mesh tools");
-    *mesh << "Mesh_Import" 
-          << "Mesh_Export" 
+    *mesh << "Mesh_Import"
+          << "Mesh_Export"
           << "Mesh_FromPartShape"
           << "Mesh_BuildRegularSolid";
-		  
+
     Gui::ToolBarItem* modifying = new Gui::ToolBarItem(root);
     modifying->setCommand("Mesh modify");
-    *modifying << "Mesh_HarmonizeNormals" 
+    *modifying << "Mesh_HarmonizeNormals"
                << "Mesh_FlipNormals"
                << "Mesh_FillupHoles"
                << "Mesh_FillInteractiveHole"
@@ -265,13 +263,13 @@ Gui::ToolBarItem* Workbench::setupToolBars() const
                << "Mesh_RemeshGmsh"
                << "Mesh_Decimating"
                << "Mesh_Scale";
-			   
+
     Gui::ToolBarItem* boolean = new Gui::ToolBarItem(root);
     boolean->setCommand("Mesh boolean");
     *boolean << "Mesh_Union"
              << "Mesh_Intersection"
              << "Mesh_Difference";
-			 
+
     Gui::ToolBarItem* cutting = new Gui::ToolBarItem(root);
     cutting->setCommand("Mesh cutting");
     *cutting << "Mesh_PolyCut"
@@ -279,14 +277,14 @@ Gui::ToolBarItem* Workbench::setupToolBars() const
              << "Mesh_TrimByPlane"
              << "Mesh_SectionByPlane"
              << "Mesh_CrossSections";
-			 
+
     Gui::ToolBarItem* compseg = new Gui::ToolBarItem(root);
     compseg->setCommand("Mesh segmentation");
     *compseg << "Mesh_Merge"
              << "Mesh_SplitComponents"
              << "Mesh_Segmentation"
              << "Mesh_SegmentationBestFit";
-			 
+
     Gui::ToolBarItem* analyze = new Gui::ToolBarItem(root);
     analyze->setCommand("Mesh analyze");
     *analyze << "Mesh_Evaluation"
@@ -295,8 +293,8 @@ Gui::ToolBarItem* Workbench::setupToolBars() const
              << "Mesh_CurvatureInfo"
              << "Mesh_EvaluateSolid"
              << "Mesh_BoundingBox";
-		  
-		  
+
+
     return root;
 }
 
