@@ -20,33 +20,29 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <BRepBuilderAPI_MakePolygon.hxx>
 # include <TopoDS.hxx>
 #endif
 
-#include <CXX/Extensions.hxx>
-#include <CXX/Objects.hxx>
-
-#include <Base/PyObjectBase.h>
 #include <Base/Console.h>
-#include <Base/Vector3D.h>
 #include <Base/Converter.h>
-#include <Base/Interpreter.h>
-#include <Base/VectorPy.h>
 #include <Base/GeometryPyCXX.h>
-#include <Mod/Part/App/TopoShapePy.h>
+#include <Base/Interpreter.h>
+#include <Base/Vector3D.h>
+#include <Base/VectorPy.h>
 #include <Mod/Part/App/TopoShapeEdgePy.h>
+#include <Mod/Part/App/TopoShapePy.h>
 #include <Mod/Part/App/TopoShapeWirePy.h>
+#include <Mod/Mesh/App/MeshPy.h>
 #include <Mod/Mesh/App/Core/Algorithm.h>
 #include <Mod/Mesh/App/Core/MeshKernel.h>
-#include <Mod/Mesh/App/Mesh.h>
-#include <Mod/Mesh/App/MeshPy.h>
+
 #include "MeshAlgos.h"
 #include "Mesher.h"
 
+
 namespace MeshPart {
 class Module : public Py::ExtensionModule<Module>
 {
@@ -144,10 +140,10 @@ public:
         initialize("This module is the MeshPart module."); // register with Python
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
-    virtual Py::Object invoke_method_varargs(void *method_def, const Py::Tuple &args)
+    Py::Object invoke_method_varargs(void *method_def, const Py::Tuple &args) override
     {
         try {
             return Py::ExtensionModule<Module>::invoke_method_varargs(method_def, args);
@@ -221,7 +217,7 @@ private:
         }
 
         TopoDS_Shape aShape = pcObject->getTopoShapePtr()->getShape();
-        // use the MeshAlgos 
+        // use the MeshAlgos
         MeshPart::MeshAlgos::LoftOnCurve(M,aShape,poly,Base::Vector3f(x,y,z),size);
         return Py::asObject(new Mesh::MeshPy(new Mesh::MeshObject(M)));
     }
@@ -272,7 +268,7 @@ private:
             proj.projectToMesh(shape, maxDist, polylines);
 
             Py::List list;
-            for (auto it : polylines) {
+            for (const auto& it : polylines) {
                 Py::List poly;
                 for (auto jt : it.points) {
                     Py::Vector v(jt);
@@ -304,7 +300,7 @@ private:
             std::vector<MeshProjection::PolyLine> polylines;
             proj.projectParallelToMesh(shape, dir, polylines);
             Py::List list;
-            for (auto it : polylines) {
+            for (const auto& it : polylines) {
                 Py::List poly;
                 for (auto jt : it.points) {
                     Py::Vector v(jt);
@@ -354,7 +350,7 @@ private:
             proj.projectParallelToMesh(polylinesIn, dir, polylines);
 
             Py::List list;
-            for (auto it : polylines) {
+            for (const auto& it : polylines) {
                 Py::List poly;
                 for (auto jt : it.points) {
                     Py::Vector v(jt);
@@ -495,8 +491,8 @@ private:
             mesher.setDeflection(lindeflection);
             mesher.setAngularDeflection(angdeflection);
             mesher.setRegular(true);
-            mesher.setRelative(PyObject_IsTrue(relative) ? true : false);
-            mesher.setSegments(PyObject_IsTrue(segment) ? true : false);
+            mesher.setRelative(Base::asBoolean(relative));
+            mesher.setSegments(Base::asBoolean(segment));
             if (groupColors) {
                 Py::Sequence list(groupColors);
                 std::vector<uint32_t> colors;
