@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # ifdef FC_OS_LINUX
@@ -28,41 +27,36 @@
 # endif
 # include <Bnd_Box.hxx>
 # include <BndLib_Add3dCurve.hxx>
+# include <BRep_Tool.hxx>
 # include <BRepAdaptor_Curve.hxx>
 # include <BRepBuilderAPI_MakeVertex.hxx>
 # include <BRepExtrema_DistShapeShape.hxx>
 # include <GCPnts_AbscissaPoint.hxx>
 # include <GCPnts_UniformDeflection.hxx>
 # include <GCPnts_UniformAbscissa.hxx>
+# include <GeomAPI_IntCS.hxx>
+# include <Geom_Curve.hxx>
+# include <Geom_Plane.hxx>
 # include <gp_Pln.hxx>
+# include <Standard_Failure.hxx>
 # include <TopExp_Explorer.hxx>
 # include <TopoDS.hxx>
 # include <TopoDS_Edge.hxx>
-# include <Geom_Curve.hxx>
-# include <Geom_Plane.hxx>
-# include <BRep_Tool.hxx>
-# include <GeomAPI_IntCS.hxx>
-# include <Standard_Failure.hxx>
 #endif
 
-
-#include "MeshAlgos.h"
-#include "CurveProjector.h"
-
-#include <Mod/Mesh/App/Core/MeshIO.h>
-#include <Mod/Mesh/App/Core/MeshKernel.h>
-#include <Mod/Mesh/App/Core/Iterator.h>
-#include <Mod/Mesh/App/Core/Algorithm.h>
-#include <Mod/Mesh/App/Core/Projection.h>
-#include <Mod/Mesh/App/Core/Grid.h>
-#include <Mod/Mesh/App/Mesh.h>
-
-#include <Base/Exception.h>
 #include <Base/Console.h>
 #include <Base/FileInfo.h>
 #include <Base/Sequencer.h>
 #include <Base/Stream.h>
 
+#include <Mod/Mesh/App/Core/Algorithm.h>
+#include <Mod/Mesh/App/Core/Grid.h>
+#include <Mod/Mesh/App/Core/Iterator.h>
+#include <Mod/Mesh/App/Core/MeshKernel.h>
+#include <Mod/Mesh/App/Core/Projection.h>
+
+#include "MeshAlgos.h"
+
 
 using namespace MeshPart;
 using MeshCore::MeshKernel;
@@ -104,7 +98,7 @@ CurveProjectorShape::CurveProjectorShape(const TopoDS_Shape &aShape, const MeshK
   Do();
 }
 
-void CurveProjectorShape::Do(void)
+void CurveProjectorShape::Do()
 {
   TopExp_Explorer Ex;
   for (Ex.Init(_Shape, TopAbs_EDGE); Ex.More(); Ex.Next()) {
@@ -121,11 +115,11 @@ void CurveProjectorShape::projectCurve( const TopoDS_Edge& aEdge,
 {
   Standard_Real fFirst, fLast;
   Handle(Geom_Curve) hCurve = BRep_Tool::Curve( aEdge,fFirst,fLast );
-  
+
   // getting start point
   gp_Pnt gpPt = hCurve->Value(fFirst);
 
-  // projection of the first point 
+  // projection of the first point
   Base::Vector3f cStartPoint = Base::Vector3f((float)gpPt.X(),
                                               (float)gpPt.Y(),
                                               (float)gpPt.Z());
@@ -134,7 +128,7 @@ void CurveProjectorShape::projectCurve( const TopoDS_Edge& aEdge,
   MeshCore::FacetIndex uLastFacetIdx=MeshCore::FACET_INDEX_MAX-1; // use another value as FACET_INDEX_MAX
   MeshCore::FacetIndex auNeighboursIdx[3];
   bool GoOn;
-  
+
   if( !findStartPoint(_Mesh,cStartPoint,cResultPoint,uStartFacetIdx) )
     return;
 
@@ -146,11 +140,11 @@ void CurveProjectorShape::projectCurve( const TopoDS_Edge& aEdge,
 
     GoOn = false;
     int NbrOfHits = 0,HitIdx=0;
-    
+
     for(int i=0; i<3; i++)
     {
       // ignore last visited facet
-      if ( auNeighboursIdx[i] == uLastFacetIdx ) 
+      if ( auNeighboursIdx[i] == uLastFacetIdx )
         continue;
 
       // get points of the edge i
@@ -169,10 +163,10 @@ void CurveProjectorShape::projectCurve( const TopoDS_Edge& aEdge,
         cPlanePnt    = cP0;
       }
 
-      Handle(Geom_Plane) hPlane = new Geom_Plane(gp_Pln(gp_Pnt(cPlanePnt.x,cPlanePnt.y,cPlanePnt.z), 
+      Handle(Geom_Plane) hPlane = new Geom_Plane(gp_Pln(gp_Pnt(cPlanePnt.x,cPlanePnt.y,cPlanePnt.z),
                                                         gp_Dir(cPlaneNormal.x,cPlaneNormal.y,cPlaneNormal.z)));
- 
-      GeomAPI_IntCS Alg(hCurve,hPlane); 
+
+      GeomAPI_IntCS Alg(hCurve,hPlane);
 
       if ( Alg.IsDone() )
       {
@@ -267,7 +261,7 @@ CurveProjectorSimple::CurveProjectorSimple(const TopoDS_Shape &aShape, const Mes
 }
 
 
-void CurveProjectorSimple::Do(void)
+void CurveProjectorSimple::Do()
 {
   TopExp_Explorer Ex;
 
@@ -312,13 +306,13 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
   bool bFirst = true;
   //unsigned long auNeighboursIdx[3];
   //std::map<unsigned long,std::vector<Base::Vector3f> >::iterator N1,N2,N3;
-  
+
   Standard_Real fBegin, fEnd;
   Handle(Geom_Curve) hCurve = BRep_Tool::Curve(aEdge,fBegin,fEnd);
   float fLen   = float(fEnd - fBegin);
-  
+
   unsigned long ulNbOfPoints = 1000,PointCount=0;
-  
+
   MeshFacetIterator It(_Mesh);
 
   Base::SequencerLauncher seq("Building up projection map...", ulNbOfPoints+1);
@@ -328,7 +322,7 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
   str.setf(std::ios::fixed | std::ios::showpoint);
 
   std::map<MeshCore::FacetIndex,std::vector<Base::Vector3f> > FaceProjctMap;
- 
+
   for (unsigned long i = 0; i <= ulNbOfPoints; i++)
   {
     seq.next();
@@ -338,12 +332,12 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
     for(It.Init();It.More();It.Next())
     {
       // try to project (with angle) to the face
-      if (It->IntersectWithLine (Base::Vector3f((float)gpPt.X(),(float)gpPt.Y(),(float)gpPt.Z()), 
+      if (It->IntersectWithLine (Base::Vector3f((float)gpPt.X(),(float)gpPt.Y(),(float)gpPt.Z()),
           It->GetNormal(), TempResultPoint))
       {
         FaceProjctMap[It.Position()].push_back(TempResultPoint);
-        str << TempResultPoint.x << " " 
-            << TempResultPoint.y << " " 
+        str << TempResultPoint.x << " "
+            << TempResultPoint.y << " "
             << TempResultPoint.z << std::endl;
         Base::Console().Log("IDX %d\n",It.Position());
 
@@ -375,13 +369,13 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
 
 
     }
-  
+
     FaceProjctMap.erase(uCurFacetIdx);
 
     // estimate next facet
     MeshGeomFacet cCurFacet= MeshK.GetFacet(uCurFacetIdx);
     MeshK.GetFacetNeighbours ( uCurFacetIdx, auNeighboursIdx[0], auNeighboursIdx[1], auNeighboursIdx[2]);
-    
+
     uCurFacetIdx = MeshCore::FACET_INDEX_MAX;
     PointCount = 0;
 
@@ -413,11 +407,11 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
 
   Standard_Real fFirst, fLast, fAct;
   Handle(Geom_Curve) hCurve = BRep_Tool::Curve( aEdge,fFirst,fLast );
-  
+
   // getting start point
   gp_Pnt gpPt = hCurve->Value(fFirst);
   fAct = fFirst;
-  // projection of the first point 
+  // projection of the first point
   Base::Vector3f cStartPoint = Base::Vector3f(gpPt.X(),gpPt.Y(),gpPt.Z());
   Base::Vector3f cResultPoint, cSplitPoint, cPlanePnt, cPlaneNormal,TempResultPoint;
   MeshCore::FacetIndex uStartFacetIdx,uCurFacetIdx;
@@ -479,7 +473,7 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
 
         }
       }
-  
+
       Sentinel++;
 
     }while(HitCount!=1 && Sentinel < 20);
@@ -499,23 +493,23 @@ void CurveProjectorSimple::projectCurve( const TopoDS_Edge& aEdge,
 
   Standard_Real fFirst, fLast;
   Handle(Geom_Curve) hCurve = BRep_Tool::Curve( aEdge,fFirst,fLast );
-  
+
   // getting start point
   gp_Pnt gpPt = hCurve->Value(fFirst);
 
-  // projection of the first point 
+  // projection of the first point
   Base::Vector3f cStartPoint = Base::Vector3f(gpPt.X(),gpPt.Y(),gpPt.Z());
   Base::Vector3f cResultPoint, cSplitPoint, cPlanePnt, cPlaneNormal;
   MeshCore::FacetIndex uStartFacetIdx,uCurFacetIdx;
   MeshCore::FacetIndex uLastFacetIdx=MeshCore::FACET_INDEX_MAX-1; // use another value as FACET_INDEX_MAX
   MeshCore::FacetIndex auNeighboursIdx[3];
   bool GoOn;
-  
+
   if( !findStartPoint(MeshK,cStartPoint,cResultPoint,uStartFacetIdx) )
     return;
 
   FILE* file = fopen("projected.asc", "w");
-    
+
   // go through the whole Mesh
   MeshFacetIterator It1(MeshK);
   for(It1.Init();It1.More();It1.Next())
@@ -578,7 +572,7 @@ CurveProjectorWithToolMesh::CurveProjectorWithToolMesh(const TopoDS_Shape &aShap
 }
 
 
-void CurveProjectorWithToolMesh::Do(void)
+void CurveProjectorWithToolMesh::Do()
 {
   TopExp_Explorer Ex;
   std::vector<MeshGeomFacet> cVAry;
@@ -607,10 +601,10 @@ void CurveProjectorWithToolMesh::makeToolMesh( const TopoDS_Edge& aEdge,std::vec
 
   MeshFacetIterator It(_Mesh);
 
-  Base::SequencerLauncher seq("Building up tool mesh...", ulNbOfPoints+1);  
+  Base::SequencerLauncher seq("Building up tool mesh...", ulNbOfPoints+1);
 
   std::map<MeshCore::FacetIndex,std::vector<Base::Vector3f> > FaceProjctMap;
- 
+
   for (unsigned long i = 0; i < ulNbOfPoints; i++)
   {
     seq.next();
@@ -774,7 +768,7 @@ void MeshProjection::findSectionParameters(const TopoDS_Edge& edge, const Base::
     const MeshCore::MeshPointArray& points = _rcMesh.GetPoints();
 
     Base::Vector3f res;
-    for (auto it : facets) {
+    for (const auto& it : facets) {
         for (int i=0; i<3; i++) {
             Base::Vector3f pt1 = points[it._aulPoints[i]];
             Base::Vector3f pt2 = points[it._aulPoints[(i+1)%3]];
@@ -849,7 +843,7 @@ void MeshProjection::projectOnMesh(const std::vector<Base::Vector3f>& pointsIn,
 
     const MeshCore::MeshFacetArray& facets = _rcMesh.GetFacets();
     const MeshCore::MeshPointArray& points = _rcMesh.GetPoints();
-    for (auto it : facets) {
+    for (const auto& it : facets) {
         for (int i=0; i<3; i++) {
             if (!it.HasNeighbour(i)) {
                 boundaryPoints.push_back(points[it._aulPoints[i]]);
@@ -932,9 +926,9 @@ void MeshProjection::projectParallelToMesh (const TopoDS_Shape &aShape, const Ba
         std::vector<Base::Vector3f> points;
         discretize(aEdge, points, 5);
 
-        typedef std::pair<Base::Vector3f, MeshCore::FacetIndex> HitPoint;
+        using HitPoint = std::pair<Base::Vector3f, MeshCore::FacetIndex>;
         std::vector<HitPoint> hitPoints;
-        typedef std::pair<HitPoint, HitPoint> HitPoints;
+        using HitPoints = std::pair<HitPoint, HitPoint>;
         std::vector<HitPoints> hitPointPairs;
         for (auto it : points) {
             Base::Vector3f result;
@@ -974,12 +968,12 @@ void MeshProjection::projectParallelToMesh (const std::vector<PolyLine> &aEdges,
 
     Base::SequencerLauncher seq( "Project curve on mesh", aEdges.size() );
 
-    for (auto it : aEdges) {
+    for (const auto& it : aEdges) {
         std::vector<Base::Vector3f> points = it.points;
 
-        typedef std::pair<Base::Vector3f, MeshCore::FacetIndex> HitPoint;
+        using HitPoint = std::pair<Base::Vector3f, MeshCore::FacetIndex>;
         std::vector<HitPoint> hitPoints;
-        typedef std::pair<HitPoint, HitPoint> HitPoints;
+        using HitPoints = std::pair<HitPoint, HitPoint>;
         std::vector<HitPoints> hitPointPairs;
         for (auto it : points) {
             Base::Vector3f result;
