@@ -21,19 +21,22 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
-#include <algorithm>
-#include "Mesher.h"
+#ifndef _PreComp_
+# include <algorithm>
+
+# include <BRepMesh_IncrementalMesh.hxx>
+# include <BRepTools.hxx>
+# include <Standard_Version.hxx>
+# include <TopoDS_Shape.hxx>
+#endif
 
 #include <Base/Console.h>
-#include <Base/Exception.h>
 #include <Base/Tools.h>
 #include <Mod/Mesh/App/Mesh.h>
 #include <Mod/Part/App/TopoShape.h>
 
-#include <TopoDS_Shape.hxx>
-#include <BRepTools.hxx>
-#include <BRepMesh_IncrementalMesh.hxx>
-#include <Standard_Version.hxx>
+#include "Mesher.h"
+
 
 #ifdef HAVE_SMESH
 #if defined(__clang__)
@@ -84,7 +87,7 @@ using namespace MeshPart;
 SMESH_Gen* Mesher::_mesh_gen = nullptr;
 
 
-MeshingOutput::MeshingOutput() 
+MeshingOutput::MeshingOutput()
 {
     buffer.reserve(80);
 }
@@ -177,7 +180,7 @@ public:
 
         MeshCore::MeshFacetArray faces;
         std::size_t numTriangles = 0;
-        for (auto it : domains)
+        for (const auto& it : domains)
             numTriangles += it.facets.size();
         faces.reserve(numTriangles);
 
@@ -265,7 +268,7 @@ public:
 
         MeshCore::MeshPointArray verts;
         verts.resize(vertices.size());
-        for (auto it : vertices)
+        for (const auto& it : vertices)
             verts[it.i] = it.toPoint();
 
         MeshCore::MeshKernel kernel;
@@ -275,7 +278,7 @@ public:
         meshdata->swap(kernel);
         if (createSegm) {
             int index = 0;
-            for (auto it : colorMap) {
+            for (const auto& it : colorMap) {
                 Mesh::Segment segm(meshdata, false);
                 for (auto jt : it.second) {
                     segm.addIndices(meshSegments[jt]);
@@ -291,7 +294,7 @@ public:
             }
         }
         else {
-            for (auto it : meshSegments) {
+            for (const auto& it : meshSegments) {
                 meshdata->addSegment(it);
             }
         }
