@@ -24,9 +24,11 @@
 #define MESHPART_MESHER_H
 
 #include <sstream>
+
 #include <Base/Stream.h>
+
 #ifdef HAVE_SMESH
-#include <SMESH_Version.h>
+# include <SMESH_Version.h>
 #endif
 
 class TopoDS_Shape;
@@ -48,7 +50,7 @@ public:
         Standard = 3
     };
 
-    Mesher(const TopoDS_Shape&);
+    explicit Mesher(const TopoDS_Shape&);
     ~Mesher();
 
     void setMethod(Method m)
@@ -170,8 +172,8 @@ public:
     MeshingOutput();
 
 protected:
-    int overflow(int c = EOF);
-    int sync();
+    int overflow(int c = EOF) override;
+    int sync() override;
 
 private:
     std::string buffer;
