@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <QApplication>
@@ -28,22 +27,22 @@
 # include <QPushButton>
 #endif
 
-#include <Mod/Mesh/App/MeshFeature.h>
-
-#include <Base/Converter.h>
 #include <App/Application.h>
 #include <App/Document.h>
+#include <Base/Converter.h>
 #include <Gui/Application.h>
 #include <Gui/Command.h>
 #include <Gui/Control.h>
 #include <Gui/Document.h>
 #include <Gui/MainWindow.h>
-#include <Gui/FileDialog.h>
 #include <Gui/View3DInventor.h>
 #include <Gui/View3DInventorViewer.h>
-#include "Tessellation.h"
+#include <Mod/Mesh/App/MeshFeature.h>
+
 #include "CrossSections.h"
 #include "TaskCurveOnMesh.h"
+#include "Tessellation.h"
+
 
 using namespace std;
 
@@ -68,7 +67,7 @@ void CmdMeshPartMesher::activated(int)
     Gui::Control().showDialog(new MeshPartGui::TaskTessellation());
 }
 
-bool CmdMeshPartMesher::isActive(void)
+bool CmdMeshPartMesher::isActive()
 {
     return (hasActiveDocument() && !Gui::Control().activeDialog());
 }
@@ -105,6 +104,7 @@ void CmdMeshPartTrimByPlane::activated(int)
     QPushButton* inner = msgBox.addButton(qApp->translate("MeshPart_TrimByPlane","Below"), QMessageBox::ActionRole);
     QPushButton* outer = msgBox.addButton(qApp->translate("MeshPart_TrimByPlane","Above"), QMessageBox::ActionRole);
     QPushButton* split = msgBox.addButton(qApp->translate("MeshPart_TrimByPlane","Split"), QMessageBox::ActionRole);
+    msgBox.addButton(QMessageBox::Cancel);
     msgBox.setDefaultButton(inner);
     msgBox.exec();
     QAbstractButton* click = msgBox.clickedButton();
@@ -135,13 +135,6 @@ void CmdMeshPartTrimByPlane::activated(int)
 
         Mesh::MeshObject* mesh = static_cast<Mesh::Feature*>(*it)->Mesh.startEditing();
 
-        // Apply the inverted mesh placement to the plane because the trimming is done
-        // on the untransformed mesh data
-        Base::Placement meshPlacement = mesh->getPlacement();
-        meshPlacement.invert();
-        meshPlacement.multVec(base, base);
-        meshPlacement.getRotation().multVec(normal, normal);
-
         Base::Vector3f plnBase = Base::convertTo<Base::Vector3f>(base);
         Base::Vector3f plnNormal = Base::convertTo<Base::Vector3f>(normal);
 
@@ -171,7 +164,7 @@ void CmdMeshPartTrimByPlane::activated(int)
     commitCommand();
 }
 
-bool CmdMeshPartTrimByPlane::isActive(void)
+bool CmdMeshPartTrimByPlane::isActive()
 {
     // Check for the selected mesh feature (all Mesh types)
     if (getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) != 1)
@@ -229,8 +222,8 @@ void CmdMeshPartSection::activated(int)
         std::vector<Mesh::MeshObject::TPolylines> polylines;
         mesh->crossSections(sections, polylines);
 
-        for (auto it2 : polylines) {
-            for (auto it3 : it2) {
+        for (const auto& it2 : polylines) {
+            for (const auto& it3 : it2) {
                 Py::Tuple arg(1);
                 Py::List list;
                 for (auto it4 : it3) {
@@ -255,7 +248,7 @@ void CmdMeshPartSection::activated(int)
     commitCommand();
 }
 
-bool CmdMeshPartSection::isActive(void)
+bool CmdMeshPartSection::isActive()
 {
     // Check for the selected mesh feature (all Mesh types)
     if (getSelection().countObjectsOfType(Mesh::Feature::getClassTypeId()) != 1)
@@ -297,7 +290,7 @@ void CmdMeshPartCrossSections::activated(int iMsg)
     Gui::Control().showDialog(dlg);
 }
 
-bool CmdMeshPartCrossSections::isActive(void)
+bool CmdMeshPartCrossSections::isActive()
 {
     return (Gui::Selection().countObjectsOfType(Mesh::Feature::getClassTypeId()) > 0 &&
             !Gui::Control().activeDialog());
@@ -329,7 +322,7 @@ void CmdMeshPartCurveOnMesh::activated(int)
     Gui::Control().showDialog(new MeshPartGui::TaskCurveOnMesh(static_cast<Gui::View3DInventor*>(mdis.front())));
 }
 
-bool CmdMeshPartCurveOnMesh::isActive(void)
+bool CmdMeshPartCurveOnMesh::isActive()
 {
     if (Gui::Control().activeDialog())
         return false;
@@ -343,7 +336,7 @@ bool CmdMeshPartCurveOnMesh::isActive(void)
 }
 
 
-void CreateMeshPartCommands(void)
+void CreateMeshPartCommands()
 {
     Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
     rcCmdMgr.addCommand(new CmdMeshPartMesher());
