@@ -4,17 +4,17 @@
 <context>
     <name>CmdMeshPartCrossSections</name>
     <message>
-        <location filename="../../Command.cpp" line="276"/>
+        <location filename="../../Command.cpp" line="269"/>
         <source>MeshPart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="277"/>
+        <location filename="../../Command.cpp" line="270"/>
         <source>Cross-sections...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="278"/>
+        <location filename="../../Command.cpp" line="271"/>
         <source>Cross-sections</source>
         <translation type="unfinished"></translation>
     </message>
@@ -22,17 +22,17 @@
 <context>
     <name>CmdMeshPartCurveOnMesh</name>
     <message>
-        <location filename="../../Command.cpp" line="312"/>
+        <location filename="../../Command.cpp" line="305"/>
         <source>Mesh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="313"/>
+        <location filename="../../Command.cpp" line="306"/>
         <source>Curve on mesh...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="314"/>
+        <location filename="../../Command.cpp" line="307"/>
         <source>Creates an approximated curve on top of a mesh.
 This command only works with a &apos;mesh&apos; object.</source>
         <translation type="unfinished"></translation>
@@ -41,17 +41,17 @@ This command only works with a &apos;mesh&apos; object.</source>
 <context>
     <name>CmdMeshPartMesher</name>
     <message>
-        <location filename="../../Command.cpp" line="59"/>
+        <location filename="../../Command.cpp" line="58"/>
         <source>Mesh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="60"/>
+        <location filename="../../Command.cpp" line="59"/>
         <source>Create mesh from shape...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="61"/>
+        <location filename="../../Command.cpp" line="60"/>
         <source>Tessellate shape</source>
         <translation type="unfinished"></translation>
     </message>
@@ -59,17 +59,17 @@ This command only works with a &apos;mesh&apos; object.</source>
 <context>
     <name>CmdMeshPartSection</name>
     <message>
-        <location filename="../../Command.cpp" line="192"/>
+        <location filename="../../Command.cpp" line="185"/>
         <source>Mesh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="193"/>
+        <location filename="../../Command.cpp" line="186"/>
         <source>Create section from mesh and plane</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="194"/>
+        <location filename="../../Command.cpp" line="187"/>
         <source>Section</source>
         <translation type="unfinished"></translation>
     </message>
@@ -77,18 +77,18 @@ This command only works with a &apos;mesh&apos; object.</source>
 <context>
     <name>CmdMeshPartTrimByPlane</name>
     <message>
-        <location filename="../../Command.cpp" line="84"/>
+        <location filename="../../Command.cpp" line="83"/>
         <source>Mesh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="85"/>
+        <location filename="../../Command.cpp" line="84"/>
         <source>Trim mesh with a plane</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../../Command.cpp" line="85"/>
         <location filename="../../Command.cpp" line="86"/>
-        <location filename="../../Command.cpp" line="87"/>
         <source>Trims a mesh with a plane</source>
         <translation type="unfinished"></translation>
     </message>
@@ -101,7 +101,7 @@ This command only works with a &apos;mesh&apos; object.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="215"/>
+        <location filename="../../Command.cpp" line="208"/>
         <source>Section with plane</source>
         <translation type="unfinished"></translation>
     </message>
@@ -169,7 +169,7 @@ This command only works with a &apos;mesh&apos; object.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../CrossSections.cpp" line="345"/>
+        <location filename="../../CrossSections.cpp" line="366"/>
         <source>Failure</source>
         <translation type="unfinished"></translation>
     </message>
@@ -257,7 +257,7 @@ This command only works with a &apos;mesh&apos; object, not a regular face or su
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../TaskCurveOnMesh.ui" line="129"/>
+        <location filename="../../TaskCurveOnMesh.ui" line="136"/>
         <source>Maximum curve degree</source>
         <translation type="unfinished"></translation>
     </message>
@@ -285,13 +285,8 @@ This command only works with a &apos;mesh&apos; object, not a regular face or su
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Tessellation.ui" line="145"/>
-        <source>Mefisto</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../Tessellation.ui" line="206"/>
-        <source>Netgen</source>
+        <location filename="../../Tessellation.ui" line="33"/>
+        <source>Use the standard mesher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -299,11 +294,6 @@ This command only works with a &apos;mesh&apos; object, not a regular face or su
         <source>Surface deviation:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../Tessellation.ui" line="33"/>
-        <source>Use the standard mesher</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../Tessellation.ui" line="48"/>
         <source>Maximal linear deflection of a mesh section from the surface of the object</source>
@@ -352,6 +342,11 @@ this feature (e.g. the format OBJ).</source>
         <source>Define segments by face colors</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../Tessellation.ui" line="145"/>
+        <source>Mefisto</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../Tessellation.ui" line="148"/>
         <source>Use the Mefisto mesher</source>
@@ -373,6 +368,11 @@ The smallest value is 0.</source>
         <source>Estimate</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../Tessellation.ui" line="206"/>
+        <source>Netgen</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../Tessellation.ui" line="209"/>
         <source>Use the Netgen mesher</source>
@@ -477,18 +477,30 @@ A value in the range of 0.2-10.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Tessellation.cpp" line="62"/>
-        <source>gmsh</source>
+        <location filename="../../Tessellation.cpp" line="61"/>
+        <source>Gmsh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Tessellation.cpp" line="226"/>
-        <location filename="../../Tessellation.cpp" line="232"/>
+        <location filename="../../Tessellation.cpp" line="225"/>
+        <location filename="../../Tessellation.cpp" line="231"/>
         <source>No active document</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Tessellation.cpp" line="247"/>
+        <location filename="../../Tessellation.cpp" line="259"/>
+        <source>You have selected a body without tip.
+Either set the tip of the body or select a different shape, please.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../Tessellation.cpp" line="263"/>
+        <source>You have selected a shape without faces.
+Select a different shape, please.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../Tessellation.cpp" line="267"/>
         <source>Select a shape for meshing, first.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -496,12 +508,12 @@ A value in the range of 0.2-10.</source>
 <context>
     <name>MeshPart_Section</name>
     <message>
-        <location filename="../../Command.cpp" line="205"/>
+        <location filename="../../Command.cpp" line="198"/>
         <source>Select plane</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="206"/>
+        <location filename="../../Command.cpp" line="199"/>
         <source>Please select a plane at which you section the mesh.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -509,37 +521,37 @@ A value in the range of 0.2-10.</source>
 <context>
     <name>MeshPart_TrimByPlane</name>
     <message>
-        <location filename="../../Command.cpp" line="96"/>
+        <location filename="../../Command.cpp" line="95"/>
         <source>Select plane</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="97"/>
+        <location filename="../../Command.cpp" line="96"/>
         <source>Please select a plane at which you trim the mesh.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="103"/>
+        <location filename="../../Command.cpp" line="102"/>
         <source>Trim by plane</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="104"/>
+        <location filename="../../Command.cpp" line="103"/>
         <source>Select the side you want to keep.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="105"/>
+        <location filename="../../Command.cpp" line="104"/>
         <source>Below</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="106"/>
+        <location filename="../../Command.cpp" line="105"/>
         <source>Above</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../Command.cpp" line="107"/>
+        <location filename="../../Command.cpp" line="106"/>
         <source>Split</source>
         <translation type="unfinished"></translation>
     </message>
@@ -552,4 +564,30 @@ A value in the range of 0.2-10.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>MeshPart_CreateFlatMesh</name>
+    <message>
+        <location filename="../../MeshFlatteningCommand.py" line="47"/>
+        <source>Unwrap Mesh</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../MeshFlatteningCommand.py" line="50"/>
+        <source>Find a flat representation of a mesh.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>MeshPart_CreateFlatFace</name>
+    <message>
+        <location filename="../../MeshFlatteningCommand.py" line="79"/>
+        <source>Unwrap Face</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../MeshFlatteningCommand.py" line="82"/>
+        <source>Find a flat representation of a face.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
