@@ -20,15 +20,11 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <TopExp_Explorer.hxx>
 # include <QMessageBox>
 #endif
 
-#include "Tessellation.h"
-#include "ui_Tessellation.h"
 #include <Base/Console.h>
 #include <Base/Exception.h>
 #include <Base/Stream.h>
@@ -36,19 +32,21 @@
 #include <App/Application.h>
 #include <App/Document.h>
 #include <Gui/Application.h>
+#include <Gui/BitmapFactory.h>
 #include <Gui/Command.h>
 #include <Gui/Control.h>
 #include <Gui/Document.h>
-#include <Gui/BitmapFactory.h>
 #include <Gui/Selection.h>
-#include <Gui/ViewProvider.h>
 #include <Gui/WaitCursor.h>
-#include <Mod/Mesh/App/Mesh.h>
 #include <Mod/Mesh/App/MeshFeature.h>
 #include <Mod/Part/App/BodyBase.h>
 #include <Mod/Mesh/Gui/ViewProvider.h>
 #include <Mod/Part/Gui/ViewProvider.h>
 
+#include "Tessellation.h"
+#include "ui_Tessellation.h"
+
+
 using namespace MeshPartGui;
 
 /* TRANSLATOR MeshPartGui::Tessellation */
@@ -58,7 +56,7 @@ Tessellation::Tessellation(QWidget* parent)
 {
     ui->setupUi(this);
     gmsh = new Mesh2ShapeGmsh(this);
-    connect(gmsh, SIGNAL(processed()), this, SLOT(gmshProcessed()));
+    setupConnections();
 
     ui->stackedWidget->addTab(gmsh, tr("Gmsh"));
 
@@ -79,7 +77,7 @@ Tessellation::Tessellation(QWidget* parent)
     ui->spinMaximumEdgeLength->setRange(0, INT_MAX);
 
     ui->comboFineness->setCurrentIndex(2);
-    on_comboFineness_currentIndexChanged(2);
+    onComboFinenessCurrentIndexChanged(2);
 
 #if !defined (HAVE_MEFISTO)
     ui->stackedWidget->setTabEnabled(Mefisto, false);
@@ -102,12 +100,25 @@ Tessellation::~Tessellation()
 {
 }
 
+void Tessellation::setupConnections()
+{
+    connect(gmsh, &Mesh2ShapeGmsh::processed, this, &Tessellation::gmshProcessed);
+    connect(ui->estimateMaximumEdgeLength, &QPushButton::clicked,
+            this, &Tessellation::onEstimateMaximumEdgeLengthClicked);
+    connect(ui->comboFineness, qOverload<int>(&QComboBox::currentIndexChanged),
+            this, &Tessellation::onComboFinenessCurrentIndexChanged);
+    connect(ui->checkSecondOrder, &QCheckBox::toggled,
+            this, &Tessellation::onCheckSecondOrderToggled);
+    connect(ui->checkQuadDominated, &QCheckBox::toggled,
+            this, &Tessellation::onCheckQuadDominatedToggled);
+}
+
 void Tessellation::meshingMethod(int id)
 {
     ui->stackedWidget->setCurrentIndex(id);
 }
 
-void Tessellation::on_comboFineness_currentIndexChanged(int index)
+void Tessellation::onComboFinenessCurrentIndexChanged(int index)
 {
     if (index == 5) {
         ui->doubleGrading->setEnabled(true);
@@ -121,27 +132,27 @@ void Tessellation::on_comboFineness_currentIndexChanged(int index)
     }
 
     switch (index) {
-    case 0: // Very coarse
+    case VeryCoarse:
         ui->doubleGrading->setValue(0.7);
         ui->spinEdgeElements->setValue(0.3);
         ui->spinCurvatureElements->setValue(1.0);
         break;
-    case 1: // Coarse
+    case Coarse:
         ui->doubleGrading->setValue(0.5);
         ui->spinEdgeElements->setValue(0.5);
         ui->spinCurvatureElements->setValue(1.5);
         break;
-    case 2: // Moderate
+    case Moderate:
         ui->doubleGrading->setValue(0.3);
         ui->spinEdgeElements->setValue(1.0);
         ui->spinCurvatureElements->setValue(2.0);
         break;
-    case 3: // Fine
+    case Fine:
         ui->doubleGrading->setValue(0.2);
         ui->spinEdgeElements->setValue(2.0);
         ui->spinCurvatureElements->setValue(3.0);
         break;
-    case 4: // Very fine
+    case VeryFine:
         ui->doubleGrading->setValue(0.1);
         ui->spinEdgeElements->setValue(3.0);
         ui->spinCurvatureElements->setValue(5.0);
@@ -151,13 +162,13 @@ void Tessellation::on_comboFineness_currentIndexChanged(int index)
     }
 }
 
-void Tessellation::on_checkSecondOrder_toggled(bool on)
+void Tessellation::onCheckSecondOrderToggled(bool on)
 {
     if (on)
         ui->checkQuadDominated->setChecked(false);
 }
 
-void Tessellation::on_checkQuadDominated_toggled(bool on)
+void Tessellation::onCheckQuadDominatedToggled(bool on)
 {
     if (on)
         ui->checkSecondOrder->setChecked(false);
@@ -180,7 +191,7 @@ void Tessellation::changeEvent(QEvent *e)
     QWidget::changeEvent(e);
 }
 
-void Tessellation::on_estimateMaximumEdgeLength_clicked()
+void Tessellation::onEstimateMaximumEdgeLengthClicked()
 {
     App::Document* activeDoc = App::GetApplication().getActiveDocument();
     if (!activeDoc) {
@@ -307,11 +318,11 @@ void Tessellation::process(int method, App::Document* doc, const std::list<App::
                 "__mesh__.Mesh=MeshPart.meshFromShape(%4)\n"
                 "__mesh__.Label=\"%5 (Meshed)\"\n"
                 "del __doc__, __mesh__, __part__, __shape__\n")
-                .arg(this->document)
-                .arg(objname)
-                .arg(subname)
-                .arg(param)
-                .arg(label);
+                .arg(this->document,
+                     objname,
+                     subname,
+                     param,
+                     label);
 
             Gui::Command::runCommand(Gui::Command::Doc, cmd.toUtf8());
 
@@ -370,7 +381,7 @@ std::vector<App::Color> Tessellation::getUniqueColors(const std::vector<App::Col
 
     std::vector<App::Color> unique;
     for (const auto& it : col_set)
-        unique.push_back(App::Color(it));
+        unique.emplace_back(it);
     return unique;
 }
 
