@@ -21,7 +21,7 @@
 
 __title__ = "FreeCAD OpenSCAD Workbench - Parametric Features"
 __author__ = "Sebastian Hoogen"
-__url__ = ["https://www.freecadweb.org"]
+__url__ = ["https://www.freecad.org"]
 
 try:
     long
@@ -57,11 +57,11 @@ class ViewProviderTree:
     def onChanged(self, vp, prop):
         return
 
-    def __getstate__(self):
+    def dumps(self):
 #        return {'ObjectName' : self.Object.Name}
         return None
 
-    def __setstate__(self,state):
+    def loads(self,state):
         if state is not None:
             import FreeCAD
             doc = FreeCAD.ActiveDocument #crap
@@ -197,7 +197,7 @@ class Resize:
 
     def onChanged(self, fp, prop):
         if prop in ['Object','Vector']:
-           self.createGeometry(fp)
+            self.createGeometry(fp)
 
     def execute(self, fp):
         self.createGeometry(fp)
@@ -210,10 +210,10 @@ class Resize:
         mat.A33 = self.Vector[2]
         fp.Shape = self.Target.Shape.transformGeometry(mat)
 
-    def __getstate__(self):
+    def dumps(self):
         return None
 
-    def __setstate__(self,state):
+    def loads(self,state):
         return None
 
 
@@ -364,7 +364,8 @@ class Frustum:
     def createGeometry(self,fp):
         if all((fp.Radius1,fp.Radius2,fp.FacesNumber,fp.Height)):
             import math
-            import FreeCAD,Part
+            import FreeCAD
+            import Part
             #from draftlibs import fcgeo
             plm = fp.Placement
             wires = []
@@ -413,7 +414,10 @@ class Twist:
             self.createGeometry(fp)
 
     def createGeometry(self, fp):
-        import FreeCAD,Part,math,sys
+        import FreeCAD
+        import Part
+        import math
+        import sys
         if fp.Base and fp.Height and fp.Base.Shape.isValid():
             solids = []
             for lower_face in fp.Base.Shape.Faces:
@@ -426,7 +430,7 @@ class Twist:
 
                 spine = Part.makePolygon([(0,0,0),(0,0,fp.Height.Value)])
                 if fp.Angle.Value == 0.0:
-                    auxiliary_spine = Part.makePolygon([(1,1,0),(fp.Scale[0],fp.Scale[1],fp.Height.Value)])
+                    auxiliary_spine = None
                 else:
                     num_revolutions = abs(fp.Angle.Value)/360.0
                     pitch = fp.Height.Value / num_revolutions
@@ -445,7 +449,8 @@ class Twist:
                     pipe_shell.setSpineSupport(spine)
                     pipe_shell.add(wire1)
                     pipe_shell.add(wire2)
-                    pipe_shell.setAuxiliarySpine(auxiliary_spine,True,0)
+                    if auxiliary_spine:
+                        pipe_shell.setAuxiliarySpine(auxiliary_spine,True,0)
                     assert(pipe_shell.isReady())
                     pipe_shell.build()
                     faces.extend(pipe_shell.shape().Faces)
@@ -482,7 +487,10 @@ class PrismaticToroid:
             self.createGeometry(fp)
 
     def createGeometry(self,fp):
-        import FreeCAD,Part,math,sys
+        import FreeCAD
+        import Part
+        import math
+        import sys
         if fp.Base and fp.Angle and fp.Segments and fp.Base.Shape.isValid():
             solids = []
             min_sweep_angle_per_segment = 360.0 / fp.Segments # This is how OpenSCAD defines $fn
@@ -579,7 +587,8 @@ class CGALFeature:
     def execute(self,fp):
         #arguments are ignored
         maxmeshpoints = None #TBD: add as property
-        import Part, OpenSCAD.OpenSCADUtils
+        import Part
+        import OpenSCAD.OpenSCADUtils
         shape = OpenSCAD.OpenSCADUtils.process_ObjectsViaOpenSCADShape(fp.Document,fp.Children,\
                 fp.Operation, maxmeshpoints=maxmeshpoints)
         if shape:
