@@ -106,7 +106,17 @@
     </message>
     <message>
         <location filename="../ui/openscadprefs-base.ui" line="266"/>
-        <source>maximum fragment size</source>
+        <source>Maximum fragment size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/openscadprefs-base.ui" line="289"/>
+        <source>angle (fa)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/openscadprefs-base.ui" line="385"/>
+        <source>Convexity</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -115,16 +125,6 @@
         <source>Minimum angle for a fragment</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../ui/openscadprefs-base.ui" line="289"/>
-        <source>angular (fa)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ui/openscadprefs-base.ui" line="299"/>
-        <source>°</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../ui/openscadprefs-base.ui" line="328"/>
         <location filename="../ui/openscadprefs-base.ui" line="353"/>
@@ -141,11 +141,6 @@
         <source>mm</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../ui/openscadprefs-base.ui" line="385"/>
-        <source>convexity</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../ui/openscadprefs-base.ui" line="422"/>
         <source>Mesh fallback</source>
@@ -187,119 +182,152 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="101"/>
+        <location filename="../../OpenSCADCommands.py" line="92"/>
         <source>Unable to explode %s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="148"/>
+        <location filename="../../OpenSCADCommands.py" line="139"/>
         <source>Convert Edges to Faces</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="308"/>
+        <location filename="../../OpenSCADCommands.py" line="301"/>
         <source>Please select 3 objects first</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="340"/>
-        <location filename="../../OpenSCADCommands.py" line="363"/>
+        <location filename="../../OpenSCADCommands.py" line="334"/>
+        <location filename="../../OpenSCADCommands.py" line="365"/>
         <source>Add</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="341"/>
-        <location filename="../../OpenSCADCommands.py" line="367"/>
+        <location filename="../../OpenSCADCommands.py" line="369"/>
         <source>Clear</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="342"/>
-        <location filename="../../OpenSCADCommands.py" line="364"/>
+        <location filename="../../OpenSCADCommands.py" line="366"/>
         <source>Load</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="343"/>
-        <location filename="../../OpenSCADCommands.py" line="365"/>
+        <location filename="../../OpenSCADCommands.py" line="367"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="344"/>
-        <location filename="../../OpenSCADCommands.py" line="366"/>
+        <location filename="../../OpenSCADCommands.py" line="335"/>
+        <location filename="../../OpenSCADCommands.py" line="368"/>
         <source>Refresh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="345"/>
-        <location filename="../../OpenSCADCommands.py" line="368"/>
+        <location filename="../../OpenSCADCommands.py" line="336"/>
+        <source>Clear code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="337"/>
+        <source>Open...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="338"/>
+        <source>Save...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="339"/>
+        <location filename="../../OpenSCADCommands.py" line="370"/>
         <source>as Mesh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="358"/>
-        <location filename="../../OpenSCADCommands.py" line="369"/>
+        <location filename="../../OpenSCADCommands.py" line="352"/>
+        <location filename="../../OpenSCADCommands.py" line="371"/>
         <source>Add OpenSCAD Element</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="443"/>
-        <location filename="../../OpenSCADCommands.py" line="472"/>
+        <location filename="../../OpenSCADCommands.py" line="428"/>
+        <source>Open file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="430"/>
+        <location filename="../../OpenSCADCommands.py" line="444"/>
+        <source>OpenSCAD Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="442"/>
+        <source>Save file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="456"/>
+        <location filename="../../OpenSCADCommands.py" line="485"/>
         <source>Perform</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="469"/>
-        <location filename="../../OpenSCADCommands.py" line="473"/>
+        <location filename="../../OpenSCADCommands.py" line="482"/>
+        <location filename="../../OpenSCADCommands.py" line="486"/>
         <source>Mesh Boolean</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../importCSG.py" line="549"/>
-        <location filename="../../importCSG.py" line="1385"/>
-        <source>Unsupported Function</source>
+        <location filename="../../OpenSCADCommands.py" line="487"/>
+        <source>Minkowski sum</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../importCSG.py" line="549"/>
-        <location filename="../../importCSG.py" line="1385"/>
-        <source>Press OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADUtils.py" line="710"/>
+        <location filename="../../OpenSCADUtils.py" line="654"/>
         <source>OpenSCAD file contains both 2D and 3D shapes. That is not supported in this importer, all shapes must have the same dimensionality.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADUtils.py" line="722"/>
-        <source>Error all shapes must be either 2D or both must be 3D</source>
+        <location filename="../../OpenSCADUtils.py" line="665"/>
+        <source>Error: either all shapes must be 2D or all shapes must be 3D</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../importCSG.py" line="550"/>
+        <location filename="../../importCSG.py" line="1432"/>
+        <source>Unsupported Function</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../importCSG.py" line="550"/>
+        <location filename="../../importCSG.py" line="1432"/>
+        <source>Press OK</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>OpenSCAD_AddOpenSCADElement</name>
+    <name>OpenSCAD_ExplodeGroup</name>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="516"/>
-        <source>Add OpenSCAD Element...</source>
+        <location filename="../../OpenSCADCommands.py" line="100"/>
+        <source>Explode Group</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="520"/>
-        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
+        <location filename="../../OpenSCADCommands.py" line="103"/>
+        <source>Remove fusion, apply placement to children, and color randomly</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>OpenSCAD_ColorCodeShape</name>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="125"/>
+        <location filename="../../OpenSCADCommands.py" line="116"/>
         <source>Color Shapes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="128"/>
+        <location filename="../../OpenSCADCommands.py" line="119"/>
         <source>Color Shapes by validity and type</source>
         <translation type="unfinished"></translation>
     </message>
@@ -307,172 +335,151 @@
 <context>
     <name>OpenSCAD_Edgestofaces</name>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="145"/>
+        <location filename="../../OpenSCADCommands.py" line="136"/>
         <source>Convert Edges To Faces</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>OpenSCAD_ExpandPlacements</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="290"/>
-        <source>Expand Placements</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="293"/>
-        <source>Expand all placements downwards the FeatureTree</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_ExplodeGroup</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="109"/>
-        <source>Explode Group</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="112"/>
-        <source>Remove fusion, apply placement to children, and color randomly</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_Hull</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="551"/>
-        <source>Hull</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="554"/>
-        <source>Perform Hull</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_IncreaseToleranceFeature</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="273"/>
-        <source>Increase Tolerance Feature</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="276"/>
-        <source>Create Feature that allows to increase the tolerance</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_MeshBoolean</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="531"/>
-        <source>Mesh Boolean...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="535"/>
-        <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_Minkowski</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="570"/>
-        <source>Minkowski</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="573"/>
-        <source>Perform Minkowski</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_MirrorMeshFeature</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="194"/>
-        <source>Mirror Mesh Feature...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="197"/>
-        <source>Create Mirror Mesh Feature</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>OpenSCAD_RefineShapeFeature</name>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="164"/>
+        <location filename="../../OpenSCADCommands.py" line="156"/>
         <source>Refine Shape Feature</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="167"/>
+        <location filename="../../OpenSCADCommands.py" line="159"/>
         <source>Create Refine Shape Feature</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>OpenSCAD_RemoveSubtree</name>
+    <name>OpenSCAD_MirrorMeshFeature</name>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="323"/>
-        <source>Remove Objects and their Children</source>
+        <location filename="../../OpenSCADCommands.py" line="186"/>
+        <source>Mirror Mesh Feature...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="326"/>
-        <source>Removes the selected objects and all children that are not referenced from other objects</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_ReplaceObject</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="311"/>
-        <source>Replace Object</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="314"/>
-        <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>OpenSCAD_ResizeMeshFeature</name>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="253"/>
-        <source>Resize Mesh Feature...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../OpenSCADCommands.py" line="257"/>
-        <source>Create Resize Mesh Feature</source>
+        <location filename="../../OpenSCADCommands.py" line="189"/>
+        <source>Create Mirror Mesh Feature</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>OpenSCAD_ScaleMeshFeature</name>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="223"/>
+        <location filename="../../OpenSCADCommands.py" line="215"/>
         <source>Scale Mesh Feature...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../OpenSCADCommands.py" line="227"/>
+        <location filename="../../OpenSCADCommands.py" line="219"/>
         <source>Create Scale Mesh Feature</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>Workbech</name>
+    <name>OpenSCAD_ResizeMeshFeature</name>
     <message>
-        <location filename="../../InitGui.py" line="156"/>
-        <source>OpenSCAD Part tools</source>
+        <location filename="../../OpenSCADCommands.py" line="245"/>
+        <source>Resize Mesh Feature...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="249"/>
+        <source>Create Resize Mesh Feature</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_IncreaseToleranceFeature</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="266"/>
+        <source>Increase Tolerance Feature</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="269"/>
+        <source>Create Feature that allows increasing the tolerance</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_ExpandPlacements</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="283"/>
+        <source>Expand Placements</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="286"/>
+        <source>Expand all placements downwards in the Tree view</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_ReplaceObject</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="304"/>
+        <source>Replace Object</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="307"/>
+        <source>Replace an object in the Tree view. Please select old, new, and parent object</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_RemoveSubtree</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="317"/>
+        <source>Remove Objects and their Children</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="320"/>
+        <source>Removes the selected objects and all children that are not referenced from other objects</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_AddOpenSCADElement</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="530"/>
+        <source>Add OpenSCAD Element...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="534"/>
+        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_MeshBoolean</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="545"/>
+        <source>Mesh Boolean...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="549"/>
+        <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_Hull</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="566"/>
+        <source>Hull</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="569"/>
+        <source>Use OpenSCAD to create a hull</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -480,7 +487,25 @@
     <name>Workbench</name>
     <message>
         <location filename="../../InitGui.py" line="152"/>
-        <source>OpenSCADTools</source>
+        <source>OpenSCAD Tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../InitGui.py" line="156"/>
+        <source>Frequently-used Part WB tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSCAD_Minkowski</name>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="586"/>
+        <source>Minkowski sum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../OpenSCADCommands.py" line="589"/>
+        <source>Use OpenSCAD to create a Minkowski sum</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
