@@ -20,31 +20,27 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <Geom_BSplineCurve.hxx>
 # include <Geom_BSplineSurface.hxx>
-# include <Geom_BSplineCurve.hxx>
+# include <GeomAbs_Shape.hxx>
+# include <GeomAPI_PointsToBSplineSurface.hxx>
+# include <Precision.hxx>
+# include <TColgp_Array1OfPnt.hxx>
+# include <TColgp_Array2OfPnt.hxx>
 # include <TColStd_Array1OfReal.hxx>
 # include <TColStd_Array2OfReal.hxx>
 # include <TColStd_Array1OfInteger.hxx>
-# include <TColgp_Array1OfPnt.hxx>
-# include <TColgp_Array2OfPnt.hxx>
-# include <Precision.hxx>
-# include <GeomAPI_PointsToBSplineSurface.hxx>
-# include <GeomAbs_Shape.hxx>
 #endif
 # include <GeomFill_NSections.hxx>
 
 #include <Base/GeometryPyCXX.h>
 #include <Base/VectorPy.h>
 
-#include "OCCError.h"
-#include "Geometry.h"
-#include "BSplineCurvePy.h"
 #include "BSplineSurfacePy.h"
 #include "BSplineSurfacePy.cpp"
+#include "BSplineCurvePy.h"
+#include "OCCError.h"
 
 
 using namespace Part;
@@ -57,7 +53,7 @@ std::string BSplineSurfacePy::representation(void) const
 
 PyObject *BSplineSurfacePy::PyMake(struct _typeobject *, PyObject *, PyObject *)  // Python wrapper
 {
-    // create a new instance of BSplineSurfacePy and the Twin object 
+    // create a new instance of BSplineSurfacePy and the Twin object
     return new BSplineSurfacePy(new GeomBSplineSurface);
 }
 
@@ -251,7 +247,7 @@ PyObject* BSplineSurfacePy::insertUKnot(PyObject *args)
     try {
         Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
             (getGeometryPtr()->handle());
-        surf->InsertUKnot(U,M,tol,PyObject_IsTrue(add) ? Standard_True : Standard_False);
+        surf->InsertUKnot(U, M, tol, Base::asBoolean(add));
     }
     catch (Standard_Failure& e) {
         PyErr_SetString(PartExceptionOCCError, e.GetMessageString());
@@ -290,7 +286,7 @@ PyObject* BSplineSurfacePy::insertUKnots(PyObject *args)
 
         Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
             (getGeometryPtr()->handle());
-        surf->InsertUKnots(k,m,tol,PyObject_IsTrue(add) ? Standard_True : Standard_False);
+        surf->InsertUKnots(k, m, tol, Base::asBoolean(add));
         Py_Return;
     }
     catch (Standard_Failure& e) {
@@ -312,7 +308,7 @@ PyObject* BSplineSurfacePy::insertVKnot(PyObject *args)
     try {
         Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
             (getGeometryPtr()->handle());
-        surf->InsertVKnot(V,M,tol,PyObject_IsTrue(add) ? Standard_True : Standard_False);
+        surf->InsertVKnot(V, M, tol, Base::asBoolean(add));
     }
     catch (Standard_Failure& e) {
         PyErr_SetString(PartExceptionOCCError, e.GetMessageString());
@@ -351,7 +347,7 @@ PyObject* BSplineSurfacePy::insertVKnots(PyObject *args)
 
         Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
             (getGeometryPtr()->handle());
-        surf->InsertVKnots(k,m,tol,PyObject_IsTrue(add) ? Standard_True : Standard_False);
+        surf->InsertVKnots(k, m, tol, Base::asBoolean(add));
         Py_Return;
     }
     catch (Standard_Failure& e) {
@@ -617,7 +613,7 @@ PyObject* BSplineSurfacePy::setPoleCol(PyObject *args)
 
         Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
             (getGeometryPtr()->handle());
-        if (obj2 == nullptr) {
+        if (!obj2) {
             surf->SetPoleCol(vindex, poles);
         }
         else {
@@ -657,7 +653,7 @@ PyObject* BSplineSurfacePy::setPoleRow(PyObject *args)
 
         Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
             (getGeometryPtr()->handle());
-        if (obj2 == nullptr) {
+        if (!obj2) {
             surf->SetPoleRow(uindex, poles);
         }
         else {
@@ -1171,7 +1167,7 @@ PyObject* BSplineSurfacePy::approximate(PyObject *args, PyObject *kwds)
     Standard_Real dY=0;
 
     static char* kwds_interp[] = {"Points", "DegMin", "DegMax", "Continuity", "Tolerance", "X0", "dX", "Y0", "dY", "ParamType", "LengthWeight", "CurvatureWeight", "TorsionWeight", nullptr};
-    
+
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "O|iiidddddsddd", kwds_interp, &obj, &degMin, &degMax, &continuity, &tol3d, &X0, &dX, &Y0, &dY, &parType, &weight1, &weight2, &weight3))
         return nullptr;
     try {
@@ -1224,7 +1220,7 @@ PyObject* BSplineSurfacePy::approximate(PyObject *args, PyObject *kwds)
             c = GeomAbs_C2;
             break;
         }
-        
+
         Approx_ParametrizationType pt;
         std::string pstr = parType;
         Standard_Boolean useParam = Standard_True;
@@ -1416,7 +1412,7 @@ PyObject* BSplineSurfacePy::buildFromPolesMultsKnots(PyObject *args, PyObject *k
         Standard_Integer index = 1;
         for (Py::Sequence::iterator it = umultssq.begin(); it != umultssq.end() && index <= occumults.Length(); ++it) {
             Py::Long mult(*it);
-            if (index < occumults.Length() || PyObject_Not(uperiodic)) {
+            if (index < occumults.Length() || !Base::asBoolean(uperiodic)) {
                 sum_of_umults += static_cast<int>(mult); //sum up the mults to compare them against the number of poles later
             }
             occumults(index++) = static_cast<int>(mult);
@@ -1425,7 +1421,7 @@ PyObject* BSplineSurfacePy::buildFromPolesMultsKnots(PyObject *args, PyObject *k
         index = 1;
         for (Py::Sequence::iterator it = vmultssq.begin(); it != vmultssq.end() && index <= occvmults.Length(); ++it) {
             Py::Long mult(*it);
-            if (index < occvmults.Length() || PyObject_Not(vperiodic)) {
+            if (index < occvmults.Length() || !Base::asBoolean(vperiodic)) {
                 sum_of_vmults += static_cast<int>(mult); //sum up the mults to compare them against the number of poles later
             }
             occvmults(index++) = static_cast<int>(mult);
@@ -1457,10 +1453,10 @@ PyObject* BSplineSurfacePy::buildFromPolesMultsKnots(PyObject *args, PyObject *k
                 occvknots.SetValue(i,(double)(i-1)/(occvknots.Length()-1));
             }
         }
-        if ((PyObject_IsTrue(uperiodic) && sum_of_umults != lu) ||
-            (PyObject_Not(uperiodic) && sum_of_umults - udegree -1 != lu) ||
-            (PyObject_IsTrue(vperiodic) && sum_of_vmults != lv) ||
-            (PyObject_Not(vperiodic) && sum_of_vmults - vdegree -1 != lv)) {
+        if ((Base::asBoolean(uperiodic) && sum_of_umults != lu) ||
+            (!Base::asBoolean(uperiodic) && sum_of_umults - udegree -1 != lu) ||
+            (Base::asBoolean(vperiodic) && sum_of_vmults != lv) ||
+            (!Base::asBoolean(vperiodic) && sum_of_vmults - vdegree -1 != lv)) {
             Standard_Failure::Raise("number of poles and sum of mults mismatch");
         }
         // check multiplicity of inner knots
@@ -1477,8 +1473,8 @@ PyObject* BSplineSurfacePy::buildFromPolesMultsKnots(PyObject *args, PyObject *k
 
         Handle(Geom_BSplineSurface) spline = new Geom_BSplineSurface(occpoles,occweights,
             occuknots,occvknots,occumults,occvmults,udegree,vdegree,
-            PyObject_IsTrue(uperiodic) ? Standard_True : Standard_False,
-            PyObject_IsTrue(vperiodic) ? Standard_True : Standard_False);
+            Base::asBoolean(uperiodic),
+            Base::asBoolean(vperiodic));
         if (!spline.IsNull()) {
             this->getGeomBSplineSurfacePtr()->setHandle(spline);
             Py_Return;
@@ -1538,7 +1534,7 @@ PyObject* BSplineSurfacePy::buildFromNSections(PyObject *args)
         }
 
         GeomFill_NSections fillOp(curveSeq);
-        if (PyObject_IsTrue(refSurf)) {
+        if (Base::asBoolean(refSurf)) {
             Handle(Geom_BSplineSurface) ref = Handle(Geom_BSplineSurface)::DownCast
                 (getGeometryPtr()->handle());
             fillOp.SetSurface(ref);
@@ -1577,35 +1573,35 @@ Py::Long BSplineSurfacePy::getMaxDegree(void) const
 {
     Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
         (getGeometryPtr()->handle());
-    return Py::Long(surf->MaxDegree()); 
+    return Py::Long(surf->MaxDegree());
 }
 
 Py::Long BSplineSurfacePy::getNbUPoles(void) const
 {
     Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
         (getGeometryPtr()->handle());
-    return Py::Long(surf->NbUPoles()); 
+    return Py::Long(surf->NbUPoles());
 }
 
 Py::Long BSplineSurfacePy::getNbVPoles(void) const
 {
     Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
         (getGeometryPtr()->handle());
-    return Py::Long(surf->NbVPoles()); 
+    return Py::Long(surf->NbVPoles());
 }
 
 Py::Long BSplineSurfacePy::getNbUKnots(void) const
 {
     Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
         (getGeometryPtr()->handle());
-    return Py::Long(surf->NbUKnots()); 
+    return Py::Long(surf->NbUKnots());
 }
 
 Py::Long BSplineSurfacePy::getNbVKnots(void) const
 {
     Handle(Geom_BSplineSurface) surf = Handle(Geom_BSplineSurface)::DownCast
         (getGeometryPtr()->handle());
-    return Py::Long(surf->NbVKnots()); 
+    return Py::Long(surf->NbVKnots());
 }
 
 Py::Object BSplineSurfacePy::getFirstUKnotIndex(void) const
@@ -1684,12 +1680,42 @@ Py::List BSplineSurfacePy::getVKnotSequence(void) const
     return list;
 }
 
-PyObject *BSplineSurfacePy::getCustomAttributes(const char* /*attr*/) const
+PyObject* BSplineSurfacePy::scaleKnotsToBounds(PyObject *args)
 {
+    double u0=0.0;
+    double u1=1.0;
+    double v0=0.0;
+    double v1=1.0;
+
+    if (!PyArg_ParseTuple(args, "|dddd", &u0, &u1, &v0, &v1))
+        return nullptr;
+    try {
+        if (u0 >= u1 || v0 >= v1) {
+            Standard_Failure::Raise("Bad parameter range");
+            return nullptr;;
+        }
+        GeomBSplineSurface* surf = getGeomBSplineSurfacePtr();
+        surf->scaleKnotsToBounds(u0, u1, v0, v1);
+        Py_Return;
+    }
+    catch (Standard_Failure& e) {
+        std::string err = e.GetMessageString();
+        if (err.empty()) err = e.DynamicType()->Name();
+        PyErr_SetString(PartExceptionOCCError, err.c_str());
+        return nullptr;
+    }
+}
+
+PyObject *BSplineSurfacePy::getCustomAttributes(const char* attr) const
+{
+    // for backward compatibility
+    if (strcmp(attr, "setBounds") == 0) {
+        return PyObject_GetAttrString(const_cast<BSplineSurfacePy*>(this), "scaleKnotsToBounds");
+    }
     return nullptr;
 }
 
 int BSplineSurfacePy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
 {
-    return 0; 
+    return 0;
 }
