@@ -21,16 +21,12 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef PART_DATUMFEATURE_H
 #define PART_DATUMFEATURE_H
 
-#include <QString>
-#include <App/PropertyLinks.h>
-
-#include "PartFeature.h"
 #include "AttachExtension.h"
 
+
 namespace Part
 {
 
@@ -43,11 +39,11 @@ class PartExport Datum : public Part::Feature, public Part::AttachExtension
 
 public:
     Datum();
-    virtual ~Datum();
+    ~Datum() override;
     //short mustExecute();
 
     /// returns the type name of the view provider
-    virtual const char* getViewProviderName(void) const override = 0;
+    const char* getViewProviderName(void) const override = 0;
 
     /// Return a shape including Placement representing the datum feature
     virtual TopoDS_Shape getShape() const;
@@ -55,7 +51,7 @@ public:
     /// Returns a point of the feature it counts as it's base
     virtual Base::Vector3d getBasePoint () const;
 
-    virtual App::DocumentObject *getSubObject(const char *subname, PyObject **pyObj, 
+    App::DocumentObject *getSubObject(const char *subname, PyObject **pyObj,
             Base::Matrix4D *mat, bool transform, int depth) const override;
 protected:
     void onDocumentRestored() override;
