@@ -44,7 +44,6 @@
 
 #include "ExtrusionHelper.h"
 #include "BRepOffsetAPI_MakeOffsetFix.h"
-#include "FeatureExtrusion.h"
 
 
 using namespace Part;
@@ -70,7 +69,7 @@ void ExtrusionHelper::makeDraft(const TopoDS_Shape& shape,
         TopExp_Explorer ex;
         size_t i = 0;
         for (ex.Init(shape, TopAbs_WIRE); ex.More(); ex.Next(), ++i) {
-            wiresections.push_back(std::vector<TopoDS_Shape>());
+            wiresections.emplace_back();
             wiresections[i].push_back(TopoDS::Wire(ex.Current()));
         }
         return i;
@@ -109,7 +108,7 @@ void ExtrusionHelper::makeDraft(const TopoDS_Shape& shape,
     // methods like checking the center of mass etc. don't help us here.
     // As solution we build a prism with every wire, then subtract every prism from each other.
     // If the moment of inertia changes by a subtraction, we have an inner wire prism.
-    // 
+    //
     // first build the prisms
     std::vector<TopoDS_Shape> resultPrisms;
     TopoDS_Shape singlePrism;
@@ -252,13 +251,13 @@ void ExtrusionHelper::makeDraft(const TopoDS_Shape& shape,
                 std::vector<bool>::iterator isInnerWireIterator = isInnerWire.begin();
                 std::vector<bool>::iterator isInnerWireIteratorLoop;
                 for (auto itOuter = shells.begin(); itOuter != shells.end(); ++itOuter) {
-                    if (*isInnerWireIterator == true) {
+                    if (*isInnerWireIterator) {
                         ++isInnerWireIterator;
                         continue;
                     }
                     isInnerWireIteratorLoop = isInnerWire.begin();
                     for (auto itInner = shells.begin(); itInner != shells.end(); ++itInner) {
-                        if (itOuter == itInner || *isInnerWireIteratorLoop == false) {
+                        if (itOuter == itInner || !*isInnerWireIteratorLoop) {
                             ++isInnerWireIteratorLoop;
                             continue;
                         }
@@ -330,7 +329,7 @@ void ExtrusionHelper::checkInnerWires(std::vector<bool>& isInnerWire, const gp_D
     // if nothing happens, a prism can be cancelled from the checklist
     for (auto itOuter = prisms.begin(); itOuter != prisms.end(); ++itOuter) {
         ++outer;
-        if (*toCheckIterator == false) {
+        if (!*toCheckIterator) {
             ++isInnerWireIterator;
             ++toCheckIterator;
             continue;
@@ -338,7 +337,7 @@ void ExtrusionHelper::checkInnerWires(std::vector<bool>& isInnerWire, const gp_D
         auto toCheckIteratorInner = checklist.begin();
         bool saveIsInnerWireIterator = *isInnerWireIterator;
         for (auto itInner = prisms.begin(); itInner != prisms.end(); ++itInner) {
-            if (itOuter == itInner || *toCheckIteratorInner == false) {
+            if (itOuter == itInner || !*toCheckIteratorInner) {
                 ++toCheckIteratorInner;
                 continue;
             }
@@ -363,7 +362,7 @@ void ExtrusionHelper::checkInnerWires(std::vector<bool>& isInnerWire, const gp_D
         }
         if (saveIsInnerWireIterator == *isInnerWireIterator)
             // nothing was changed and we can remove it from the list to be checked
-            // but we cannot do this before the foor loop was fully run
+            // but we cannot do this before the for loop was fully run
             toDisable[outer] = true;
         ++isInnerWireIterator;
         ++toCheckIterator;
