@@ -20,10 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <BRepFilletAPI_MakeFillet.hxx>
+# include <Precision.hxx>
 # include <TopExp.hxx>
 # include <TopExp_Explorer.hxx>
 # include <TopoDS.hxx>
@@ -31,22 +31,20 @@
 # include <TopTools_IndexedMapOfShape.hxx>
 #endif
 
-
-#include "FeatureFillet.h"
 #include <Base/Exception.h>
 
-#include <Precision.hxx>
+#include "FeatureFillet.h"
+
 
 using namespace Part;
 
-
 PROPERTY_SOURCE(Part::Fillet, Part::FilletBase)
 
 Fillet::Fillet()
 {
 }
 
-App::DocumentObjectExecReturn *Fillet::execute(void)
+App::DocumentObjectExecReturn *Fillet::execute()
 {
     App::DocumentObject* link = Base.getValue();
     if (!link)
@@ -76,7 +74,7 @@ App::DocumentObjectExecReturn *Fillet::execute(void)
             return new App::DocumentObjectExecReturn("Resulting shape is null");
 
         //shapefix re #4285
-        //https://www.forum.freecadweb.org/viewtopic.php?f=3&t=43890&sid=dae2fa6fda71670863a103b42739e47f
+        //https://www.forum.freecad.org/viewtopic.php?f=3&t=43890&sid=dae2fa6fda71670863a103b42739e47f
         TopoShape* ts = new TopoShape(shape);
         double minTol = 2.0 * Precision::Confusion();
         double maxTol = 4.0 * Precision::Confusion();
