@@ -20,20 +20,20 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef PART_FEATUREMIRRORING_H
 #define PART_FEATUREMIRRORING_H
 
 #include <App/PropertyStandard.h>
+
 #include "PartFeature.h"
-#include <Base/Matrix.h>
+
 
 namespace Part
 {
 
 class Mirroring : public Part::Feature
 {
-    PROPERTY_HEADER(Part::Mirroring);
+    PROPERTY_HEADER_WITH_OVERRIDE(Part::Mirroring);
 
 public:
     Mirroring();
@@ -45,18 +45,18 @@ public:
     /** @name methods override feature */
     //@{
     /// recalculate the feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartGui::ViewProviderMirror";
     }
     //@}
 
 protected:
-    void onChanged (const App::Property* prop);
+    void onChanged (const App::Property* prop) override;
 
-    void handleChangedPropertyType(Base::XMLReader &reader, const char *TypeName, App::Property * prop);
+    void handleChangedPropertyType(Base::XMLReader &reader, const char *TypeName, App::Property * prop) override;
 
 };
 
