@@ -34,7 +34,7 @@ namespace Part
 
 class Boolean : public Part::Feature
 {
-    PROPERTY_HEADER(Part::Boolean);
+    PROPERTY_HEADER_WITH_OVERRIDE(Part::Boolean);
 
 public:
     Boolean();
@@ -47,12 +47,12 @@ public:
     /** @name methods override Feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
     //@}
 
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartGui::ViewProviderBoolean";
     }
 
