@@ -20,18 +20,18 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <BRepBuilderAPI_MakeEdge.hxx>
 # include <gp_Circ.hxx>
-# include <TopoDS.hxx>
 # include <TopoDS_Edge.hxx>
 #endif
 
-#include "FeaturePartCircle.h"
 #include <Base/Tools.h>
 
+#include "FeaturePartCircle.h"
+
+
 using namespace Part;
 
 App::PropertyQuantityConstraint::Constraints Circle::angleRange = {0.0,360.0,1.0};
@@ -58,14 +58,14 @@ short Circle::mustExecute() const
         Angle2.isTouched() ||
         Radius.isTouched())
         return 1;
-    return Part::Feature::mustExecute();
+    return Part::Primitive::mustExecute();
 }
 
 App::DocumentObjectExecReturn *Circle::execute(void)
 {
     gp_Circ circle;
     circle.SetRadius(this->Radius.getValue());
-    
+
     BRepBuilderAPI_MakeEdge clMakeEdge(circle, Base::toRadians<double>(this->Angle1.getValue()),
                                                Base::toRadians<double>(this->Angle2.getValue()));
     const TopoDS_Edge& edge = clMakeEdge.Edge();
@@ -85,7 +85,7 @@ void Circle::onChanged(const App::Property* prop)
             }
         }
     }
-    Part::Feature::onChanged(prop);
+    Part::Feature::onChanged(prop); // clazy:exclude=skipped-base-method
 }
 
 void Circle::Restore(Base::XMLReader &reader)
