@@ -20,20 +20,18 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef PART_FEATUREPARTFUSE_H
 #define PART_FEATUREPARTFUSE_H
 
-#include <App/PropertyLinks.h>
-
 #include "FeaturePartBoolean.h"
 
+
 namespace Part
 {
 
 class Fuse : public Boolean
 {
-    PROPERTY_HEADER(Part::Fuse);
+    PROPERTY_HEADER_WITH_OVERRIDE(Part::Fuse);
 
 public:
     Fuse();
@@ -42,13 +40,13 @@ public:
     //@{
     /// recalculate the Feature
 protected:
-    BRepAlgoAPI_BooleanOperation* makeOperation(const TopoDS_Shape&, const TopoDS_Shape&) const;
+    BRepAlgoAPI_BooleanOperation* makeOperation(const TopoDS_Shape&, const TopoDS_Shape&) const override;
     //@}
 };
 
 class MultiFuse : public Part::Feature
 {
-    PROPERTY_HEADER(Part::MultiFuse);
+    PROPERTY_HEADER_WITH_OVERRIDE(Part::MultiFuse);
 
 public:
     MultiFuse();
@@ -60,11 +58,11 @@ public:
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
     //@}
     /// returns the type name of the ViewProvider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartGui::ViewProviderMultiFuse";
     }
 
