@@ -20,18 +20,13 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
-
 
 #include "FeaturePartSpline.h"
 
 
 using namespace Part;
 
-
 PROPERTY_SOURCE(Part::Spline, Part::Feature)
 
 
