@@ -20,17 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #include "GeometryExtension.h"
 #include "GeometryExtensionPy.h"
 #include "GeometryExtensionPy.cpp"
 
+
 using namespace Part;
 
 // returns a string which represents the object e.g. when printed in python
-std::string GeometryExtensionPy::representation(void) const
+std::string GeometryExtensionPy::representation() const
 {
     return "<GeometryExtension object>";
 }
@@ -76,7 +76,7 @@ PyObject* GeometryExtensionPy::copy(PyObject *args)
     return cpy;
 }
 
-Py::String GeometryExtensionPy::getName(void) const
+Py::String GeometryExtensionPy::getName() const
 {
     std::string name = this->getGeometryExtensionPtr()->getName();
 
