@@ -20,45 +20,30 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-# include <gp_Ax1.hxx>
-# include <gp_Dir.hxx>
-# include <gp_Pnt.hxx>
-# include <gp_Vec.hxx>
-# include <gp_Trsf.hxx>
-# include <Geom_Geometry.hxx>
-# include <Geom_Curve.hxx>
-# include <Geom_Surface.hxx>
-# include <Precision.hxx>
-# include <Standard_Failure.hxx>
 
+#ifndef _PreComp_
 # include <boost/uuid/uuid_io.hpp>
 #endif
 
 #include <Base/GeometryPyCXX.h>
 #include <Base/Matrix.h>
 #include <Base/MatrixPy.h>
-#include <Base/Vector3D.h>
-#include <Base/VectorPy.h>
-#include <Base/Rotation.h>
 #include <Base/Placement.h>
 #include <Base/PlacementPy.h>
+#include <Base/Vector3D.h>
+#include <Base/VectorPy.h>
 
-#include "OCCError.h"
-#include "Geometry.h"
 #include "GeometryPy.h"
 #include "GeometryPy.cpp"
-
 #include "GeometryExtensionPy.h"
-#include "TopoShape.h"
-#include "TopoShapePy.h"
+#include "OCCError.h"
+
 
 using namespace Part;
 
 // returns a string which represents the object e.g. when printed in python
-std::string GeometryPy::representation(void) const
+std::string GeometryPy::representation() const
 {
     return "<Geometry object>";
 }
@@ -440,7 +425,7 @@ PyObject* GeometryPy::getExtensions(PyObject *args)
 
 }
 
-Py::String GeometryPy::getTag(void) const
+Py::String GeometryPy::getTag() const
 {
     std::string tmp = boost::uuids::to_string(getGeometryPtr()->getTag());
     return Py::String(tmp);
