@@ -20,26 +20,21 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <gp.hxx>
-# include <gp_Lin.hxx>
+# include <GC_MakeSegment.hxx>
 # include <Geom_Line.hxx>
 # include <Geom_TrimmedCurve.hxx>
-# include <GC_MakeLine.hxx>
-# include <GC_MakeSegment.hxx>
-# include <Precision.hxx>
 #endif
 
-#include <Base/VectorPy.h>
 #include <Base/GeometryPyCXX.h>
+#include <Base/VectorPy.h>
 
+#include "LineSegmentPy.h"
+#include "LineSegmentPy.cpp"
+#include "LinePy.h"
 #include "OCCError.h"
-#include "Geometry.h"
-#include <Mod/Part/App/LinePy.h>
-#include <Mod/Part/App/LineSegmentPy.h>
-#include <Mod/Part/App/LineSegmentPy.cpp>
+
 
 using namespace Part;
 
@@ -165,7 +160,7 @@ int LineSegmentPy::PyInit(PyObject* args, PyObject* /*kwd*/)
             return 0;
         }
         catch (Standard_Failure& e) {
-    
+
             PyErr_SetString(PartExceptionOCCError, e.GetMessageString());
             return -1;
         }
@@ -200,7 +195,7 @@ PyObject* LineSegmentPy::setParameterRange(PyObject *args)
         return nullptr;
     }
 
-    Py_Return; 
+    Py_Return;
 }
 
 Py::Object LineSegmentPy::getStartPoint(void) const
@@ -322,5 +317,5 @@ PyObject *LineSegmentPy::getCustomAttributes(const char* /*attr*/) const
 
 int LineSegmentPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
 {
-    return 0; 
+    return 0;
 }
