@@ -20,10 +20,8 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <gp_Ax1.hxx>
 # include <BRep_Builder.hxx>
 # include <BRepCheck_Analyzer.hxx>
 # include <BRepGProp.hxx>
@@ -32,28 +30,27 @@
 # include <GProp_PrincipalProps.hxx>
 # include <TopoDS.hxx>
 # include <TopoDS_Shell.hxx>
-# include <ShapeUpgrade_ShellSewing.hxx>
 # include <ShapeAnalysis_Shell.hxx>
-# include <BRepPrimAPI_MakeHalfSpace.hxx>
+# include <ShapeUpgrade_ShellSewing.hxx>
 #endif
 
-#include <Base/VectorPy.h>
 #include <Base/GeometryPyCXX.h>
+#include <Base/VectorPy.h>
 
 #include "OCCError.h"
 #include "Tools.h"
-#include "TopoShape.h"
 #include "TopoShapeCompoundPy.h"
-#include "TopoShapeCompSolidPy.h"
+#include "TopoShapeCompoundPy.h"
 #include "TopoShapeFacePy.h"
 #include "TopoShapeShellPy.h"
 #include "TopoShapeShellPy.cpp"
 #include "TopoShapeSolidPy.h"
 
+
 using namespace Part;
 
 // returns a string which represents the object e.g. when printed in python
-std::string TopoShapeShellPy::representation(void) const
+std::string TopoShapeShellPy::representation() const
 {
     // Note: As the return type is 'const char*' we cannot create a temporary
     // char array neither on the stack because the array would be freed when
@@ -167,11 +164,8 @@ PyObject*  TopoShapeShellPy::getFreeEdges(PyObject *args)
         return nullptr;
     ShapeAnalysis_Shell as;
     as.LoadShells(getTopoShapePtr()->getShape());
-#if OCC_VERSION_HEX < 0x060500
-    as.CheckOrientedShells(getTopoShapePtr()->getShape(), Standard_True);
-#else
     as.CheckOrientedShells(getTopoShapePtr()->getShape(), Standard_True, Standard_True);
-#endif
+
     TopoDS_Compound comp = as.FreeEdges();
     return new TopoShapeCompoundPy(new TopoShape(comp));
 }
@@ -182,11 +176,8 @@ PyObject*  TopoShapeShellPy::getBadEdges(PyObject *args)
         return nullptr;
     ShapeAnalysis_Shell as;
     as.LoadShells(getTopoShapePtr()->getShape());
-#if OCC_VERSION_HEX < 0x060500
-    as.CheckOrientedShells(getTopoShapePtr()->getShape(), Standard_True);
-#else
     as.CheckOrientedShells(getTopoShapePtr()->getShape(), Standard_True, Standard_True);
-#endif
+
     TopoDS_Compound comp = as.BadEdges();
     return new TopoShapeCompoundPy(new TopoShape(comp));
 }
@@ -208,7 +199,7 @@ PyObject* TopoShapeShellPy::makeHalfSpace(PyObject *args)
     }
 }
 
-Py::Object TopoShapeShellPy::getMass(void) const
+Py::Object TopoShapeShellPy::getMass() const
 {
     GProp_GProps props;
     BRepGProp::SurfaceProperties(getTopoShapePtr()->getShape(), props);
@@ -216,7 +207,7 @@ Py::Object TopoShapeShellPy::getMass(void) const
     return Py::Float(c);
 }
 
-Py::Object TopoShapeShellPy::getCenterOfMass(void) const
+Py::Object TopoShapeShellPy::getCenterOfMass() const
 {
     GProp_GProps props;
     BRepGProp::SurfaceProperties(getTopoShapePtr()->getShape(), props);
@@ -224,7 +215,7 @@ Py::Object TopoShapeShellPy::getCenterOfMass(void) const
     return Py::Vector(Base::Vector3d(c.X(),c.Y(),c.Z()));
 }
 
-Py::Object TopoShapeShellPy::getMatrixOfInertia(void) const
+Py::Object TopoShapeShellPy::getMatrixOfInertia() const
 {
     GProp_GProps props;
     BRepGProp::SurfaceProperties(getTopoShapePtr()->getShape(), props);
@@ -238,7 +229,7 @@ Py::Object TopoShapeShellPy::getMatrixOfInertia(void) const
     return Py::Matrix(mat);
 }
 
-Py::Object TopoShapeShellPy::getStaticMoments(void) const
+Py::Object TopoShapeShellPy::getStaticMoments() const
 {
     GProp_GProps props;
     BRepGProp::SurfaceProperties(getTopoShapePtr()->getShape(), props);
@@ -251,7 +242,7 @@ Py::Object TopoShapeShellPy::getStaticMoments(void) const
     return tuple;
 }
 
-Py::Dict TopoShapeShellPy::getPrincipalProperties(void) const
+Py::Dict TopoShapeShellPy::getPrincipalProperties() const
 {
     GProp_GProps props;
     BRepGProp::SurfaceProperties(getTopoShapePtr()->getShape(), props);
