@@ -20,15 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef PART_EDGECLUSTER_H
 #define PART_EDGECLUSTER_H
 
-#include <Mod/Part/PartGlobal.h>
+#include <map>
+#include <vector>
+
 #include <gp_Pnt.hxx>
 #include <TopoDS_Edge.hxx>
-#include <vector>
-#include <map>
+
+#include <Mod/Part/PartGlobal.h>
 
 
 namespace Part {
@@ -51,19 +52,19 @@ struct Edgesort_gp_Pnt_Less
 };
 
 
-typedef std::vector<TopoDS_Edge> tEdgeVector;
-typedef std::map<gp_Pnt,tEdgeVector,Edgesort_gp_Pnt_Less>  tMapPntEdge;
-typedef std::pair<gp_Pnt,tEdgeVector> tMapPntEdgePair;
-typedef std::vector<std::vector<TopoDS_Edge> > tEdgeClusterVector;
+using tEdgeVector = std::vector<TopoDS_Edge>;
+using tMapPntEdge = std::map<gp_Pnt,tEdgeVector,Edgesort_gp_Pnt_Less>;
+using tMapPntEdgePair = std::pair<gp_Pnt,tEdgeVector>;
+using tEdgeClusterVector = std::vector<std::vector<TopoDS_Edge> >;
 
 
 class PartExport Edgecluster
 {
 public:
-    Edgecluster(const std::vector<TopoDS_Edge>& usorted_edges);
-    virtual ~Edgecluster(void);
+    explicit Edgecluster(const std::vector<TopoDS_Edge>& usorted_edges);
+    virtual ~Edgecluster();
 
-    tEdgeClusterVector GetClusters(void);
+    tEdgeClusterVector GetClusters();
 
 private:
     void Perform();
