@@ -1,13 +1,25 @@
 /***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *   for detail see the LICENCE text file.                                 *
- *   Juergen Riegel 2002                                                   *
- *                                                                         *
- ***************************************************************************/
+*   Copyright (c) 2002 Juergen Riegel <juergen.riegel@web.de>             *
+*                                                                         *
+*   This file is part of the FreeCAD CAx development system.              *
+*                                                                         *
+*   This program is free software; you can redistribute it and/or modify  *
+*   it under the terms of the GNU Lesser General Public License (LGPL)    *
+*   as published by the Free Software Foundation; either version 2 of     *
+*   the License, or (at your option) any later version.                   *
+*   for detail see the LICENCE text file.                                 *
+*                                                                         *
+*   FreeCAD is distributed in the hope that it will be useful,            *
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+*   GNU Lesser General Public License for more details.                   *
+*                                                                         *
+*   You should have received a copy of the GNU Library General Public     *
+*   License along with FreeCAD; if not, write to the Free Software        *
+*   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
+*   USA                                                                   *
+*                                                                         *
+***************************************************************************/
 
 
 #include "PreCompiled.h"
@@ -20,22 +32,25 @@
 #include <Base/PyObjectBase.h>
 #include <Gui/Application.h>
 #include <Gui/BitmapFactory.h>
+#include <Gui/DlgPreferencesImp.h>
 #include <Gui/WidgetFactory.h>
 #include <Gui/Language/Translator.h>
 
 #include "AttacherTexts.h"
 #include "PropertyEnumAttacherItem.h"
+#include "DlgSettings3DViewPartImp.h"
+#include "DlgSettingsGeneral.h"
+#include "DlgSettingsMeasure.h"
+#include "DlgSettingsObjectColor.h"
+#include "TaskDimension.h"
 #include "SoBrepEdgeSet.h"
 #include "SoBrepFaceSet.h"
 #include "SoBrepPointSet.h"
 #include "SoFCShapeObject.h"
-#include "TaskDimension.h"
-#include "DlgSettings3DViewPartImp.h"
-#include "DlgSettingsGeneral.h"
-#include "DlgSettingsObjectColor.h"
 #include "ViewProvider.h"
 #include "ViewProvider2DObject.h"
 #include "ViewProviderAttachExtension.h"
+#include "ViewProviderGridExtension.h"
 #include "ViewProviderBoolean.h"
 #include "ViewProviderBox.h"
 #include "ViewProviderCircleParametric.h"
@@ -64,14 +79,15 @@
 
 
 // use a different name to CreateCommand()
-void CreatePartCommands(void);
-void CreateSimplePartCommands(void);
-void CreateParamPartCommands(void);
+void CreatePartCommands();
+void CreateSimplePartCommands();
+void CreateParamPartCommands();
 
 void loadPartResource()
 {
     // add resources and reloads the translators
     Q_INIT_RESOURCE(Part);
+    Q_INIT_RESOURCE(Part_translation);
     Gui::Translator::instance()->refresh();
 }
 
@@ -84,7 +100,7 @@ public:
         initialize("This module is the PartGui module."); // register with Python
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
 };
@@ -141,6 +157,8 @@ PyMOD_INIT_FUNC(PartGui)
     PartGui::SoFCControlPoints                      ::initClass();
     PartGui::ViewProviderAttachExtension            ::init();
     PartGui::ViewProviderAttachExtensionPython      ::init();
+    PartGui::ViewProviderGridExtension              ::init();
+    PartGui::ViewProviderGridExtensionPython        ::init();
     PartGui::ViewProviderSplineExtension            ::init();
     PartGui::ViewProviderSplineExtensionPython      ::init();
     PartGui::ViewProviderPartExt                    ::init();
@@ -207,9 +225,11 @@ PyMOD_INIT_FUNC(PartGui)
     }
 
     // register preferences pages
+    Gui::Dialog::DlgPreferencesImp::setGroupData("Part/Part Design", "Part design", QObject::tr("Part and Part Design workbench"));
     (void)new Gui::PrefPageProducer<PartGui::DlgSettingsGeneral>(QT_TRANSLATE_NOOP("QObject", "Part/Part Design"));
     (void)new Gui::PrefPageProducer<PartGui::DlgSettings3DViewPart>(QT_TRANSLATE_NOOP("QObject", "Part/Part Design"));
     (void)new Gui::PrefPageProducer<PartGui::DlgSettingsObjectColor>(QT_TRANSLATE_NOOP("QObject", "Part/Part Design"));
+    (void)new Gui::PrefPageProducer<PartGui::DlgSettingsMeasure>(QT_TRANSLATE_NOOP("QObject", "Part/Part Design"));
     (void)new Gui::PrefPageProducer<PartGui::DlgImportExportIges>(QT_TRANSLATE_NOOP("QObject", "Import-Export"));
     (void)new Gui::PrefPageProducer<PartGui::DlgImportExportStep>(QT_TRANSLATE_NOOP("QObject", "Import-Export"));
     Gui::ViewProviderBuilder::add(
