@@ -20,46 +20,32 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
 # include <sstream>
 # include <BRep_Tool.hxx>
-# include <BRepGProp.hxx>
-# include <GProp_GProps.hxx>
 # include <gp_Pnt.hxx>
 # include <TopExp_Explorer.hxx>
 # include <TopoDS.hxx>
 # include <TopTools_IndexedMapOfShape.hxx>
-# include <QFontMetrics>
-# include <QMessageBox>
-# include <QSet>
 # include <Inventor/SoPickedPoint.h>
-# include <Inventor/actions/SoRayPickAction.h>
-# include <Inventor/actions/SoSearchAction.h>
-# include <Inventor/details/SoFaceDetail.h>
 # include <Inventor/events/SoMouseButtonEvent.h>
 # include <Inventor/nodes/SoCamera.h>
-# include <Inventor/nodes/SoSeparator.h>
 #endif
 
-#include "BoxSelection.h"
-#include "ViewProviderExt.h"
-
+#include <App/Document.h>
+#include <App/DocumentObject.h>
 #include <Gui/Application.h>
-#include <Gui/Document.h>
 #include <Gui/MainWindow.h>
 #include <Gui/Selection.h>
 #include <Gui/SelectionFilter.h>
-#include <Gui/SoFCUnifiedSelection.h>
 #include <Gui/Utilities.h>
 #include <Gui/View3DInventor.h>
 #include <Gui/View3DInventorViewer.h>
 
-#include <App/Document.h>
-#include <App/DocumentObject.h>
-#include <Mod/Part/App/PartFeature.h>
+#include "BoxSelection.h"
+#include "ViewProviderExt.h"
 
 
 using namespace PartGui;
@@ -71,10 +57,10 @@ public:
         : Gui::SelectionFilterGate()
     {
     }
-    ~FaceSelectionGate()
+    ~FaceSelectionGate() override
     {
     }
-    bool allow(App::Document*, App::DocumentObject*, const char*sSubName)
+    bool allow(App::Document*, App::DocumentObject*, const char*sSubName) override
     {
         if (!sSubName || sSubName[0] == '\0')
             return false;
@@ -84,6 +70,8 @@ public:
 };
 
 BoxSelection::BoxSelection()
+    : autodelete(false)
+    , shapeEnum(TopAbs_SHAPE)
 {
 
 }
@@ -93,12 +81,21 @@ BoxSelection::~BoxSelection()
 
 }
 
+void BoxSelection::setAutoDelete(bool on)
+{
+    autodelete = on;
+}
+
+bool BoxSelection::isAutoDelete() const
+{
+    return autodelete;
+}
+
 void BoxSelection::selectionCallback(void * ud, SoEventCallback * cb)
 {
-    Gui::View3DInventorViewer* view  = reinterpret_cast<Gui::View3DInventorViewer*>(cb->getUserData());
+    Gui::View3DInventorViewer* view  = static_cast<Gui::View3DInventorViewer*>(cb->getUserData());
     view->removeEventCallback(SoMouseButtonEvent::getClassTypeId(), selectionCallback, ud);
-    SoNode* root = view->getSceneGraph();
-    static_cast<Gui::SoFCUnifiedSelection*>(root)->selectionRole.setValue(true);
+    view->setSelectionEnabled(true);
 
     std::vector<SbVec2f> picked = view->getGLPolygon();
     SoCamera* cam = view->getSoRenderManager()->getCamera();
@@ -129,40 +126,61 @@ void BoxSelection::selectionCallback(void * ud, SoEventCallback * cb)
             if (!vp->isVisible())
                 continue;
             const TopoDS_Shape& shape = it->Shape.getValue();
-            self->addFacesToSelection(doc->getName(), it->getNameInDocument(), proj, polygon, shape);
+            self->addShapeToSelection(doc->getName(), it->getNameInDocument(), proj, polygon, shape, self->shapeEnum);
         }
         view->redraw();
     }
 
     Gui::Selection().rmvSelectionGate();
-    delete self;
+
+    if (self->isAutoDelete()) {
+        delete self;
+    }
 }
 
-void BoxSelection::addFacesToSelection(const char* doc, const char* obj,
+const char* BoxSelection::nameFromShapeType(TopAbs_ShapeEnum type) const
+{
+    switch (type) {
+    case TopAbs_FACE:
+        return "Face";
+    case TopAbs_EDGE:
+        return "Edge";
+    case TopAbs_VERTEX:
+        return "Vertex";
+    default:
+        return nullptr;
+    }
+}
+
+void BoxSelection::addShapeToSelection(const char* doc, const char* obj,
                                        const Gui::ViewVolumeProjection& proj,
                                        const Base::Polygon2d& polygon,
-                                       const TopoDS_Shape& shape)
+                                       const TopoDS_Shape& shape,
+                                       TopAbs_ShapeEnum subtype)
 {
     try {
-        TopTools_IndexedMapOfShape M;
+        const char* subname = nameFromShapeType(subtype);
+        if (!subname)
+            return;
 
-        TopExp_Explorer xp_face(shape,TopAbs_FACE);
-        while (xp_face.More()) {
-            M.Add(xp_face.Current());
-            xp_face.Next();
+        TopTools_IndexedMapOfShape M;
+        TopExp_Explorer xp(shape, subtype);
+        while (xp.More()) {
+            M.Add(xp.Current());
+            xp.Next();
         }
 
         for (Standard_Integer k = 1; k <= M.Extent(); k++) {
-            const TopoDS_Shape& face = M(k);
+            const TopoDS_Shape& subshape = M(k);
 
-            TopExp_Explorer xp_vertex(face,TopAbs_VERTEX);
+            TopExp_Explorer xp_vertex(subshape, TopAbs_VERTEX);
             while (xp_vertex.More()) {
                 gp_Pnt p = BRep_Tool::Pnt(TopoDS::Vertex(xp_vertex.Current()));
                 Base::Vector3d pt2d;
                 pt2d = proj(Base::Vector3d(p.X(), p.Y(), p.Z()));
                 if (polygon.Contains(Base::Vector2d(pt2d.x, pt2d.y))) {
                     std::stringstream str;
-                    str << "Face" << k;
+                    str << subname << k;
                     Gui::Selection().addSelection(doc, obj, str.str().c_str());
                     break;
                 }
@@ -174,7 +192,7 @@ void BoxSelection::addFacesToSelection(const char* doc, const char* obj,
     }
 }
 
-void BoxSelection::start()
+void BoxSelection::start(TopAbs_ShapeEnum shape)
 {
     Gui::View3DInventor* view = qobject_cast<Gui::View3DInventor*>(Gui::getMainWindow()->activeWindow());
     if (view) {
@@ -184,10 +202,8 @@ void BoxSelection::start()
             viewer->addEventCallback(SoMouseButtonEvent::getClassTypeId(), selectionCallback, this);
             // avoid that the selection node handles the event otherwise the callback function won't be
             // called immediately
-            SoNode* root = viewer->getSceneGraph();
-            static_cast<Gui::SoFCUnifiedSelection*>(root)->selectionRole.setValue(false);
-
-            Gui::Selection().addSelectionGate(new FaceSelectionGate);
+            viewer->setSelectionEnabled(false);
+            shapeEnum = shape;
         }
     }
 }
