@@ -35,7 +35,7 @@
 namespace Base {
     class Quantity;
 }
-namespace Part { 
+namespace Part {
     class FilletBase;
     class Fillet;
     class Chamfer;
@@ -49,17 +49,17 @@ class FilletRadiusDelegate : public QItemDelegate
     Q_OBJECT
 
 public:
-    FilletRadiusDelegate(QObject *parent = nullptr);
+    explicit FilletRadiusDelegate(QObject *parent = nullptr);
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const;
+                          const QModelIndex &index) const override;
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
     void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const;
+                      const QModelIndex &index) const override;
 
-    void updateEditorGeometry(QWidget *editor, 
-        const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    void updateEditorGeometry(QWidget *editor,
+        const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 class FilletRadiusModel : public QStandardItemModel
@@ -67,12 +67,12 @@ class FilletRadiusModel : public QStandardItemModel
     Q_OBJECT
 
 public:
-    FilletRadiusModel(QObject * parent = nullptr);
+    explicit FilletRadiusModel(QObject * parent = nullptr);
 
-    Qt::ItemFlags flags (const QModelIndex & index) const;
+    Qt::ItemFlags flags (const QModelIndex & index) const override;
     bool setData (const QModelIndex & index, const QVariant & value,
-                  int role = Qt::EditRole);
-    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const;
+                  int role = Qt::EditRole) override;
+    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const override;
     void updateCheckStates();
 
 Q_SIGNALS:
@@ -87,31 +87,32 @@ public:
     enum FilletType { FILLET, CHAMFER };
 
     DlgFilletEdges(FilletType type, Part::FilletBase*, QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
-    ~DlgFilletEdges();
+    ~DlgFilletEdges() override;
     bool accept();
 
 protected:
     void findShapes();
     void setupFillet(const std::vector<App::DocumentObject*>&);
-    void changeEvent(QEvent *e);
+    void changeEvent(QEvent *e) override;
     virtual const char* getFilletType() const;
 
 private:
-    void onSelectionChanged(const Gui::SelectionChanges& msg);
+    void onSelectionChanged(const Gui::SelectionChanges& msg) override;
     void onDeleteObject(const App::DocumentObject&);
     void onDeleteDocument(const App::Document&);
     void onSelectEdge(const QString& subelement, int type);
     void onSelectEdgesOfFace(const QString& subelement, int type);
 
-private Q_SLOTS:
-    void on_shapeObject_activated(int);
-    void on_selectEdges_toggled(bool);
-    void on_selectFaces_toggled(bool);
-    void on_selectAllButton_clicked();
-    void on_selectNoneButton_clicked();
-    void on_filletType_activated(int);
-    void on_filletStartRadius_valueChanged(const Base::Quantity&);
-    void on_filletEndRadius_valueChanged(const Base::Quantity&);
+private:
+    void setupConnections();
+    void onShapeObjectActivated(int);
+    void onSelectEdgesToggled(bool);
+    void onSelectFacesToggled(bool);
+    void onSelectAllButtonClicked();
+    void onSelectNoneButtonClicked();
+    void onFilletTypeActivated(int);
+    void onFilletStartRadiusValueChanged(const Base::Quantity&);
+    void onFilletEndRadiusValueChanged(const Base::Quantity&);
     void toggleCheckState(const QModelIndex&);
     void onHighlightEdges();
 
@@ -127,8 +128,8 @@ class FilletEdgesDialog : public QDialog
 
 public:
     FilletEdgesDialog(DlgFilletEdges::FilletType type, Part::FilletBase* fillet, QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
-    ~FilletEdgesDialog();
-    void accept();
+    ~FilletEdgesDialog() override;
+    void accept() override;
 
 private:
     DlgFilletEdges* widget;
@@ -139,11 +140,11 @@ class DlgChamferEdges : public DlgFilletEdges
     Q_OBJECT
 
 public:
-    DlgChamferEdges(Part::FilletBase*, QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
-    ~DlgChamferEdges();
+    explicit DlgChamferEdges(Part::FilletBase*, QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
+    ~DlgChamferEdges() override;
 
 protected:
-    virtual const char* getFilletType() const;
+    const char* getFilletType() const override;
 };
 
 class TaskFilletEdges : public Gui::TaskView::TaskDialog
@@ -151,18 +152,18 @@ class TaskFilletEdges : public Gui::TaskView::TaskDialog
     Q_OBJECT
 
 public:
-    TaskFilletEdges(Part::Fillet*);
-    ~TaskFilletEdges();
+    explicit TaskFilletEdges(Part::Fillet*);
+    ~TaskFilletEdges() override;
 
 public:
-    virtual void open();
-    virtual void clicked(int);
-    virtual bool accept();
-    virtual bool reject();
+    void open() override;
+    void clicked(int) override;
+    bool accept() override;
+    bool reject() override;
 
-    virtual QDialogButtonBox::StandardButtons getStandardButtons() const
+    QDialogButtonBox::StandardButtons getStandardButtons() const override
     { return QDialogButtonBox::Ok|QDialogButtonBox::Cancel; }
-    virtual bool needsFullSpace() const
+    bool needsFullSpace() const override
     { return true; }
 
 private:
@@ -175,18 +176,18 @@ class TaskChamferEdges : public Gui::TaskView::TaskDialog
     Q_OBJECT
 
 public:
-    TaskChamferEdges(Part::Chamfer*);
-    ~TaskChamferEdges();
+    explicit TaskChamferEdges(Part::Chamfer*);
+    ~TaskChamferEdges() override;
 
 public:
-    virtual void open();
-    virtual void clicked(int);
-    virtual bool accept();
-    virtual bool reject();
+    void open() override;
+    void clicked(int) override;
+    bool accept() override;
+    bool reject() override;
 
-    virtual QDialogButtonBox::StandardButtons getStandardButtons() const
+    QDialogButtonBox::StandardButtons getStandardButtons() const override
     { return QDialogButtonBox::Ok|QDialogButtonBox::Cancel; }
-    virtual bool needsFullSpace() const
+    bool needsFullSpace() const override
     { return true; }
 
 private:
