@@ -70,9 +70,9 @@ public:
   {
     canSelect = false;
   }
-  ~EdgeSelection() {}
+  ~EdgeSelection() override {}
 
-  bool allow(App::Document* /*pDoc*/, App::DocumentObject* iPObj, const char* sSubName)
+  bool allow(App::Document* /*pDoc*/, App::DocumentObject* iPObj, const char* sSubName) override
   {
     Part::Feature* aPart = dynamic_cast<Part::Feature*>(iPObj);
     if (!aPart)
@@ -104,9 +104,9 @@ public:
   {
     canSelect = false;
   }
-  ~FaceSelection() {}
+  ~FaceSelection() override {}
 
-  bool allow(App::Document* /*pDoc*/, App::DocumentObject* iPObj, const char* sSubName)
+  bool allow(App::Document* /*pDoc*/, App::DocumentObject* iPObj, const char* sSubName) override
   {
     Part::Feature* aPart = dynamic_cast<Part::Feature*>(iPObj);
     if (!aPart)
@@ -137,6 +137,8 @@ DlgProjectionOnSurface::DlgProjectionOnSurface(QWidget *parent)
   , filterFace(nullptr)
 {
     ui->setupUi(this);
+    setupConnections();
+
     ui->pushButtonAddEdge->setCheckable(true);
     ui->pushButtonAddFace->setCheckable(true);
     ui->pushButtonAddProjFace->setCheckable(true);
@@ -170,14 +172,14 @@ DlgProjectionOnSurface::DlgProjectionOnSurface(QWidget *parent)
       throw Base::ValueError(QString(tr("Can not create a projection object!!!")).toUtf8());
     }
     m_projectionObject->Label.setValue(std::string(m_projectionObjectName.toUtf8()).c_str());
-    on_radioButtonShowAll_clicked();
+    onRadioButtonShowAllClicked();
     m_lastDepthVal = ui->doubleSpinBoxSolidDepth->value();
 }
 
 DlgProjectionOnSurface::~DlgProjectionOnSurface()
 {
   delete ui;
-  for ( auto it : m_projectionSurfaceVec)
+  for (const auto& it : m_projectionSurfaceVec)
   {
     try {
       higlight_object(it.partFeature, it.partName, false, 0);
@@ -192,7 +194,7 @@ DlgProjectionOnSurface::~DlgProjectionOnSurface()
       vp->Transparency.setValue(it.transparency);
     }
   }
-  for (auto it : m_shapeVec)
+  for (const auto& it : m_shapeVec)
   {
     try {
       higlight_object(it.partFeature, it.partName, false, 0);
@@ -204,6 +206,36 @@ DlgProjectionOnSurface::~DlgProjectionOnSurface()
   Gui::Selection().rmvSelectionGate();
 }
 
+void PartGui::DlgProjectionOnSurface::setupConnections()
+{
+    connect(ui->pushButtonAddFace, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonAddFaceClicked);
+    connect(ui->pushButtonAddEdge, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonAddEdgeClicked);
+    connect(ui->pushButtonGetCurrentCamDir, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonGetCurrentCamDirClicked);
+    connect(ui->pushButtonDirX, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonDirXClicked);
+    connect(ui->pushButtonDirY, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonDirYClicked);
+    connect(ui->pushButtonDirZ, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonDirZClicked);
+    connect(ui->pushButtonAddProjFace, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonAddProjFaceClicked);
+    connect(ui->radioButtonShowAll, &QRadioButton::clicked,
+            this, &DlgProjectionOnSurface::onRadioButtonShowAllClicked);
+    connect(ui->radioButtonFaces, &QRadioButton::clicked,
+            this, &DlgProjectionOnSurface::onRadioButtonFacesClicked);
+    connect(ui->radioButtonEdges, &QRadioButton::clicked,
+            this, &DlgProjectionOnSurface::onRadioButtonEdgesClicked);
+    connect(ui->doubleSpinBoxExtrudeHeight, qOverload<double>(&QDoubleSpinBox::valueChanged),
+            this, &DlgProjectionOnSurface::onDoubleSpinBoxExtrudeHeightValueChanged);
+    connect(ui->pushButtonAddWire, &QPushButton::clicked,
+            this, &DlgProjectionOnSurface::onPushButtonAddWireClicked);
+    connect(ui->doubleSpinBoxSolidDepth, qOverload<double>(&QDoubleSpinBox::valueChanged),
+            this, &DlgProjectionOnSurface::onDoubleSpinBoxSolidDepthValueChanged);
+}
+
 void PartGui::DlgProjectionOnSurface::slotDeletedDocument(const App::Document& Doc)
 {
   if (m_partDocument == &Doc) {
@@ -219,19 +251,19 @@ void PartGui::DlgProjectionOnSurface::slotDeletedObject(const App::DocumentObjec
   }
 }
 
-void PartGui::DlgProjectionOnSurface::apply(void)
+void PartGui::DlgProjectionOnSurface::apply()
 {
   if (m_partDocument)
     m_partDocument->commitTransaction();
 }
 
-void PartGui::DlgProjectionOnSurface::reject(void)
+void PartGui::DlgProjectionOnSurface::reject()
 {
   if (m_partDocument)
     m_partDocument->abortTransaction();
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonAddFace_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonAddFaceClicked()
 {
   if ( ui->pushButtonAddFace->isChecked() )
   {
@@ -252,7 +284,7 @@ void PartGui::DlgProjectionOnSurface::on_pushButtonAddFace_clicked()
   }
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonAddEdge_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonAddEdgeClicked()
 {
   if (ui->pushButtonAddEdge->isChecked())
   {
@@ -264,7 +296,7 @@ void PartGui::DlgProjectionOnSurface::on_pushButtonAddEdge_clicked()
       Gui::Selection().addSelectionGate(filterEdge);
     }
     ui->radioButtonEdges->setChecked(true);
-    on_radioButtonEdges_clicked();
+    onRadioButtonEdgesClicked();
   }
   else
   {
@@ -275,22 +307,22 @@ void PartGui::DlgProjectionOnSurface::on_pushButtonAddEdge_clicked()
   }
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonGetCurrentCamDir_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonGetCurrentCamDirClicked()
 {
   get_camera_direction();
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonDirX_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonDirXClicked()
 {
   set_xyz_dir_spinbox(ui->doubleSpinBoxDirX);
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonDirY_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonDirYClicked()
 {
   set_xyz_dir_spinbox(ui->doubleSpinBoxDirY);
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonDirZ_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonDirZClicked()
 {
   set_xyz_dir_spinbox(ui->doubleSpinBoxDirZ);
 }
@@ -311,7 +343,7 @@ void PartGui::DlgProjectionOnSurface::onSelectionChanged(const Gui::SelectionCha
     {
       m_projectionSurfaceVec.clear();
       store_current_selected_parts(m_projectionSurfaceVec, 0xffff0000);
-      if (m_projectionSurfaceVec.size())
+      if (!m_projectionSurfaceVec.empty())
       {
         PartGui::ViewProviderPartExt* vp = dynamic_cast<PartGui::ViewProviderPartExt*>(Gui::Application::Instance->getViewProvider(m_projectionSurfaceVec.back().partFeature));
         if (vp)
@@ -322,12 +354,12 @@ void PartGui::DlgProjectionOnSurface::onSelectionChanged(const Gui::SelectionCha
       }
 
       ui->pushButtonAddProjFace->setChecked(false);
-      on_pushButtonAddProjFace_clicked();
+      onPushButtonAddProjFaceClicked();
     }
   }
 }
 
-void PartGui::DlgProjectionOnSurface::get_camera_direction(void)
+void PartGui::DlgProjectionOnSurface::get_camera_direction()
 {
   auto mainWindow = Gui::getMainWindow();
 
@@ -352,7 +384,7 @@ void PartGui::DlgProjectionOnSurface::store_current_selected_parts(std::vector<S
   if (!m_partDocument)
       return;
   std::vector<Gui::SelectionObject> selObj = Gui::Selection().getSelectionEx();
-  if (selObj.size())
+  if (!selObj.empty())
   {
     for (auto it = selObj.begin(); it != selObj.end(); ++it)
     {
@@ -372,7 +404,7 @@ void PartGui::DlgProjectionOnSurface::store_current_selected_parts(std::vector<S
           currentShapeStore.is_selectable = vp->Selectable.getValue();
           currentShapeStore.transparency = vp->Transparency.getValue();
         }
-        if (it->getSubNames().size() )
+        if (!it->getSubNames().empty() )
         {
           auto parentShape = currentShapeStore.inputShape;
           for (auto itName = selObj.front().getSubNames().begin(); itName != selObj.front().getSubNames().end(); ++itName)
@@ -440,7 +472,7 @@ bool PartGui::DlgProjectionOnSurface::store_part_in_vector(SShapeStore& iCurrent
   auto valZ = ui->doubleSpinBoxDirZ->value();
 
   iCurrentShape.aProjectionDir = gp_Dir(valX, valY, valZ);
-  if ( m_projectionSurfaceVec.size() )
+  if ( !m_projectionSurfaceVec.empty() )
   {
     iCurrentShape.surfaceToProject = m_projectionSurfaceVec.front().aFace;
   }
@@ -457,14 +489,14 @@ void PartGui::DlgProjectionOnSurface::create_projection_wire(std::vector<SShapeS
     for ( auto &itCurrentShape : iCurrentShape )
     {
       if (m_projectionSurfaceVec.empty()) continue;;
-      if (itCurrentShape.aProjectedEdgeVec.size()) continue;;
+      if (!itCurrentShape.aProjectedEdgeVec.empty()) continue;;
       if (!itCurrentShape.aProjectedFace.IsNull()) continue;;
-      if (itCurrentShape.aProjectedWireVec.size()) continue;;
+      if (!itCurrentShape.aProjectedWireVec.empty()) continue;;
 
       if (!itCurrentShape.aFace.IsNull())
       {
         get_all_wire_from_face(itCurrentShape);
-        for (auto itWire : itCurrentShape.aWireVec)
+        for (const auto& itWire : itCurrentShape.aWireVec)
         {
           BRepProj_Projection aProjection(itWire, itCurrentShape.surfaceToProject, itCurrentShape.aProjectionDir);
           double minDistance = std::numeric_limits<double>::max();
@@ -523,15 +555,15 @@ TopoDS_Shape PartGui::DlgProjectionOnSurface::create_compound(const std::vector<
   TopoDS_Builder aBuilder;
   aBuilder.MakeCompound(aCompound);
 
-  for (auto it : iShapeVec)
+  for (const auto& it : iShapeVec)
   {
     if ( m_currentShowType == "edges" )
     {
-      for (auto it2 : it.aProjectedEdgeVec)
+      for (const auto& it2 : it.aProjectedEdgeVec)
       {
         aBuilder.Add(aCompound, it2);
       }
-      for (auto it2 : it.aProjectedWireVec)
+      for (const auto& it2 : it.aProjectedWireVec)
       {
         aBuilder.Add(aCompound, it2);
       }
@@ -541,7 +573,7 @@ TopoDS_Shape PartGui::DlgProjectionOnSurface::create_compound(const std::vector<
     {
       if (it.aProjectedFace.IsNull())
       {
-        for (auto it2 : it.aProjectedWireVec)
+        for (const auto& it2 : it.aProjectedWireVec)
         {
           if (!it2.IsNull())
           {
@@ -562,17 +594,17 @@ TopoDS_Shape PartGui::DlgProjectionOnSurface::create_compound(const std::vector<
       {
         aBuilder.Add(aCompound, it.aProjectedFace);
       }
-      else if (it.aProjectedWireVec.size())
+      else if (!it.aProjectedWireVec.empty())
       {
-        for ( auto itWire : it.aProjectedWireVec )
+        for (const auto& itWire : it.aProjectedWireVec )
         {
           if ( itWire.IsNull() ) continue;
           aBuilder.Add(aCompound, itWire);
         }
       }
-      else if (it.aProjectedEdgeVec.size())
+      else if (!it.aProjectedEdgeVec.empty())
       {
-        for (auto itEdge : it.aProjectedEdgeVec)
+        for (const auto& itEdge : it.aProjectedEdgeVec)
         {
           if (itEdge.IsNull()) continue;
           aBuilder.Add(aCompound, itEdge);
@@ -720,7 +752,7 @@ void PartGui::DlgProjectionOnSurface::create_projection_face_from_wire(std::vect
 
       //create a wire of all edges in parametric space on the surface of the face to projected
       // --> otherwise BRepBuilderAPI_MakeFace can not make a face from the wire!
-      for (auto itWireVec : itCurrentShape.aProjectedWireVec)
+      for (const auto& itWireVec : itCurrentShape.aProjectedWireVec)
       {
         std::vector<TopoDS_Shape> edgeVec;
         for (TopExp_Explorer aExplorer(itWireVec, TopAbs_EDGE); aExplorer.More(); aExplorer.Next())
@@ -816,7 +848,7 @@ TopoDS_Wire PartGui::DlgProjectionOnSurface::sort_and_heal_wire(const std::vecto
   Handle(TopTools_HSequenceOfShape) aWireHandle;
   Handle(TopTools_HSequenceOfShape) aWireWireHandle;
 
-  for (auto it : iEdgeVec)
+  for (const auto& it : iEdgeVec)
   {
     shapeList->Append(it);
   }
@@ -892,7 +924,7 @@ void PartGui::DlgProjectionOnSurface::store_wire_in_vector(const SShapeStore& iC
   }
 
   std::vector<TopoDS_Edge> edgeVec;
-  for ( auto it : aWireVec )
+  for (const auto& it : aWireVec )
   {
     bool edgeExists = false;
     for (TopExp_Explorer aExplorer(it, TopAbs_EDGE); aExplorer.More(); aExplorer.Next())
@@ -912,7 +944,7 @@ void PartGui::DlgProjectionOnSurface::store_wire_in_vector(const SShapeStore& iC
   if (indexMap.IsEmpty())
       return;
 
-  for ( auto it : edgeVec )
+  for (const auto& it : edgeVec )
   {
     if ( it.IsSame(iCurrentShape.inputShape)) continue;
     if (!indexMap.Contains(it))
@@ -978,7 +1010,7 @@ void PartGui::DlgProjectionOnSurface::transform_shape_to_global_position(TopoDS_
   }
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonAddProjFace_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonAddProjFaceClicked()
 {
   if (ui->pushButtonAddProjFace->isChecked())
   {
@@ -998,32 +1030,32 @@ void PartGui::DlgProjectionOnSurface::on_pushButtonAddProjFace_clicked()
     filterFace = nullptr;
   }
 }
-void PartGui::DlgProjectionOnSurface::on_radioButtonShowAll_clicked()
+void PartGui::DlgProjectionOnSurface::onRadioButtonShowAllClicked()
 {
   m_currentShowType = "all";
   show_projected_shapes(m_shapeVec);
 }
 
-void PartGui::DlgProjectionOnSurface::on_radioButtonFaces_clicked()
+void PartGui::DlgProjectionOnSurface::onRadioButtonFacesClicked()
 {
   m_currentShowType = "faces";
   show_projected_shapes(m_shapeVec);
 }
 
-void PartGui::DlgProjectionOnSurface::on_radioButtonEdges_clicked()
+void PartGui::DlgProjectionOnSurface::onRadioButtonEdgesClicked()
 {
   m_currentShowType = "edges";
   show_projected_shapes(m_shapeVec);
 }
 
-void PartGui::DlgProjectionOnSurface::on_doubleSpinBoxExtrudeHeight_valueChanged(double arg1)
+void PartGui::DlgProjectionOnSurface::onDoubleSpinBoxExtrudeHeightValueChanged(double arg1)
 {
   Q_UNUSED(arg1);
   create_face_extrude(m_shapeVec);
   show_projected_shapes(m_shapeVec);
 }
 
-void PartGui::DlgProjectionOnSurface::on_pushButtonAddWire_clicked()
+void PartGui::DlgProjectionOnSurface::onPushButtonAddWireClicked()
 {
   if (ui->pushButtonAddWire->isChecked())
   {
@@ -1035,7 +1067,7 @@ void PartGui::DlgProjectionOnSurface::on_pushButtonAddWire_clicked()
       Gui::Selection().addSelectionGate(filterEdge);
     }
     ui->radioButtonEdges->setChecked(true);
-    on_radioButtonEdges_clicked();
+    onRadioButtonEdgesClicked();
   }
   else
   {
@@ -1046,7 +1078,7 @@ void PartGui::DlgProjectionOnSurface::on_pushButtonAddWire_clicked()
   }
 }
 
-void PartGui::DlgProjectionOnSurface::on_doubleSpinBoxSolidDepth_valueChanged(double arg1)
+void PartGui::DlgProjectionOnSurface::onDoubleSpinBoxSolidDepthValueChanged(double arg1)
 {
   auto valX = ui->doubleSpinBoxDirX->value();
   auto valY = ui->doubleSpinBoxDirY->value();
