@@ -20,24 +20,22 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
+
 #ifndef _PreComp_
-# include <QMessageBox>
-# include <QRegExp>
-# include <QTreeWidget>
-# include <TopoDS_Shape.hxx>
-# include <TopExp_Explorer.hxx>
+
+// to avoid compiler warnings of redefining contents of basic.h
+// later by #include <Gui/ViewProvider.h>
+# define _USE_MATH_DEFINES
+# include <cmath>
+
 # include <cfloat>
-# include <Inventor/system/inttypes.h>
+# include <QMessageBox>
+# include <QRegularExpression>
+# include <QTreeWidget>
 #endif
 
-#include "Mirroring.h"
-#include "ui_Mirroring.h"
-#include "../App/PartFeature.h"
-#include <Base/Exception.h>
 #include <Base/Tools.h>
-#include <Base/UnitsApi.h>
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObject.h>
@@ -51,6 +49,11 @@
 #include <Gui/Utilities.h>
 #include <Gui/ViewProvider.h>
 #include <Gui/WaitCursor.h>
+#include <Mod/Part/App/PartFeature.h>
+
+#include "Mirroring.h"
+#include "ui_Mirroring.h"
+
 
 using namespace PartGui;
 
@@ -74,7 +77,7 @@ Mirroring::Mirroring(QWidget* parent)
     sel.applyFrom(Gui::Selection().getObjectsOfType(App::Part::getClassTypeId()));
 }
 
-/*  
+/*
  *  Destroys the object and frees any allocated resources
  */
 Mirroring::~Mirroring()
@@ -107,7 +110,7 @@ void Mirroring::findShapes()
         if (!shape.isNull()) {
             QString label = QString::fromUtf8((*it)->Label.getValue());
             QString name = QString::fromLatin1((*it)->getNameInDocument());
-            
+
             QTreeWidgetItem* child = new QTreeWidgetItem();
             child->setText(0, label);
             child->setToolTip(0, label);
@@ -139,7 +142,7 @@ bool Mirroring::accept()
     activeDoc->openTransaction("Mirroring");
 
     QString shape, label;
-    QRegExp rx(QString::fromLatin1(" \\(Mirror #\\d+\\)$"));
+    QRegularExpression rx(QString::fromLatin1(" \\(Mirror #\\d+\\)$"));
     QList<QTreeWidgetItem *> items = ui->shapes->selectedItems();
     float normx=0, normy=0, normz=0;
     int index = ui->comboBox->currentIndex();
@@ -171,7 +174,7 @@ bool Mirroring::accept()
             "__doc__.ActiveObject.Normal=(%4,%5,%6)\n"
             "__doc__.ActiveObject.Base=(%7,%8,%9)\n"
             "del __doc__")
-            .arg(this->document).arg(shape).arg(label)
+            .arg(this->document, shape, label)
             .arg(normx).arg(normy).arg(normz)
             .arg(basex).arg(basey).arg(basez);
         Gui::Command::runCommand(Gui::Command::App, code.toLatin1());
