@@ -40,9 +40,9 @@ class PartGuiExport PropertyEnumAttacherItem: public Gui::PropertyEditor::Proper
 public:
     PROPERTYITEM_HEADER
 
-    virtual QWidget* createEditor(QWidget* parent, const QObject* receiver, const char* method) const;
-    virtual void setEditorData(QWidget* editor, const QVariant& data) const;
-    virtual QVariant editorData(QWidget* editor) const;
+    QWidget* createEditor(QWidget* parent, const QObject* receiver, const char* method) const override;
+    void setEditorData(QWidget* editor, const QVariant& data) const override;
+    QVariant editorData(QWidget* editor) const override;
 
 protected Q_SLOTS:
     void openTask();
