@@ -37,7 +37,7 @@ class SoTextureCoordinateBundle;
 namespace PartGui {
 
 class PartGuiExport SoBrepPointSet : public SoPointSet {
-    typedef SoPointSet inherited;
+    using inherited = SoPointSet;
 
     SO_NODE_HEADER(SoBrepPointSet);
 
@@ -46,16 +46,16 @@ public:
     SoBrepPointSet();
 
 protected:
-    virtual ~SoBrepPointSet() {};
-    virtual void GLRender(SoGLRenderAction *action);
-    virtual void GLRenderBelowPath(SoGLRenderAction * action);
-    virtual void doAction(SoAction* action); 
+    ~SoBrepPointSet() override {}
+    void GLRender(SoGLRenderAction *action) override;
+    void GLRenderBelowPath(SoGLRenderAction * action) override;
+    void doAction(SoAction* action) override;
 
-    virtual void getBoundingBox(SoGetBoundingBoxAction * action);
+    void getBoundingBox(SoGetBoundingBoxAction * action) override;
 
 private:
-    typedef Gui::SoFCSelectionContext SelContext;
-    typedef Gui::SoFCSelectionContextPtr SelContextPtr;
+    using SelContext = Gui::SoFCSelectionContext;
+    using SelContextPtr = Gui::SoFCSelectionContextPtr;
     void renderHighlight(SoGLRenderAction *action, SelContextPtr);
     void renderSelection(SoGLRenderAction *action, SelContextPtr, bool push=true);
 
