@@ -78,7 +78,7 @@ public:
             : Gui::SelectionFilterGate(nullPointer())
         {
         }
-        bool allow(App::Document* /*pDoc*/, App::DocumentObject*pObj, const char*sSubName)
+        bool allow(App::Document* /*pDoc*/, App::DocumentObject*pObj, const char*sSubName) override
         {
             if (!sSubName || sSubName[0] == '\0') {
                 // If selecting again the same edge the passed sub-element is empty. If the whole
@@ -136,10 +136,12 @@ SweepWidget::SweepWidget(QWidget* parent)
     d->ui.selector->setSelectedLabel(tr("Selected profiles"));
     d->ui.labelPath->clear();
 
-    connect(d->ui.selector->availableTreeWidget(), SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)),
-            this, SLOT(onCurrentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)));
-    connect(d->ui.selector->selectedTreeWidget(), SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)),
-            this, SLOT(onCurrentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)));
+    connect(d->ui.buttonPath, &QPushButton::toggled,
+            this, &SweepWidget::onButtonPathToggled);
+    connect(d->ui.selector->availableTreeWidget(), &QTreeWidget::currentItemChanged,
+            this, &SweepWidget::onCurrentItemChanged);
+    connect(d->ui.selector->selectedTreeWidget(), &QTreeWidget::currentItemChanged,
+            this, &SweepWidget::onCurrentItemChanged);
 
     findShapes();
 }
@@ -205,7 +207,7 @@ void SweepWidget::findShapes()
             shape.ShapeType() == TopAbs_VERTEX) {
             QString label = QString::fromUtf8((*it)->Label.getValue());
             QString name = QString::fromLatin1((*it)->getNameInDocument());
-            
+
             QTreeWidgetItem* child = new QTreeWidgetItem();
             child->setText(0, label);
             child->setToolTip(0, label);
@@ -355,11 +357,11 @@ bool SweepWidget::accept()
             "App.getDocument('%5').ActiveObject.Solid=%3\n"
             "App.getDocument('%5').ActiveObject.Frenet=%4\n"
             )
-            .arg(list)
-            .arg(QLatin1String(selection.c_str()))
-            .arg(solid)
-            .arg(frenet)
-            .arg(QString::fromLatin1(d->document.c_str()));
+            .arg(list,
+                 QLatin1String(selection.c_str()),
+                 solid,
+                 frenet,
+                 QString::fromLatin1(d->document.c_str()));
 
         Gui::Document* doc = Gui::Application::Instance->getDocument(d->document.c_str());
         if (!doc)
@@ -376,7 +378,7 @@ bool SweepWidget::accept()
         doc->commitCommand();
     }
     catch (const Base::Exception& e) {
-        QMessageBox::warning(this, tr("Input error"), QString::fromLatin1(e.what()));
+        QMessageBox::warning(this, tr("Input error"), QCoreApplication::translate("Exception", e.what()));
         return false;
     }
 
@@ -402,7 +404,7 @@ void SweepWidget::onCurrentItemChanged(QTreeWidgetItem* current, QTreeWidgetItem
     }
 }
 
-void SweepWidget::on_buttonPath_toggled(bool on)
+void SweepWidget::onButtonPathToggled(bool on)
 {
     if (on) {
         QList<QWidget*> c = this->findChildren<QWidget*>();
@@ -492,7 +494,7 @@ void TaskSweep::clicked(int id)
         }
 
         label->show();
-        QTimer::singleShot(3000, label, SLOT(hide()));
+        QTimer::singleShot(3000, label, &Gui::StatusWidget::hide);
     }
 }
 
