@@ -20,19 +20,14 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-#endif
-
 #include "ViewProviderBox.h"
 
 
 using namespace PartGui;
 using namespace std;
 
-
 //**************************************************************************
 // Construction/Destruction
 
@@ -53,16 +48,16 @@ ViewProviderBox::~ViewProviderBox()
 
 // **********************************************************************************
 
-std::vector<std::string> ViewProviderBox::getDisplayModes(void) const
+std::vector<std::string> ViewProviderBox::getDisplayModes() const
 {
   // get the modes of the father
   std::vector<std::string> StrList;
 
   // add your own modes
-  StrList.push_back("Flat Lines");
-  StrList.push_back("Shaded");
-  StrList.push_back("Wireframe");
-  StrList.push_back("Points");
+  StrList.emplace_back("Flat Lines");
+  StrList.emplace_back("Shaded");
+  StrList.emplace_back("Wireframe");
+  StrList.emplace_back("Points");
 
   return StrList;
 }
