@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
@@ -40,8 +39,8 @@
 # include <TColgp_Array1OfDir.hxx>
 # include <TColgp_Array1OfPnt.hxx>
 # include <TColStd_Array1OfInteger.hxx>
-# include <TopExp_Explorer.hxx>
 # include <TopExp.hxx>
+# include <TopExp_Explorer.hxx>
 # include <TopoDS.hxx>
 # include <TopoDS_Edge.hxx>
 # include <TopoDS_Face.hxx>
@@ -65,7 +64,11 @@
 # include <Inventor/nodes/SoNormal.h>
 # include <Inventor/nodes/SoNormalBinding.h>
 # include <Inventor/nodes/SoPolygonOffset.h>
+# include <Inventor/nodes/SoSeparator.h>
 # include <Inventor/nodes/SoShapeHints.h>
+
+# include <boost/regex.hpp>
+# include <boost/algorithm/string/predicate.hpp>
 #endif
 
 #include <App/Application.h>
@@ -74,11 +77,9 @@
 #include <Base/Parameter.h>
 #include <Base/TimeInfo.h>
 #include <Base/Tools.h>
-#include <boost/algorithm/string/predicate.hpp>
-#include <boost/regex.hpp>
+
 #include <Gui/BitmapFactory.h>
 #include <Gui/Control.h>
-#include <Gui/Selection.h>
 #include <Gui/SoFCSelectionAction.h>
 #include <Gui/SoFCUnifiedSelection.h>
 #include <Gui/ViewParams.h>
@@ -107,7 +108,7 @@ App::PropertyQuantityConstraint::Constraints ViewProviderPartExt::angDeflectionR
 const char* ViewProviderPartExt::LightingEnums[]= {"One side","Two side",nullptr};
 const char* ViewProviderPartExt::DrawStyleEnums[]= {"Solid","Dashed","Dotted","Dashdot",nullptr};
 
-ViewProviderPartExt::ViewProviderPartExt() 
+ViewProviderPartExt::ViewProviderPartExt()
 {
     VisualTouched = true;
     forceUpdateCount = 0;
@@ -118,12 +119,12 @@ ViewProviderPartExt::ViewProviderPartExt()
     float lr,lg,lb;
     lr = ((lcol >> 24) & 0xff) / 255.0; lg = ((lcol >> 16) & 0xff) / 255.0; lb = ((lcol >> 8) & 0xff) / 255.0;
     // get default vertex color
-    unsigned long vcol = Gui::ViewParams::instance()->getDefaultShapeVertexColor(); 
+    unsigned long vcol = Gui::ViewParams::instance()->getDefaultShapeVertexColor();
     float vr,vg,vb;
     vr = ((vcol >> 24) & 0xff) / 255.0; vg = ((vcol >> 16) & 0xff) / 255.0; vb = ((vcol >> 8) & 0xff) / 255.0;
     int lwidth = Gui::ViewParams::instance()->getDefaultShapeLineWidth();
     int psize = Gui::ViewParams::instance()->getDefaultShapePointSize();
-	
+
 
 
     ParameterGrp::handle hPart = App::GetApplication().GetParameterGroupByPath
@@ -154,8 +155,8 @@ ViewProviderPartExt::ViewProviderPartExt()
     vmat.specularColor.set(0.0f,0.0f,0.0f);
     vmat.emissiveColor.set(0.0f,0.0f,0.0f);
     vmat.shininess = 1.0f;
-    vmat.transparency = 0.0f;	
-	
+    vmat.transparency = 0.0f;
+
     ADD_PROPERTY_TYPE(LineMaterial,(lmat), osgroup, App::Prop_None, "Object line material.");
     ADD_PROPERTY_TYPE(PointMaterial,(vmat), osgroup, App::Prop_None, "Object point material.");
     ADD_PROPERTY_TYPE(LineColor, (lmat.diffuseColor), osgroup, App::Prop_None, "Set object line color.");
@@ -172,7 +173,7 @@ ViewProviderPartExt::ViewProviderPartExt()
             "in the 3D view (tessellation). Lower values indicate better quality.\n"
             "The value is in percent of object's size.");
     Deviation.setConstraints(&tessRange);
-    ADD_PROPERTY_TYPE(AngularDeflection,(28.65), osgroup, App::Prop_None,
+    ADD_PROPERTY_TYPE(AngularDeflection,(28.5), osgroup, App::Prop_None,
             "Specify how finely to generate the mesh for rendering on screen or when exporting.\n"
             "The default value is 28.5 degrees, or 0.5 radians. The smaller the value\n"
             "the smoother the appearance in the 3D view, and the finer the mesh that will be exported.");
@@ -253,15 +254,15 @@ void ViewProviderPartExt::onChanged(const App::Property* prop)
 {
     // The lower limit of the deviation has been increased to avoid
     // to freeze the GUI
-    // https://forum.freecadweb.org/viewtopic.php?f=3&t=24912&p=195613
+    // https://forum.freecad.org/viewtopic.php?f=3&t=24912&p=195613
     if (prop == &Deviation) {
-        if(isUpdateForced()||Visibility.getValue()) 
+        if(isUpdateForced()||Visibility.getValue())
             updateVisual();
         else
             VisualTouched = true;
     }
     if (prop == &AngularDeflection) {
-        if(isUpdateForced()||Visibility.getValue()) 
+        if(isUpdateForced()||Visibility.getValue())
             updateVisual();
         else
             VisualTouched = true;
@@ -468,16 +469,16 @@ void ViewProviderPartExt::setDisplayMode(const char* ModeName)
     ViewProviderGeometryObject::setDisplayMode( ModeName );
 }
 
-std::vector<std::string> ViewProviderPartExt::getDisplayModes(void) const
+std::vector<std::string> ViewProviderPartExt::getDisplayModes() const
 {
     // get the modes of the father
     std::vector<std::string> StrList = ViewProviderGeometryObject::getDisplayModes();
 
     // add your own modes
-    StrList.push_back("Flat Lines");
-    StrList.push_back("Shaded");
-    StrList.push_back("Wireframe");
-    StrList.push_back("Points");
+    StrList.emplace_back("Flat Lines");
+    StrList.emplace_back("Shaded");
+    StrList.emplace_back("Wireframe");
+    StrList.emplace_back("Points");
 
     return StrList;
 }
@@ -514,7 +515,7 @@ SoDetail* ViewProviderPartExt::getDetail(const char* subelement) const
     boost::regex ex("^(Face|Edge|Vertex)([1-9][0-9]*)$");
     boost::cmatch what;
 
-    if (boost::regex_match(subelement, what, ex)) {
+    if (subelement && boost::regex_match(subelement, what, ex)) {
         element = what[1].str();
         index = std::atoi(what[2].str().c_str());
 
@@ -786,13 +787,6 @@ void ViewProviderPartExt::setHighlightedPoints(const std::vector<App::Color>& co
         getObject()->touch(true);
     int size = static_cast<int>(colors.size());
     if (size > 1) {
-#if 0
-        int numPoints = coords->point.getNum() - nodeset->startIndex.getValue();
-        if (numPoints != size) {
-            SoDebugError::postWarning("ViewProviderPartExt::setHighlightedPoints",
-                                      "The number of points (%d) doesn't match with the number of colors (%d).", numPoints, size);
-        }
-#endif
         pcPointBind->value = SoMaterialBinding::PER_VERTEX;
         pcPointMaterial->diffuseColor.setNum(size);
         SbColor* ca = pcPointMaterial->diffuseColor.startEditing();
@@ -833,22 +827,22 @@ bool ViewProviderPartExt::loadParameter()
 
 void ViewProviderPartExt::reload()
 {
-    if (loadParameter()) 
+    if (loadParameter())
         updateVisual();
 }
 
 void ViewProviderPartExt::updateData(const App::Property* prop)
 {
     const char *propName = prop->getName();
-    if (propName && (strcmp(propName, "Shape") == 0 || strstr(propName, "Touched") != nullptr)) {
+    if (propName && (strcmp(propName, "Shape") == 0 || strstr(propName, "Touched"))) {
         // calculate the visual only if visible
         if (isUpdateForced() || Visibility.getValue())
             updateVisual();
-        else 
+        else
             VisualTouched = true;
 
         if (!VisualTouched) {
-            if (this->faceset->partIndex.getNum() > 
+            if (this->faceset->partIndex.getNum() >
                 this->pcShapeMaterial->diffuseColor.getNum()) {
                 this->pcFaceBind->value = SoMaterialBinding::OVERALL;
             }
@@ -946,16 +940,31 @@ void ViewProviderPartExt::updateVisual()
 
         // Since OCCT 7.6 a value of equal 0 is not allowed any more, this can happen if a single vertex
         // should be displayed.
-        if (deflection < gp::Resolution())
+        if (deflection < gp::Resolution()) {
             deflection = Precision::Confusion();
+        }
+
+        // For very big objects the computed deflection can become very high and thus leads to a useless
+        // tessellation. To avoid this the upper limit is set to 20.0
+        // See also forum: https://forum.freecad.org/viewtopic.php?t=77521
+        deflection = std::min(deflection, 20.0);
 
         // create or use the mesh on the data structure
-#if OCC_VERSION_HEX >= 0x060600
         Standard_Real AngDeflectionRads = AngularDeflection.getValue() / 180.0 * M_PI;
-        BRepMesh_IncrementalMesh(cShape, deflection, Standard_False, AngDeflectionRads, Standard_True);
+
+#if OCC_VERSION_HEX >= 0x070500
+        IMeshTools_Parameters meshParams;
+        meshParams.Deflection = deflection;
+        meshParams.Relative = Standard_False;
+        meshParams.Angle = AngDeflectionRads;
+        meshParams.InParallel = Standard_True;
+        meshParams.AllowQualityDecrease = Standard_True;
+
+        BRepMesh_IncrementalMesh(cShape, meshParams);
 #else
-        BRepMesh_IncrementalMesh(cShape, deflection);
+        BRepMesh_IncrementalMesh(cShape, deflection, Standard_False, AngDeflectionRads, Standard_True);
 #endif
+
         // We must reset the location here because the transformation data
         // are set in the placement property
         TopLoc_Location aLoc;
@@ -1076,7 +1085,7 @@ void ViewProviderPartExt::updateVisual()
 #endif
             if (NormalsFromUV)
                 Part::Tools::getPointNormals(actFace, mesh, Normals);
-            
+
             for (int g=1;g<=nbTriInFace;g++) {
                 // Get the triangle
                 Standard_Integer N1,N2,N3;
@@ -1157,12 +1166,12 @@ void ViewProviderPartExt::updateVisual()
                 edgeVector.push_back((int32_t)edgeIndex-1);
                 // already processed this index ?
                 if (edgeIdxSet.find(edgeIndex)!=edgeIdxSet.end()) {
-                    
+
                     // this holds the indices of the edge's triangulation to the current polygon
                     Handle(Poly_PolygonOnTriangulation) aPoly = BRep_Tool::PolygonOnTriangulation(curEdge, mesh, aLoc);
                     if (aPoly.IsNull())
                         continue; // polygon does not exist
-                    
+
                     // getting the indexes of the edge polygon
                     const TColStd_Array1OfInteger& indices = aPoly->Nodes();
                     for (Standard_Integer i=indices.Lower();i <= indices.Upper();i++) {
@@ -1191,7 +1200,7 @@ void ViewProviderPartExt::updateVisual()
             }
 
             edgeVector.push_back(-1);
-            
+
             // counting up the per Face offsets
             faceNodeOffset += nbNodesInFace;
             faceTriaOffset += nbTriInFace;
@@ -1239,10 +1248,10 @@ void ViewProviderPartExt::updateVisual()
             verts[faceNodeOffset+i].setValue((float)(pnt.X()),(float)(pnt.Y()),(float)(pnt.Z()));
         }
 
-        // normalize all normals 
+        // normalize all normals
         for (int i = 0; i< numNorms ;i++)
             norms[i].normalize();
-        
+
         std::vector<int32_t> lineSetCoords;
         for (std::map<int, std::vector<int32_t> >::iterator it = lineSetMap.begin(); it != lineSetMap.end(); ++it) {
             lineSetCoords.insert(lineSetCoords.end(), it->second.begin(), it->second.end());
@@ -1277,9 +1286,17 @@ void ViewProviderPartExt::updateVisual()
         // printing some information
         Base::Console().Log("ViewProvider update time: %f s\n",Base::TimeInfo::diffTimeF(start_time,Base::TimeInfo()));
         Base::Console().Log("Shape tria info: Faces:%d Edges:%d Nodes:%d Triangles:%d IdxVec:%d\n",numFaces,numEdges,numNodes,numTriangles,numLines);
+#   else
+    (void)numEdges;
 #   endif
     VisualTouched = false;
+
+    // The material has to be checked again
+    setHighlightedFaces(DiffuseColor.getValues());
+    setHighlightedEdges(LineColorArray.getValues());
+    setHighlightedPoints(PointColorArray.getValue());
 }
+
 void ViewProviderPartExt::forceUpdate(bool enable) {
     if(enable) {
         if(++forceUpdateCount == 1) {
