@@ -20,27 +20,13 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-#endif
-
 #include "ViewProviderImport.h"
-#include <Mod/Part/App/PartFeature.h>
-
-/// Here the FreeCAD includes sorted by Base,App,Gui......
-#include <Base/Console.h>
-#include <Base/Parameter.h>
-#include <Base/Exception.h>
-#include <Base/Sequencer.h>
-#include <Gui/View3DInventorViewer.h>
-#include <App/Application.h>
 
 
 using namespace PartGui;
 
-
 //**************************************************************************
 // Construction/Destruction
 
