@@ -20,23 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-#endif
-
-#include "ViewProviderRuledSurface.h"
+#include <Gui/Application.h>
 #include <Mod/Part/App/PartFeatures.h>
 
-#include <Gui/Application.h>
-#include <Base/Parameter.h>
+#include "ViewProviderRuledSurface.h"
 
 
 using namespace PartGui;
 using namespace std;
 
-
 //**************************************************************************
 // Construction/Destruction
 
@@ -72,11 +66,11 @@ void ViewProviderRuledSurface::updateData(const App::Property* prop)
         //const std::vector<Part::ShapeHistory>& hist = static_cast<const Part::PropertyShapeHistory*>
         //    (prop)->getValues();
     }
-    /*  //The following hides the Children shapes. If the edges from which the Ruled Surface was created 
-     * were selected from the subshapes of another shape, it is likely that one would not want to hide the shape 
+    /*  //The following hides the Children shapes. If the edges from which the Ruled Surface was created
+     * were selected from the subshapes of another shape, it is likely that one would not want to hide the shape
      * hence this section is commented out
-    Part::RuledSurface* pRuledSurface = static_cast<Part::RuledSurface*>(getObject()); 
-    App::DocumentObject *pCurve1 = pRuledSurface->Curve1.getValue(); 
+    Part::RuledSurface* pRuledSurface = static_cast<Part::RuledSurface*>(getObject());
+    App::DocumentObject *pCurve1 = pRuledSurface->Curve1.getValue();
     App::DocumentObject *pCurve2 = pRuledSurface->Curve2.getValue();
     if (pCurve1)
         Gui::Application::Instance->hideViewProvider(pCurve1);
@@ -84,12 +78,12 @@ void ViewProviderRuledSurface::updateData(const App::Property* prop)
         Gui::Application::Instance->hideViewProvider(pCurve2);*/
 
     }
-    
+
 bool ViewProviderRuledSurface::onDelete(const std::vector<std::string> &)
 {
     // get the input shape
-    Part::RuledSurface* pRuledSurface = static_cast<Part::RuledSurface*>(getObject()); 
-    App::DocumentObject *pCurve1 = pRuledSurface->Curve1.getValue(); 
+    Part::RuledSurface* pRuledSurface = static_cast<Part::RuledSurface*>(getObject());
+    App::DocumentObject *pCurve1 = pRuledSurface->Curve1.getValue();
     App::DocumentObject *pCurve2 = pRuledSurface->Curve2.getValue();
     if (pCurve1)
         Gui::Application::Instance->showViewProvider(pCurve1);
@@ -102,16 +96,16 @@ bool ViewProviderRuledSurface::onDelete(const std::vector<std::string> &)
 
 // **********************************************************************************
 
-std::vector<std::string> ViewProviderRuledSurface::getDisplayModes(void) const
+std::vector<std::string> ViewProviderRuledSurface::getDisplayModes() const
 {
   // get the modes of the father
   std::vector<std::string> StrList;
 
   // add your own modes
-  StrList.push_back("Flat Lines");
-  StrList.push_back("Shaded");
-  StrList.push_back("Wireframe");
-  StrList.push_back("Points");
+  StrList.emplace_back("Flat Lines");
+  StrList.emplace_back("Shaded");
+  StrList.emplace_back("Wireframe");
+  StrList.emplace_back("Points");
 
   return StrList;
 }
