@@ -1,8 +1,5 @@
-# FreeCAD init script of the part module  
-# (c) 2001 Juergen Riegel
-
 #***************************************************************************
-#*   (c) Juergen Riegel (juergen.riegel@web.de) 2002                       *   
+#*   Copyright (c) 2001, 2002 Juergen Riegel <juergen.riegel@web.de>       *
 #*                                                                         *
 #*   This file is part of the FreeCAD CAx development system.              *
 #*                                                                         *
@@ -13,26 +10,26 @@
 #*   for detail see the LICENCE text file.                                 *
 #*                                                                         *
 #*   FreeCAD is distributed in the hope that it will be useful,            *
-#*   but WITHOUT ANY WARRANTY; without even the implied warranty of        * 
+#*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 #*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 #*   GNU Lesser General Public License for more details.                   *
 #*                                                                         *
 #*   You should have received a copy of the GNU Library General Public     *
-#*   License along with FreeCAD; if not, write to the Free Software        * 
+#*   License along with FreeCAD; if not, write to the Free Software        *
 #*   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
 #*   USA                                                                   *
 #*                                                                         *
-#*   Juergen Riegel 2002                                                   *
 #***************************************************************************/
 
+# FreeCAD init script of the part module
 
 #FreeCAD.addImportType("CAD formats (*.igs *.iges *.step *.stp *.brep *.brp)","Part")
 #FreeCAD.addExportType("CAD formats (*.igs *.iges *.step *.stp *.brep *.brp)","Part")
-FreeCAD.addImportType("BREP format (*.brep *.brp)","Part")
+FreeCAD.addImportType("BREP format (*.brep *.BREP *.brp *.BRP)","Part")
 FreeCAD.addExportType("BREP format (*.brep *.brp)","Part")
-FreeCAD.addImportType("IGES format (*.iges *.igs)","Part")
+FreeCAD.addImportType("IGES format (*.iges *.IGES *.igs *.IGS)","Part")
 FreeCAD.addExportType("IGES format (*.iges *.igs)","Part")
-FreeCAD.addImportType("STEP with colors (*.step *.stp)","Import")
+FreeCAD.addImportType("STEP with colors (*.step *.STEP *.stp *.STP)","Import")
 FreeCAD.addExportType("STEP with colors (*.step *.stp)","Import")
 
 FreeCAD.__unit_test__ += [ "TestPartApp" ]
