@@ -50,11 +50,11 @@ public:
     /** @name methods override feature */
     //@{
     /// recalculate the feature
-    App::DocumentObjectExecReturn *execute(void) override;
+    App::DocumentObjectExecReturn *execute() override;
     short mustExecute() const override;
 
     /// returns the type name of the view provider
-    const char* getViewProviderName(void) const override {
+    const char* getViewProviderName() const override {
         return "PartDesignGui::ViewProviderBody";
     }
     //@}
@@ -63,8 +63,8 @@ public:
      * Add the feature into the body at the current insert point.
      * The insertion poin is the before next solid after the Tip feature
      */
-    virtual std::vector<App::DocumentObject*> addObject(App::DocumentObject*) override;
-    virtual std::vector< DocumentObject* > addObjects(std::vector< DocumentObject* > obj) override;
+    std::vector<App::DocumentObject*> addObject(App::DocumentObject*) override;
+    std::vector< DocumentObject* > addObjects(std::vector< DocumentObject* > obj) override;
 
     /**
      * Insert the feature into the body after the given feature.
@@ -82,7 +82,7 @@ public:
     void setBaseProperty(App::DocumentObject* feature);
 
     /// Remove the feature from the body
-    virtual std::vector<DocumentObject*> removeObject(DocumentObject* obj) override;
+    std::vector<DocumentObject*> removeObject(DocumentObject* obj) override;
 
     /**
      * Checks if the given document object lays after the current insert point
@@ -91,21 +91,23 @@ public:
     bool isAfterInsertPoint(App::DocumentObject* feature);
 
     /// Return true if the given feature is member of a MultiTransform feature
-    static bool isMemberOfMultiTransform(const App::DocumentObject* f);
+    static bool isMemberOfMultiTransform(const App::DocumentObject *obj);
 
     /**
       * Return true if the given feature is a solid feature allowed in a Body. Currently this is only valid
       * for features derived from PartDesign::Feature
       * Return false if the given feature is a Sketch or a Part::Datum feature
       */
-    static bool isSolidFeature(const App::DocumentObject* f);
+    static bool isSolidFeature(const App::DocumentObject *obj);
 
     /**
       * Return true if the given feature is allowed in a Body. Currently allowed are
       * all features derived from PartDesign::Feature and Part::Datum and sketches
       */
-    static bool isAllowed(const App::DocumentObject* f);
-    virtual bool allowObject(DocumentObject* f) override {return isAllowed(f);}
+    static bool isAllowed(const App::DocumentObject *obj);
+    bool allowObject(DocumentObject *obj) override {
+      return isAllowed(obj);
+    }
 
     /**
      * Return the body which this feature belongs too, or NULL
@@ -113,10 +115,10 @@ public:
      */
     static Body *findBodyOf(const App::DocumentObject* feature);
 
-    PyObject *getPyObject(void) override;
+    PyObject *getPyObject() override;
 
-    virtual std::vector<std::string> getSubObjects(int reason=0) const override;
-    virtual App::DocumentObject *getSubObject(const char *subname,
+    std::vector<std::string> getSubObjects(int reason=0) const override;
+    App::DocumentObject *getSubObject(const char *subname,
         PyObject **pyObj, Base::Matrix4D *pmat, bool transform, int depth) const override;
 
     void setShowTip(bool enable) {
@@ -136,20 +138,20 @@ public:
     App::DocumentObject *getNextSolidFeature(App::DocumentObject* start = nullptr);
 
     // a body is solid if it has features that are solid according to member isSolidFeature.
-    bool isSolid(void);
+    bool isSolid();
 
 protected:
-    virtual void onSettingDocument() override;
+    void onSettingDocument() override;
 
     /// Adjusts the first solid's feature's base on BaseFeature getting set
-    virtual void onChanged (const App::Property* prop) override;
+    void onChanged (const App::Property* prop) override;
 
     /// Creates the corresponding Origin object
-    virtual void setupObject () override;
+    void setupObject () override;
     /// Removes all planes and axis if they are still linked to the document
-    virtual void unsetupObject () override;
+    void unsetupObject () override;
 
-    virtual void onDocumentRestored() override;
+    void onDocumentRestored() override;
 
 private:
     boost::signals2::scoped_connection connection;
