@@ -33,7 +33,7 @@
 using namespace PartDesign;
 
 // returns a string which represents the object e.g. when printed in python
-std::string BodyPy::representation(void) const
+std::string BodyPy::representation() const
 {
     return std::string("<body object>");
 }
@@ -71,7 +71,7 @@ PyObject* BodyPy::insertObject(PyObject *args)
         return nullptr;
     }
 
-    bool after = PyObject_IsTrue(afterPy) ? true : false;
+    bool after = Base::asBoolean(afterPy);
     Body* body = this->getBodyPtr();
 
     try {
