@@ -40,7 +40,7 @@ enum class HelixMode {
 
 class PartDesignExport Helix : public ProfileBased
 {
-    PROPERTY_HEADER(PartDesign::Helix);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Helix);
 
 public:
     Helix();
@@ -64,20 +64,20 @@ public:
 
     /** @name methods override feature */
     //@{
-    App::DocumentObjectExecReturn* execute(void);
-    short mustExecute() const;
+    App::DocumentObjectExecReturn* execute() override;
+    short mustExecute() const override;
     /// returns the type name of the view provider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartDesignGui::ViewProviderHelix";
     }
     //@}
 
     void proposeParameters(bool force = false);
-    double safePitch(void);
+    double safePitch();
 
 protected:
     /// updates Axis from ReferenceAxis
-    void updateAxis(void);
+    void updateAxis();
 
     /// generate helix and move it to the right location.
     TopoDS_Shape generateHelixPath(double startOffset0 = 0.0);
@@ -89,9 +89,9 @@ protected:
     Base::Vector3d getProfileCenterPoint();
 
     // handle changed property types for backward compatibility
-    virtual void handleChangedPropertyType(Base::XMLReader& reader, const char* TypeName, App::Property* prop);
+    void handleChangedPropertyType(Base::XMLReader& reader, const char* TypeName, App::Property* prop) override;
 
-    void onChanged(const App::Property* prop);
+    void onChanged(const App::Property* prop) override;
 
     static const App::PropertyFloatConstraint::Constraints floatTurns;
     static const App::PropertyAngle::Constraints floatAngle;
@@ -106,7 +106,7 @@ private:
 
 class PartDesignExport AdditiveHelix : public Helix {
 
-    PROPERTY_HEADER(PartDesign::AdditiveHelix);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveHelix);
 public:
     AdditiveHelix();
 };
@@ -114,7 +114,7 @@ public:
 
 class PartDesignExport SubtractiveHelix : public Helix {
 
-    PROPERTY_HEADER(PartDesign::SubtractiveHelix);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveHelix);
 public:
     SubtractiveHelix();
 };
