@@ -68,7 +68,7 @@ const char* Hole::DrillPointEnums[]                  = { "Flat", "Angled", nullp
 
 /* "None" profile */
 
-const char* Hole::HoleCutType_None_Enums[]           = { "None", "Counterbore", "Countersink", nullptr };
+const char* Hole::HoleCutType_None_Enums[]           = { "None", "Counterbore", "Countersink", "Counterdrill", nullptr };
 const char* Hole::ThreadSize_None_Enums[]            = { "None", nullptr };
 const char* Hole::ThreadClass_None_Enums[]           = { "None", nullptr };
 
@@ -475,7 +475,11 @@ const Hole::UTSClearanceDefinition Hole::UTSHoleDiameters[22] =
 };
 
 /* ISO coarse metric enums */
-std::vector<std::string> Hole::HoleCutType_ISOmetric_Enums  = { "None", "Counterbore", "Countersink", "Cheesehead (deprecated)", "Countersink socket screw (deprecated)", "Cap screw (deprecated)" };
+std::vector<std::string> Hole::HoleCutType_ISOmetric_Enums = {
+    "None",
+    "Counterbore",
+    "Countersink",
+    "Counterdrill"};
 const char* Hole::ThreadSize_ISOmetric_Enums[]   = { "M1",   "M1.1", "M1.2", "M1.4", "M1.6",
                                                      "M1.8", "M2",   "M2.2", "M2.5", "M3",
                                                      "M3.5", "M4",   "M4.5", "M5",   "M6",
@@ -486,7 +490,11 @@ const char* Hole::ThreadSize_ISOmetric_Enums[]   = { "M1",   "M1.1", "M1.2", "M1
                                                      "M52",  "M56",  "M60",  "M64",  "M68",  nullptr };
 const char* Hole::ThreadClass_ISOmetric_Enums[]  = { "4G", "4H", "5G", "5H", "6G", "6H", "7G", "7H","8G", "8H", nullptr };
 
-std::vector<std::string> Hole::HoleCutType_ISOmetricfine_Enums  = { "None", "Counterbore", "Countersink", "Cheesehead (deprecated)", "Countersink socket screw (deprecated)", "Cap screw (deprecated)" };
+std::vector<std::string> Hole::HoleCutType_ISOmetricfine_Enums = {
+    "None",
+    "Counterbore",
+    "Countersink",
+    "Counterdrill"};
 const char* Hole::ThreadSize_ISOmetricfine_Enums[]   = {
     "M1x0.2",      "M1.1x0.2",    "M1.2x0.2",    "M1.4x0.2",
     "M1.6x0.2",    "M1.8x0.2",    "M2x0.25",     "M2.2x0.25",
@@ -597,7 +605,7 @@ const double Hole::ThreadRunout[ThreadRunout_size][2] = {
 /* Details from https://en.wikipedia.org/wiki/Unified_Thread_Standard */
 
 /* UTS coarse */
-const char* Hole::HoleCutType_UNC_Enums[]  = { "None", "Counterbore", "Countersink", nullptr};
+const char* Hole::HoleCutType_UNC_Enums[]  = { "None", "Counterbore", "Countersink", "Counterdrill", nullptr};
 const char* Hole::ThreadSize_UNC_Enums[]   = { "#1", "#2", "#3", "#4", "#5", "#6",
                                                "#8",  "#10", "#12",
                                                "1/4", "5/16", "3/8", "7/16", "1/2", "9/16",
@@ -608,7 +616,7 @@ const char* Hole::ThreadSize_UNC_Enums[]   = { "#1", "#2", "#3", "#4", "#5", "#6
 const char* Hole::ThreadClass_UNC_Enums[]  = { "1B", "2B", "3B", nullptr };
 
 /* UTS fine */
-const char* Hole::HoleCutType_UNF_Enums[]  = { "None", "Counterbore", "Countersink", nullptr};
+const char* Hole::HoleCutType_UNF_Enums[]  = { "None", "Counterbore", "Countersink", "Counterdrill", nullptr};
 const char* Hole::ThreadSize_UNF_Enums[]   = { "#0", "#1", "#2", "#3", "#4", "#5", "#6",
                                                "#8", "#10", "#12",
                                                "1/4", "5/16", "3/8", "7/16", "1/2", "9/16",
@@ -617,7 +625,7 @@ const char* Hole::ThreadSize_UNF_Enums[]   = { "#0", "#1", "#2", "#3", "#4", "#5
 const char* Hole::ThreadClass_UNF_Enums[]  = { "1B", "2B", "3B", nullptr };
 
 /* UTS extrafine */
-const char* Hole::HoleCutType_UNEF_Enums[] = { "None", "Counterbore", "Countersink", nullptr};
+const char* Hole::HoleCutType_UNEF_Enums[] = { "None", "Counterbore", "Countersink", "Counterdrill", nullptr};
 const char* Hole::ThreadSize_UNEF_Enums[]  = { "#12", "1/4", "5/16", "3/8", "7/16", "1/2",
                                                "9/16", "5/8", "11/16", "3/4", "13/16", "7/8",
                                                "15/16", "1", "1 1/16", "1 1/8", "1 1/4",
@@ -760,7 +768,7 @@ void Hole::updateHoleCutParams()
             HoleCutDepth.setReadOnly(false);
             HoleCutCountersinkAngle.setReadOnly(true);
         }
-        else if (holeCutTypeStr == "Countersink") {
+        else if (holeCutTypeStr == "Countersink"  || holeCutTypeStr == "Counterdrill") {
             // read ISO 10642 values
             const CutDimensionSet& counter = find_cutDimensionSet(threadTypeStr, "ISO 10642");
             if (HoleCutDiameter.getValue() == 0.0 || HoleCutDiameter.getValue() <= diameterVal) {
@@ -776,11 +784,45 @@ void Hole::updateHoleCutParams()
             if (HoleCutCountersinkAngle.getValue() == 0.0) {
                 HoleCutCountersinkAngle.setValue(counter.angle);
             }
+            if (HoleCutDepth.getValue() == 0.0 && holeCutTypeStr == "Counterdrill") {
+                HoleCutDepth.setValue(1.0);
+            }
             HoleCutDiameter.setReadOnly(false);
             HoleCutDepth.setReadOnly(false);
             HoleCutCountersinkAngle.setReadOnly(false);
         }
 
+        // handle since FreeCAD 0.18 deprecated types that were
+        // removed after FreeCAD 0.20
+        if (holeCutTypeStr == "Cheesehead (deprecated)") {
+            HoleCutType.setValue("Counterbore");
+            holeCutTypeStr = "Counterbore";
+            HoleCutDiameter.setValue(diameterVal * 1.6);
+            HoleCutDepth.setValue(diameterVal * 0.6);
+            HoleCutDiameter.setReadOnly(false);
+            HoleCutDepth.setReadOnly(false);
+        }
+        else if (holeCutTypeStr == "Countersink socket screw (deprecated)") {
+            HoleCutType.setValue("Countersink");
+            holeCutTypeStr = "Countersink";
+            HoleCutDiameter.setValue(diameterVal * 2.0);
+            HoleCutDepth.setValue(diameterVal * 0.0);
+            if (HoleCutCountersinkAngle.getValue() == 0.0) {
+                HoleCutCountersinkAngle.setValue(90.0);
+            }
+            HoleCutDiameter.setReadOnly(false);
+            HoleCutDepth.setReadOnly(false);
+            HoleCutCountersinkAngle.setReadOnly(false);
+        }
+        else if (holeCutTypeStr == "Cap screw (deprecated)") {
+            HoleCutType.setValue("Counterbore");
+            holeCutTypeStr = "Counterbore";
+            HoleCutDiameter.setValue(diameterVal * 1.5);
+            HoleCutDepth.setValue(diameterVal * 1.25);
+            HoleCutDiameter.setReadOnly(false);
+            HoleCutDepth.setReadOnly(false);
+        }
+
         // cut definition
         CutDimensionKey key{ threadTypeStr, holeCutTypeStr };
         if (HoleCutTypeMap.count(key)) {
@@ -864,30 +906,6 @@ void Hole::updateHoleCutParams()
             }
         }
 
-        // handle legacy types but don't change user settings for
-        // user defined None, Counterbore and Countersink
-        else if (holeCutTypeStr == "Cheesehead (deprecated)") {
-            HoleCutDiameter.setValue(diameterVal * 1.6);
-            HoleCutDepth.setValue(diameterVal * 0.6);
-            HoleCutDiameter.setReadOnly(false);
-            HoleCutDepth.setReadOnly(false);
-        }
-        else if (holeCutTypeStr == "Countersink socket screw (deprecated)") {
-            HoleCutDiameter.setValue(diameterVal * 2.0);
-            HoleCutDepth.setValue(diameterVal * 0.0);
-            if (HoleCutCountersinkAngle.getValue() == 0.0) {
-                HoleCutCountersinkAngle.setValue(90.0);
-            }
-            HoleCutDiameter.setReadOnly(false);
-            HoleCutDepth.setReadOnly(false);
-            HoleCutCountersinkAngle.setReadOnly(false);
-        }
-        else if (holeCutTypeStr == "Cap screw (deprecated)") {
-            HoleCutDiameter.setValue(diameterVal * 1.5);
-            HoleCutDepth.setValue(diameterVal * 1.25);
-            HoleCutDiameter.setReadOnly(false);
-            HoleCutDepth.setReadOnly(false);
-        }
     }
     else { // we have an UTS profile or none
 
@@ -905,7 +923,7 @@ void Hole::updateHoleCutParams()
             HoleCutDiameter.setReadOnly(false);
             HoleCutDepth.setReadOnly(false);
         }
-        else if (holeCutTypeStr == "Countersink") {
+        else if (holeCutTypeStr == "Countersink" || holeCutTypeStr == "Counterdrill") {
             if (HoleCutDiameter.getValue() == 0.0 || HoleCutDiameter.getValue() <= diameterVal) {
                 HoleCutDiameter.setValue(diameterVal * 1.7);
                 // 82 degrees for UTS, 90 otherwise
@@ -920,6 +938,9 @@ void Hole::updateHoleCutParams()
                 else
                     HoleCutCountersinkAngle.setValue(90.0);
             }
+            if (HoleCutDepth.getValue() == 0.0 && holeCutTypeStr == "Counterdrill") {
+                HoleCutDepth.setValue(1.0);
+            }
             HoleCutDiameter.setReadOnly(false);
             HoleCutDepth.setReadOnly(false);
             HoleCutCountersinkAngle.setReadOnly(false);
@@ -1629,11 +1650,10 @@ static gp_Pnt toPnt(gp_Vec dir)
     return gp_Pnt(dir.X(), dir.Y(), dir.Z());
 }
 
-App::DocumentObjectExecReturn* Hole::execute(void)
+App::DocumentObjectExecReturn* Hole::execute()
 {
      TopoDS_Shape profileshape;
     try {
-
         profileshape = getVerifiedFace();
     }
     catch (const Base::Exception& e) {
@@ -1646,7 +1666,7 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         base = getBaseShape();
     }
     catch (const Base::Exception&) {
-        std::string text(QT_TR_NOOP("The requested feature cannot be created. The reason may be that:\n"
+        std::string text(QT_TRANSLATE_NOOP("Exception", "The requested feature cannot be created. The reason may be that:\n"
             "  - the active Body does not contain a base shape, so there is no\n"
             "  material to be removed;\n"
             "  - the selected sketch does not belong to the active Body."));
@@ -1663,7 +1683,8 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         base.Move(invObjLoc);
 
         if (profileshape.IsNull())
-            return new App::DocumentObjectExecReturn("Hole error: Creating a face from sketch failed");
+            return new App::DocumentObjectExecReturn(
+                QT_TRANSLATE_NOOP("Exception", "Hole error: Creating a face from sketch failed"));
         profileshape.Move(invObjLoc);
 
         /* Build the prototype hole */
@@ -1687,27 +1708,26 @@ App::DocumentObjectExecReturn* Hole::execute(void)
             length = getThroughAllLength();
         }
         else
-            return new App::DocumentObjectExecReturn("Hole error: Unsupported length specification");
+            return new App::DocumentObjectExecReturn(
+                QT_TRANSLATE_NOOP("Exception", "Hole error: Unsupported length specification"));
 
         if (length <= 0.0)
-            return new App::DocumentObjectExecReturn("Hole error: Invalid hole depth");
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Invalid hole depth"));
 
         BRepBuilderAPI_MakeWire mkWire;
         const std::string holeCutType = HoleCutType.getValueAsString();
         const std::string threadType = ThreadType.getValueAsString();
         bool isCountersink = (holeCutType == "Countersink" ||
-            holeCutType == "Countersink socket screw (deprecated)" ||
             isDynamicCountersink(threadType, holeCutType));
         bool isCounterbore = (holeCutType == "Counterbore" ||
-            holeCutType == "Cheesehead (deprecated)" ||
-            holeCutType == "Cap screw (deprecated)" ||
             isDynamicCounterbore(threadType, holeCutType));
+        bool isCounterdrill = (holeCutType == "Counterdrill");
 
-        double TaperedAngleVal = Tapered.getValue() ? Base::toRadians(TaperedAngle.getValue()) : Base::toRadians(90.0);
+        double TaperedAngleVal =
+            Tapered.getValue() ? Base::toRadians(TaperedAngle.getValue()) : Base::toRadians(90.0);
         double radiusBottom = Diameter.getValue() / 2.0 - length / tan(TaperedAngleVal);
 
         double radius = Diameter.getValue() / 2.0;
-        double holeCutRadius = HoleCutDiameter.getValue() / 2.0;
         gp_Pnt firstPoint(0, 0, 0);
         gp_Pnt lastPoint(0, 0, 0);
         double lengthCounter = 0.0;
@@ -1715,46 +1735,36 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         double zPosCounter = 0.0;
 
         if (TaperedAngleVal <= 0.0 || TaperedAngleVal > Base::toRadians(180.0))
-            return new App::DocumentObjectExecReturn("Hole error: Invalid taper angle");
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Invalid taper angle"));
 
-        if (isCountersink) {
+        if (isCountersink || isCounterbore || isCounterdrill) {
+            double holeCutRadius = HoleCutDiameter.getValue() / 2.0;
+            double holeCutDepth = HoleCutDepth.getValue();
             double countersinkAngle = Base::toRadians(HoleCutCountersinkAngle.getValue() / 2.0);
 
-            if (countersinkAngle <= 0 || countersinkAngle > Base::toRadians(180.0))
-                return new App::DocumentObjectExecReturn("Hole error: Invalid countersink angle");
+            if (isCounterbore) {
+                // Counterbore is rendered the same way as a countersink, but with a hardcoded
+                // angle of 90deg
+                countersinkAngle = Base::toRadians(90.0);
+            }
+
+            if (isCountersink) {
+                holeCutDepth = 0.0;
+                // We cannot recalculate the HoleCutDiameter because the previous HoleCutDepth
+                // is unknown. Therefore we cannot know with what HoleCutDepth the current
+                // HoleCutDiameter was calculated.
+            }
 
             if (holeCutRadius < radius)
-                return new App::DocumentObjectExecReturn("Hole error: Hole cut diameter too small");
-
-            // Top point
-            gp_Pnt newPoint = toPnt(holeCutRadius * xDir);
-            mkWire.Add(BRepBuilderAPI_MakeEdge(lastPoint, newPoint));
-            lastPoint = newPoint;
-
-            computeIntersection(gp_Pnt( holeCutRadius, 0, 0 ),
-                                gp_Pnt(holeCutRadius - sin(countersinkAngle), -cos(countersinkAngle), 0),
-                                gp_Pnt(radius, 0, 0),
-                                gp_Pnt(radiusBottom, -length, 0), xPosCounter, zPosCounter);
-            if (-length > zPosCounter)
-                return new App::DocumentObjectExecReturn("Hole error: Invalid countersink");
-
-            lengthCounter = zPosCounter;
-
-            newPoint = toPnt(xPosCounter * xDir + zPosCounter * zDir);
-            mkWire.Add(BRepBuilderAPI_MakeEdge(lastPoint, newPoint));
-            lastPoint = newPoint;
-        }
-        else if (isCounterbore) {
-            double holeCutDepth = HoleCutDepth.getValue();
-
-            if (holeCutDepth <= 0.0)
-                return new App::DocumentObjectExecReturn("Hole error: Hole cut depth must be greater than zero");
+                return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Hole cut diameter too small"));
 
             if (holeCutDepth > length)
-                return new App::DocumentObjectExecReturn("Hole error: Hole cut depth must be less than hole depth");
+                return new App::DocumentObjectExecReturn(
+                    QT_TRANSLATE_NOOP("Exception", "Hole error: Hole cut depth must be less than hole depth"));
 
-            if (holeCutRadius < radius)
-                return new App::DocumentObjectExecReturn("Hole error: Hole cut diameter too small");
+            if (holeCutDepth < 0.0)
+                return new App::DocumentObjectExecReturn(
+                    QT_TRANSLATE_NOOP("Exception", "Hole error: Hole cut depth must be greater or equal to zero"));
 
             // Top point
             gp_Pnt newPoint = toPnt(holeCutRadius * xDir);
@@ -1762,15 +1772,21 @@ App::DocumentObjectExecReturn* Hole::execute(void)
             lastPoint = newPoint;
 
             // Bottom of counterbore
-            newPoint = toPnt(holeCutRadius * xDir - holeCutDepth * zDir);
-            mkWire.Add(BRepBuilderAPI_MakeEdge(lastPoint, newPoint));
-            lastPoint = newPoint;
+            if (holeCutDepth > 0.0) {
+                newPoint = toPnt(holeCutRadius * xDir - holeCutDepth * zDir);
+                mkWire.Add(BRepBuilderAPI_MakeEdge(lastPoint, newPoint));
+                lastPoint = newPoint;
+            }
 
             // Compute intersection of tapered edge and line at bottom of counterbore hole
-            computeIntersection(gp_Pnt(0, -holeCutDepth, 0),
-                                gp_Pnt(holeCutRadius, -holeCutDepth, 0),
+            computeIntersection(gp_Pnt(holeCutRadius, -holeCutDepth, 0 ),
+                                gp_Pnt(holeCutRadius - sin(countersinkAngle),
+                                       -cos(countersinkAngle) - holeCutDepth, 0),
                                 gp_Pnt(radius, 0, 0),
-                                gp_Pnt(radiusBottom, length, 0), xPosCounter, zPosCounter);
+                                gp_Pnt(radiusBottom, -length, 0), xPosCounter, zPosCounter);
+
+            if (-length > zPosCounter)
+                return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Invalid countersink"));
 
             lengthCounter = zPosCounter;
             newPoint = toPnt(xPosCounter * xDir + zPosCounter * zDir);
@@ -1803,7 +1819,7 @@ App::DocumentObjectExecReturn* Hole::execute(void)
 
             // the angle is in any case > 0 and < 90 but nevertheless this safeguard:
             if (drillPointAngle <= 0.0 || drillPointAngle >= Base::toRadians(180.0))
-                return new App::DocumentObjectExecReturn("Hole error: Invalid drill point angle");
+                return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Invalid drill point angle"));
 
             // if option to take drill point size into account
             // the next wire point is the intersection of the drill edge and the hole edge
@@ -1813,7 +1829,7 @@ App::DocumentObjectExecReturn* Hole::execute(void)
                     gp_Pnt(radius, 0, 0),
                     gp_Pnt(radiusBottom, -length, 0), xPosDrill, zPosDrill);
                 if (zPosDrill > 0 || zPosDrill >= lengthCounter)
-                    return new App::DocumentObjectExecReturn("Hole error: Invalid drill point");
+                    return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Invalid drill point"));
 
                 newPoint = toPnt(xPosDrill * xDir + zPosDrill * zDir);
                 mkWire.Add(BRepBuilderAPI_MakeEdge(lastPoint, newPoint));
@@ -1847,11 +1863,11 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         double angle = Base::toRadians<double>(360.0);
         BRepPrimAPI_MakeRevol RevolMaker(face, gp_Ax1(firstPoint, zDir), angle);
         if (!RevolMaker.IsDone())
-            return new App::DocumentObjectExecReturn("Hole error: Could not revolve sketch");
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Could not revolve sketch"));
 
         TopoDS_Shape protoHole = RevolMaker.Shape();
         if (protoHole.IsNull())
-            return new App::DocumentObjectExecReturn("Hole error: Resulting shape is empty");
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Hole error: Resulting shape is empty"));
 
 
         // Make thread
@@ -1861,7 +1877,7 @@ App::DocumentObjectExecReturn* Hole::execute(void)
             // fuse the thread to the hole
             BRepAlgoAPI_Fuse mkFuse(protoHole, protoThread);
             if (!mkFuse.IsDone())
-                return new App::DocumentObjectExecReturn("Error: Adding the thread failed");
+                return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Error: Adding the thread failed"));
 
             // we reuse the name protoHole (only now it is threaded)
             protoHole = mkFuse.Shape();
@@ -1873,9 +1889,7 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         // For some reason it is faster to do the cut through a BooleanOperation.
         BRepAlgoAPI_Cut mkBool(base, holes);
         if (!mkBool.IsDone()) {
-            std::stringstream error;
-            error << "Boolean operation failed";
-            return new App::DocumentObjectExecReturn(error.str());
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Boolean operation failed"));
         }
         TopoDS_Shape result = mkBool.Shape();
 
@@ -1883,14 +1897,15 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         // We have to get the solids (fuse sometimes creates compounds)
         base = getSolid(result);
         if (base.IsNull())
-            return new App::DocumentObjectExecReturn("Hole: Resulting shape is not a solid");
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception", "Resulting shape is not a solid"));
         base = refineShapeIfActive(base);
 
 
 
         int solidCount = countSolids(base);
         if (solidCount > 1) {
-            return new App::DocumentObjectExecReturn("Hole: Result has multiple solids. This is not supported at this time.");
+            return new App::DocumentObjectExecReturn(
+                QT_TRANSLATE_NOOP("Exception", "Result has multiple solids: that is not currently supported."));
         }
 
         this->Shape.setValue(base);
@@ -1898,11 +1913,13 @@ App::DocumentObjectExecReturn* Hole::execute(void)
         return App::DocumentObject::StdReturn;
     }
     catch (Standard_Failure& e) {
-        if (std::string(e.GetMessageString()) == "TopoDS::Face" &&
-            (std::string(DepthType.getValueAsString()) == "UpToFirst" || std::string(DepthType.getValueAsString()) == "UpToFace"))
-            return new App::DocumentObjectExecReturn("Could not create face from sketch.\n"
+        if (std::string(e.GetMessageString()) == "TopoDS::Face"
+            && (std::string(DepthType.getValueAsString()) == "UpToFirst"
+                || std::string(DepthType.getValueAsString()) == "UpToFace"))
+            return new App::DocumentObjectExecReturn(QT_TRANSLATE_NOOP("Exception",
+                "Could not create face from sketch.\n"
                 "Intersecting sketch entities or multiple faces in a sketch are not allowed "
-                "for making a pocket up to a face.");
+                "for making a pocket up to a face."));
         else
             return new App::DocumentObjectExecReturn(e.GetMessageString());
     }
@@ -1911,7 +1928,8 @@ App::DocumentObjectExecReturn* Hole::execute(void)
     }
 }
 
-void Hole::rotateToNormal(const gp_Dir& helixAxis, const gp_Dir& normalAxis, TopoDS_Shape& helixShape) const
+void Hole::rotateToNormal(const gp_Dir& helixAxis, const gp_Dir& normalAxis,
+                          TopoDS_Shape& helixShape) const
 {
     auto getRotationAxis = [](const gp_Dir& dir1, const gp_Dir& dir2, gp_Dir& dir3, double& angle) {
         if (dir1.IsEqual(dir2, Precision::Angular()))
@@ -1959,12 +1977,14 @@ gp_Vec Hole::computePerpendicular(const gp_Vec& zDir) const
     else
         xDir = gp_Vec(0, -zDir.Z(), zDir.Y());
 
-    // Normalize xDir; this is needed as the computation above does not necessarily give a unit-length vector.
+    // Normalize xDir; this is needed as the computation above does not necessarily give
+    // a unit-length vector.
     xDir.Normalize();
     return xDir;
 }
 
-TopoDS_Compound Hole::findHoles(const TopoDS_Shape& profileshape, const TopoDS_Shape& protohole) const
+TopoDS_Compound Hole::findHoles(const TopoDS_Shape& profileshape,
+                                const TopoDS_Shape& protohole) const
 {
     BRep_Builder builder;
     TopoDS_Compound holes;
@@ -2002,10 +2022,10 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
     int threadType = ThreadType.getValue();
     int threadSize = ThreadSize.getValue();
     if (threadType < 0) {
-        throw Base::IndexError("Thread type out of range");
+        throw Base::IndexError(QT_TRANSLATE_NOOP("Exception", "Thread type out of range"));
     }
     if (threadSize < 0) {
-        throw Base::IndexError("Thread size out of range");
+        throw Base::IndexError(QT_TRANSLATE_NOOP("Exception", "Thread size out of range"));
     }
 
     bool leftHanded = (bool)ThreadDirection.getValue();
@@ -2014,11 +2034,11 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
     // this is the same for all metric and UTS threads as stated here:
     // https://en.wikipedia.org/wiki/File:ISO_and_UTS_Thread_Dimensions.svg
     // Note that in the ISO standard, Dmaj is called D, which has been followed here.
-    double D = threadDescription[threadType][threadSize].diameter;  // Major diameter
-    double P = getThreadPitch();
-    double H = sqrt(3) / 2 * P;                                                           // Height of fundamental triangle
+    double Diam = threadDescription[threadType][threadSize].diameter; // major diameter
+    double Pitch = getThreadPitch();
+    double H = sqrt(3) / 2 * Pitch; // height of fundamental triangle
 
-    double clearance;                                                                     // clearance to be added on the diameter
+    double clearance; // clearance to be added on the diameter
     if (UseCustomThreadClearance.getValue())
         clearance = CustomThreadClearance.getValue();
     else
@@ -2026,13 +2046,13 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
 
     // construct the cross section going counter-clockwise
     // for graphical explanation of geometrical construction of p1-p6 see:
-    // https://forum.freecadweb.org/viewtopic.php?f=19&t=54284#p466570
-    gp_Pnt p1 = toPnt((D / 2 - 5 * H / 8 + clearance / 2) * xDir + P / 8 * zDir);
-    gp_Pnt p2 = toPnt((D / 2 + clearance / 2) * xDir + 7 * P / 16 * zDir);
-    gp_Pnt p3 = toPnt((D / 2 + clearance / 2) * xDir + 9 * P / 16 * zDir);
-    gp_Pnt p4 = toPnt((D / 2 - 5 * H / 8 + clearance / 2) * xDir + 7 * P / 8 * zDir);
-    gp_Pnt p5 = toPnt(0.9 * (D / 2 - 5 * H / 8) * xDir + 7 * P / 8 * zDir);
-    gp_Pnt p6 = toPnt(0.9 * (D / 2 - 5 * H / 8) * xDir + P / 8 * zDir);
+    // https://forum.freecad.org/viewtopic.php?f=19&t=54284#p466570
+    gp_Pnt p1 = toPnt((Diam / 2 - 5 * H / 8 + clearance / 2) * xDir + Pitch / 8 * zDir);
+    gp_Pnt p2 = toPnt((Diam / 2 + clearance / 2) * xDir + 7 * Pitch / 16 * zDir);
+    gp_Pnt p3 = toPnt((Diam / 2 + clearance / 2) * xDir + 9 * Pitch / 16 * zDir);
+    gp_Pnt p4 = toPnt((Diam / 2 - 5 * H / 8 + clearance / 2) * xDir + 7 * Pitch / 8 * zDir);
+    gp_Pnt p5 = toPnt(0.9 * (Diam / 2 - 5 * H / 8) * xDir + 7 * Pitch / 8 * zDir);
+    gp_Pnt p6 = toPnt(0.9 * (Diam / 2 - 5 * H / 8) * xDir + Pitch / 8 * zDir);
 
     BRepBuilderAPI_MakeWire mkThreadWire;
     mkThreadWire.Add(BRepBuilderAPI_MakeEdge(p1, p2).Edge());
@@ -2046,7 +2066,7 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
 
     //create the helix path
     double threadDepth = ThreadDepth.getValue();
-    double helixLength = threadDepth + P / 2;
+    double helixLength = threadDepth + Pitch / 2;
     double holeDepth = Depth.getValue();
     std::string threadDepthMethod(ThreadDepthType.getValueAsString());
     std::string depthMethod(DepthType.getValueAsString());
@@ -2054,28 +2074,28 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
         if (depthMethod == "ThroughAll") {
             threadDepth = length;
             ThreadDepth.setValue(threadDepth);
-            helixLength = threadDepth + 2 * P;
+            helixLength = threadDepth + 2 * Pitch;
         }
         else if (threadDepthMethod == "Tapped (DIN76)") {
             threadDepth = holeDepth - getThreadRunout();
             ThreadDepth.setValue(threadDepth);
-            helixLength = threadDepth + P / 2;
+            helixLength = threadDepth + Pitch / 2;
         }
         else { // Hole depth
             threadDepth = holeDepth;
             ThreadDepth.setValue(threadDepth);
-            helixLength = threadDepth + P / 8;
+            helixLength = threadDepth + Pitch / 8;
         }
     }
     else {
         if (depthMethod == "Dimension") {
             // the thread must not be deeper than the hole
             // thus the max helixLength is holeDepth + P / 8;
-            if (threadDepth > (holeDepth - P / 2))
-                helixLength = holeDepth + P / 8;
+            if (threadDepth > (holeDepth - Pitch / 2))
+                helixLength = holeDepth + Pitch / 8;
         }
     }
-    TopoDS_Shape helix = TopoShape().makeLongHelix(P, helixLength, D / 2, 0.0, leftHanded);
+    TopoDS_Shape helix = TopoShape().makeLongHelix(Pitch, helixLength, Diam / 2, 0.0, leftHanded);
 
     gp_Pnt origo(0.0, 0.0, 0.0);
     gp_Dir dir_axis1(0.0, 0.0, 1.0);  // pointing along the helix axis, as created.
@@ -2097,7 +2117,7 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
     mkPS.SetMode(true);  //This is for frenet
     mkPS.Add(threadWire);
     if (!mkPS.IsReady())
-        throw Base::CADKernelError("Error: Thread could not be built");
+        throw Base::CADKernelError(QT_TRANSLATE_NOOP("Exception", "Error: Thread could not be built"));
     TopoDS_Shape shell = mkPS.Shape();
 
     // create faces at the ends of the pipe shell
@@ -2122,7 +2142,7 @@ TopoDS_Shape Hole::makeThread(const gp_Vec& xDir, const gp_Vec& zDir, double len
     BRepBuilderAPI_MakeSolid mkSolid;
     mkSolid.Add(TopoDS::Shell(sewer.SewedShape()));
     if (!mkSolid.IsDone())
-        throw Base::CADKernelError("Error: Result is not a solid");
+        throw Base::CADKernelError(QT_TRANSLATE_NOOP("Exception", "Error: Result is not a solid"));
     TopoDS_Shape result = mkSolid.Shape();
 
     // check if the algorithm has confused the inside and outside of the solid
