@@ -43,7 +43,7 @@ static constexpr size_t ThreadRunout_size = 24;
 
 class PartDesignExport Hole : public ProfileBased
 {
-    PROPERTY_HEADER(PartDesign::Hole);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Hole);
 
 public:
     Hole();
@@ -77,14 +77,14 @@ public:
     /** @name methods override feature */
     //@{
     /// recalculate the feature
-    App::DocumentObjectExecReturn *execute(void);
+    App::DocumentObjectExecReturn *execute() override;
 
     /// returns the type name of the view provider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartDesignGui::ViewProviderHole";
     }
     //@}
-    short mustExecute() const;
+    short mustExecute() const override;
 
     typedef struct {
         const char * designation;
@@ -104,12 +104,12 @@ public:
     } UTSClearanceDefinition;
     static const UTSClearanceDefinition UTSHoleDiameters[22];
 
-    virtual void Restore(Base::XMLReader & reader);
+    void Restore(Base::XMLReader & reader) override;
 
     virtual void updateProps();
 
 protected:
-    void onChanged(const App::Property* prop);
+    void onChanged(const App::Property* prop) override;
     static const App::PropertyAngle::Constraints floatAngle;
 
 private:
