@@ -34,7 +34,7 @@ namespace PartDesign
 
 class PartDesignExport PolarPattern : public PartDesign::Transformed
 {
-    PROPERTY_HEADER(PartDesign::PolarPattern);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::PolarPattern);
 
 public:
     PolarPattern();
@@ -46,10 +46,10 @@ public:
 
    /** @name methods override feature */
     //@{
-    short mustExecute() const;
+    short mustExecute() const override;
 
     /// returns the type name of the view provider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartDesignGui::ViewProviderPolarPattern";
     }
     //@}
@@ -64,10 +64,10 @@ public:
       * the given edge, which must be linear.
       * If Reversed is true, the direction of rotation will be opposite.
       */
-    const std::list<gp_Trsf> getTransformations(const std::vector<App::DocumentObject*>);
+    const std::list<gp_Trsf> getTransformations(const std::vector<App::DocumentObject*>) override;
 
 protected:
-    virtual void handleChangedPropertyType(Base::XMLReader& reader, const char* TypeName, App::Property* prop);
+    void handleChangedPropertyType(Base::XMLReader& reader, const char* TypeName, App::Property* prop) override;
     static const App::PropertyIntegerConstraint::Constraints intOccurrences;
     static const App::PropertyAngle::Constraints floatAngle;
 };
