@@ -46,58 +46,58 @@ public:
         Prism,
         Wedge
     };
-    
+
     FeaturePrimitive();
-    
-    virtual const char* getViewProviderName(void) const override {
+
+    const char* getViewProviderName() const override {
         return "PartDesignGui::ViewProviderPrimitive";
     }
     Type         getPrimitiveType() {return primitiveType;}
-    virtual void onChanged(const App::Property* prop) override;
-    virtual PyObject* getPyObject() override;
-    
+    void onChanged(const App::Property* prop) override;
+    PyObject* getPyObject() override;
+
     /// Do nothing, just to suppress warning, must be redefined in derived classes
-    virtual App::DocumentObjectExecReturn* execute() override {
+    App::DocumentObjectExecReturn* execute() override {
         return PartDesign::FeatureAddSub::execute();
     }
 protected:
     void handleChangedPropertyName(Base::XMLReader &reader, const char* TypeName, const char* PropName) override;
     //make the boolean ops with the primitives provided by the derived features
     App::DocumentObjectExecReturn* execute(const TopoDS_Shape& primitiveShape);
-    Type primitiveType = Box;   
+    Type primitiveType = Box;
 };
 
 class PartDesignExport Box : public PartDesign::FeaturePrimitive {
 
-    PROPERTY_HEADER(PartDesign::Box);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Box);
 
 public:
-    
+
     Box();
-    
+
     App::PropertyLength Length,Height,Width;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
-    
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
+
 protected:
-    
+
 };
 
 class PartDesignExport AdditiveBox : public Box {
-    PROPERTY_HEADER(PartDesign::AdditiveBox);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveBox);
+
     AdditiveBox() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveBox : public Box {
-    PROPERTY_HEADER(PartDesign::SubtractiveBox);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveBox);
+
     SubtractiveBox() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -106,34 +106,34 @@ class PartDesignExport SubtractiveBox : public Box {
 
 class PartDesignExport Cylinder : public PartDesign::FeaturePrimitive, public Part::PrismExtension {
 
-    PROPERTY_HEADER(PartDesign::Cylinder);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Cylinder);
 
 public:
-    
+
     Cylinder();
-    
+
     App::PropertyLength Radius;
     App::PropertyLength Height;
     App::PropertyAngle Angle;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
 };
 
 class PartDesignExport AdditiveCylinder : public Cylinder {
-    PROPERTY_HEADER(PartDesign::AdditiveCylinder);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveCylinder);
+
     AdditiveCylinder() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveCylinder : public Cylinder {
-    PROPERTY_HEADER(PartDesign::SubtractiveCylinder);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveCylinder);
+
     SubtractiveCylinder() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -142,38 +142,38 @@ class PartDesignExport SubtractiveCylinder : public Cylinder {
 
 class PartDesignExport Sphere : public PartDesign::FeaturePrimitive {
 
-    PROPERTY_HEADER(PartDesign::Sphere);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Sphere);
 
 public:
-    
+
     Sphere();
-    
+
     App::PropertyLength Radius;
     App::PropertyAngle Angle1;
     App::PropertyAngle Angle2;
     App::PropertyAngle Angle3;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
-    
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
+
 protected:
-    
+
 };
 
 class PartDesignExport AdditiveSphere : public Sphere {
-    PROPERTY_HEADER(PartDesign::AdditiveSphere);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveSphere);
+
     AdditiveSphere() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveSphere : public Sphere {
-    PROPERTY_HEADER(PartDesign::SubtractiveSphere);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveSphere);
+
     SubtractiveSphere() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -181,38 +181,38 @@ class PartDesignExport SubtractiveSphere : public Sphere {
 
 class PartDesignExport Cone : public PartDesign::FeaturePrimitive {
 
-    PROPERTY_HEADER(PartDesign::Cone);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Cone);
 
 public:
-    
+
     Cone();
-    
+
     App::PropertyLength Radius1;
     App::PropertyLength Radius2;
     App::PropertyLength Height;
     App::PropertyAngle  Angle;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
-    
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
+
 protected:
-    
+
 };
 
 class PartDesignExport AdditiveCone : public Cone {
-    PROPERTY_HEADER(PartDesign::AdditiveCone);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveCone);
+
     AdditiveCone() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveCone : public Cone {
-    PROPERTY_HEADER(PartDesign::SubtractiveCone);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveCone);
+
     SubtractiveCone() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -221,40 +221,40 @@ class PartDesignExport SubtractiveCone : public Cone {
 
 class PartDesignExport Ellipsoid : public PartDesign::FeaturePrimitive {
 
-    PROPERTY_HEADER(PartDesign::Ellipsoid);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Ellipsoid);
 
 public:
-    
+
     Ellipsoid();
-    
+
     App::PropertyLength Radius1;
     App::PropertyLength Radius2;
     App::PropertyLength Radius3;
     App::PropertyAngle Angle1;
     App::PropertyAngle Angle2;
     App::PropertyAngle Angle3;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
-    
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
+
 protected:
-    
+
 };
 
 class PartDesignExport AdditiveEllipsoid : public Ellipsoid {
-    PROPERTY_HEADER(PartDesign::AdditiveEllipsoid);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveEllipsoid);
+
     AdditiveEllipsoid() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveEllipsoid : public Ellipsoid {
-    PROPERTY_HEADER(PartDesign::SubtractiveEllipsoid);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveEllipsoid);
+
     SubtractiveEllipsoid() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -263,39 +263,39 @@ class PartDesignExport SubtractiveEllipsoid : public Ellipsoid {
 
 class PartDesignExport Torus : public PartDesign::FeaturePrimitive {
 
-    PROPERTY_HEADER(PartDesign::Torus);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Torus);
 
 public:
-    
+
     Torus();
-    
+
     App::PropertyLength Radius1;
     App::PropertyLength Radius2;
     App::PropertyAngle Angle1;
     App::PropertyAngle Angle2;
     App::PropertyAngle Angle3;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
-    
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
+
 protected:
-    
+
 };
 
 class PartDesignExport AdditiveTorus : public Torus {
-    PROPERTY_HEADER(PartDesign::AdditiveTorus);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveTorus);
+
     AdditiveTorus() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveTorus : public Torus {
-    PROPERTY_HEADER(PartDesign::SubtractiveTorus);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveTorus);
+
     SubtractiveTorus() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -304,7 +304,7 @@ class PartDesignExport SubtractiveTorus : public Torus {
 
 class PartDesignExport Prism : public PartDesign::FeaturePrimitive, public Part::PrismExtension {
 
-    PROPERTY_HEADER(PartDesign::Prism);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Prism);
 
 public:
     Prism();
@@ -312,25 +312,25 @@ public:
     App::PropertyIntegerConstraint Polygon;
     App::PropertyLength Circumradius;
     App::PropertyLength Height;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
 };
 
 class PartDesignExport AdditivePrism : public Prism {
-    PROPERTY_HEADER(PartDesign::AdditivePrism);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditivePrism);
+
     AdditivePrism() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractivePrism : public Prism {
-    PROPERTY_HEADER(PartDesign::SubtractivePrism);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractivePrism);
+
     SubtractivePrism() {
         addSubType = FeatureAddSub::Subtractive;
     }
@@ -339,12 +339,12 @@ class PartDesignExport SubtractivePrism : public Prism {
 
 class PartDesignExport Wedge : public PartDesign::FeaturePrimitive {
 
-    PROPERTY_HEADER(PartDesign::Wedge);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Wedge);
 
 public:
-    
+
     Wedge();
-    
+
     App::PropertyDistance Xmin;
     App::PropertyDistance Ymin;
     App::PropertyDistance Zmin;
@@ -355,28 +355,28 @@ public:
     App::PropertyDistance Zmax;
     App::PropertyDistance Z2max;
     App::PropertyDistance X2max;
-    
+
     /** @name methods override feature */
     //@{
     /// recalculate the Feature
-    App::DocumentObjectExecReturn *execute(void);
-    short mustExecute() const;
-    
+    App::DocumentObjectExecReturn *execute() override;
+    short mustExecute() const override;
+
 protected:
-    
+
 };
 
 class PartDesignExport AdditiveWedge : public Wedge {
-    PROPERTY_HEADER(PartDesign::AdditiveWedge);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::AdditiveWedge);
+
     AdditiveWedge() {
         addSubType = FeatureAddSub::Additive;
     }
 };
 
 class PartDesignExport SubtractiveWedge : public Wedge {
-    PROPERTY_HEADER(PartDesign::SubtractiveWedge);
-    
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::SubtractiveWedge);
+
     SubtractiveWedge() {
         addSubType = FeatureAddSub::Subtractive;
     }
