@@ -33,7 +33,7 @@ namespace PartDesign
 
 class PartDesignExport Scaled : public PartDesign::Transformed
 {
-    PROPERTY_HEADER(PartDesign::Scaled);
+    PROPERTY_HEADER_WITH_OVERRIDE(PartDesign::Scaled);
 
 public:
     Scaled();
@@ -43,10 +43,10 @@ public:
 
    /** @name methods override feature */
     //@{
-    short mustExecute() const;
+    short mustExecute() const override;
 
     /// returns the type name of the view provider
-    const char* getViewProviderName(void) const {
+    const char* getViewProviderName() const override {
         return "PartDesignGui::ViewProviderScaled";
     }
     //@}
@@ -60,7 +60,7 @@ public:
       */
     // Note: We can't just use the Originals property because this will fail if the Scaled feature
     // is being used inside a MultiTransform feature
-    const std::list<gp_Trsf> getTransformations(const std::vector<App::DocumentObject*> originals);
+    const std::list<gp_Trsf> getTransformations(const std::vector<App::DocumentObject*> originals) override;
 };
 
 } //namespace PartDesign
