@@ -39,10 +39,10 @@ class TaskChamferParameters : public TaskDressUpParameters
     Q_OBJECT
 
 public:
-    TaskChamferParameters(ViewProviderDressUp *DressUpView, QWidget *parent=nullptr);
-    ~TaskChamferParameters();
+    explicit TaskChamferParameters(ViewProviderDressUp *DressUpView, QWidget *parent=nullptr);
+    ~TaskChamferParameters() override;
 
-    virtual void apply();
+    void apply() override;
 
 private Q_SLOTS:
     void onTypeChanged(int);
@@ -50,15 +50,15 @@ private Q_SLOTS:
     void onSize2Changed(double);
     void onAngleChanged(double);
     void onFlipDirection(bool);
-    void onRefDeleted(void);
+    void onRefDeleted(void) override;
     void onAddAllEdges(void);
     void onCheckBoxUseAllEdgesToggled(bool checked);
 
 protected:
-    virtual void clearButtons(const selectionModes notThis);
-    bool event(QEvent *e);
-    void changeEvent(QEvent *e);
-    virtual void onSelectionChanged(const Gui::SelectionChanges& msg);
+    void setButtons(const selectionModes mode) override;
+    bool event(QEvent *e) override;
+    void changeEvent(QEvent *e) override;
+    void onSelectionChanged(const Gui::SelectionChanges& msg) override;
 
     int getType(void) const;
     double getSize(void) const;
@@ -78,12 +78,12 @@ class TaskDlgChamferParameters : public TaskDlgDressUpParameters
     Q_OBJECT
 
 public:
-    TaskDlgChamferParameters(ViewProviderChamfer *DressUpView);
-    ~TaskDlgChamferParameters();
+    explicit TaskDlgChamferParameters(ViewProviderChamfer *DressUpView);
+    ~TaskDlgChamferParameters() override;
 
 public:
     /// is called by the framework if the dialog is accepted (Ok)
-    virtual bool accept();
+    bool accept() override;
 };
 
 } //namespace PartDesignGui
