@@ -151,9 +151,9 @@ void TaskExtrudeParameters::setupDialog()
     }
     else if (obj && faceId >= 0) {
         ui->lineFaceName->setText(QString::fromLatin1("%1:%2%3")
-                                  .arg(QString::fromUtf8(obj->Label.getValue()))
-                                  .arg(tr("Face"))
-                                  .arg(faceId));
+                                  .arg(QString::fromUtf8(obj->Label.getValue()),
+                                       tr("Face"),
+                                       QString::number(faceId)));
         ui->lineFaceName->setProperty("FeatureName", QByteArray(obj->getNameInDocument()));
     }
     else {
@@ -626,7 +626,7 @@ void TaskExtrudeParameters::setDirectionMode(int index)
         extrude->UseCustomVector.setValue(false);
     }
 
-    // if we dont use custom direction, only allow to show its direction
+    // if we don't use custom direction, only allow to show its direction
     if (index != DirectionModes::Custom) {
         ui->XDirectionEdit->setEnabled(false);
         ui->YDirectionEdit->setEnabled(false);
@@ -734,9 +734,7 @@ void TaskExtrudeParameters::translateFaceName()
 
         if (ok) {
             ui->lineFaceName->setText(QString::fromLatin1("%1:%2%3")
-                                      .arg(parts[0])
-                                      .arg(tr("Face"))
-                                      .arg(faceId));
+                                      .arg(parts[0], tr("Face")).arg(faceId));
         }
         else {
             ui->lineFaceName->setText(parts[0]);
@@ -744,22 +742,22 @@ void TaskExtrudeParameters::translateFaceName()
     }
 }
 
-double TaskExtrudeParameters::getOffset(void) const
+double TaskExtrudeParameters::getOffset() const
 {
     return ui->offsetEdit->value().getValue();
 }
 
-bool TaskExtrudeParameters::getAlongSketchNormal(void) const
+bool TaskExtrudeParameters::getAlongSketchNormal() const
 {
     return ui->checkBoxAlongDirection->isChecked();
 }
 
-bool TaskExtrudeParameters::getCustom(void) const
+bool TaskExtrudeParameters::getCustom() const
 {
     return (ui->directionCB->currentIndex() == DirectionModes::Custom);
 }
 
-std::string TaskExtrudeParameters::getReferenceAxis(void) const
+std::string TaskExtrudeParameters::getReferenceAxis() const
 {
     std::vector<std::string> sub;
     App::DocumentObject* obj;
@@ -767,37 +765,37 @@ std::string TaskExtrudeParameters::getReferenceAxis(void) const
     return buildLinkSingleSubPythonStr(obj, sub);
 }
 
-double TaskExtrudeParameters::getXDirection(void) const
+double TaskExtrudeParameters::getXDirection() const
 {
     return ui->XDirectionEdit->value();
 }
 
-double TaskExtrudeParameters::getYDirection(void) const
+double TaskExtrudeParameters::getYDirection() const
 {
     return ui->YDirectionEdit->value();
 }
 
-double TaskExtrudeParameters::getZDirection(void) const
+double TaskExtrudeParameters::getZDirection() const
 {
     return ui->ZDirectionEdit->value();
 }
 
-bool TaskExtrudeParameters::getReversed(void) const
+bool TaskExtrudeParameters::getReversed() const
 {
     return ui->checkBoxReversed->isChecked();
 }
 
-bool TaskExtrudeParameters::getMidplane(void) const
+bool TaskExtrudeParameters::getMidplane() const
 {
     return ui->checkBoxMidplane->isChecked();
 }
 
-int TaskExtrudeParameters::getMode(void) const
+int TaskExtrudeParameters::getMode() const
 {
     return ui->changeMode->currentIndex();
 }
 
-QString TaskExtrudeParameters::getFaceName(void) const
+QString TaskExtrudeParameters::getFaceName() const
 {
     QVariant featureName = ui->lineFaceName->property("FeatureName");
     if (featureName.isValid()) {
@@ -846,7 +844,7 @@ void TaskExtrudeParameters::changeEvent(QEvent *e)
     }
 }
 
-void TaskExtrudeParameters::saveHistory(void)
+void TaskExtrudeParameters::saveHistory()
 {
     // save the user values to history
     ui->lengthEdit->pushToHistory();
@@ -891,12 +889,12 @@ void TaskExtrudeParameters::translateModeList(int)
     // implement in sub-class
 }
 
-void TaskExtrudeParameters::handleLineFaceNameClick(void)
+void TaskExtrudeParameters::handleLineFaceNameClick()
 {
     ui->lineFaceName->setPlaceholderText(tr("Click on a face in the model"));
 }
 
-void TaskExtrudeParameters::handleLineFaceNameNo(void)
+void TaskExtrudeParameters::handleLineFaceNameNo()
 {
     ui->lineFaceName->setPlaceholderText(tr("No face selected"));
 }
