@@ -41,10 +41,10 @@ class TaskFeatureParameters : public Gui::TaskView::TaskBox,
 public:
     TaskFeatureParameters(PartDesignGui::ViewProvider* vp, QWidget *parent,
                               const std::string& pixmapname, const QString& parname);
-    virtual ~TaskFeatureParameters() {}
+    ~TaskFeatureParameters() override {}
 
     /// save field history
-    virtual void saveHistory(void) {}
+    virtual void saveHistory() {}
     /// apply changes made in the parameters input to the model via commands
     virtual void apply() {}
 
@@ -56,7 +56,7 @@ protected Q_SLOTS:
 
 private:
     /** Notifies when the object is about to be removed. */
-    virtual void slotDeletedObject(const Gui::ViewProviderDocumentObject& Obj);
+    void slotDeletedObject(const Gui::ViewProviderDocumentObject& Obj) override;
 
 protected:
     PartDesignGui::ViewProvider *vp;
@@ -70,14 +70,14 @@ class TaskDlgFeatureParameters : public Gui::TaskView::TaskDialog
     Q_OBJECT
 
 public:
-    TaskDlgFeatureParameters(PartDesignGui::ViewProvider *vp);
-    virtual ~TaskDlgFeatureParameters();
+    explicit TaskDlgFeatureParameters(PartDesignGui::ViewProvider *vp);
+    ~TaskDlgFeatureParameters() override;
 
 public:
     /// is called by the framework if the dialog is accepted (Ok)
-    virtual bool accept();
+    bool accept() override;
     /// is called by the framework if the dialog is rejected (Cancel)
-    virtual bool reject();
+    bool reject() override;
 
     /// Returns the view provider dialog is runed for
      PartDesignGui::ViewProvider *viewProvider() const { return vp; }
