@@ -85,14 +85,14 @@ TaskFeaturePick::TaskFeaturePick(std::vector<App::DocumentObject*>& objects,
     proxy = new QWidget(this);
     ui->setupUi(proxy);
 
-    connect(ui->checkUsed, SIGNAL(toggled(bool)), this, SLOT(onUpdate(bool)));
-    connect(ui->checkOtherBody, SIGNAL(toggled(bool)), this, SLOT(onUpdate(bool)));
-    connect(ui->checkOtherPart, SIGNAL(toggled(bool)), this, SLOT(onUpdate(bool)));
-    connect(ui->radioIndependent, SIGNAL(toggled(bool)), this, SLOT(onUpdate(bool)));
-    connect(ui->radioDependent, SIGNAL(toggled(bool)), this, SLOT(onUpdate(bool)));
-    connect(ui->radioXRef, SIGNAL(toggled(bool)), this, SLOT(onUpdate(bool)));
-    connect(ui->listWidget, SIGNAL(itemSelectionChanged()), this, SLOT(onItemSelectionChanged()));
-    connect(ui->listWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(onDoubleClick(QListWidgetItem *)));
+    connect(ui->checkUsed, &QCheckBox::toggled, this, &TaskFeaturePick::onUpdate);
+    connect(ui->checkOtherBody, &QCheckBox::toggled, this, &TaskFeaturePick::onUpdate);
+    connect(ui->checkOtherPart, &QCheckBox::toggled, this, &TaskFeaturePick::onUpdate);
+    connect(ui->radioIndependent, &QRadioButton::toggled, this, &TaskFeaturePick::onUpdate);
+    connect(ui->radioDependent, &QRadioButton::toggled, this, &TaskFeaturePick::onUpdate);
+    connect(ui->radioXRef, &QRadioButton::toggled, this, &TaskFeaturePick::onUpdate);
+    connect(ui->listWidget, &QListWidget::itemSelectionChanged, this, &TaskFeaturePick::onItemSelectionChanged);
+    connect(ui->listWidget, &QListWidget::itemDoubleClicked, this, &TaskFeaturePick::onDoubleClick);
 
 
     if (!singleFeatureSelect) {
@@ -112,8 +112,8 @@ TaskFeaturePick::TaskFeaturePick(std::vector<App::DocumentObject*>& objects,
     for (; statusIt != status.end(); ++statusIt, ++objIt) {
         QListWidgetItem* item = new QListWidgetItem(
                 QString::fromLatin1("%1 (%2)")
-                    .arg(QString::fromUtf8((*objIt)->Label.getValue()))
-                    .arg(getFeatureStatusString(*statusIt)
+                    .arg(QString::fromUtf8((*objIt)->Label.getValue()),
+                         getFeatureStatusString(*statusIt)
                 )
         );
         item->setData(Qt::UserRole, QString::fromLatin1((*objIt)->getNameInDocument()));
@@ -509,14 +509,14 @@ void TaskFeaturePick::slotDeletedObject(const Gui::ViewProviderDocumentObject& O
 void TaskFeaturePick::slotUndoDocument(const Gui::Document&)
 {
     if (origins.empty()) {
-        QTimer::singleShot(100, &Gui::Control(), SLOT(closeDialog()));
+        QTimer::singleShot(100, &Gui::Control(), &Gui::ControlSingleton::closeDialog);
     }
 }
 
 void TaskFeaturePick::slotDeleteDocument(const Gui::Document&)
 {
     origins.clear();
-    QTimer::singleShot(100, &Gui::Control(), SLOT(closeDialog()));
+    QTimer::singleShot(100, &Gui::Control(), &Gui::ControlSingleton::closeDialog);
 }
 
 void TaskFeaturePick::showExternal(bool val)
@@ -534,10 +534,10 @@ void TaskFeaturePick::showExternal(bool val)
 
 TaskDlgFeaturePick::TaskDlgFeaturePick( std::vector<App::DocumentObject*> &objects,
                                         const std::vector<TaskFeaturePick::featureStatus> &status,
-                                        boost::function<bool (std::vector<App::DocumentObject*>)> afunc,
-                                        boost::function<void (std::vector<App::DocumentObject*>)> wfunc,
+                                        std::function<bool (std::vector<App::DocumentObject*>)> afunc,
+                                        std::function<void (std::vector<App::DocumentObject*>)> wfunc,
                                         bool singleFeatureSelect,
-                                        boost::function<void (void)> abortfunc /* = NULL */ )
+                                        std::function<void (void)> abortfunc /* = NULL */ )
     : TaskDialog(), accepted(false)
 {
     pick  = new TaskFeaturePick(objects, status, singleFeatureSelect);
