@@ -114,12 +114,12 @@ void TaskRevolutionParameters::fillAxisCombo(bool forceRefill)
         ui->axis->clear();
         axesInList.clear();
 
-        //add sketch axes
         auto *pcFeat = dynamic_cast<PartDesign::ProfileBased*>(vp->getObject());
         if (!pcFeat)
             throw Base::TypeError("The object is not ProfileBased.");
-        auto *pcSketch = static_cast<Part::Part2DObject*>(pcFeat->Profile.getValue());
-        if (pcSketch){
+
+        //add sketch axes
+        if (auto *pcSketch = dynamic_cast<Part::Part2DObject*>(pcFeat->Profile.getValue())) {
             addAxisToCombo(pcSketch, "V_Axis", QObject::tr("Vertical sketch axis"));
             addAxisToCombo(pcSketch, "H_Axis", QObject::tr("Horizontal sketch axis"));
             for (int i=0; i < pcSketch->getAxisCount(); i++) {
@@ -130,9 +130,8 @@ void TaskRevolutionParameters::fillAxisCombo(bool forceRefill)
             }
         }
 
-        //add part axes
-        PartDesign::Body * body = PartDesign::Body::findBodyOf ( pcFeat );
-        if (body) {
+        //add origin axes
+        if (PartDesign::Body * body = PartDesign::Body::findBodyOf(pcFeat)) {
             try {
                 App::Origin* orig = body->getOrigin();
                 addAxisToCombo(orig->getX(), std::string(), tr("Base X axis"));
@@ -242,7 +241,7 @@ void TaskRevolutionParameters::onAxisChanged(int num)
         oldRefName = oldSubRefAxis.front();
 
     App::PropertyLinkSub &lnk = *(axesInList[num]);
-    if (lnk.getValue() == nullptr) {
+    if (!lnk.getValue()) {
         // enter reference selection mode
         if (auto sketch = dynamic_cast<Part::Part2DObject*>(pcRevolution->Profile.getValue())) {
             Gui::cmdAppObjectShow(sketch);
@@ -302,11 +301,6 @@ void TaskRevolutionParameters::onReversed(bool on)
     recomputeFeature();
 }
 
-double TaskRevolutionParameters::getAngle(void) const
-{
-    return ui->revolveAngle->value().getValue();
-}
-
 void TaskRevolutionParameters::getReferenceAxis(App::DocumentObject*& obj, std::vector<std::string>& sub) const
 {
     if (axesInList.empty())
@@ -314,7 +308,7 @@ void TaskRevolutionParameters::getReferenceAxis(App::DocumentObject*& obj, std::
 
     int num = ui->axis->currentIndex();
     const App::PropertyLinkSub &lnk = *(axesInList[num]);
-    if (lnk.getValue() == nullptr) {
+    if (!lnk.getValue()) {
         throw Base::RuntimeError("Still in reference selection mode; reference wasn't selected yet");
     } else {
         PartDesign::ProfileBased* pcRevolution = static_cast<PartDesign::ProfileBased*>(vp->getObject());
@@ -327,12 +321,12 @@ void TaskRevolutionParameters::getReferenceAxis(App::DocumentObject*& obj, std::
     }
 }
 
-bool TaskRevolutionParameters::getMidplane(void) const
+bool TaskRevolutionParameters::getMidplane() const
 {
     return ui->checkBoxMidplane->isChecked();
 }
 
-bool TaskRevolutionParameters::getReversed(void) const
+bool TaskRevolutionParameters::getReversed() const
 {
     return ui->checkBoxReversed->isChecked();
 }
