@@ -39,17 +39,15 @@ class ViewProvider;
 
 namespace PartDesignGui {
 
-
-
 class TaskRevolutionParameters : public TaskSketchBasedParameters
 {
     Q_OBJECT
 
 public:
-    TaskRevolutionParameters(ViewProvider* RevolutionView,QWidget *parent = nullptr);
-    ~TaskRevolutionParameters();
+    explicit TaskRevolutionParameters(ViewProvider* RevolutionView, QWidget* parent = nullptr);
+    ~TaskRevolutionParameters() override;
 
-    virtual void apply() override;
+    void apply() override;
 
     /**
      * @brief fillAxisCombo fills the combo and selects the item according to
@@ -71,9 +69,8 @@ protected:
     void onSelectionChanged(const Gui::SelectionChanges& msg) override;
     void changeEvent(QEvent *event) override;
     void getReferenceAxis(App::DocumentObject *&obj, std::vector<std::string> &sub) const;
-    double getAngle(void) const;
-    bool getMidplane(void) const;
-    bool getReversed(void) const;
+    bool getMidplane() const;
+    bool getReversed() const;
 
     //mirrors of revolution's or groove's properties
     //should have been done by inheriting revolution and groove from common class...
@@ -107,10 +104,12 @@ class TaskDlgRevolutionParameters : public TaskDlgSketchBasedParameters
     Q_OBJECT
 
 public:
-    TaskDlgRevolutionParameters(PartDesignGui::ViewProvider *RevolutionView);
+    explicit TaskDlgRevolutionParameters(PartDesignGui::ViewProvider *RevolutionView);
 
     ViewProvider* getRevolutionView() const
-    { return vp; }
+    {
+        return vp;
+    }
 };
 
 } //namespace PartDesignGui
