@@ -36,8 +36,10 @@ class TaskThicknessParameters : public TaskDressUpParameters
     Q_OBJECT
 
 public:
-    TaskThicknessParameters(ViewProviderDressUp *DressUpView, QWidget *parent=nullptr);
-    ~TaskThicknessParameters();
+    explicit TaskThicknessParameters(ViewProviderDressUp *DressUpView, QWidget *parent=nullptr);
+    ~TaskThicknessParameters() override;
+
+    void apply() override;
 
     double getValue(void) const;
     bool getReversed(void) const;
@@ -51,13 +53,13 @@ private Q_SLOTS:
     void onJoinTypeChanged(int join);
     void onReversedChanged(bool reversed);
     void onIntersectionChanged(bool intersection);
-    void onRefDeleted(void);
+    void onRefDeleted(void) override;
 
 protected:
-    virtual void clearButtons(const selectionModes notThis);
-    bool event(QEvent *e);
-    void changeEvent(QEvent *e);
-    virtual void onSelectionChanged(const Gui::SelectionChanges& msg);
+    void setButtons(const selectionModes mode) override;
+    bool event(QEvent *e) override;
+    void changeEvent(QEvent *e) override;
+    void onSelectionChanged(const Gui::SelectionChanges& msg) override;
 
 private:
     std::unique_ptr<Ui_TaskThicknessParameters> ui;
@@ -69,12 +71,12 @@ class TaskDlgThicknessParameters : public TaskDlgDressUpParameters
     Q_OBJECT
 
 public:
-    TaskDlgThicknessParameters(ViewProviderThickness *ThicknessView);
-    ~TaskDlgThicknessParameters();
+    explicit TaskDlgThicknessParameters(ViewProviderThickness *ThicknessView);
+    ~TaskDlgThicknessParameters() override;
 
 public:
     /// is called by the framework if the dialog is accepted (Ok)
-    virtual bool accept();
+    bool accept() override;
 };
 
 } //namespace PartDesignGui
