@@ -64,9 +64,9 @@ public:
      * remove items from the combo directly, otherwise internal tracking list
      * will go out of sync, and crashes may result.
      */
-    ComboLinks(QComboBox &combo);
+    explicit ComboLinks(QComboBox &combo);
     ComboLinks() {_combo = nullptr; doc = nullptr;}
-    void setCombo(QComboBox &combo) {assert(_combo == nullptr); this->_combo = &combo; _combo->clear();}
+    void setCombo(QComboBox &combo) {assert(!_combo); this->_combo = &combo; _combo->clear();}
 
     /**
      * @brief addLink adds an item to the combo. Doesn't check for duplicates.
@@ -123,10 +123,10 @@ class TaskTransformedParameters : public Gui::TaskView::TaskBox,
 
 public:
     /// Constructor for task with ViewProvider
-    TaskTransformedParameters(ViewProviderTransformed *TransformedView, QWidget *parent = nullptr);
+    explicit TaskTransformedParameters(ViewProviderTransformed *TransformedView, QWidget *parent = nullptr);
     /// Constructor for task with parent task (MultiTransform mode)
-    TaskTransformedParameters(TaskMultiTransformParameters *parentTask);
-    virtual ~TaskTransformedParameters();
+    explicit TaskTransformedParameters(TaskMultiTransformParameters *parentTask);
+    ~TaskTransformedParameters() override;
 
     /// Returns the originals property of associated top feeature object
     const std::vector<App::DocumentObject*> & getOriginals(void) const;
@@ -141,6 +141,7 @@ public:
     void exitSelectionMode();
 
     virtual void apply() = 0;
+    virtual void onUpdateView(bool) = 0;
 
     /*!
      * \brief setEnabledTransaction
@@ -156,7 +157,7 @@ public:
         return transactionID;
     }
 
-protected Q_SLOTS:
+protected:
     /**
      * Returns the base transformation view provider
      * For stand alone features it will be view provider associated with this object
@@ -171,6 +172,7 @@ protected Q_SLOTS:
      */
     PartDesign::Transformed *getTopTransformedObject () const;
 
+protected Q_SLOTS:
     /// Connect the subTask OK button to the MultiTransform task
     virtual void onSubTaskButtonOK() {}
     void onButtonAddFeature(const bool checked);
@@ -207,9 +209,9 @@ protected:
     virtual void addObject(App::DocumentObject*);
     virtual void removeObject(App::DocumentObject*);
     /** Notifies when the object is about to be removed. */
-    virtual void slotDeletedObject(const Gui::ViewProviderDocumentObject& Obj);
-    virtual void changeEvent(QEvent *e) = 0;
-    virtual void onSelectionChanged(const Gui::SelectionChanges& msg) = 0;
+    void slotDeletedObject(const Gui::ViewProviderDocumentObject& Obj) override;
+    void changeEvent(QEvent *e) override = 0;
+    void onSelectionChanged(const Gui::SelectionChanges& msg) override = 0;
     virtual void clearButtons()=0;
     static void removeItemFromListWidget(QListWidget* widget, const QString& itemstr);
 
@@ -239,17 +241,17 @@ class TaskDlgTransformedParameters : public PartDesignGui::TaskDlgFeatureParamet
     Q_OBJECT
 
 public:
-    TaskDlgTransformedParameters(ViewProviderTransformed *TransformedView);
-    virtual ~TaskDlgTransformedParameters() {}
+    explicit TaskDlgTransformedParameters(ViewProviderTransformed *TransformedView);
+    ~TaskDlgTransformedParameters() override {}
 
     ViewProviderTransformed* getTransformedView() const
     { return static_cast<ViewProviderTransformed*>(vp); }
 
 public:
     /// is called by the framework if the dialog is accepted (Ok)
-    virtual bool accept();
+    bool accept() override;
     /// is called by the framework if the dialog is rejected (Cancel)
-    virtual bool reject();
+    bool reject() override;
 protected:
     TaskTransformedParameters  *parameter;
     TaskTransformedMessages  *message;
