@@ -55,30 +55,46 @@ using namespace Attacher;
 
 namespace PartDesignGui {
 
+// TODO: Refactor DocumentObjectItem::getSubName() that has similar logic
+App::DocumentObject* getParent(App::DocumentObject* obj, std::string& subname)
+{
+    auto inlist = obj->getInList();
+    for (auto it : inlist) {
+        if (it->hasExtension(App::GeoFeatureGroupExtension::getExtensionClassTypeId())) {
+            std::string parent;
+            parent += obj->getNameInDocument();
+            parent += '.';
+            subname = parent + subname;
+            return getParent(it, subname);
+        }
+    }
+
+    return obj;
+}
+
 bool setEdit(App::DocumentObject *obj, PartDesign::Body *body) {
-    if(!obj || !obj->getNameInDocument()) {
+    if (!obj || !obj->getNameInDocument()) {
         FC_ERR("invalid object");
         return false;
     }
-    if(body == nullptr) {
+    if (!body) {
         body = getBodyFor(obj, false);
-        if(!body) {
+        if (!body) {
             FC_ERR("no body found");
             return false;
         }
     }
     auto *activeView = Gui::Application::Instance->activeView();
-    if(!activeView)
+    if (!activeView)
         return false;
     App::DocumentObject *parent = nullptr;
     std::string subname;
-    auto activeBody = activeView->getActiveObject<PartDesign::Body*>(PDBODYKEY,&parent,&subname);
-    if(activeBody != body) {
+    auto activeBody = activeView->getActiveObject<PartDesign::Body*>(PDBODYKEY);
+    if (activeBody != body) {
         parent = obj;
-        subname.clear();
-    }else{
-        subname += obj->getNameInDocument();
-        subname += '.';
+    }
+    else {
+        parent = getParent(obj, subname);
     }
 
     Gui::cmdGuiDocument(parent, std::ostringstream() << "setEdit("
@@ -95,7 +111,7 @@ bool setEdit(App::DocumentObject *obj, PartDesign::Body *body) {
  * \param autoActivate
  * \return Body
  */
-PartDesign::Body *getBody(bool messageIfNot, bool autoActivate, bool assertModern, 
+PartDesign::Body *getBody(bool messageIfNot, bool autoActivate, bool assertModern,
         App::DocumentObject **topParent, std::string *subname)
 {
     PartDesign::Body * activeBody = nullptr;
@@ -153,7 +169,8 @@ PartDesign::Body * makeBodyActive(App::DocumentObject *body, App::Document *doc,
 
     if(body) {
         auto _doc = parent?parent->getDocument():body->getDocument();
-        _FCMD_DOC_CMD(Gui, _doc, "ActiveView.setActiveObject('" << PDBODYKEY
+        Gui::cmdGuiDocument(_doc, std::stringstream()
+                      << "ActiveView.setActiveObject('" << PDBODYKEY
                       << "'," << Gui::Command::getObjectCmd(parent?parent:body)
                       << ",'" << sub << "')");
         return Gui::Application::Instance->activeView()->
@@ -437,6 +454,9 @@ void relinkToBody (PartDesign::Feature *feature) {
 
 bool isFeatureMovable(App::DocumentObject* const feat)
 {
+    if (!feat)
+        return false;
+
     if (feat->getTypeId().isDerivedFrom(PartDesign::Feature::getClassTypeId())) {
         auto prim = static_cast<PartDesign::Feature*>(feat);
         App::DocumentObject* bf = prim->BaseFeature.getValue();
