@@ -46,18 +46,21 @@ PROPERTY_SOURCE(PartDesignGui::ViewProviderDressUp,PartDesignGui::ViewProvider)
 
 void ViewProviderDressUp::setupContextMenu(QMenu* menu, QObject* receiver, const char* member)
 {
-    QAction* act;
-    act = menu->addAction(QObject::tr("Edit %1").arg(QString::fromStdString(featureName())), receiver, member);
-    act->setData(QVariant((int)ViewProvider::Default));
+    QString text = QString::fromStdString(getObject()->Label.getStrValue());
+    addDefaultAction(menu, QObject::tr("Edit %1").arg(text));
     PartDesignGui::ViewProvider::setupContextMenu(menu, receiver, member);
 }
 
-
 const std::string & ViewProviderDressUp::featureName() const {
     static const std::string name = "Undefined";
     return name;
 }
 
+std::string ViewProviderDressUp::featureIcon() const
+{
+    return std::string("PartDesign_") + featureName();
+}
+
 
 bool ViewProviderDressUp::setEdit(int ModNum) {
     if (ModNum == ViewProvider::Default ) {
@@ -86,11 +89,11 @@ void ViewProviderDressUp::highlightReferences(const bool on)
 {
     PartDesign::DressUp* pcDressUp = static_cast<PartDesign::DressUp*>(getObject());
     Part::Feature* base = pcDressUp->getBaseObject (/*silent =*/ true);
-    if (base == nullptr)
+    if (!base)
         return;
     PartGui::ViewProviderPart* vp = dynamic_cast<PartGui::ViewProviderPart*>(
                 Gui::Application::Instance->getViewProvider(base));
-    if (vp == nullptr)
+    if (!vp)
         return;
 
     std::vector<std::string> faces = pcDressUp->Base.getSubValuesStartsWith("Face");
