@@ -37,16 +37,22 @@ TaskDlgFeatureParameters *ViewProviderMultiTransform::getEditDialog() {
     return new TaskDlgMultiTransformParameters (this);
 }
 
-void ViewProviderMultiTransform::setupContextMenu(QMenu* menu, QObject* receiver, const char* member)
+const std::string & ViewProviderMultiTransform::featureName() const
 {
-    this->addDefaultAction(menu, QObject::tr("Edit %1").arg(QString::fromStdString(featureName)));
-    PartDesignGui::ViewProvider::setupContextMenu(menu, receiver, member);
+    static const std::string name = "MultiTransform";
+    return name;
 }
 
-std::vector<App::DocumentObject*> ViewProviderMultiTransform::claimChildren(void) const
+void ViewProviderMultiTransform::setupContextMenu(QMenu* menu, QObject* receiver, const char* member)
+{
+    addDefaultAction(menu, QObject::tr("Edit multi-transform"));
+    PartDesignGui::ViewProvider::setupContextMenu(menu, receiver, member); // clazy:exclude=skipped-base-method
+}
+
+std::vector<App::DocumentObject*> ViewProviderMultiTransform::claimChildren() const
 {
     PartDesign::MultiTransform* pcMultiTransform = static_cast<PartDesign::MultiTransform*>(getObject());
-    if (pcMultiTransform == nullptr)
+    if (!pcMultiTransform)
         return std::vector<App::DocumentObject*>(); // TODO: Show error?
 
     std::vector<App::DocumentObject*> transformFeatures = pcMultiTransform->Transformations.getValues();
