@@ -37,28 +37,29 @@ class PartDesignGuiExport ViewProviderTransformed : public ViewProvider
 public:
     /// constructor
     ViewProviderTransformed()
-        : featureName("undefined"), pcRejectedRoot(nullptr) {}
+        : pcRejectedRoot(nullptr) {}
     /// destructor
-    virtual ~ViewProviderTransformed()
+    ~ViewProviderTransformed() override
         {}
 
+    // The feature name of the subclass
+    virtual const std::string & featureName() const;
+    std::string featureIcon() const;
     void setupContextMenu(QMenu*, QObject*, const char*) override;
 
-    virtual bool onDelete(const std::vector<std::string> &) override;
+    bool onDelete(const std::vector<std::string> &) override;
 
     /// signals if the transformation contains errors
     boost::signals2::signal<void (QString msg)> signalDiagnosis;
 
-    // The feature name of the subclass
-    std::string featureName;
     // Name of menu dialog
     QString menuName;
 
-    virtual Gui::ViewProvider *startEditing(int ModNum=0) override;
+    Gui::ViewProvider *startEditing(int ModNum=0) override;
 
 protected:
-    virtual bool setEdit(int ModNum) override;
-    virtual void unsetEdit(int ModNum) override;
+    bool setEdit(int ModNum) override;
+    void unsetEdit(int ModNum) override;
 
     bool checkDlgOpen(TaskDlgTransformedParameters* transformedDlg);
 
