@@ -20,19 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef PATH_FeaturePath_H
 #define PATH_FeaturePath_H
 
 #include <App/DocumentObject.h>
 #include <App/GeoFeature.h>
-#include <App/PropertyFile.h>
-#include <App/PropertyGeo.h>
 #include <App/FeaturePython.h>
 
-#include "Path.h"
 #include "PropertyPath.h"
 
+
 namespace Path
 {
 
@@ -64,7 +61,7 @@ protected:
 
 };
 
-typedef App::FeaturePythonT<Feature> FeaturePython;
+using FeaturePython = App::FeaturePythonT<Feature>;
 
 } //namespace Path
 
