@@ -20,10 +20,8 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#include "Voronoi.h"
 #include "VoronoiEdge.h"
 
 
@@ -55,8 +53,8 @@ VoronoiEdge::VoronoiEdge(Voronoi::diagram_type *d, const Voronoi::diagram_type::
 VoronoiEdge::~VoronoiEdge() {
 }
 
-bool VoronoiEdge::isBound(void) const {
-  if (ptr != nullptr && dia.isValid() && index != Voronoi::InvalidIndex) {
+bool VoronoiEdge::isBound() const {
+  if (ptr && dia.isValid() && index != Voronoi::InvalidIndex) {
     if (&(dia->edges()[index]) == ptr) {
       return true;
     }
