@@ -20,28 +20,23 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #include "Base/GeometryPyCXX.h"
 #include "Base/Vector3D.h"
 #include "Base/VectorPy.h"
 
-#include "Voronoi.h"
-#include "VoronoiCell.h"
-#include "VoronoiCellPy.h"
-#include "VoronoiEdge.h"
-#include "VoronoiEdgePy.h"
 #include "VoronoiPy.h"
 #include "VoronoiPy.cpp"
-#include "VoronoiVertex.h"
+#include "VoronoiCellPy.h"
+#include "VoronoiEdgePy.h"
 #include "VoronoiVertexPy.h"
 
 
 using namespace Path;
 
 // returns a string which represents the object e.g. when printed in python
-std::string VoronoiPy::representation(void) const
+std::string VoronoiPy::representation() const
 {
   std::stringstream ss;
   ss.precision(5);
@@ -143,7 +138,7 @@ PyObject* VoronoiPy::numVertices(PyObject *args)
   return PyLong_FromLong(getVoronoiPtr()->numVertices());
 }
 
-Py::List VoronoiPy::getVertices(void) const {
+Py::List VoronoiPy::getVertices() const {
   Py::List list;
   for (int i=0; i<getVoronoiPtr()->numVertices(); ++i) {
     list.append(Py::asObject(new VoronoiVertexPy(getVoronoiPtr()->create<VoronoiVertex>(i))));
@@ -151,7 +146,7 @@ Py::List VoronoiPy::getVertices(void) const {
   return list;
 }
 
-Py::List VoronoiPy::getEdges(void) const {
+Py::List VoronoiPy::getEdges() const {
   Py::List list;
   for (int i=0; i<getVoronoiPtr()->numEdges(); ++i) {
     list.append(Py::asObject(new VoronoiEdgePy(getVoronoiPtr()->create<VoronoiEdge>(i))));
@@ -159,7 +154,7 @@ Py::List VoronoiPy::getEdges(void) const {
   return list;
 }
 
-Py::List VoronoiPy::getCells(void) const {
+Py::List VoronoiPy::getCells() const {
   Py::List list;
   for (int i=0; i<getVoronoiPtr()->numCells(); ++i) {
     list.append(Py::asObject(new VoronoiCellPy(getVoronoiPtr()->create<VoronoiCell>(i))));
@@ -167,8 +162,8 @@ Py::List VoronoiPy::getCells(void) const {
   return list;
 }
 
-typedef std::map<uintptr_t,bool> exterior_map_t;
-typedef std::map<int32_t, std::set<int32_t> > coordinate_map_t;
+using exterior_map_t = std::map<uintptr_t,bool>;
+using coordinate_map_t = std::map<int32_t, std::set<int32_t> >;
 
 #define VORONOI_USE_EXTERIOR_CACHE 1
 
@@ -188,7 +183,7 @@ static bool callbackWithVertex(Voronoi::diagram_type *dia, PyObject *callback, c
 #endif
       Py_DECREF(arglist);
       Py_DECREF(vx);
-      if (result == nullptr) {
+      if (!result) {
         bail = true;
       } else {
         rc = result == Py_True;
