@@ -20,10 +20,8 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#include "Voronoi.h"
 #include "VoronoiVertex.h"
 
 
@@ -55,8 +53,8 @@ VoronoiVertex::VoronoiVertex(Voronoi::diagram_type *d, const Voronoi::diagram_ty
 VoronoiVertex::~VoronoiVertex() {
 }
 
-bool VoronoiVertex::isBound(void) const {
-  if (ptr != nullptr && dia.isValid() && index != Voronoi::InvalidIndex) {
+bool VoronoiVertex::isBound() const {
+  if (ptr && dia.isValid() && index != Voronoi::InvalidIndex) {
     if (&(dia->vertices()[index]) == ptr) {
       return true;
     }
