@@ -21,26 +21,20 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
-#
-#include <CXX/Extensions.hxx>
-#include <CXX/Objects.hxx>
-
-#include <QDir>
-#include <QFileInfo>
-
-#include <Base/Console.h>
-#include <Base/VectorPy.h>
-#include <Base/FileInfo.h>
-#include <Base/Interpreter.h>
+#ifndef _PreComp_
+# include <QDir>
+# include <QFileInfo>
+#endif
 
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObjectPy.h>
 
+#include <Base/FileInfo.h>
+#include <Base/Interpreter.h>
 #include <Gui/Command.h>
 #include <Gui/WaitCursor.h>
 
-#include "ViewProviderPath.h"
 #include "DlgProcessorChooser.h"
 #include "ui_DlgProcessorChooser.h"
 
@@ -63,7 +57,7 @@ public:
         initialize("This module is the PathGui module."); // register with Python
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
     Py::Object open(const Py::Tuple& args)
@@ -82,7 +76,7 @@ private:
 
         try {
             std::string path = App::Application::getHomePath();
-            path += "Mod/Path/PathScripts/post/";
+            path += "Mod/Path/Path/Post/scripts/";
             QDir dir1(QString::fromUtf8(path.c_str()), QString::fromLatin1("*_pre.py"));
             std::string cMacroPath = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Macro")
                 ->GetASCII("MacroPath",App::Application::getUserMacroDir().c_str());
@@ -104,7 +98,7 @@ private:
             std::ostringstream pre;
             std::ostringstream cmd;
             if (processor.empty()) {
-                App::Document *pcDoc = App::GetApplication().newDocument("Unnamed");
+                App::Document *pcDoc = App::GetApplication().newDocument();
                 Gui::Command::runCommand(Gui::Command::Gui,"import Path");
                 cmd << "Path.read(\"" << EncodedName << "\",\"" << pcDoc->getName() << "\")";
                 Gui::Command::runCommand(Gui::Command::Gui,cmd.str().c_str());
@@ -113,7 +107,7 @@ private:
                     QFileInfo fileInfo = list.at(i);
                     if (fileInfo.baseName().toStdString() == processor) {
                         if (fileInfo.absoluteFilePath().contains(QString::fromLatin1("PathScripts"))) {
-                            pre << "from PathScripts.post import " << processor;
+                            pre << "from Path.Post.scripts import " << processor;
                         } else {
                             pre << "import " << processor;
                         }
@@ -149,7 +143,7 @@ private:
 
         try {
             std::string path = App::Application::getHomePath();
-            path += "Mod/Path/PathScripts/post/";
+            path += "Mod/Path/Path/Post/scripts/";
             QDir dir1(QString::fromUtf8(path.c_str()), QString::fromLatin1("*_pre.py"));
             std::string cMacroPath = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Macro")
                 ->GetASCII("MacroPath",App::Application::getUserMacroDir().c_str());
@@ -189,7 +183,7 @@ private:
                     QFileInfo fileInfo = list.at(i);
                     if (fileInfo.baseName().toStdString() == processor) {
                         if (fileInfo.absoluteFilePath().contains(QString::fromLatin1("PathScripts"))) {
-                            pre << "from PathScripts.post import " << processor;
+                            pre << "from Path.Post.scripts import " << processor;
                         } else {
                             pre << "import " << processor;
                         }
@@ -225,7 +219,7 @@ private:
                 throw Py::RuntimeError("No object to export");
 
             std::string path = App::Application::getHomePath();
-            path += "Mod/Path/PathScripts/post/";
+            path += "Mod/Path/Path/Post/scripts/";
             QDir dir1(QString::fromUtf8(path.c_str()), QString::fromLatin1("*_post.py"));
             std::string cMacroPath = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Macro")
                 ->GetASCII("MacroPath",App::Application::getUserMacroDir().c_str());
@@ -265,7 +259,7 @@ private:
                     QFileInfo fileInfo = list.at(i);
                     if (fileInfo.baseName().toStdString() == processor) {
                         if (fileInfo.absoluteFilePath().contains(QString::fromLatin1("PathScripts"))) {
-                            pre << "from PathScripts.post import " << processor;
+                            pre << "from Path.Post.scripts import " << processor;
                         } else {
                             pre << "import " << processor;
                         }
