@@ -20,20 +20,18 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef PATHSIMULATOR_PathSim_H
 #define PATHSIMULATOR_PathSim_H
 
-// Exporting of App classes
-
-#include <Base/Persistence.h>
-#include <Base/Vector3D.h>
-#include <TopoDS.hxx>
+#include <memory>
 #include <TopoDS_Shape.hxx>
+
 #include <Mod/Path/App/Command.h>
 #include <Mod/Part/App/TopoShape.h>
+
 #include "VolSim.h"
 
+
 using namespace Path;
 
 namespace PathSimulator
@@ -54,8 +52,8 @@ namespace PathSimulator
 			Base::Placement * ApplyCommand(Base::Placement * pos, Command * cmd);
 
 		public:
-			cStock * m_stock;
-			cSimTool *m_tool;
+			std::unique_ptr<cStock> m_stock;
+			std::unique_ptr<cSimTool> m_tool;
 	};
 
 } //namespace Path
