@@ -20,31 +20,26 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <memory>
 #endif
 
-
-#include <CXX/Extensions.hxx>
-#include <CXX/Objects.hxx>
-
-#include <Base/Console.h>
-#include <Base/Interpreter.h>
-#include <Base/FileInfo.h>
-
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObject.h>
 #include <App/DocumentObjectPy.h>
 #include <App/Property.h>
+#include <Base/Console.h>
+#include <Base/Interpreter.h>
+#include <Base/FileInfo.h>
 
 #include "Points.h"
-#include "PointsPy.h"
 #include "PointsAlgos.h"
-#include "Structured.h"
+#include "PointsPy.h"
 #include "Properties.h"
+#include "Structured.h"
+
 
 namespace Points {
 class Module : public Py::ExtensionModule<Module>
@@ -64,7 +59,7 @@ public:
         initialize("This module is the Points module."); // register with Python
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
     std::tuple<bool, bool, float> readE57Settings() const
@@ -113,7 +108,7 @@ private:
 
             reader->read(EncodedName);
 
-            App::Document* pcDoc = App::GetApplication().newDocument("Unnamed");
+            App::Document* pcDoc = App::GetApplication().newDocument();
 
             Points::Feature* pcFeature = nullptr;
             if (reader->hasProperties()) {
@@ -403,6 +398,7 @@ private:
             Points::Feature* pcFeature = static_cast<Points::Feature*>(pcDoc->addObject("Points::Feature", name));
             // copy the data
             pcFeature->Points.setValue(*(pPoints->getPointKernelPtr()));
+	    return Py::asObject(pcFeature->getPyObject());
         }
         catch (const Base::Exception& e) {
             throw Py::RuntimeError(e.what());
