@@ -20,35 +20,35 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <algorithm>
-# include <QFileInfo>
 # include <QInputDialog>
 # include <Inventor/events/SoMouseButtonEvent.h>
 #endif
 
-#include <Base/Exception.h>
-#include <Base/Matrix.h>
-#include <Base/Tools.h>
-#include <Base/UnitsApi.h>
 #include <App/Application.h>
 #include <App/Document.h>
+#include <Base/Exception.h>
+#include <Base/Interpreter.h>
+#include <Base/Tools.h>
+#include <Base/UnitsApi.h>
 #include <Gui/Application.h>
-#include <Gui/Document.h>
-#include <Gui/MainWindow.h>
 #include <Gui/Command.h>
+#include <Gui/Document.h>
 #include <Gui/FileDialog.h>
+#include <Gui/MainWindow.h>
 #include <Gui/Selection.h>
-#include <Gui/ViewProvider.h>
 #include <Gui/View3DInventor.h>
 #include <Gui/View3DInventorViewer.h>
+#include <Gui/ViewProviderDocumentObject.h>
 #include <Gui/WaitCursor.h>
 
 #include "../App/PointsFeature.h"
 #include "../App/Structured.h"
 #include "../App/Properties.h"
+#include "../App/Tools.h"
+
 #include "DlgPointsReadImp.h"
 #include "ViewProvider.h"
 
@@ -212,59 +212,43 @@ void CmdPointsConvert::activated(int iMsg)
 
     Gui::WaitCursor wc;
     openCommand(QT_TRANSLATE_NOOP("Command", "Convert to points"));
-    std::vector<App::DocumentObject*> geoObject = getSelection().getObjectsOfType(Base::Type::fromName("App::GeoFeature"));
+    std::vector<App::GeoFeature*> geoObject = getSelection().getObjectsOfType<App::GeoFeature>();
 
-    bool addedPoints = false;
-    for (std::vector<App::DocumentObject*>::iterator it = geoObject.begin(); it != geoObject.end(); ++it) {
-        Base::Placement globalPlacement = static_cast<App::GeoFeature*>(*it)->globalPlacement();
-        Base::Placement localPlacement = static_cast<App::GeoFeature*>(*it)->Placement.getValue();
-        localPlacement = globalPlacement * localPlacement.inverse();
-        const App::PropertyComplexGeoData* prop = static_cast<App::GeoFeature*>(*it)->getPropertyOfGeometry();
-        if (prop) {
-            const Data::ComplexGeoData* data = prop->getComplexData();
-            std::vector<Base::Vector3d> vertexes;
-            std::vector<Base::Vector3d> normals;
-            data->getPoints(vertexes, normals, static_cast<float>(tol));
-            if (!vertexes.empty()) {
-                Points::Feature* fea = nullptr;
-                if (vertexes.size() == normals.size()) {
-                    fea = static_cast<Points::Feature*>(Base::Type::fromName("Points::FeatureCustom").createInstance());
-                    if (!fea) {
-                        Base::Console().Error("Failed to create instance of 'Points::FeatureCustom'\n");
-                        continue;
-                    }
-                    Points::PropertyNormalList* prop = static_cast<Points::PropertyNormalList*>
-                        (fea->addDynamicProperty("Points::PropertyNormalList", "Normal"));
-                    if (prop) {
-                        std::vector<Base::Vector3f> normf;
-                        normf.resize(normals.size());
-                        std::transform(normals.begin(), normals.end(), normf.begin(), Base::toVector<float, double>);
-                        prop->setValues(normf);
-                    }
-                }
-                else {
-                    fea = new Points::Feature;
-                }
-
-                Points::PointKernel kernel;
-                kernel.reserve(vertexes.size());
-                for (std::vector<Base::Vector3d>::iterator pt = vertexes.begin(); pt != vertexes.end(); ++pt)
-                    kernel.push_back(*pt);
-                fea->Points.setValue(kernel);
-                fea->Placement.setValue(localPlacement);
-
-                App::Document* doc = (*it)->getDocument();
-                doc->addObject(fea, "Points");
-                fea->purgeTouched();
-                addedPoints = true;
+    auto run_python = [](const std::vector<App::GeoFeature*>& geoObject, double tol) -> bool {
+        Py::List list;
+        for (auto it : geoObject) {
+            const App::PropertyComplexGeoData* prop = it->getPropertyOfGeometry();
+            if (prop) {
+                list.append(Py::asObject(it->getPyObject()));
             }
         }
-    }
 
-    if (addedPoints)
-        commitCommand();
-    else
+        if (list.size() > 0) {
+            PyObject* module = PyImport_ImportModule("pointscommands.commands");
+            if (!module) {
+                throw Py::Exception();
+            }
+
+            Py::Module commands(module, true);
+            commands.callMemberFunction("make_points_from_geometry", Py::TupleN(list, Py::Float(tol)));
+            return true;
+        }
+
+        return false;
+    };
+
+    Base::PyGILStateLocker lock;
+    try {
+        if (run_python(geoObject, tol))
+            commitCommand();
+        else
+            abortCommand();
+    }
+    catch (const Py::Exception&) {
         abortCommand();
+        Base::PyException e;
+        e.ReportException();
+    }
 }
 
 bool CmdPointsConvert::isActive()
@@ -341,8 +325,8 @@ void CmdPointsMerge::activated(int iMsg)
     Points::PointKernel* kernel = pts->Points.startEditing();
 
     std::vector<App::DocumentObject*> docObj = Gui::Selection().getObjectsOfType(Points::Feature::getClassTypeId());
-    for (std::vector<App::DocumentObject*>::iterator it = docObj.begin(); it != docObj.end(); ++it) {
-        const Points::PointKernel& k = static_cast<Points::Feature*>(*it)->Points.getValue();
+    for (auto it : docObj) {
+        const Points::PointKernel& k = static_cast<Points::Feature*>(it)->Points.getValue();
         std::size_t numPts = kernel->size();
         kernel->resize(numPts + k.size());
         for (std::size_t i=0; i<k.size(); ++i) {
@@ -351,6 +335,24 @@ void CmdPointsMerge::activated(int iMsg)
     }
 
     pts->Points.finishEditing();
+
+    // Add properties
+    std::string displayMode = "Points";
+    if (Points::copyProperty<App::PropertyColorList>(pts, docObj, "Color")) {
+        displayMode = "Color";
+    }
+    if (Points::copyProperty<Points::PropertyNormalList>(pts, docObj, "Normal")) {
+        displayMode = "Shaded";
+    }
+    if (Points::copyProperty<Points::PropertyGreyValueList>(pts, docObj, "Intensity")) {
+        displayMode = "Intensity";
+    }
+
+    if (auto vp = dynamic_cast<Gui::ViewProviderDocumentObject*>
+            (Gui::Application::Instance->getViewProvider(pts))) {
+        vp->DisplayMode.setValue(displayMode.c_str());
+    }
+
     doc->commitTransaction();
     updateActive();
 }
