@@ -61,18 +61,18 @@
   <context>
     <name>CmdPointsMerge</name>
     <message>
-      <location filename="../../Command.cpp" line="326"/>
+      <location filename="../../Command.cpp" line="310"/>
       <source>Points</source>
       <translation>Σημεία</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="327"/>
+      <location filename="../../Command.cpp" line="311"/>
       <source>Merge point clouds</source>
       <translation>Συγχώνευση νεφών σημείων</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="328"/>
-      <location filename="../../Command.cpp" line="330"/>
+      <location filename="../../Command.cpp" line="312"/>
+      <location filename="../../Command.cpp" line="314"/>
       <source>Merge several point clouds into one</source>
       <translation>Συγχώνευση διαφόρων νεφών σημείων σε ένα</translation>
     </message>
@@ -80,18 +80,18 @@
   <context>
     <name>CmdPointsPolyCut</name>
     <message>
-      <location filename="../../Command.cpp" line="281"/>
+      <location filename="../../Command.cpp" line="265"/>
       <source>Points</source>
       <translation>Σημεία</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="282"/>
+      <location filename="../../Command.cpp" line="266"/>
       <source>Cut point cloud</source>
       <translation>Περικοπή νέφους σημείων</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="283"/>
-      <location filename="../../Command.cpp" line="285"/>
+      <location filename="../../Command.cpp" line="267"/>
+      <location filename="../../Command.cpp" line="269"/>
       <source>Cuts a point cloud with a picked polygon</source>
       <translation>Περικόπτει ένα νέφος σημείων με ένα επιλεγμένο πολύγωνο</translation>
     </message>
@@ -99,20 +99,20 @@
   <context>
     <name>CmdPointsStructure</name>
     <message>
-      <location filename="../../Command.cpp" line="369"/>
+      <location filename="../../Command.cpp" line="371"/>
       <source>Points</source>
       <translation>Σημεία</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="370"/>
+      <location filename="../../Command.cpp" line="372"/>
       <source>Structured point cloud</source>
       <translation>Structured point cloud</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="371"/>
       <location filename="../../Command.cpp" line="373"/>
+      <location filename="../../Command.cpp" line="375"/>
       <source>Convert points to structured point cloud</source>
-      <translation>Convert points to structured point cloud</translation>
+      <translation>Μετατροπή σημείων σε δομημένο σύννεφο σημείων</translation>
     </message>
   </context>
   <context>
@@ -125,13 +125,13 @@
     <message>
       <location filename="../../Command.cpp" line="153"/>
       <source>Transform Points</source>
-      <translation>Μετασχηματισμός Σημείων</translation>
+      <translation>Μετατόπιση Σημείων</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="154"/>
       <location filename="../../Command.cpp" line="156"/>
       <source>Test to transform a point cloud</source>
-      <translation>Δοκιμή μετασχηματισμού ενός νέφους σημείων</translation>
+      <translation>Δοκιμή μετατόπισης ενός νέφους σημείων</translation>
     </message>
   </context>
   <context>
@@ -144,7 +144,7 @@
     <message>
       <location filename="../../Command.cpp" line="168"/>
       <source>Transform points</source>
-      <translation>Transform points</translation>
+      <translation>Μετατόπιση Σημείων</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="214"/>
@@ -152,8 +152,8 @@
       <translation>Μετατροπή σε σημεία</translation>
     </message>
     <message>
-      <location filename="../../ViewProvider.cpp" line="467"/>
-      <location filename="../../ViewProvider.cpp" line="626"/>
+      <location filename="../../ViewProvider.cpp" line="456"/>
+      <location filename="../../ViewProvider.cpp" line="615"/>
       <source>Cut points</source>
       <translation>Cut points</translation>
     </message>
@@ -210,16 +210,6 @@
       <source>Number separator:</source>
       <translation>Διαχωριστικό αριθμού:</translation>
     </message>
-    <message>
-      <location filename="../../DlgPointsRead.ui" line="157"/>
-      <source>,</source>
-      <translation>,</translation>
-    </message>
-    <message>
-      <location filename="../../DlgPointsRead.ui" line="162"/>
-      <source>;</source>
-      <translation>·</translation>
-    </message>
     <message>
       <location filename="../../DlgPointsRead.ui" line="167"/>
       <source>\t</source>
@@ -297,11 +287,6 @@
       <source>Number of previewed lines:</source>
       <translation>Αριθμός των απεικονιζόμενων γραμμών:</translation>
     </message>
-    <message>
-      <location filename="../../DlgPointsRead.ui" line="348"/>
-      <source>100</source>
-      <translation>100</translation>
-    </message>
   </context>
   <context>
     <name>QObject</name>
@@ -331,12 +316,12 @@
   <context>
     <name>Workbench</name>
     <message>
-      <location filename="../../Workbench.cpp" line="37"/>
+      <location filename="../../Workbench.cpp" line="34"/>
       <source>Points tools</source>
       <translation>Εργαλεία σημείων</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="38"/>
+      <location filename="../../Workbench.cpp" line="35"/>
       <source>&amp;Points</source>
       <translation>Σημεία</translation>
     </message>
