@@ -22,35 +22,30 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <TColgp_Array1OfPnt.hxx>
 # include <Geom_BSplineSurface.hxx>
+# include <TColgp_Array1OfPnt.hxx>
 #endif
 
 #include <Base/Console.h>
 #include <Base/Converter.h>
-#include <Base/Interpreter.h>
-#include <Base/PyObjectBase.h>
 #include <Base/GeometryPyCXX.h>
-
-#include <CXX/Extensions.hxx>
-#include <CXX/Objects.hxx>
-
+#include <Base/Interpreter.h>
 #include <Mod/Part/App/BSplineSurfacePy.h>
-#include <Mod/Mesh/App/Mesh.h>
 #include <Mod/Mesh/App/MeshPy.h>
 #include <Mod/Points/App/PointsPy.h>
+#if defined(HAVE_PCL_FILTERS)
+# include <pcl/filters/passthrough.h>
+# include <pcl/filters/voxel_grid.h>
+# include <pcl/point_types.h>
+#endif
 
 #include "ApproxSurface.h"
 #include "BSplineFitting.h"
-#include "SurfaceTriangulation.h"
 #include "RegionGrowing.h"
-#include "Segmentation.h"
 #include "SampleConsensus.h"
-#if defined(HAVE_PCL_FILTERS)
-#include <pcl/filters/passthrough.h>
-#include <pcl/filters/voxel_grid.h>
-#include <pcl/point_types.h>
-#endif
+#include "Segmentation.h"
+#include "SurfaceTriangulation.h"
+
 
 /*
 Dependency of pcl components:
@@ -79,9 +74,24 @@ public:
     Module() : Py::ExtensionModule<Module>("ReverseEngineering")
     {
         add_keyword_method("approxSurface",&Module::approxSurface,
-            "approxSurface(Points=,UDegree=3,VDegree=3,NbUPoles=6,NbVPoles=6,Smooth=True,\n"
-            "Weight=0.1,Grad=1.0,Bend=0.0,\n"
-            "Iterations=5,Correction=True,PatchFactor=1.0)"
+            "approxSurface(Points, UDegree=3, VDegree=3, NbUPoles=6, NbVPoles=6,\n"
+            "Smooth=True, Weight=0.1, Grad=1.0, Bend=0.0, Curv=0.0\n"
+            "Iterations=5, Correction=True, PatchFactor=1.0, UVDirs=((ux, uy, uz), (vx, vy, vz)))\n\n"
+            "Points: the input data (e.g. a point cloud or mesh)\n"
+            "UDegree: the degree in u parametric direction\n"
+            "VDegree: the degree in v parametric direction\n"
+            "NbUPoles: the number of control points in u parametric direction\n"
+            "NbVPoles: the number of control points in v parametric direction\n"
+            "Smooth: use energy terms to create a smooth surface\n"
+            "Weight: weight of the energy terms altogether\n"
+            "Grad: weight of the gradient term\n"
+            "Bend: weight of the bending energy term\n"
+            "Curv: weight of the deviation of curvature term\n"
+            "Iterations: number of iterations\n"
+            "Correction: perform a parameter correction of each iteration step\n"
+            "PatchFactor: create an extended surface\n"
+            "UVDirs: set the u,v parameter directions as tuple of two vectors\n"
+            "        If not set then they will be determined by computing a best-fit plane\n"
         );
 #if defined(HAVE_PCL_SURFACE)
         add_keyword_method("triangulate",&Module::triangulate,
@@ -147,7 +157,7 @@ public:
         initialize("This module is the ReverseEngineering module."); // register with Python
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
     Py::Object approxSurface(const Py::Tuple& args, const Py::Dict& kwds)
@@ -248,8 +258,8 @@ private:
                 Base::Vector3d v = Py::Vector(t.getItem(1)).toVector();
                 pc.SetUV(u, v);
             }
-            pc.EnableSmoothing(PyObject_IsTrue(smooth) ? true : false, weight, grad, bend, curv);
-            hSurf = pc.CreateSurface(clPoints, iteration, PyObject_IsTrue(correction) ? true : false, factor);
+            pc.EnableSmoothing(Base::asBoolean(smooth), weight, grad, bend, curv);
+            hSurf = pc.CreateSurface(clPoints, iteration, Base::asBoolean(correction), factor);
             if (!hSurf.IsNull()) {
                 return Py::asObject(new Part::BSplineSurfacePy(new Part::GeomBSplineSurface(hSurf)));
             }
