@@ -20,25 +20,25 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#include <math_Gauss.hxx>
-#include <math_Householder.hxx>
-#include <Geom_BSplineSurface.hxx>
-#include <Precision.hxx>
+#ifndef _PreComp_
+# include <QFuture>
+# include <QFutureWatcher>
+# include <QtConcurrentMap>
 
-#include <QFuture>
-#include <QFutureWatcher>
-#include <QtConcurrentMap>
-#include <boost_bind_bind.hpp>
+# include <Geom_BSplineSurface.hxx>
+# include <math_Gauss.hxx>
+# include <math_Householder.hxx>
+# include <Precision.hxx>
+#endif
 
-#include <Mod/Mesh/App/Core/Approximation.h>
 #include <Base/Sequencer.h>
-#include <Base/Tools2D.h>
 #include <Base/Tools.h>
+#include <Mod/Mesh/App/Core/Approximation.h>
 
 #include "ApproxSurface.h"
 
+
 using namespace Reen;
 namespace bp = boost::placeholders;
 
@@ -589,7 +589,7 @@ void ParameterCorrection::CalcEigenvectors()
 bool ParameterCorrection::DoInitialParameterCorrection(double fSizeFactor)
 {
     // if directions are not given, calculate yourself
-    if (_bGetUVDir == false)
+    if (!_bGetUVDir)
         CalcEigenvectors();
     if (!GetUVParameters(fSizeFactor))
         return false;
@@ -721,7 +721,7 @@ Handle(Geom_BSplineSurface) ParameterCorrection::CreateSurface(const TColgp_Arra
                                                                bool  bParaCor,
                                                                double fSizeFactor)
 {
-    if (_pvcPoints != nullptr) {
+    if (_pvcPoints) {
         delete _pvcPoints;
         _pvcPoints = nullptr;
         delete _pvcUVParam;
@@ -1008,7 +1008,7 @@ namespace Reen {
 class ScalarProduct
 {
 public:
-    ScalarProduct(const math_Matrix& mat) : mat(mat)
+    explicit ScalarProduct(const math_Matrix& mat) : mat(mat)
     {
     }
     std::vector<double> multiply(int col) const
