@@ -20,51 +20,43 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef __PRECOMPILED__
 #define __PRECOMPILED__
 
 #include <FCConfig.h>
 
 #ifdef _MSC_VER
-#   pragma warning(disable : 4181)
-#   pragma warning(disable : 4267)
-#   pragma warning(disable : 4275)
-#   pragma warning(disable : 4305)
-#   pragma warning(disable : 4522)
+# pragma warning(disable : 4181)
+# pragma warning(disable : 4267)
+# pragma warning(disable : 4275)
+# pragma warning(disable : 4305)
+# pragma warning(disable : 4522)
 #endif
 
 // pcl headers include <boost/bind.hpp> instead of <boost/bind/bind.hpp>
 #ifndef BOOST_BIND_GLOBAL_PLACEHOLDERS
-#define BOOST_BIND_GLOBAL_PLACEHOLDERS
+# define BOOST_BIND_GLOBAL_PLACEHOLDERS
 #endif
 
 #ifdef _PreComp_
 
 // standard
-#include <iostream>
-#include <sstream>
-#include <cstdio>
-#include <cassert>
-#include <string>
 #include <map>
-#include <vector>
-#include <set>
-#include <bitset>
+
+// boost
+#include <boost/math/special_functions/fpclassify.hpp>
 
 // OpenCasCade
+#include <Geom_BSplineSurface.hxx>
 #include <math_Gauss.hxx>
 #include <math_Householder.hxx>
-#include <math_Matrix.hxx>
-#include <TColStd_Array1OfReal.hxx>
-#include <TColStd_Array1OfInteger.hxx>
+#include <Precision.hxx>
 #include <TColgp_Array1OfPnt.hxx>
-#include <TColgp_Array2OfPnt.hxx>
-#include <TColgp_Array1OfPnt2d.hxx>
-#include <Geom_BSplineSurface.hxx>
-#include <BRepBuilderAPI_MakeFace.hxx>
-#include <TopoDS_Face.hxx>
 
-#endif
+// Qt
+#include <QFuture>
+#include <QFutureWatcher>
+#include <QtConcurrentMap>
+
 #endif // _PreComp_
-
+#endif
