@@ -20,13 +20,12 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef REENGUI_POISSON_H
 #define REENGUI_POISSON_H
 
-#include <Gui/TaskView/TaskView.h>
 #include <Gui/TaskView/TaskDialog.h>
-#include <App/DocumentObserver.h>
+#include <Gui/TaskView/TaskView.h>
+
 
 namespace ReenGui {
 
@@ -35,13 +34,13 @@ class PoissonWidget : public QWidget
     Q_OBJECT
 
 public:
-    PoissonWidget(const App::DocumentObjectT&, QWidget* parent = nullptr);
-    ~PoissonWidget();
+    explicit PoissonWidget(const App::DocumentObjectT&, QWidget* parent = nullptr);
+    ~PoissonWidget() override;
 
     bool accept();
 
 private:
-    void changeEvent(QEvent *e);
+    void changeEvent(QEvent *e) override;
 
 private:
     class Private;
@@ -53,14 +52,14 @@ class TaskPoisson : public Gui::TaskView::TaskDialog
     Q_OBJECT
 
 public:
-    TaskPoisson(const App::DocumentObjectT&);
-    ~TaskPoisson();
+    explicit TaskPoisson(const App::DocumentObjectT&);
+    ~TaskPoisson() override;
 
 public:
-    void open();
-    bool accept();
+    void open() override;
+    bool accept() override;
 
-    QDialogButtonBox::StandardButtons getStandardButtons() const
+    QDialogButtonBox::StandardButtons getStandardButtons() const override
     { return QDialogButtonBox::Ok|QDialogButtonBox::Cancel; }
 
 private:
