@@ -20,17 +20,14 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <qobject.h>
-#endif
-
-#include "Workbench.h"
 #include <Gui/MenuManager.h>
 #include <Gui/ToolBarManager.h>
 
+#include "Workbench.h"
+
+
 using namespace ReverseEngineeringGui;
 
 #if 0 // needed for Qt's lupdate utility
