@@ -20,31 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
-
+# include "kdl_cp/chainiksolverpos_nr.hpp"
+# include "kdl_cp/chainiksolvervel_pinv.hpp"
+# include "kdl_cp/chainfksolverpos_recursive.hpp"
+# include "kdl_cp/frames_io.hpp"
 #endif
 
-#include "kdl_cp/chain.hpp"
-#include "kdl_cp/chainfksolver.hpp"
-#include "kdl_cp/chainfksolverpos_recursive.hpp"
-#include "kdl_cp/frames_io.hpp"
-#include "kdl_cp/chainiksolver.hpp"
-#include "kdl_cp/chainiksolvervel_pinv.hpp"
-#include "kdl_cp/chainjnttojacsolver.hpp"
-#include "kdl_cp/chainiksolverpos_nr.hpp"
-
-#include <cstdio>
-#include <iostream>
-
-#include <Base/Console.h>
-#include <Base/VectorPy.h>
-
-
 #include "RobotAlgos.h"
 
+
 using namespace Robot;
 using namespace std;
 using namespace KDL;
@@ -62,9 +48,7 @@ using namespace KDL;
 // FeatureView
 //===========================================================================
 
-
-
-RobotAlgos::RobotAlgos(void) 
+RobotAlgos::RobotAlgos()
 {
 	
 }
@@ -73,15 +57,15 @@ RobotAlgos::~RobotAlgos()
 {
 }
 
-void RobotAlgos::Test(void)
+void RobotAlgos::Test()
 {
-	    //Definition of a kinematic chain & add segments to the chain
+    // Definition of a kinematic chain & add segments to the chain
     KDL::Chain chain;
-    chain.addSegment(Segment(Joint(Joint::RotZ),Frame(Vector(0.0,0.0,1.020))));
-    chain.addSegment(Segment(Joint(Joint::RotX),Frame(Vector(0.0,0.0,0.480))));
-    chain.addSegment(Segment(Joint(Joint::RotX),Frame(Vector(0.0,0.0,0.645))));
+    chain.addSegment(Segment(Joint(Joint::RotZ), Frame(Vector(0.0, 0.0, 1.020))));
+    chain.addSegment(Segment(Joint(Joint::RotX), Frame(Vector(0.0, 0.0, 0.480))));
+    chain.addSegment(Segment(Joint(Joint::RotX), Frame(Vector(0.0, 0.0, 0.645))));
     chain.addSegment(Segment(Joint(Joint::RotZ)));
-    chain.addSegment(Segment(Joint(Joint::RotX),Frame(Vector(0.0,0.0,0.120))));
+    chain.addSegment(Segment(Joint(Joint::RotX), Frame(Vector(0.0, 0.0, 0.120))));
     chain.addSegment(Segment(Joint(Joint::RotZ)));
  
     // Create solver based on kinematic chain
@@ -92,12 +76,12 @@ void RobotAlgos::Test(void)
     KDL::JntArray jointpositions = JntArray(nj);
  
     // Assign some values to the joint positions
-    for(unsigned int i=0;i<nj;i++){
+    for (unsigned int i = 0; i < nj; i++) {
         float myinput;
-        printf ("Enter the position of joint %i: ",i);
-        int result = scanf ("%e",&myinput);
-	(void)result;
-        jointpositions(i)=(double)myinput;
+        printf("Enter the position of joint %i: ", i);
+        int result = scanf("%e", &myinput);
+        (void)result;
+        jointpositions(i) = (double)myinput;
     }
  
     // Create the frame that will contain the results
@@ -106,31 +90,30 @@ void RobotAlgos::Test(void)
     // Calculate forward position kinematics
     int kinematics_status;
     kinematics_status = fksolver.JntToCart(jointpositions,cartpos);
-    if(kinematics_status>=0){
-        std::cout << cartpos <<std::endl;
-        printf("%s \n","Success, thanks KDL!");
-    }else{
-        printf("%s \n","Error: could not calculate forward kinematics :(");
+    if (kinematics_status >= 0) {
+        std::cout << cartpos << std::endl;
+        printf("%s \n", "Success, thanks KDL!");
+    }
+    else {
+        printf("%s \n", "Error: could not calculate forward kinematics :(");
     }
 
-
-	//Creation of the solvers:
-	ChainFkSolverPos_recursive fksolver1(chain);//Forward position solver
-	ChainIkSolverVel_pinv iksolver1v(chain);//Inverse velocity solver
-	ChainIkSolverPos_NR iksolver1(chain,fksolver1,iksolver1v,100,1e-6);//Maximum 100 iterations, stop at accuracy 1e-6
+	// Creation of the solvers:
+    ChainFkSolverPos_recursive fksolver1(chain);// Forward position solver
+    ChainIkSolverVel_pinv iksolver1v(chain);    // Inverse velocity solver
+    ChainIkSolverPos_NR iksolver1(chain, fksolver1, iksolver1v,
+        100, 1e-6);// Maximum 100 iterations, stop at accuracy 1e-6
 	 
-	//Creation of jntarrays:
+	// Creation of jntarrays:
 	JntArray result(chain.getNrOfJoints());
 	JntArray q_init(chain.getNrOfJoints());
 	 
-	//Set destination frame
+	// Set destination frame
 	Frame F_dest=cartpos;
 	 
 	iksolver1.CartToJnt(q_init,F_dest,result);
 
-	for(unsigned int i=0;i<nj;i++){
-        printf ("Axle %i: %f \n",i,result(i));
-    }
-
+	for (unsigned int i = 0; i < nj; i++)
+        printf("Axle %i: %f \n", i, result(i));
 
 }
