@@ -20,36 +20,19 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-
-#endif
-
-#include "kdl_cp/chain.hpp"
-#include "kdl_cp/frames_io.hpp"
-
-#include <cstdio>
-#include <iostream>
-
-#include <Base/Console.h>
-
-
 #include "Simulation.h"
 
+
 using namespace Robot;
 using namespace std;
 using namespace KDL;
 
-
-
 //===========================================================================
 // Simulation class
 //===========================================================================
 
-
-
 Simulation::Simulation(const Robot::Trajectory &Trac,Robot::Robot6Axis &Rob)
 :Pos(0.0),Trac(Trac),Rob(Rob)
 {
@@ -97,7 +80,7 @@ void Simulation::setToTime(float t)
 
 }
 
-void Simulation::reset(void)
+void Simulation::reset()
 {
     Rob.setAxis(0,startAxis[0]);
     Rob.setAxis(1,startAxis[1]);
