@@ -20,30 +20,28 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
 # include <memory>
+
+# include "kdl_cp/path_line.hpp"
+# include "kdl_cp/path_roundedcomposite.hpp"
+# include "kdl_cp/rotational_interpolation_sa.hpp"
+# include "kdl_cp/trajectory_composite.hpp"
+# include "kdl_cp/trajectory_segment.hpp"
+# include "kdl_cp/utilities/error.h"
+# include "kdl_cp/velocityprofile_trap.hpp"
 #endif
 
-#include <Base/Writer.h>
-#include <Base/Reader.h>
 #include <Base/Exception.h>
-
-#include "kdl_cp/chain.hpp"
-#include "kdl_cp/path_line.hpp"
-#include "kdl_cp/path_roundedcomposite.hpp"
-#include "kdl_cp/trajectory_composite.hpp"
-#include "kdl_cp/rotational_interpolation_sa.hpp"
-#include "kdl_cp/velocityprofile_trap.hpp"
-#include "kdl_cp/trajectory_segment.hpp"
-#include "kdl_cp/path_roundedcomposite.hpp"
-#include "kdl_cp/utilities/error.h"
+#include <Base/Reader.h>
+#include <Base/Writer.h>
 
 #include "Trajectory.h"
 #include "RobotAlgos.h"
 
+
 #ifndef M_PI
     #define M_PI 3.14159265358979323846
     #define M_PI    3.14159265358979323846 /* pi */
@@ -146,9 +144,9 @@ void Trajectory::deleteLast(unsigned int n)
 
 }
 
-void Trajectory::generateTrajectory(void)
+void Trajectory::generateTrajectory()
 {
-    if (vpcWaypoints.size() == 0)
+    if (vpcWaypoints.empty())
         return;
 
     // delete the old and create a new one
@@ -194,7 +192,7 @@ void Trajectory::generateTrajectory(void)
                         pcRoundComp->Add(Next);
                         // end a continuous block
                     }
-                    else if (Cont == false && pcRoundComp) {
+                    else if (!Cont && pcRoundComp) {
                         // add the last one
                         pcRoundComp->Add(Next);
                         pcRoundComp->Finish();
@@ -203,7 +201,7 @@ void Trajectory::generateTrajectory(void)
 
                         // normal block
                     }
-                    else if (Cont == false && !pcRoundComp) {
+                    else if (!Cont && !pcRoundComp) {
                         KDL::Path* pcPath;
                         pcPath = new KDL::Path_Line(Last,
                             Next,
@@ -268,7 +266,7 @@ std::string Trajectory::getUniqueWaypointName(const char *Name) const
             const std::string &ObjName = (*it)->Name;
             if (ObjName.substr(0, CleanName.length()) == CleanName) { // same prefix
                 std::string clSuffix(ObjName.substr(CleanName.length()));
-                if (clSuffix.size() > 0) {
+                if (!clSuffix.empty()) {
                     std::string::size_type nPos = clSuffix.find_first_not_of("0123456789");
                     if (nPos==std::string::npos)
                         nSuff = std::max<int>(nSuff, std::atol(clSuffix.c_str()));
@@ -293,7 +291,7 @@ void Trajectory::addWaypoint(const Waypoint &WPnt)
 
 
 
-unsigned int Trajectory::getMemSize (void) const
+unsigned int Trajectory::getMemSize () const
 {
 	return 0;
 }
