@@ -20,33 +20,26 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <QInputDialog>
 # include <QMessageBox>
 #endif
 
-#include <App/Application.h>
 #include <Gui/Application.h>
 #include <Gui/Command.h>
-#include <Gui/MainWindow.h>
-#include <Gui/FileDialog.h>
-#include <Gui/Selection.h>
 #include <Gui/Document.h>
+#include <Gui/MainWindow.h>
 #include <Gui/Placement.h>
-#include <Gui/Control.h>
-
-
-#include <Mod/Part/App/PartFeature.h>
-#include <Mod/Robot/App/RobotObject.h>
-#include <Mod/Robot/App/TrajectoryObject.h>
+#include <Gui/Selection.h>
 #include <Mod/Robot/App/Edge2TracObject.h>
-#include <Mod/Robot/App/TrajectoryDressUpObject.h>
+#include <Mod/Robot/App/RobotObject.h>
 #include <Mod/Robot/App/TrajectoryCompound.h>
+#include <Mod/Robot/App/TrajectoryDressUpObject.h>
+#include <Mod/Robot/App/TrajectoryObject.h>
+
 #include "TaskDlgEdge2Trac.h"
 
-#include "TrajectorySimulate.h"
 
 using namespace std;
 using namespace RobotGui;
@@ -79,7 +72,7 @@ void CmdRobotCreateTrajectory::activated(int)
 
 }
 
-bool CmdRobotCreateTrajectory::isActive(void)
+bool CmdRobotCreateTrajectory::isActive()
 {
     return hasActiveDocument();
 }
@@ -136,7 +129,7 @@ void CmdRobotInsertWaypoint::activated(int)
 
 }
 
-bool CmdRobotInsertWaypoint::isActive(void)
+bool CmdRobotInsertWaypoint::isActive()
 {
     return hasActiveDocument();
 }
@@ -178,16 +171,16 @@ void CmdRobotInsertWaypointPreselect::activated(int)
 
 
     Robot::TrajectoryObject *pcTrajectoryObject;
-    if(Sel[0].pObject->getTypeId() == Robot::TrajectoryObject::getClassTypeId())
+    if (Sel[0].pObject->getTypeId() == Robot::TrajectoryObject::getClassTypeId())
         pcTrajectoryObject = static_cast<Robot::TrajectoryObject*>(Sel[0].pObject);
-    else  {
+    else {
         QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
             QObject::tr("Select one Trajectory object."));
         return;
     }
     std::string TrakName = pcTrajectoryObject->getNameInDocument();
 
-    if(PreSel.pDocName == nullptr){
+    if (!PreSel.pDocName) {
         QMessageBox::warning(Gui::getMainWindow(), QObject::tr("No preselection"),
             QObject::tr("You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details."));
         return;
@@ -200,7 +193,7 @@ void CmdRobotInsertWaypointPreselect::activated(int)
 
 }
 
-bool CmdRobotInsertWaypointPreselect::isActive(void)
+bool CmdRobotInsertWaypointPreselect::isActive()
 {
     return hasActiveDocument();
 }
@@ -227,6 +220,7 @@ void CmdRobotSetDefaultOrientation::activated(int)
 {
     // create placement dialog
     Gui::Dialog::Placement Dlg;
+    Dlg.setSelection(Gui::Selection().getSelectionEx());
     Base::Placement place;
     Dlg.setPlacement(place);
     if (Dlg.exec() == QDialog::Accepted ){
@@ -238,7 +232,7 @@ void CmdRobotSetDefaultOrientation::activated(int)
     }
 }
 
-bool CmdRobotSetDefaultOrientation::isActive(void)
+bool CmdRobotSetDefaultOrientation::isActive()
 {
     return true;
 }
@@ -304,7 +298,7 @@ void CmdRobotSetDefaultValues::activated(int)
 
 }
 
-bool CmdRobotSetDefaultValues::isActive(void)
+bool CmdRobotSetDefaultValues::isActive()
 {
     return true;
 }
@@ -368,7 +362,7 @@ void CmdRobotEdge2Trac::activated(int)
 
 }
 
-bool CmdRobotEdge2Trac::isActive(void)
+bool CmdRobotEdge2Trac::isActive()
 {
     return true;
 }
@@ -415,7 +409,7 @@ void CmdRobotTrajectoryDressUp::activated(int)
     }
  }
 
-bool CmdRobotTrajectoryDressUp::isActive(void)
+bool CmdRobotTrajectoryDressUp::isActive()
 {
     return true;
 }
@@ -455,7 +449,7 @@ void CmdRobotTrajectoryCompound::activated(int)
     }
 }
 
-bool CmdRobotTrajectoryCompound::isActive(void)
+bool CmdRobotTrajectoryCompound::isActive()
 {
     return true;
 }
@@ -466,7 +460,7 @@ bool CmdRobotTrajectoryCompound::isActive(void)
 
 
 
-void CreateRobotCommandsTrajectory(void)
+void CreateRobotCommandsTrajectory()
 {
     Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
 
