@@ -4,17 +4,17 @@
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="215"/>
+      <location filename="../../CommandInsertRobot.cpp" line="210"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="216"/>
+      <location filename="../../CommandInsertRobot.cpp" line="211"/>
       <source>Add tool</source>
       <translation>新增工具</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="217"/>
+      <location filename="../../CommandInsertRobot.cpp" line="212"/>
       <source>Add a tool shape to the robot</source>
       <translation>於機器人上增加工具造型</translation>
     </message>
@@ -22,17 +22,17 @@
   <context>
     <name>CmdRobotConstraintAxle</name>
     <message>
-      <location filename="../../Command.cpp" line="159"/>
+      <location filename="../../Command.cpp" line="154"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="160"/>
+      <location filename="../../Command.cpp" line="155"/>
       <source>Place robot...</source>
       <translation>放置機器人...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="161"/>
+      <location filename="../../Command.cpp" line="156"/>
       <source>Place a robot (experimental!)</source>
       <translation>放置一個機器人(測試!)</translation>
     </message>
@@ -40,17 +40,17 @@
   <context>
     <name>CmdRobotCreateTrajectory</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="62"/>
+      <location filename="../../CommandTrajectory.cpp" line="55"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="63"/>
+      <location filename="../../CommandTrajectory.cpp" line="56"/>
       <source>Create trajectory</source>
       <translation>建立軌跡</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="64"/>
+      <location filename="../../CommandTrajectory.cpp" line="57"/>
       <source>Create a new empty trajectory</source>
       <translation>建立新的空白軌跡</translation>
     </message>
@@ -58,17 +58,17 @@
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="320"/>
+      <location filename="../../CommandTrajectory.cpp" line="314"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="321"/>
+      <location filename="../../CommandTrajectory.cpp" line="315"/>
       <source>Edge to Trajectory...</source>
       <translation>邊至軌跡...</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="322"/>
+      <location filename="../../CommandTrajectory.cpp" line="316"/>
       <source>Generate a Trajectory from a set of edges</source>
       <translation>由一組邊產生軌跡</translation>
     </message>
@@ -76,17 +76,17 @@
   <context>
     <name>CmdRobotExportKukaCompact</name>
     <message>
-      <location filename="../../CommandExport.cpp" line="50"/>
+      <location filename="../../CommandExport.cpp" line="46"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="51"/>
+      <location filename="../../CommandExport.cpp" line="47"/>
       <source>Kuka compact subroutine...</source>
       <translation>Kuka精簡子程式...</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="52"/>
+      <location filename="../../CommandExport.cpp" line="48"/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
       <translation>以精簡KRL子程式匯出軌跡</translation>
     </message>
@@ -94,17 +94,17 @@
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
-      <location filename="../../CommandExport.cpp" line="112"/>
+      <location filename="../../CommandExport.cpp" line="108"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="113"/>
+      <location filename="../../CommandExport.cpp" line="109"/>
       <source>Kuka full subroutine...</source>
       <translation>Kuka完整子程式...</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="114"/>
+      <location filename="../../CommandExport.cpp" line="110"/>
       <source>Export the trajectory as a full KRL subroutine.</source>
       <translation>以完整KRL子程式匯出軌跡</translation>
     </message>
@@ -112,17 +112,17 @@
   <context>
     <name>CmdRobotInsertKukaIR125</name>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="174"/>
+      <location filename="../../CommandInsertRobot.cpp" line="169"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="175"/>
+      <location filename="../../CommandInsertRobot.cpp" line="170"/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="176"/>
+      <location filename="../../CommandInsertRobot.cpp" line="171"/>
       <source>Insert a Kuka IR125 into the document.</source>
       <translation>於此文件中插入Kula IR125</translation>
     </message>
@@ -130,17 +130,17 @@
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="93"/>
+      <location filename="../../CommandInsertRobot.cpp" line="88"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="94"/>
+      <location filename="../../CommandInsertRobot.cpp" line="89"/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="95"/>
+      <location filename="../../CommandInsertRobot.cpp" line="90"/>
       <source>Insert a Kuka IR16 into the document.</source>
       <translation>於此文件中插入Kula IR16</translation>
     </message>
@@ -148,17 +148,17 @@
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="134"/>
+      <location filename="../../CommandInsertRobot.cpp" line="129"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="135"/>
+      <location filename="../../CommandInsertRobot.cpp" line="130"/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="136"/>
+      <location filename="../../CommandInsertRobot.cpp" line="131"/>
       <source>Insert a Kuka IR210 into the document.</source>
       <translation>於此文件中插入Kula IR210</translation>
     </message>
@@ -166,17 +166,17 @@
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="51"/>
+      <location filename="../../CommandInsertRobot.cpp" line="46"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="52"/>
+      <location filename="../../CommandInsertRobot.cpp" line="47"/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="53"/>
+      <location filename="../../CommandInsertRobot.cpp" line="48"/>
       <source>Insert a Kuka IR500 into the document.</source>
       <translation>於此文件中插入Kula IR500</translation>
     </message>
@@ -184,17 +184,17 @@
   <context>
     <name>CmdRobotInsertWaypoint</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="95"/>
+      <location filename="../../CommandTrajectory.cpp" line="88"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="96"/>
+      <location filename="../../CommandTrajectory.cpp" line="89"/>
       <source>Insert in trajectory</source>
       <translation>於軌跡中插入</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="97"/>
+      <location filename="../../CommandTrajectory.cpp" line="90"/>
       <source>Insert robot Tool location into trajectory</source>
       <translation>插入機器人工具位置至軌跡中</translation>
     </message>
@@ -202,17 +202,17 @@
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="152"/>
+      <location filename="../../CommandTrajectory.cpp" line="145"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="153"/>
+      <location filename="../../CommandTrajectory.cpp" line="146"/>
       <source>Insert in trajectory</source>
       <translation>於軌跡中插入</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="154"/>
+      <location filename="../../CommandTrajectory.cpp" line="147"/>
       <source>Insert preselection position into trajectory (W)</source>
       <translation>插入預選位置至軌跡(W)</translation>
     </message>
@@ -220,13 +220,13 @@
   <context>
     <name>CmdRobotRestoreHomePos</name>
     <message>
-      <location filename="../../Command.cpp" line="105"/>
+      <location filename="../../Command.cpp" line="100"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="106"/>
-      <location filename="../../Command.cpp" line="107"/>
+      <location filename="../../Command.cpp" line="101"/>
+      <location filename="../../Command.cpp" line="102"/>
       <source>Move to home</source>
       <translation>移動至原點</translation>
     </message>
@@ -234,17 +234,17 @@
   <context>
     <name>CmdRobotSetDefaultOrientation</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="216"/>
+      <location filename="../../CommandTrajectory.cpp" line="209"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="217"/>
+      <location filename="../../CommandTrajectory.cpp" line="210"/>
       <source>Set default orientation</source>
       <translation>設定預設方向</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="218"/>
+      <location filename="../../CommandTrajectory.cpp" line="211"/>
       <source>Set the default orientation for subsequent commands for waypoint creation</source>
       <translation>設定預設的方向為後續建立航點的命令</translation>
     </message>
@@ -252,17 +252,17 @@
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="254"/>
+      <location filename="../../CommandTrajectory.cpp" line="248"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="255"/>
+      <location filename="../../CommandTrajectory.cpp" line="249"/>
       <source>Set default values</source>
       <translation>設定預設值</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="256"/>
+      <location filename="../../CommandTrajectory.cpp" line="250"/>
       <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
       <translation>設定預設值給速率, 加速度和連續性為了後續命令建立新航點</translation>
     </message>
@@ -270,13 +270,13 @@
   <context>
     <name>CmdRobotSetHomePos</name>
     <message>
-      <location filename="../../Command.cpp" line="56"/>
+      <location filename="../../Command.cpp" line="51"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="57"/>
-      <location filename="../../Command.cpp" line="58"/>
+      <location filename="../../Command.cpp" line="52"/>
+      <location filename="../../Command.cpp" line="53"/>
       <source>Set the home position</source>
       <translation>設定原點位置</translation>
     </message>
@@ -284,17 +284,17 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
-      <location filename="../../Command.cpp" line="200"/>
+      <location filename="../../Command.cpp" line="195"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="201"/>
+      <location filename="../../Command.cpp" line="196"/>
       <source>Simulate a trajectory</source>
       <translation>模擬軌跡</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="202"/>
+      <location filename="../../Command.cpp" line="197"/>
       <source>Run a simulation on a trajectory</source>
       <translation>於軌跡上進行模擬</translation>
     </message>
@@ -302,17 +302,17 @@
   <context>
     <name>CmdRobotTrajectoryCompound</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="431"/>
+      <location filename="../../CommandTrajectory.cpp" line="425"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="432"/>
+      <location filename="../../CommandTrajectory.cpp" line="426"/>
       <source>Trajectory compound...</source>
       <translation>軌跡物件...</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="433"/>
+      <location filename="../../CommandTrajectory.cpp" line="427"/>
       <source>Group and connect some trajectories to one</source>
       <translation>連結並群組數個軌跡成一個</translation>
     </message>
@@ -320,17 +320,17 @@
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="384"/>
+      <location filename="../../CommandTrajectory.cpp" line="378"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="385"/>
+      <location filename="../../CommandTrajectory.cpp" line="379"/>
       <source>Dress-up trajectory...</source>
       <translation>修改軌跡</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="386"/>
+      <location filename="../../CommandTrajectory.cpp" line="380"/>
       <source>Create a dress-up object which overrides some aspects of a trajectory</source>
       <translation>建立覆蓋軌跡部分設定的修改物件</translation>
     </message>
@@ -338,17 +338,17 @@
   <context>
     <name>Gui::TaskView::TaskWatcherCommands</name>
     <message>
-      <location filename="../../Workbench.cpp" line="53"/>
+      <location filename="../../Workbench.cpp" line="51"/>
       <source>Trajectory tools</source>
       <translation>軌跡工具</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="54"/>
+      <location filename="../../Workbench.cpp" line="52"/>
       <source>Robot tools</source>
       <translation>機器人設定工具</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="55"/>
+      <location filename="../../Workbench.cpp" line="53"/>
       <source>Insert Robot</source>
       <translation>插入機器人</translation>
     </message>
@@ -356,135 +356,135 @@
   <context>
     <name>QObject</name>
     <message>
-      <location filename="../../Command.cpp" line="76"/>
-      <location filename="../../Command.cpp" line="125"/>
-      <location filename="../../Command.cpp" line="225"/>
-      <location filename="../../Command.cpp" line="254"/>
-      <location filename="../../CommandExport.cpp" line="65"/>
-      <location filename="../../CommandExport.cpp" line="127"/>
-      <location filename="../../CommandInsertRobot.cpp" line="234"/>
-      <location filename="../../CommandTrajectory.cpp" line="111"/>
-      <location filename="../../CommandTrajectory.cpp" line="167"/>
-      <location filename="../../CommandTrajectory.cpp" line="184"/>
-      <location filename="../../CommandTrajectory.cpp" line="412"/>
+      <location filename="../../CommandInsertRobot.cpp" line="229"/>
+      <location filename="../../CommandTrajectory.cpp" line="104"/>
+      <location filename="../../CommandTrajectory.cpp" line="160"/>
+      <location filename="../../CommandTrajectory.cpp" line="177"/>
+      <location filename="../../CommandTrajectory.cpp" line="406"/>
+      <location filename="../../Command.cpp" line="71"/>
+      <location filename="../../Command.cpp" line="120"/>
+      <location filename="../../Command.cpp" line="220"/>
+      <location filename="../../Command.cpp" line="249"/>
+      <location filename="../../CommandExport.cpp" line="61"/>
+      <location filename="../../CommandExport.cpp" line="123"/>
       <source>Wrong selection</source>
       <translation>錯誤的選取</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="77"/>
+      <location filename="../../Command.cpp" line="72"/>
       <source>Select one Robot to set home position</source>
       <translation>選擇要設置起始位置之機器人</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="126"/>
+      <location filename="../../Command.cpp" line="121"/>
       <source>Select one Robot</source>
       <translation>選取一機器人</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="226"/>
-      <location filename="../../Command.cpp" line="255"/>
-      <location filename="../../CommandExport.cpp" line="66"/>
-      <location filename="../../CommandExport.cpp" line="128"/>
-      <location filename="../../CommandTrajectory.cpp" line="112"/>
+      <location filename="../../CommandTrajectory.cpp" line="105"/>
+      <location filename="../../Command.cpp" line="221"/>
+      <location filename="../../Command.cpp" line="250"/>
+      <location filename="../../CommandExport.cpp" line="62"/>
+      <location filename="../../CommandExport.cpp" line="124"/>
       <source>Select one Robot and one Trajectory object.</source>
       <translation>選取一個機器人和一軌跡物件</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="231"/>
+      <location filename="../../Command.cpp" line="226"/>
       <source>Trajectory not valid</source>
       <translation>無效軌跡</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="232"/>
+      <location filename="../../Command.cpp" line="227"/>
       <source>You need at least two waypoints in a trajectory to simulate.</source>
       <translation>軌跡中至少需要兩個航路點才能進行模擬.</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="88"/>
-      <location filename="../../CommandExport.cpp" line="150"/>
+      <location filename="../../CommandExport.cpp" line="84"/>
+      <location filename="../../CommandExport.cpp" line="146"/>
       <source>KRL file</source>
       <translation>KRL 檔</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="89"/>
-      <location filename="../../CommandExport.cpp" line="151"/>
+      <location filename="../../CommandExport.cpp" line="85"/>
+      <location filename="../../CommandExport.cpp" line="147"/>
       <source>All Files</source>
       <translation>所有檔案</translation>
     </message>
     <message>
-      <location filename="../../CommandExport.cpp" line="90"/>
-      <location filename="../../CommandExport.cpp" line="152"/>
+      <location filename="../../CommandExport.cpp" line="86"/>
+      <location filename="../../CommandExport.cpp" line="148"/>
       <source>Export program</source>
       <translation>匯出程式</translation>
     </message>
     <message>
-      <location filename="../../CommandInsertRobot.cpp" line="235"/>
+      <location filename="../../CommandInsertRobot.cpp" line="230"/>
       <source>Select one robot and one shape or VRML object.</source>
       <translation>選取一個機器人和一造型或VRML物件</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="168"/>
-      <location filename="../../CommandTrajectory.cpp" line="185"/>
+      <location filename="../../CommandTrajectory.cpp" line="161"/>
+      <location filename="../../CommandTrajectory.cpp" line="178"/>
       <source>Select one Trajectory object.</source>
       <translation>選取一軌跡物件</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="191"/>
+      <location filename="../../CommandTrajectory.cpp" line="184"/>
       <source>No preselection</source>
       <translation>無預選</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="192"/>
+      <location filename="../../CommandTrajectory.cpp" line="185"/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
       <translation>您需要將滑鼠停留於幾何(預選)上方來使用此功能,相系說明請查詢文件</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="268"/>
+      <location filename="../../CommandTrajectory.cpp" line="262"/>
       <source>Set default speed</source>
       <translation>設定預設的速率</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="269"/>
+      <location filename="../../CommandTrajectory.cpp" line="263"/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
       <translation>速度：(e.g. 1 m/s or 3 cm/s)</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="278"/>
+      <location filename="../../CommandTrajectory.cpp" line="272"/>
       <source>Set default continuity</source>
       <translation>設定預設的連續性</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="279"/>
+      <location filename="../../CommandTrajectory.cpp" line="273"/>
       <source>continuous ?</source>
       <translation>連續?</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="285"/>
+      <location filename="../../CommandTrajectory.cpp" line="279"/>
       <source>Set default acceleration</source>
       <translation>設定預設加速度</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="286"/>
+      <location filename="../../CommandTrajectory.cpp" line="280"/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
       <translation>加速度：(e.g. 1 m/s^2 or 3 cm/s^2)</translation>
     </message>
     <message>
-      <location filename="../../CommandTrajectory.cpp" line="413"/>
+      <location filename="../../CommandTrajectory.cpp" line="407"/>
       <source>Select the Trajectory which you want to dress up.</source>
       <translation>選取您想要修改的軌跡</translation>
     </message>
     <message>
-      <location filename="../../ViewProviderTrajectory.cpp" line="164"/>
+      <location filename="../../ViewProviderTrajectory.cpp" line="149"/>
       <source>Modify</source>
       <translation>修改</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="81"/>
+      <location filename="../../Workbench.cpp" line="79"/>
       <source>No robot files installed</source>
       <translation>無安裝之機器人檔案</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="82"/>
+      <location filename="../../Workbench.cpp" line="80"/>
       <source>Please visit %1 and copy the files to %2</source>
       <translation>請參照%1並複製至檔案%2</translation>
     </message>
@@ -506,11 +506,6 @@
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
-    <message>
-      <location filename="../../TrajectorySimulate.ui" line="120"/>
-      <source>||</source>
-      <translation>||</translation>
-    </message>
     <message>
       <location filename="../../TrajectorySimulate.ui" line="151"/>
       <source>|&gt;</source>
@@ -526,11 +521,6 @@
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
-    <message>
-      <location filename="../../TrajectorySimulate.ui" line="237"/>
-      <source>%</source>
-      <translation>％</translation>
-    </message>
     <message>
       <location filename="../../TrajectorySimulate.ui" line="272"/>
       <source>Type</source>
@@ -560,7 +550,7 @@
   <context>
     <name>RobotGui::TaskEdge2TracParameter</name>
     <message>
-      <location filename="../../TaskEdge2TracParameter.cpp" line="47"/>
+      <location filename="../../TaskEdge2TracParameter.cpp" line="42"/>
       <source>TaskEdge2TracParameter</source>
       <translation type="unfinished">TaskEdge2TracParameter</translation>
     </message>
@@ -613,12 +603,7 @@
       <translation>工具： (0,0,400,0,0,0)</translation>
     </message>
     <message>
-      <location filename="../../TaskRobot6Axis.ui" line="345"/>
-      <source>...</source>
-      <translation>...</translation>
-    </message>
-    <message>
-      <location filename="../../TaskRobot6Axis.cpp" line="52"/>
+      <location filename="../../TaskRobot6Axis.cpp" line="41"/>
       <source>TaskRobot6Axis</source>
       <translation type="unfinished">TaskRobot6Axis</translation>
     </message>
@@ -626,7 +611,7 @@
   <context>
     <name>RobotGui::TaskRobotControl</name>
     <message>
-      <location filename="../../TaskRobotControl.cpp" line="46"/>
+      <location filename="../../TaskRobotControl.cpp" line="35"/>
       <source>TaskRobotControl</source>
       <translation type="unfinished">TaskRobotControl</translation>
     </message>
@@ -634,7 +619,7 @@
   <context>
     <name>RobotGui::TaskRobotMessages</name>
     <message>
-      <location filename="../../TaskRobotMessages.cpp" line="46"/>
+      <location filename="../../TaskRobotMessages.cpp" line="35"/>
       <source>TaskRobotMessages</source>
       <translation type="unfinished">TaskRobotMessages</translation>
     </message>
@@ -656,11 +641,6 @@
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
-    <message>
-      <location filename="../../TaskTrajectory.ui" line="120"/>
-      <source>||</source>
-      <translation>||</translation>
-    </message>
     <message>
       <location filename="../../TaskTrajectory.ui" line="151"/>
       <source>|&gt;</source>
@@ -676,11 +656,6 @@
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
-    <message>
-      <location filename="../../TaskTrajectory.ui" line="237"/>
-      <source>%</source>
-      <translation>％</translation>
-    </message>
     <message>
       <location filename="../../TaskTrajectory.ui" line="254"/>
       <source>10 ms</source>
@@ -737,7 +712,7 @@
       <translation>A</translation>
     </message>
     <message>
-      <location filename="../../TaskTrajectory.cpp" line="44"/>
+      <location filename="../../TaskTrajectory.cpp" line="37"/>
       <source>Trajectory</source>
       <translation type="unfinished">Trajectory</translation>
     </message>
@@ -745,7 +720,7 @@
   <context>
     <name>RobotGui::TaskTrajectoryDressUpParameter</name>
     <message>
-      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="48"/>
+      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="41"/>
       <source>Dress Up Parameter</source>
       <translation type="unfinished">Dress Up Parameter</translation>
     </message>
@@ -962,16 +937,6 @@
       <source>Position and Orientation:</source>
       <translation>位置和方向：</translation>
     </message>
-    <message>
-      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="136"/>
-      <source>(0,0,0),(0,0,0)</source>
-      <translation>(0,0,0),(0,0,0)</translation>
-    </message>
-    <message>
-      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="149"/>
-      <source>...</source>
-      <translation>...</translation>
-    </message>
     <message>
       <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
       <source>Don't change Position &amp; Orientation</source>
@@ -996,22 +961,22 @@
   <context>
     <name>Workbench</name>
     <message>
-      <location filename="../../Workbench.cpp" line="49"/>
+      <location filename="../../Workbench.cpp" line="47"/>
       <source>Robot</source>
       <translation>機器人</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="50"/>
+      <location filename="../../Workbench.cpp" line="48"/>
       <source>Insert Robots</source>
       <translation>插入機器人</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="51"/>
+      <location filename="../../Workbench.cpp" line="49"/>
       <source>&amp;Robot</source>
       <translation>&amp;機器人</translation>
     </message>
     <message>
-      <location filename="../../Workbench.cpp" line="52"/>
+      <location filename="../../Workbench.cpp" line="50"/>
       <source>Export trajectory</source>
       <translation>匯出軌跡</translation>
     </message>
