@@ -1,6 +1,5 @@
 #/***************************************************************************
-# *   Copyright (c) Victor Titov (DeepSOIC)                                 *
-# *                                           (vv.titov@gmail.com) 2016     *
+# *   Copyright (c) 2016 Victor Titov (DeepSOIC) <vv.titov@gmail.com>       *
 # *                                                                         *
 # *   This file is part of the FreeCAD CAx development system.              *
 # *                                                                         *
@@ -21,7 +20,7 @@
 # *                                                                         *
 # ***************************************************************************/
 
-# module is named mTempoVis, because Show.TimpoVis exposes the class as its member, and hides the module TempoVis.py.
+# module is named mTempoVis, because Show.TimpoVis exposes the class as its member, and hides the module TempoVis.py
 
 from . import Containers
 
@@ -37,7 +36,7 @@ Log = lambda msg: App.Console.PrintLog(msg + "\n")
 from copy import copy
 
 S_EMPTY = 0 # TV is initialized, but no changes were done through it
-S_ACTIVE = 1 # TV has something to be undone 
+S_ACTIVE = 1 # TV has something to be undone
 S_RESTORED = 2 # TV has been restored
 S_INTERNAL = 3 # TV instance is being used by another TV instance as a redo data storage
 
@@ -61,15 +60,15 @@ class TempoVis(object):
     then restoring all visibilities after editing.
 
     Constructors:
-    TempoVis(document, stack = MAINSTACK, **kwargs): creates a new TempoVis. 
-    
+    TempoVis(document, stack = MAINSTACK, **kwargs): creates a new TempoVis.
+
     document: required. Objects not belonging to the document can't be modified via TempoVis.
-    
+
     stack: optional. Which stack to insert this new TV into. Can be:
-    a TVStack instance (then, the new TV is added to the top of the stack), 
-    MAINSTACK special value (a global stack for the document will be used), or 
+    a TVStack instance (then, the new TV is added to the top of the stack),
+    MAINSTACK special value (a global stack for the document will be used), or
     None (then, the TV is not in any stack, and can be manually instertd into one if desired).
-    
+
     Any additional keyword args are assigned as attributes. You can use it to immediately set a tag, for example.'''
 
     document = None
@@ -77,47 +76,47 @@ class TempoVis(object):
 
     data = None # dict. key = ("class_id","key"), value = instance of SceneDetail
     data_requested = None #same as data, but stores (wanted) values passed to modify()
-    
+
     state = S_EMPTY
-    
+
     tag = '' #stores any user-defined string for identification purposes
 
     def _init_attrs(self):
         '''initialize member variables to empty values (needed because we can't use mutable initial values when initializing member variables in class definition)'''
         self.data = {}
         self.data_requested = {}
-        
+
   #<core interface>
     def __init__(self, document, stack = MAINSTACK, **kwargs):
         self._init_attrs()
         self.document = document
-        
+
         if stack is MAINSTACK:
             stack = TVStack.mainStack(document)
-        
+
         if stack is None:
             pass
         else:
             stack.insert(self)
-        
+
         for key,val in kwargs.items():
             setattr(self, key, val)
-    
+
     def __del__(self):
         if self.state == S_ACTIVE:
             self.restore(ultimate= True)
-    
+
     def has(self, detail):
         '''has(self, detail): returns True if this TV has this detail value saved.
         example: tv.has(VProperty(obj, "Visibility"))'''
         return detail.full_key in self.data
-    
+
     def stored_val(self, detail):
         '''stored_val(self, detail): returns value of detail remembered by this TV. If not, raises KeyError.'''
         return self.data[detail.full_key].data
 
     def save(self, detail, mild_restore = False):
-        '''save(detail, mild_restore = False):saves the scene detail to be restored. 
+        '''save(detail, mild_restore = False):saves the scene detail to be restored.
         The detail is saved only once; repeated calls are ignored.
         mild_restore: internal, do not use.'''
         self._change()
@@ -133,36 +132,36 @@ class TempoVis(object):
                 stored_dt.mild_restore = False
 
     def modify(self, detail, mild_restore = None):
-        '''modify(detail, mild_restore = True): modifies scene detail through this TV. 
+        '''modify(detail, mild_restore = True): modifies scene detail through this TV.
         The value is provided as an instance of SceneDetail implementation.
-        The procedure takes care to account for the stack - that is, if in a TV applied 
-        later than this one this detail was changed too, the value saved therein is altered, 
+        The procedure takes care to account for the stack - that is, if in a TV applied
+        later than this one this detail was changed too, the value saved therein is altered,
         rather than applied to the scene.
-        
-        mild_restore: if True, when restoring later, checks if the value was changed 
+
+        mild_restore: if True, when restoring later, checks if the value was changed
         by user after last call to modify(), and doesn't restore if it was changed.
-        
+
         Example: tv.modify(VProperty(obj, "Visibility", True))'''
 
         self._change()
-        
+
         if mild_restore is not None:
             detail.mild_restore = mild_restore
-        
+
         # save current
         self.save(detail, detail.mild_restore)
-        
+
         # apply
         tv1, curr = self._value_after(detail)
         if tv1 is not None:
             tv1.data[detail.full_key].data = detail.data
         else:
             detail.apply_data(detail.data)
-        
+
         # and record.
         if detail.mild_restore:
             self.data_requested[detail.full_key] = copy(detail)
-        
+
     def restoreDetail(self, detail, ultimate = False):
         '''restoreDetail(detail, ultimate = False): restores a specific scene detail.
         ultimate: if true, the saved value is cleaned out.
@@ -173,15 +172,15 @@ class TempoVis(object):
         self._restore_detail(detail)
         if ultimate:
             self.forgetDetail(detail)
-    
-    
+
+
     def forgetDetail(self, detail):
         '''forgetDetail(detail): ditches a saved detail value, making the change done through this TV permanent.'''
         self.data.pop(detail.full_key, None)
         self.data_requested.pop(detail.full_key, None)
-    
+
     def forget(self):
-        '''forget(self): clears this TV, making all changes done through it permanent. 
+        '''forget(self): clears this TV, making all changes done through it permanent.
         Also, withdraws the TV from the stack.'''
         self.state = S_EMPTY
         self.data = {}
@@ -190,15 +189,15 @@ class TempoVis(object):
 
     def restore(self, ultimate = True):
         '''restore(ultimate = True): undoes all changes done through this tempovis / restores saved scene details.
-        ultimate: if true, the saved values are cleaned out, and the TV is withdrawn from 
+        ultimate: if true, the saved values are cleaned out, and the TV is withdrawn from
         the stack. If false, the TV will still remember stuff, and restore can be called again.
         '''
         if self.state == S_RESTORED:
             return
 
         if self.state != S_INTERNAL and ultimate:
-            self.state = S_RESTORED        
-        
+            self.state = S_RESTORED
+
         for key, detail in self.data.items():
             try:
                 self._restoreDetail(detail)
@@ -209,9 +208,9 @@ class TempoVis(object):
             self.data = {}
             if self.is_in_stack:
                 self.stack.withdraw(self)
-    
+
   #</core interface>
-  
+
   #<stack interface>
     def _inserted(self, stack, index):
         '''calles when this tv is inserted into a stack'''
@@ -224,15 +223,15 @@ class TempoVis(object):
         return self.stack is not None
   #</stack interface>
 
-  #<convenience functions>            
+  #<convenience functions>
     def modifyVPProperty(self, doc_obj_or_list, prop_names, new_value = JUST_SAVE, mild_restore = None):
         '''modifyVPProperty(doc_obj_or_list, prop_names, new_value = JUST_SAVE, mild_restore = None): modifies
         prop_name property of ViewProvider of doc_obj_or_list, and remembers
         original value of the property. Original values will be restored upon
         TempoVis deletion, or call to restore().
-        
+
         mild_restore: test if user changed the value manually when restoring the TV.'''
-        
+
         if self.state == S_RESTORED:
             Wrn("Attempting to use a TV that has been restored. There must be a problem with code.")
             return
@@ -264,7 +263,7 @@ class TempoVis(object):
     def restoreVPProperty(self, doc_obj_or_list, prop_names):
         '''restoreVPProperty(doc_obj_or_list, prop_name, new_value): restores specific property changes.'''
         from .SceneDetails.VProperty import VProperty
-        
+
         if not hasattr(doc_obj_or_list, '__iter__'):
             doc_obj_or_list = [doc_obj_or_list]
         if not isinstance(prop_names,(tuple,list)):
@@ -279,7 +278,7 @@ class TempoVis(object):
 
 
     def saveBodyVisibleFeature(self, doc_obj_or_list):
-        """saveBodyVisibleFeature(self, doc_obj_or_list): saves Visibility of currently 
+        """saveBodyVisibleFeature(self, doc_obj_or_list): saves Visibility of currently
         visible feature, for every body of PartDesign features in the provided list."""
         if not hasattr(doc_obj_or_list, '__iter__'):
             doc_obj_or_list = [doc_obj_or_list]
@@ -297,7 +296,7 @@ class TempoVis(object):
         return objs
 
     def show(self, doc_obj_or_list, links_too = True, mild_restore = None):
-        '''show(doc_obj_or_list, links_too = True): shows objects (sets their Visibility to True). 
+        '''show(doc_obj_or_list, links_too = True): shows objects (sets their Visibility to True).
         doc_obj_or_list can be a document object, or a list of document objects.
         If links_too is True, all Links of the objects are also hidden, by setting LinkVisibility attribute of each object.'''
         doc_obj_or_list = self._3D_objects(doc_obj_or_list)
@@ -320,15 +319,15 @@ class TempoVis(object):
         from .Containers import isAContainer
         from .DepGraphTools import getAllDependencies, getAllDependent
         if subname:
-            # a link-path was provided. doc_obj has nothing to do with the object we want 
+            # a link-path was provided. doc_obj has nothing to do with the object we want
             # to collect dependencies from. So, replace it with the one pointed by link-path.
             cnt_chain = doc_obj.getSubObjectList(subname)
             doc_obj = cnt_chain[-1].getLinkedObject()
-            # cnt_chain can either end with the object (e.g. if a sketch is in a part, and 
-            # a link is to a part), or it may be a Link object (if we have a straight or 
+            # cnt_chain can either end with the object (e.g. if a sketch is in a part, and
+            # a link is to a part), or it may be a Link object (if we have a straight or
             # even nested Link to the sketch).
             #
-            # I don't know why do we need that isAContainer check here, but I'm leaving it, 
+            # I don't know why do we need that isAContainer check here, but I'm leaving it,
             # realthunder must be knowing his business --DeepSOIC
             cnt_chain = [ o for o in cnt_chain
                             if o==cnt_chain[-1] or isAContainer(o, links_too= True) ]
@@ -364,7 +363,7 @@ class TempoVis(object):
         self._change()
         from .SceneDetails.Camera import Camera
         self.save(Camera(self.document))
-        
+
     def restoreCamera(self, ultimate = False):
         from .SceneDetails.Camera import Camera
         dt = Camera(self.document)
@@ -373,17 +372,17 @@ class TempoVis(object):
     def setUnpickable(self, doc_obj_or_list, actual_pick_style = 2): #2 is coin.SoPickStyle.UNPICKABLE
         '''setUnpickable(doc_obj_or_list, actual_pick_style = 2): sets object unpickable (transparent to clicks).
         doc_obj_or_list: object or list of objects to alter (App)
-        actual_pick_style: optional parameter, specifying the actual pick style: 
+        actual_pick_style: optional parameter, specifying the actual pick style:
         0 = regular, 1 = bounding box, 2 (default) = unpickable.
-        
-        Implementation detail: uses SoPickStyle node. If viewprovider already has a node 
-        of this type as direct child, one is used. Otherwise, new one is created and 
-        inserted as the very first node, and remains there even after restore()/deleting 
+
+        Implementation detail: uses SoPickStyle node. If viewprovider already has a node
+        of this type as direct child, one is used. Otherwise, new one is created and
+        inserted as the very first node, and remains there even after restore()/deleting
         tempovis. '''
-        
+
         from .SceneDetails.Pickability import Pickability
         from .ShowUtils import is3DObject
-        
+
         if not hasattr(doc_obj_or_list, '__iter__'):
             doc_obj_or_list = [doc_obj_or_list]
         for doc_obj in doc_obj_or_list:
@@ -392,20 +391,20 @@ class TempoVis(object):
             dt = Pickability(doc_obj, actual_pick_style)
             self.modify(dt)
 
-    def clipPlane(self, doc_obj_or_list, enable, placement, offset = 0.02): 
+    def clipPlane(self, doc_obj_or_list, enable, placement, offset = 0.02):
         '''clipPlane(doc_obj_or_list, enable, placement, offset): slices off the object with a clipping plane.
         doc_obj_or_list: object or list of objects to alter (App)
-        enable: True if you want clipping, False if you want to remove clipping: 
+        enable: True if you want clipping, False if you want to remove clipping:
         placement: XY plane of local coordinates of the placement is the clipping plane. The placement must be in document's global coordinate system.
         offset: shifts the plane. Positive offset reveals more of the object.
-        
-        Implementation detail: uses SoClipPlane node. If viewprovider already has a node 
-        of this type as direct child, one is used. Otherwise, new one is created and 
+
+        Implementation detail: uses SoClipPlane node. If viewprovider already has a node
+        of this type as direct child, one is used. Otherwise, new one is created and
         inserted as the very first node. The node is left, but disabled when tempovis is restoring.'''
-        
+
         from .SceneDetails.ObjectClipPlane import ObjectClipPlane
         from .ShowUtils import is3DObject
-        
+
         if not hasattr(doc_obj_or_list, '__iter__'):
             doc_obj_or_list = [doc_obj_or_list]
         for doc_obj in doc_obj_or_list:
@@ -413,14 +412,14 @@ class TempoVis(object):
                 continue
             dt = ObjectClipPlane(doc_obj, enable, placement, offset)
             self.modify(dt)
-                    
+
     @staticmethod
     def allVisibleObjects(aroundObject):
-        '''allVisibleObjects(aroundObject): returns list of objects that have to be toggled invisible for only aroundObject to remain. 
+        '''allVisibleObjects(aroundObject): returns list of objects that have to be toggled invisible for only aroundObject to remain.
         If a whole container can be made invisible, it is returned, instead of its child objects.'''
         from .ShowUtils import is3DObject
         from . import Containers
-        
+
         chain = Containers.VisGroupChain(aroundObject)
         result = []
         for i in range(len(chain)):
@@ -434,13 +433,13 @@ class TempoVis(object):
                     if container.isChildVisible(obj):
                         result.append(obj)
         return result
-        
-    def sketchClipPlane(self, sketch, enable = None):
-        '''sketchClipPlane(sketch, enable = None): Clips all objects by plane of sketch. 
+
+    def sketchClipPlane(self, sketch, enable = None, reverted = False):
+        '''sketchClipPlane(sketch, enable = None): Clips all objects by plane of sketch.
         If enable argument is omitted, calling the routine repeatedly will toggle clipping plane.'''
-        
+
         from .SceneDetails.ClipPlane import ClipPlane
-        
+
         editDoc = Gui.editDocument()
         if editDoc is None:
             doc = sketch.Document
@@ -449,13 +448,20 @@ class TempoVis(object):
             doc = editDoc.Document
             pla = App.Placement(editDoc.EditingTransform)
         toggle = {False: 0, True: 1, None: -1}[enable]
-        
-        self.modify(ClipPlane(doc, toggle, pla, 0.02))
-    
+
+        if reverted:
+            pla = pla * App.Rotation(0, 1, 0, 0)
+
+        if enable: # clip plane shall be disabled so new placement can be applied
+            self.modify(ClipPlane(doc, 0))
+
+        self.modify(ClipPlane(doc, toggle, pla, 0.001))
+        sketch.ViewObject.SectionView = enable if enable is not None else not sketch.ViewObject.SectionView
+
     def activateWorkbench(self, wb_name):
         from .SceneDetails.Workbench import Workbench
         self.modify(Workbench(wb_name))
-    
+
   #</convenience functions>
 
   #<internals>
@@ -473,7 +479,7 @@ class TempoVis(object):
         else:
             #modify saved detail of higher TV
             tv1.data[detail.full_key].data = p.data
-    
+
     def _purge_milds(self, detail):
         """_purge_milds(detail): wipes out detail from earlier TVs if the detail is mild-restore."""
         if not self.is_in_stack:
@@ -493,13 +499,13 @@ class TempoVis(object):
             self.state = S_ACTIVE
         if self.state == S_RESTORED:
             Wrn("Attempting to use a TV that has been restored. There must be a problem with code.")
-        self.tv_redo = None    
+        self.tv_redo = None
 
     def _value_after(self, detail, query_scene = False):
-        '''_value_current(detail): returns (tv, detail1). SceneDetail instance holds "current" value of 
-        scene detail (current from the context of this TV; i.e. either the current scene 
+        '''_value_current(detail): returns (tv, detail1). SceneDetail instance holds "current" value of
+        scene detail (current from the context of this TV; i.e. either the current scene
         status, or the saved state from upper TVs).
-        If no upper TV has saved the detail value, returns either (None, None), or 
+        If no upper TV has saved the detail value, returns either (None, None), or
         (None, detail1) if query_scene is True, where detail1 holds value from the scene.'''
         def scene_value():
             if query_scene:
@@ -508,7 +514,7 @@ class TempoVis(object):
                 return (None, cpy)
             else:
                 return (None, None)
-            
+
         if self.is_in_stack:
             va = self.stack.value_after(self, detail)
             if va is None:
@@ -517,20 +523,18 @@ class TempoVis(object):
                 return va
         else:
             return scene_value()
-            
+
     def _3D_objects(self, doc_obj_or_list):
         """_3D_objects(doc_obj_or_list): returns list of objects that are in 3d view."""
         from .ShowUtils import is3DObject
-        
+
         if not hasattr(doc_obj_or_list, '__iter__'):
             doc_obj_or_list = [doc_obj_or_list]
-        
+
         return [obj for obj in doc_obj_or_list if is3DObject(obj)]
-        
-    def __getstate__(self):
+
+    def dumps(self):
         return None
-        
-    def __setstate__(self, state):
+
+    def loads(self, state):
         self._init_attrs()
-    
-        
