@@ -20,66 +20,65 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-
+#include <boost/uuid/uuid_io.hpp>
 #endif
 
 #include "GeometryFacade.h"
-
-//#include <Base/Console.h> // Only for Debug, when/if necessary
-#include <Base/Exception.h>
-#include <boost/uuid/uuid_io.hpp>
-
 #include "GeometryFacadePy.h"
 
+
 using namespace Sketcher;
 
-TYPESYSTEM_SOURCE(Sketcher::GeometryFacade,Base::BaseClass)
+TYPESYSTEM_SOURCE(Sketcher::GeometryFacade, Base::BaseClass)
 
-GeometryFacade::GeometryFacade(): Geo(nullptr), OwnerGeo(false), SketchGeoExtension(nullptr)
+GeometryFacade::GeometryFacade()
+    : Geo(nullptr),
+      OwnerGeo(false),
+      SketchGeoExtension(nullptr)
+{}
+
+GeometryFacade::GeometryFacade(const Part::Geometry* geometry, bool owner)
+    : Geo(geometry),
+      OwnerGeo(owner)
 {
-
-}
-
-GeometryFacade::GeometryFacade(const Part::Geometry * geometry, bool owner)
-: Geo(geometry), OwnerGeo(owner)
-{
-    assert(geometry != nullptr); // This should never be nullptr, as this constructor is protected
+    assert(geometry);// This should never be nullptr, as this constructor is protected
 
     initExtension();
 }
 
 GeometryFacade::~GeometryFacade()
 {
-    if (OwnerGeo && Geo != nullptr)
+    if (OwnerGeo && Geo)
         delete Geo;
 }
 
-std::unique_ptr<GeometryFacade> GeometryFacade::getFacade(Part::Geometry * geometry, bool owner)
+std::unique_ptr<GeometryFacade> GeometryFacade::getFacade(Part::Geometry* geometry, bool owner)
 {
-    if(geometry != nullptr)
+    if (geometry)
         return std::unique_ptr<GeometryFacade>(new GeometryFacade(geometry, owner));
     else
         return std::unique_ptr<GeometryFacade>(nullptr);
-    //return std::make_unique<GeometryFacade>(geometry); // make_unique has no access to private constructor
+    // make_unique has no access to private constructor
+    // return std::make_unique<GeometryFacade>(geometry);
 }
 
-std::unique_ptr<const GeometryFacade> GeometryFacade::getFacade(const Part::Geometry * geometry)
+std::unique_ptr<const GeometryFacade> GeometryFacade::getFacade(const Part::Geometry* geometry)
 {
-    if(geometry != nullptr)
+    if (geometry)
         return std::unique_ptr<const GeometryFacade>(new GeometryFacade(geometry));
-     else
+    else
         return std::unique_ptr<const GeometryFacade>(nullptr);
-    //return std::make_unique<const GeometryFacade>(geometry); // make_unique has no access to private constructor
+    // make_unique has no access to private constructor
+    // return std::make_unique<const GeometryFacade>(geometry);
 }
 
-void GeometryFacade::setGeometry(Part::Geometry *geometry)
+void GeometryFacade::setGeometry(Part::Geometry* geometry)
 {
     Geo = geometry;
 
-    if(geometry != nullptr)
+    if (geometry)
         initExtension();
     else
         THROWM(Base::ValueError, "GeometryFacade initialized with Geometry null pointer");
@@ -87,46 +86,48 @@ void GeometryFacade::setGeometry(Part::Geometry *geometry)
 
 void GeometryFacade::initExtension()
 {
-    if(!Geo->hasExtension(SketchGeometryExtension::getClassTypeId())) {
+    if (!Geo->hasExtension(SketchGeometryExtension::getClassTypeId())) {
 
-        getGeo()->setExtension(std::make_unique<SketchGeometryExtension>()); // Create getExtension
+        getGeo()->setExtension(std::make_unique<SketchGeometryExtension>());// Create getExtension
 
-        //Base::Console().Warning("%s\nSketcher Geometry without Extension: %s \n", boost::uuids::to_string(Geo->getTag()).c_str());
+        // Base::Console().Warning("%s\nSketcher Geometry without Extension: %s \n",
+        // boost::uuids::to_string(Geo->getTag()).c_str());
     }
 
-    SketchGeoExtension =
-        std::static_pointer_cast<const SketchGeometryExtension>(
-            (Geo->getExtension(SketchGeometryExtension::getClassTypeId())).lock()
-        );
+    SketchGeoExtension = std::static_pointer_cast<const SketchGeometryExtension>(
+        (Geo->getExtension(SketchGeometryExtension::getClassTypeId())).lock());
 }
 
 void GeometryFacade::initExtension() const
 {
     // const Geometry without SketchGeometryExtension cannot initialise a GeometryFacade
-    if(!Geo->hasExtension(SketchGeometryExtension::getClassTypeId()))
-        THROWM(Base::ValueError, "Cannot create a GeometryFacade out of a const Geometry pointer not having a SketchGeometryExtension!");
+    if (!Geo->hasExtension(SketchGeometryExtension::getClassTypeId()))
+        THROWM(Base::ValueError,
+               "Cannot create a GeometryFacade out of a const Geometry pointer not having a "
+               "SketchGeometryExtension!");
 
-    auto ext = std::static_pointer_cast<const SketchGeometryExtension>(Geo->getExtension(SketchGeometryExtension::getClassTypeId()).lock());
+    auto ext = std::static_pointer_cast<const SketchGeometryExtension>(
+        Geo->getExtension(SketchGeometryExtension::getClassTypeId()).lock());
 
-    const_cast<GeometryFacade *>(this)->SketchGeoExtension = ext;
+    const_cast<GeometryFacade*>(this)->SketchGeoExtension = ext;
 }
 
-void GeometryFacade::throwOnNullPtr(const Part::Geometry * geo)
+void GeometryFacade::throwOnNullPtr(const Part::Geometry* geo)
 {
-    if(geo == nullptr)
+    if (!geo)
         THROWM(Base::ValueError, "Geometry is nullptr!");
 }
 
-void GeometryFacade::ensureSketchGeometryExtension(Part::Geometry * geometry)
+void GeometryFacade::ensureSketchGeometryExtension(Part::Geometry* geometry)
 {
     throwOnNullPtr(geometry);
 
-    if(!geometry->hasExtension(SketchGeometryExtension::getClassTypeId())) {
-        geometry->setExtension(std::make_unique<SketchGeometryExtension>()); // Create getExtension
+    if (!geometry->hasExtension(SketchGeometryExtension::getClassTypeId())) {
+        geometry->setExtension(std::make_unique<SketchGeometryExtension>());// Create getExtension
     }
 }
 
-void GeometryFacade::copyId(const Part::Geometry * src, Part::Geometry * dst)
+void GeometryFacade::copyId(const Part::Geometry* src, Part::Geometry* dst)
 {
     throwOnNullPtr(src);
     throwOnNullPtr(dst);
@@ -136,7 +137,7 @@ void GeometryFacade::copyId(const Part::Geometry * src, Part::Geometry * dst)
     gfdst->setId(gfsrc->getId());
 }
 
-bool GeometryFacade::getConstruction(const Part::Geometry * geometry)
+bool GeometryFacade::getConstruction(const Part::Geometry* geometry)
 {
     throwOnNullPtr(geometry);
 
@@ -144,7 +145,7 @@ bool GeometryFacade::getConstruction(const Part::Geometry * geometry)
     return gf->getConstruction();
 }
 
-void GeometryFacade::setConstruction(Part::Geometry * geometry, bool construction)
+void GeometryFacade::setConstruction(Part::Geometry* geometry, bool construction)
 {
     throwOnNullPtr(geometry);
 
@@ -152,7 +153,7 @@ void GeometryFacade::setConstruction(Part::Geometry * geometry, bool constructio
     return gf->setConstruction(construction);
 }
 
-bool GeometryFacade::isInternalType(const Part::Geometry * geometry, InternalType::InternalType type)
+bool GeometryFacade::isInternalType(const Part::Geometry* geometry, InternalType::InternalType type)
 {
     throwOnNullPtr(geometry);
 
@@ -160,7 +161,15 @@ bool GeometryFacade::isInternalType(const Part::Geometry * geometry, InternalTyp
     return gf->getInternalType() == type;
 }
 
-bool GeometryFacade::getBlocked(const Part::Geometry * geometry)
+bool GeometryFacade::isInternalAligned(const Part::Geometry* geometry)
+{
+    throwOnNullPtr(geometry);
+
+    auto gf = GeometryFacade::getFacade(geometry);
+    return gf->isInternalAligned();
+}
+
+bool GeometryFacade::getBlocked(const Part::Geometry* geometry)
 {
     throwOnNullPtr(geometry);
 
@@ -168,7 +177,7 @@ bool GeometryFacade::getBlocked(const Part::Geometry * geometry)
     return gf->getBlocked();
 }
 
-PyObject * GeometryFacade::getPyObject(void)
+PyObject* GeometryFacade::getPyObject()
 {
     return new GeometryFacadePy(new GeometryFacade(this->Geo));
 }
