@@ -20,27 +20,22 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-//#ifndef _PreComp_
-//# include <gp.hxx>
-//#endif
-
-#include <Mod/Part/App/Geometry.h>
-#include "SketchObject.h"
 #include "SketchGeometryExtensionPy.h"
+
 #include "SketchGeometryExtensionPy.cpp"
 
+
 using namespace Sketcher;
 
 // returns a string which represents the object e.g. when printed in python
-std::string SketchGeometryExtensionPy::representation(void) const
+std::string SketchGeometryExtensionPy::representation() const
 {
     std::stringstream str;
     str << "<SketchGeometryExtension (";
 
-    if(getSketchGeometryExtensionPtr()->getName().size()>0)
+    if (!getSketchGeometryExtensionPtr()->getName().empty())
         str << "\'" << getSketchGeometryExtensionPtr()->getName() << "\', ";
 
     str << "\"";
@@ -49,7 +44,8 @@ std::string SketchGeometryExtensionPy::representation(void) const
     return str.str();
 }
 
-PyObject *SketchGeometryExtensionPy::PyMake(struct _typeobject *, PyObject *, PyObject *)  // Python wrapper
+// Python wrapper
+PyObject* SketchGeometryExtensionPy::PyMake(struct _typeobject*, PyObject*, PyObject*)
 {
     // create a new instance of PointPy and the Twin object
     return new SketchGeometryExtensionPy(new SketchGeometryExtension);
@@ -72,14 +68,14 @@ int SketchGeometryExtensionPy::PyInit(PyObject* args, PyObject* /*kwd*/)
     }
 
 
-
-    PyErr_SetString(PyExc_TypeError, "SketchGeometryExtension constructor accepts:\n"
-        "-- empty parameter list\n"
-        "-- int\n");
+    PyErr_SetString(PyExc_TypeError,
+                    "SketchGeometryExtension constructor accepts:\n"
+                    "-- empty parameter list\n"
+                    "-- int\n");
     return -1;
 }
 
-Py::Long SketchGeometryExtensionPy::getId(void) const
+Py::Long SketchGeometryExtensionPy::getId() const
 {
     return Py::Long(this->getSketchGeometryExtensionPtr()->getId());
 }
@@ -89,16 +85,17 @@ void SketchGeometryExtensionPy::setId(Py::Long Id)
     this->getSketchGeometryExtensionPtr()->setId(long(Id));
 }
 
-Py::String SketchGeometryExtensionPy::getInternalType(void) const
+Py::String SketchGeometryExtensionPy::getInternalType() const
 {
     int internaltypeindex = (int)this->getSketchGeometryExtensionPtr()->getInternalType();
 
-    if(internaltypeindex >= InternalType::NumInternalGeometryType)
+    if (internaltypeindex >= InternalType::NumInternalGeometryType)
         throw Py::NotImplementedError("String name of enum not implemented");
 
-    std::string typestr = this->getSketchGeometryExtensionPtr()->internaltype2str[internaltypeindex];
+    std::string typestr =
+        this->getSketchGeometryExtensionPtr()->internaltype2str[internaltypeindex];
 
-     return Py::String(typestr);
+    return Py::String(typestr);
 }
 
 void SketchGeometryExtensionPy::setInternalType(Py::String arg)
@@ -106,7 +103,7 @@ void SketchGeometryExtensionPy::setInternalType(Py::String arg)
     std::string argstr = arg;
     InternalType::InternalType type;
 
-    if(SketchGeometryExtension::getInternalTypeFromName(argstr, type)) {
+    if (SketchGeometryExtension::getInternalTypeFromName(argstr, type)) {
         this->getSketchGeometryExtensionPtr()->setInternalType(type);
         return;
     }
@@ -114,7 +111,7 @@ void SketchGeometryExtensionPy::setInternalType(Py::String arg)
     throw Py::ValueError("Argument is not a valid internal geometry type.");
 }
 
-Py::Boolean SketchGeometryExtensionPy::getBlocked(void) const
+Py::Boolean SketchGeometryExtensionPy::getBlocked() const
 {
     return Py::Boolean(getSketchGeometryExtensionPtr()->testGeometryMode(GeometryMode::Blocked));
 }
@@ -124,9 +121,10 @@ void SketchGeometryExtensionPy::setBlocked(Py::Boolean arg)
     getSketchGeometryExtensionPtr()->setGeometryMode(GeometryMode::Blocked, arg);
 }
 
-Py::Boolean SketchGeometryExtensionPy::getConstruction(void) const
+Py::Boolean SketchGeometryExtensionPy::getConstruction() const
 {
-     return Py::Boolean(getSketchGeometryExtensionPtr()->testGeometryMode(GeometryMode::Construction));
+    return Py::Boolean(
+        getSketchGeometryExtensionPtr()->testGeometryMode(GeometryMode::Construction));
 }
 
 void SketchGeometryExtensionPy::setConstruction(Py::Boolean arg)
@@ -134,15 +132,16 @@ void SketchGeometryExtensionPy::setConstruction(Py::Boolean arg)
     getSketchGeometryExtensionPtr()->setGeometryMode(GeometryMode::Construction, arg);
 }
 
-PyObject* SketchGeometryExtensionPy::testGeometryMode(PyObject *args)
+PyObject* SketchGeometryExtensionPy::testGeometryMode(PyObject* args)
 {
     char* flag;
-    if (PyArg_ParseTuple(args, "s",&flag)) {
+    if (PyArg_ParseTuple(args, "s", &flag)) {
 
         GeometryMode::GeometryMode mode;
 
-        if(getSketchGeometryExtensionPtr()->getGeometryModeFromName(flag, mode))
-            return new_reference_to(Py::Boolean(getSketchGeometryExtensionPtr()->testGeometryMode(mode)));
+        if (getSketchGeometryExtensionPtr()->getGeometryModeFromName(flag, mode))
+            return new_reference_to(
+                Py::Boolean(getSketchGeometryExtensionPtr()->testGeometryMode(mode)));
 
         PyErr_SetString(PyExc_TypeError, "Flag string does not exist.");
         return nullptr;
@@ -152,16 +151,16 @@ PyObject* SketchGeometryExtensionPy::testGeometryMode(PyObject *args)
     return nullptr;
 }
 
-PyObject* SketchGeometryExtensionPy::setGeometryMode(PyObject *args)
+PyObject* SketchGeometryExtensionPy::setGeometryMode(PyObject* args)
 {
-    char * flag;
-    PyObject * bflag = Py_True;
+    char* flag;
+    PyObject* bflag = Py_True;
     if (PyArg_ParseTuple(args, "s|O!", &flag, &PyBool_Type, &bflag)) {
 
         GeometryMode::GeometryMode mode;
 
-        if(getSketchGeometryExtensionPtr()->getGeometryModeFromName(flag, mode)) {
-            getSketchGeometryExtensionPtr()->setGeometryMode(mode, PyObject_IsTrue(bflag) ? true : false);
+        if (getSketchGeometryExtensionPtr()->getGeometryModeFromName(flag, mode)) {
+            getSketchGeometryExtensionPtr()->setGeometryMode(mode, Base::asBoolean(bflag));
             Py_Return;
         }
 
@@ -173,7 +172,7 @@ PyObject* SketchGeometryExtensionPy::setGeometryMode(PyObject *args)
     Py_Return;
 }
 
-Py::Long SketchGeometryExtensionPy::getGeometryLayerId(void) const
+Py::Long SketchGeometryExtensionPy::getGeometryLayerId() const
 {
     return Py::Long(this->getSketchGeometryExtensionPtr()->getGeometryLayerId());
 }
@@ -183,7 +182,7 @@ void SketchGeometryExtensionPy::setGeometryLayerId(Py::Long Id)
     this->getSketchGeometryExtensionPtr()->setGeometryLayerId(long(Id));
 }
 
-PyObject *SketchGeometryExtensionPy::getCustomAttributes(const char* /*attr*/) const
+PyObject* SketchGeometryExtensionPy::getCustomAttributes(const char* /*attr*/) const
 {
     return nullptr;
 }
@@ -192,4 +191,3 @@ int SketchGeometryExtensionPy::setCustomAttributes(const char* /*attr*/, PyObjec
 {
     return 0;
 }
-
