@@ -20,47 +20,44 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <QMessageBox>
 #endif
 
 #include <Gui/Action.h>
 #include <Gui/Application.h>
+#include <Gui/CommandT.h>
 #include <Gui/Document.h>
+#include <Gui/MainWindow.h>
+#include <Gui/Notifications.h>
 #include <Gui/Selection.h>
 #include <Gui/SelectionObject.h>
-#include <Gui/CommandT.h>
-#include <Gui/MainWindow.h>
-#include <Gui/BitmapFactory.h>
-#include <Gui/DlgEditFileIncludePropertyExternal.h>
-
-#include <Mod/Part/App/Geometry.h>
 #include <Mod/Sketcher/App/SketchObject.h>
 
-#include "ViewProviderSketch.h"
 #include "GeometryCreationMode.h"
 #include "Utils.h"
+#include "ViewProviderSketch.h"
+
 
 using namespace std;
 using namespace SketcherGui;
 using namespace Sketcher;
 
-bool isAlterGeoActive(Gui::Document *doc)
+bool isAlterGeoActive(Gui::Document* doc)
 {
-   if (doc) {
+    if (doc) {
         // checks if a Sketch Viewprovider is in Edit
-        if (doc->getInEdit() && doc->getInEdit()->isDerivedFrom
-            (SketcherGui::ViewProviderSketch::getClassTypeId())) {
-                return true;
+        if (doc->getInEdit()
+            && doc->getInEdit()->isDerivedFrom(SketcherGui::ViewProviderSketch::getClassTypeId())) {
+            return true;
         }
     }
 
     return false;
 }
 
-namespace SketcherGui {
+namespace SketcherGui
+{
 
 extern GeometryCreationMode geometryCreationMode;
 
@@ -68,20 +65,20 @@ extern GeometryCreationMode geometryCreationMode;
 DEF_STD_CMD_A(CmdSketcherToggleConstruction)
 
 CmdSketcherToggleConstruction::CmdSketcherToggleConstruction()
-    :Command("Sketcher_ToggleConstruction")
+    : Command("Sketcher_ToggleConstruction")
 {
-    sAppModule      = "Sketcher";
-    sGroup          = "Sketcher";
-    sMenuText       = QT_TR_NOOP("Toggle construction geometry");
-    sToolTipText    = QT_TR_NOOP("Toggles the toolbar or selected geometry to/from construction mode");
-    sWhatsThis      = "Sketcher_ToggleConstruction";
-    sStatusTip      = sToolTipText;
-    sPixmap         = "Sketcher_ToggleConstruction";
-    sAccel          = "G, N";
-    eType           = ForEdit;
+    sAppModule = "Sketcher";
+    sGroup = "Sketcher";
+    sMenuText = QT_TR_NOOP("Toggle construction geometry");
+    sToolTipText = QT_TR_NOOP("Toggles the toolbar or selected geometry to/from construction mode");
+    sWhatsThis = "Sketcher_ToggleConstruction";
+    sStatusTip = sToolTipText;
+    sPixmap = "Sketcher_ToggleConstruction";
+    sAccel = "G, N";
+    eType = ForEdit;
 
     // list of toggle construction commands
-    Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
+    Gui::CommandManager& rcCmdMgr = Gui::Application::Instance->commandManager();
     rcCmdMgr.addCommandMode("ToggleConstruction", "Sketcher_CreateLine");
     rcCmdMgr.addCommandMode("ToggleConstruction", "Sketcher_CreateRectangle");
     rcCmdMgr.addCommandMode("ToggleConstruction", "Sketcher_CreateRectangle_Center");
@@ -119,9 +116,9 @@ void CmdSketcherToggleConstruction::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
     // Option A: nothing is selected change creation mode from/to construction
-    if(Gui::Selection().countObjectsOfType(Sketcher::SketchObject::getClassTypeId()) == 0){
+    if (Gui::Selection().countObjectsOfType(Sketcher::SketchObject::getClassTypeId()) == 0) {
 
-        Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
+        Gui::CommandManager& rcCmdMgr = Gui::Application::Instance->commandManager();
 
         if (geometryCreationMode == Construction) {
             geometryCreationMode = Normal;
@@ -132,26 +129,30 @@ void CmdSketcherToggleConstruction::activated(int iMsg)
 
         rcCmdMgr.updateCommands("ToggleConstruction", static_cast<int>(geometryCreationMode));
     }
-    else // there was a selection, so operate in toggle mode.
+    else// there was a selection, so operate in toggle mode.
     {
         // get the selection
         std::vector<Gui::SelectionObject> selection;
-        selection = getSelection().getSelectionEx(nullptr, Sketcher::SketchObject::getClassTypeId());
+        selection =
+            getSelection().getSelectionEx(nullptr, Sketcher::SketchObject::getClassTypeId());
 
-        Sketcher::SketchObject* Obj = static_cast<Sketcher::SketchObject*>(selection[0].getObject());
+        Sketcher::SketchObject* Obj =
+            static_cast<Sketcher::SketchObject*>(selection[0].getObject());
 
         // only one sketch with its subelements are allowed to be selected
         if (selection.size() != 1) {
-            QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
-                QObject::tr("Select edge(s) from the sketch."));
+            Gui::TranslatedUserWarning(Obj,
+                                       QObject::tr("Wrong selection"),
+                                       QObject::tr("Select edge(s) from the sketch."));
             return;
         }
 
         // get the needed lists and objects
-        const std::vector<std::string> &SubNames = selection[0].getSubNames();
+        const std::vector<std::string>& SubNames = selection[0].getSubNames();
         if (SubNames.empty()) {
-            QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
-                QObject::tr("Select edge(s) from the sketch."));
+            Gui::TranslatedUserWarning(Obj,
+                                       QObject::tr("Wrong selection"),
+                                       QObject::tr("Select edge(s) from the sketch."));
             return;
         }
 
@@ -159,28 +160,49 @@ void CmdSketcherToggleConstruction::activated(int iMsg)
         openCommand(QT_TRANSLATE_NOOP("Command", "Toggle draft from/to draft"));
 
         // go through the selected subelements
-        for (std::vector<std::string>::const_iterator it=SubNames.begin();it!=SubNames.end();++it){
+        bool verticesonly = true;
+
+        for (const auto& subname : SubNames) {
+            if (subname.size() > 4 && subname.substr(0, 4) == "Edge") {
+                verticesonly = false;
+            }
+        }
+
+        for (std::vector<std::string>::const_iterator it = SubNames.begin(); it != SubNames.end();
+             ++it) {
+            // It was decided to provide a special behaviour:
+            // Vertices will only be toggled to/from construction IF ONLY
+            // vertices are within the group.
+            // If there are a mixture of edges and vertices, vertices will be ignored.
+            //
+            // Why?
+            // Because it is quite common to box select geometry for toggling (specially in
+            // connection with carbon copy operations). In 99% of the cases the user does not
+            // want to toggle individual points during such operations. For the remaining 1%,
+            // in 90% of the cases the uses will select just the points only naturally.
+
+
             // only handle edges
-            if (it->size() > 4 && it->substr(0,4) == "Edge") {
-                int GeoId = std::atoi(it->substr(4,4000).c_str()) - 1;
+            if (it->size() > 4 && it->substr(0, 4) == "Edge") {
+                int GeoId = std::atoi(it->substr(4, 4000).c_str()) - 1;
                 // issue the actual commands to toggle
                 Gui::cmdAppObjectArgs(selection[0].getObject(), "toggleConstruction(%d) ", GeoId);
             }
-            if (it->size() > 6 && it->substr(0,6) == "Vertex") {
-                int vertexId = std::atoi(it->substr(6,4000).c_str()) - 1;
+            else if (verticesonly && it->size() > 6 && it->substr(0, 6) == "Vertex") {
+                int vertexId = std::atoi(it->substr(6, 4000).c_str()) - 1;
 
                 int geoId;
                 PointPos pos;
-                Obj->getGeoVertexIndex(vertexId,geoId, pos);
+                Obj->getGeoVertexIndex(vertexId, geoId, pos);
 
                 auto geo = Obj->getGeometry(geoId);
 
-                if(geo && geo->getTypeId() == Part::GeomPoint::getClassTypeId()) {
+                if (geo && geo->getTypeId() == Part::GeomPoint::getClassTypeId()) {
                     // issue the actual commands to toggle
-                    Gui::cmdAppObjectArgs(selection[0].getObject(), "toggleConstruction(%d) ", geoId);
+                    Gui::cmdAppObjectArgs(
+                        selection[0].getObject(), "toggleConstruction(%d) ", geoId);
                 }
             }
-
         }
         // finish the transaction and update
         commitCommand();
@@ -192,16 +214,16 @@ void CmdSketcherToggleConstruction::activated(int iMsg)
     }
 }
 
-bool CmdSketcherToggleConstruction::isActive(void)
+bool CmdSketcherToggleConstruction::isActive()
 {
-    return isAlterGeoActive( getActiveGuiDocument() );
+    return isAlterGeoActive(getActiveGuiDocument());
 }
 
-}
+}// namespace SketcherGui
 
-void CreateSketcherCommandsAlterGeo(void)
+void CreateSketcherCommandsAlterGeo()
 {
-    Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
+    Gui::CommandManager& rcCmdMgr = Gui::Application::Instance->commandManager();
 
     rcCmdMgr.addCommand(new CmdSketcherToggleConstruction());
 }
