@@ -20,40 +20,34 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
-# include <QPainter>
-# include <QPixmap>
-# include <QMessageBox>
+#include <QMessageBox>
+#include <QPainter>
+#include <QPixmap>
 #endif
 
+#include <App/Application.h>
+#include <Base/Console.h>
+#include <Base/Interpreter.h>
+#include <Gui/Command.h>
+
 #include "SketcherSettings.h"
 #include "ui_SketcherSettings.h"
-#include "ui_SketcherSettingsDisplay.h"
 #include "ui_SketcherSettingsColors.h"
-#include "TaskSketcherGeneral.h"
-#include <Base/Console.h>
-#include <Base/Interpreter.h>
-#include <App/Application.h>
-#include <Gui/PrefWidgets.h>
-#include <Gui/Inventor/MarkerBitmaps.h>
-#include <Gui/Command.h>
+#include "ui_SketcherSettingsDisplay.h"
+#include "ui_SketcherSettingsGrid.h"
+
 
 using namespace SketcherGui;
 
 /* TRANSLATOR SketcherGui::SketcherSettings */
 
 SketcherSettings::SketcherSettings(QWidget* parent)
-    : PreferencePage(parent), ui(new Ui_SketcherSettings)
+    : PreferencePage(parent)
+    , ui(new Ui_SketcherSettings)
 {
     ui->setupUi(this);
-    QGridLayout* gridLayout = new QGridLayout(ui->placeholder);
-    gridLayout->setSpacing(0);
-    gridLayout->setMargin(0);
-    form = new SketcherGeneralWidget(ui->placeholder);
-    gridLayout->addWidget(form, 0, 0, 1, 1);
 }
 
 /**
@@ -72,7 +66,6 @@ void SketcherSettings::saveSettings()
     ui->checkBoxEnableEscape->onSave();
     ui->checkBoxNotifyConstraintSubstitutions->onSave();
     ui->checkBoxAutoRemoveRedundants->onSave();
-    form->saveSettings();
 }
 
 void SketcherSettings::loadSettings()
@@ -83,13 +76,12 @@ void SketcherSettings::loadSettings()
     ui->checkBoxEnableEscape->onRestore();
     ui->checkBoxNotifyConstraintSubstitutions->onRestore();
     ui->checkBoxAutoRemoveRedundants->onRestore();
-    form->loadSettings();
 }
 
 /**
  * Sets the strings of the subwidgets using the current language.
  */
-void SketcherSettings::changeEvent(QEvent *e)
+void SketcherSettings::changeEvent(QEvent* e)
 {
     if (e->type() == QEvent::LanguageChange) {
         ui->retranslateUi(this);
@@ -99,23 +91,22 @@ void SketcherSettings::changeEvent(QEvent *e)
     }
 }
 
+/* TRANSLATOR SketcherGui::SketcherSettingsGrid */
 
-/* TRANSLATOR SketcherGui::SketcherSettingsDisplay */
-
-SketcherSettingsDisplay::SketcherSettingsDisplay(QWidget* parent)
-    : PreferencePage(parent), ui(new Ui_SketcherSettingsDisplay)
+SketcherSettingsGrid::SketcherSettingsGrid(QWidget* parent)
+    : PreferencePage(parent)
+    , ui(new Ui_SketcherSettingsGrid)
 {
     ui->setupUi(this);
 
-    QList < QPair<Qt::PenStyle, int> > styles;
-    styles << qMakePair(Qt::SolidLine, 0xffff)
-           << qMakePair(Qt::DashLine, 0x0f0f)
+    QList<QPair<Qt::PenStyle, int>> styles;
+    styles << qMakePair(Qt::SolidLine, 0xffff) << qMakePair(Qt::DashLine, 0x0f0f)
            << qMakePair(Qt::DotLine, 0xaaaa);
-//           << qMakePair(Qt::DashDotLine, 0x????)
-//           << qMakePair(Qt::DashDotDotLine, 0x????);
-    ui->comboBox->setIconSize (QSize(80, 12));
-    for (QList < QPair<Qt::PenStyle, int> >::iterator it = styles.begin(); it != styles.end(); ++it) {
-        QPixmap px(ui->comboBox->iconSize());
+
+    ui->gridLinePattern->setIconSize(QSize(80, 12));
+    ui->gridDivLinePattern->setIconSize(QSize(80, 12));
+    for (QList<QPair<Qt::PenStyle, int>>::iterator it = styles.begin(); it != styles.end(); ++it) {
+        QPixmap px(ui->gridLinePattern->iconSize());
         px.fill(Qt::transparent);
         QBrush brush(Qt::black);
         QPen pen(it->first);
@@ -124,14 +115,92 @@ SketcherSettingsDisplay::SketcherSettingsDisplay(QWidget* parent)
 
         QPainter painter(&px);
         painter.setPen(pen);
-        double mid = ui->comboBox->iconSize().height() / 2.0;
-        painter.drawLine(0, mid, ui->comboBox->iconSize().width(), mid);
+        double mid = ui->gridLinePattern->iconSize().height() / 2.0;
+        painter.drawLine(0, mid, ui->gridLinePattern->iconSize().width(), mid);
         painter.end();
 
-        ui->comboBox->addItem(QIcon(px), QString(), QVariant(it->second));
+        ui->gridLinePattern->addItem(QIcon(px), QString(), QVariant(it->second));
+        ui->gridDivLinePattern->addItem(QIcon(px), QString(), QVariant(it->second));
     }
+}
 
-    connect(ui->btnTVApply, SIGNAL(clicked(bool)), this, SLOT(onBtnTVApplyClicked(bool)));
+SketcherSettingsGrid::~SketcherSettingsGrid()
+{
+    // no need to delete child widgets, Qt does it all for us
+}
+
+void SketcherSettingsGrid::saveSettings()
+{
+    ui->checkBoxShowGrid->onSave();
+    ui->gridSize->onSave();
+    ui->checkBoxGridAuto->onSave();
+    ui->gridSizePixelThreshold->onSave();
+    ui->gridLineColor->onSave();
+    ui->gridDivLineColor->onSave();
+    ui->gridLineWidth->onSave();
+    ui->gridDivLineWidth->onSave();
+    ui->gridNumberSubdivision->onSave();
+
+    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath(
+        "User parameter:BaseApp/Preferences/Mod/Sketcher/General");
+    QVariant data = ui->gridLinePattern->itemData(ui->gridLinePattern->currentIndex());
+    int pattern = data.toInt();
+    hGrp->SetInt("GridLinePattern", pattern);
+
+    data = ui->gridDivLinePattern->itemData(ui->gridDivLinePattern->currentIndex());
+    pattern = data.toInt();
+    hGrp->SetInt("GridDivLinePattern", pattern);
+}
+
+void SketcherSettingsGrid::loadSettings()
+{
+    ui->checkBoxShowGrid->onRestore();
+    ui->gridSize->onRestore();
+    ui->checkBoxGridAuto->onRestore();
+    ui->gridSizePixelThreshold->onRestore();
+    ui->gridLineColor->onRestore();
+    ui->gridDivLineColor->onRestore();
+    ui->gridLineWidth->onRestore();
+    ui->gridDivLineWidth->onRestore();
+    ui->gridNumberSubdivision->onRestore();
+
+    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath(
+        "User parameter:BaseApp/Preferences/Mod/Sketcher/General");
+    int pattern = hGrp->GetInt("GridLinePattern", 0x0f0f);
+    int index = ui->gridLinePattern->findData(QVariant(pattern));
+    if (index < 0)
+        index = 1;
+    ui->gridLinePattern->setCurrentIndex(index);
+    pattern = hGrp->GetInt("GridDivLinePattern", 0xffff);
+    index = ui->gridDivLinePattern->findData(QVariant(pattern));
+    if (index < 0)
+        index = 0;
+    ui->gridDivLinePattern->setCurrentIndex(index);
+}
+
+/**
+ * Sets the strings of the subwidgets using the current language.
+ */
+void SketcherSettingsGrid::changeEvent(QEvent* e)
+{
+    if (e->type() == QEvent::LanguageChange) {
+        ui->retranslateUi(this);
+    }
+    else {
+        QWidget::changeEvent(e);
+    }
+}
+
+/* TRANSLATOR SketcherGui::SketcherSettingsDisplay */
+
+SketcherSettingsDisplay::SketcherSettingsDisplay(QWidget* parent)
+    : PreferencePage(parent)
+    , ui(new Ui_SketcherSettingsDisplay)
+{
+    ui->setupUi(this);
+
+    connect(
+        ui->btnTVApply, &QPushButton::clicked, this, &SketcherSettingsDisplay::onBtnTVApplyClicked);
 }
 
 /**
@@ -151,6 +220,8 @@ void SketcherSettingsDisplay::saveSettings()
     ui->continueMode->onSave();
     ui->constraintMode->onSave();
     ui->checkBoxHideUnits->onSave();
+    ui->checkBoxShowCursorCoords->onSave();
+    ui->checkBoxUseSystemDecimals->onSave();
     ui->checkBoxShowDimensionalName->onSave();
     ui->prefDimensionalStringFormat->onSave();
     ui->checkBoxTVHideDependent->onSave();
@@ -159,11 +230,6 @@ void SketcherSettingsDisplay::saveSettings()
     ui->checkBoxTVRestoreCamera->onSave();
     ui->checkBoxTVForceOrtho->onSave();
     ui->checkBoxTVSectionView->onSave();
-
-    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Mod/Part");
-    QVariant data = ui->comboBox->itemData(ui->comboBox->currentIndex());
-    int pattern = data.toInt();
-    hGrp->SetInt("GridLinePattern", pattern);
 }
 
 void SketcherSettingsDisplay::loadSettings()
@@ -175,6 +241,8 @@ void SketcherSettingsDisplay::loadSettings()
     ui->continueMode->onRestore();
     ui->constraintMode->onRestore();
     ui->checkBoxHideUnits->onRestore();
+    ui->checkBoxShowCursorCoords->onRestore();
+    ui->checkBoxUseSystemDecimals->onRestore();
     ui->checkBoxShowDimensionalName->onRestore();
     ui->prefDimensionalStringFormat->onRestore();
     ui->checkBoxTVHideDependent->onRestore();
@@ -184,18 +252,12 @@ void SketcherSettingsDisplay::loadSettings()
     ui->checkBoxTVForceOrtho->onRestore();
     this->ui->checkBoxTVForceOrtho->setEnabled(this->ui->checkBoxTVRestoreCamera->isChecked());
     ui->checkBoxTVSectionView->onRestore();
-
-    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Mod/Part");
-    int pattern = hGrp->GetInt("GridLinePattern", 0x0f0f);
-    int index = ui->comboBox->findData(QVariant(pattern));
-    if (index <0) index = 1;
-    ui->comboBox->setCurrentIndex(index);
 }
 
 /**
  * Sets the strings of the subwidgets using the current language.
  */
-void SketcherSettingsDisplay::changeEvent(QEvent *e)
+void SketcherSettingsDisplay::changeEvent(QEvent* e)
 {
     if (e->type() == QEvent::LanguageChange) {
         ui->retranslateUi(this);
@@ -208,40 +270,42 @@ void SketcherSettingsDisplay::changeEvent(QEvent *e)
 void SketcherSettingsDisplay::onBtnTVApplyClicked(bool)
 {
     QString errMsg;
-    try{
+    try {
         Gui::Command::doCommand(Gui::Command::Gui,
-            "for name,doc in App.listDocuments().items():\n"
-            "    for sketch in doc.findObjects('Sketcher::SketchObject'):\n"
-            "        sketch.ViewObject.HideDependent = %s\n"
-            "        sketch.ViewObject.ShowLinks = %s\n"
-            "        sketch.ViewObject.ShowSupport = %s\n"
-            "        sketch.ViewObject.RestoreCamera = %s\n"
-            "        sketch.ViewObject.ForceOrtho = %s\n"
-            "        sketch.ViewObject.SectionView = %s\n",
-            this->ui->checkBoxTVHideDependent->isChecked() ? "True": "False",
-            this->ui->checkBoxTVShowLinks->isChecked()     ? "True": "False",
-            this->ui->checkBoxTVShowSupport->isChecked()   ? "True": "False",
-            this->ui->checkBoxTVRestoreCamera->isChecked() ? "True": "False",
-            this->ui->checkBoxTVForceOrtho->isChecked()    ? "True": "False",
-            this->ui->checkBoxTVSectionView->isChecked()   ? "True": "False");
-    } catch (Base::PyException &e){
-        Base::Console().Error("SketcherSettings::onBtnTVApplyClicked:\n");
+                                "for name,doc in App.listDocuments().items():\n"
+                                "    for sketch in doc.findObjects('Sketcher::SketchObject'):\n"
+                                "        sketch.ViewObject.HideDependent = %s\n"
+                                "        sketch.ViewObject.ShowLinks = %s\n"
+                                "        sketch.ViewObject.ShowSupport = %s\n"
+                                "        sketch.ViewObject.RestoreCamera = %s\n"
+                                "        sketch.ViewObject.ForceOrtho = %s\n"
+                                "        sketch.ViewObject.SectionView = %s\n",
+                                this->ui->checkBoxTVHideDependent->isChecked() ? "True" : "False",
+                                this->ui->checkBoxTVShowLinks->isChecked() ? "True" : "False",
+                                this->ui->checkBoxTVShowSupport->isChecked() ? "True" : "False",
+                                this->ui->checkBoxTVRestoreCamera->isChecked() ? "True" : "False",
+                                this->ui->checkBoxTVForceOrtho->isChecked() ? "True" : "False",
+                                this->ui->checkBoxTVSectionView->isChecked() ? "True" : "False");
+    }
+    catch (Base::PyException& e) {
+        Base::Console().DeveloperError("SketcherSettings", "error in onBtnTVApplyClicked:\n");
         e.ReportException();
         errMsg = QString::fromLatin1(e.what());
-    } catch (...) {
+    }
+    catch (...) {
         errMsg = tr("Unexpected C++ exception");
     }
-    if(errMsg.length()>0){
-        QMessageBox::warning(this, tr("Sketcher"),errMsg);
+    if (errMsg.length() > 0) {
+        QMessageBox::warning(this, tr("Sketcher"), errMsg);
     }
 }
 
 
-
 /* TRANSLATOR SketcherGui::SketcherSettingsColors */
 
 SketcherSettingsColors::SketcherSettingsColors(QWidget* parent)
-    : PreferencePage(parent), ui(new Ui_SketcherSettingsColors)
+    : PreferencePage(parent)
+    , ui(new Ui_SketcherSettingsColors)
 {
     ui->setupUi(this);
 }
@@ -313,7 +377,7 @@ void SketcherSettingsColors::loadSettings()
 /**
  * Sets the strings of the subwidgets using the current language.
  */
-void SketcherSettingsColors::changeEvent(QEvent *e)
+void SketcherSettingsColors::changeEvent(QEvent* e)
 {
     if (e->type() == QEvent::LanguageChange) {
         ui->retranslateUi(this);
@@ -324,4 +388,3 @@ void SketcherSettingsColors::changeEvent(QEvent *e)
 }
 
 #include "moc_SketcherSettings.cpp"
-
