@@ -24,16 +24,16 @@
 #include "PreCompiled.h"
 
 #include <boost/tokenizer.hpp>
-#include <Base/Exception.h>
-#include <Mod/Spreadsheet/App/Sheet.h>
-#include <App/PropertyStandard.h>
-#include "Utils.h"
-#include <App/Range.h>
 
+#include <App/Range.h>
+#include <Base/Exception.h>
+
+#include "Sheet.h"
 // inclusion of the generated files (generated out of SheetPy.xml)
 #include "SheetPy.h"
 #include "SheetPy.cpp"
 
+
 using namespace Spreadsheet;
 using namespace App;
 
@@ -71,7 +71,7 @@ PyObject* SheetPy::set(PyObject *args)
         std::string cellAddress = sheet->getAddressFromAlias(address).c_str();
 
         /* Check to see if address is really an alias first */
-        if (cellAddress.size() > 0)
+        if (!cellAddress.empty())
             sheet->setCell(cellAddress.c_str(), contents);
         else {
             Range rangeIter(address);
@@ -123,7 +123,7 @@ PyObject* SheetPy::get(PyObject *args)
 
     App::Property * prop = this->getSheetPtr()->getPropertyByName(address);
 
-    if (prop == nullptr) {
+    if (!prop) {
         PyErr_Format(PyExc_ValueError, 
                 "Invalid cell address or property: %s",address);
         return nullptr;
@@ -494,13 +494,8 @@ PyObject* SheetPy::setAlias(PyObject *args)
 
     try {
         address = stringToAddress(strAddress);
-        if (PyUnicode_Check(value))
-            getSheetPtr()->setAlias(address, PyUnicode_AsUTF8(value));
-        else if (value == Py_None)
-            getSheetPtr()->setAlias(address, "");
-        else
-            throw Base::TypeError("String or None expected");
-
+        Base::PyTypeCheck(&value, &PyUnicode_Type, "String or None expected");
+        getSheetPtr()->setAlias(address, value ? PyUnicode_AsUTF8(value) : "");
         Py_Return;
     }
     catch (const Base::Exception & e) {
@@ -523,10 +518,8 @@ PyObject* SheetPy::getAlias(PyObject *args)
 
         if (cell && cell->getAlias(alias))
             return Py::new_reference_to( Py::String( alias ) );
-        else {
-            Py_INCREF(Py_None);
-            return Py_None;
-        }
+        else
+            Py_Return;
     }
     catch (const Base::Exception & e) {
         PyErr_SetString(PyExc_ValueError, e.what());
@@ -544,12 +537,10 @@ PyObject* SheetPy::getCellFromAlias(PyObject *args)
     try {
         std::string address = getSheetPtr()->getAddressFromAlias(alias);
 
-        if (address.size() > 0)
+        if (!address.empty())
             return Py::new_reference_to( Py::String( address ) );
-        else {
-            Py_INCREF(Py_None);
-            return Py_None;
-        }
+        else
+            Py_Return;
     }
     catch (const Base::Exception & e) {
         PyErr_SetString(PyExc_ValueError, e.what());
@@ -622,7 +613,7 @@ PyObject* SheetPy::setAlignment(PyObject *args)
         tokenizer<escaped_list_separator<char> > tok(line, e);
 
         for(tokenizer<escaped_list_separator<char> >::iterator i = tok.begin(); i != tok.end();++i) {
-            if(i->size())
+            if(!i->empty())
                 alignment = Cell::decodeAlignment(*i, alignment);
         }
     }
@@ -989,6 +980,57 @@ PyObject *SheetPy::recomputeCells(PyObject *args) {
     }PY_CATCH;
 }
 
+PyObject *SheetPy::getUsedCells(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, "")) {
+        return nullptr;
+    }
+    auto usedCells = getSheetPtr()->getCells()->getUsedCells();
+    Py::List pyCellList;
+    for (const auto &cell : usedCells) { 
+        pyCellList.append(Py::String(cell.toString()));
+    }
+    return Py::new_reference_to(pyCellList);
+}
+
+PyObject *SheetPy::getUsedRange(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, "")) {
+        return nullptr;
+    }
+    auto usedRange = getSheetPtr()->getCells()->getUsedRange();
+    Py::Tuple pyTuple(2);
+    pyTuple[0] = Py::String(std::get<0>(usedRange).toString());
+    pyTuple[1] = Py::String(std::get<1>(usedRange).toString());
+    return Py::new_reference_to(pyTuple);
+}
+
+PyObject *SheetPy::getNonEmptyCells(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, "")) {
+        return nullptr;
+    }
+    auto nonEmptyCells = getSheetPtr()->getCells()->getNonEmptyCells();
+    Py::List pyCellList;
+    for (const auto &cell : nonEmptyCells) { 
+        pyCellList.append(Py::String(cell.toString())); 
+    }
+    return Py::new_reference_to(pyCellList);
+}
+
+PyObject *SheetPy::getNonEmptyRange(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, "")) {
+        return nullptr;
+    }
+    auto nonEmptyRange = getSheetPtr()->getCells()->getNonEmptyRange();
+    Py::Tuple pyTuple(2);
+    pyTuple[0] = Py::String(std::get<0>(nonEmptyRange).toString());
+    pyTuple[1] = Py::String(std::get<1>(nonEmptyRange).toString());
+    return Py::new_reference_to(pyTuple);
+}
+
+
 // +++ custom attributes implementer ++++++++++++++++++++++++++++++++++++++++
 
 PyObject *SheetPy::getCustomAttributes(const char*) const
