@@ -20,37 +20,26 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
+
 #ifndef _PreComp_
-# include <QAction>
-# include <QFileDialog>
-# include <QImage>
-# include <QImageReader>
-# include <QMessageBox>
-# include <QTextStream>
+# include <sstream>
 #endif
 
-#include <ctime>
 #if defined(FC_OS_WIN32)
-#include <sys/timeb.h>
+# include <sys/timeb.h>
 #endif
 
-#include <Base/Exception.h>
-#include <Base/Interpreter.h>
-#include <Base/Tools.h>
 #include <App/Document.h>
 #include <Gui/Application.h>
-#include <Gui/MainWindow.h>
 #include <Gui/Command.h>
 #include <Gui/Document.h>
-#include <Gui/ViewProvider.h>
-#include <Gui/BitmapFactory.h>
-# include <Gui/FileDialog.h>
+#include <Gui/FileDialog.h>
+#include <Gui/MainWindow.h>
+#include <Mod/Spreadsheet/App/Sheet.h>
 
-#include "SpreadsheetView.h"
-#include "../App/Sheet.h"
-#include <App/Range.h>
-#include "ViewProviderSpreadsheet.h"
 #include "PropertiesDialog.h"
+#include "SpreadsheetView.h"
+
 
 //++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
@@ -87,7 +76,7 @@ void CmdSpreadsheetMergeCells::activated(int iMsg)
             std::vector<Range> ranges = sheetView->selectedRanges();
 
             // Execute mergeCells commands
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Merge cells"));
                 std::vector<Range>::const_iterator i = ranges.begin();
                 for (; i != ranges.end(); ++i)
@@ -193,7 +182,7 @@ void CmdSpreadsheetImport::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
     QString selectedFilter;
-    QString formatList = QObject::tr("All (*)");
+    QString formatList = QObject::tr("CSV (*.csv *.CSV);;All (*)");
     QString fileName = Gui::FileDialog::getOpenFileName(Gui::getMainWindow(),
                                                         QObject::tr("Import file"),
                                                         QString(),
@@ -249,7 +238,7 @@ void CmdSpreadsheetExport::activated(int iMsg)
         if (sheetView) {
             Sheet * sheet = sheetView->getSheet();
             QString selectedFilter;
-            QString formatList = QObject::tr("All (*)");
+            QString formatList = QObject::tr("CSV (*.csv *.CSV);;All (*)");
             QString fileName = Gui::FileDialog::getSaveFileName(Gui::getMainWindow(),
                                                                 QObject::tr("Export file"),
                                                                 QString(),
@@ -311,7 +300,7 @@ void CmdSpreadsheetAlignLeft::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             std::vector<Range> ranges = sheetView->selectedRanges();
 
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 std::vector<Range>::const_iterator i = ranges.begin();
 
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Left-align cell"));
@@ -363,7 +352,7 @@ void CmdSpreadsheetAlignCenter::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             std::vector<Range> ranges = sheetView->selectedRanges();
 
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 std::vector<Range>::const_iterator i = ranges.begin();
 
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Center cell"));
@@ -415,7 +404,7 @@ void CmdSpreadsheetAlignRight::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             std::vector<Range> ranges = sheetView->selectedRanges();
 
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 std::vector<Range>::const_iterator i = ranges.begin();
 
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Right-align cell"));
@@ -467,7 +456,7 @@ void CmdSpreadsheetAlignTop::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             std::vector<Range> ranges = sheetView->selectedRanges();
 
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 std::vector<Range>::const_iterator i = ranges.begin();
 
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Top-align cell"));
@@ -519,7 +508,7 @@ void CmdSpreadsheetAlignBottom::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             std::vector<Range> ranges = sheetView->selectedRanges();
 
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 std::vector<Range>::const_iterator i = ranges.begin();
 
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Bottom-align cell"));
@@ -571,7 +560,7 @@ void CmdSpreadsheetAlignVCenter::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             std::vector<Range> ranges = sheetView->selectedRanges();
 
-            if (ranges.size() > 0) {
+            if (!ranges.empty()) {
                 std::vector<Range>::const_iterator i = ranges.begin();
 
                 Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Vertically center cells"));
@@ -623,10 +612,10 @@ void CmdSpreadsheetStyleBold::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             QModelIndexList selection = sheetView->selectedIndexes();
 
-            if (selection.size() > 0) {
+            if (!selection.empty()) {
                 bool allBold = true;
 
-                for (QModelIndexList::const_iterator it = selection.begin(); it != selection.end(); ++it) {
+                for (QModelIndexList::const_iterator it = selection.cbegin(); it != selection.cend(); ++it) {
                     const Cell * cell = sheet->getCell(CellAddress((*it).row(), (*it).column()));
 
                     if (cell) {
@@ -697,10 +686,10 @@ void CmdSpreadsheetStyleItalic::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             QModelIndexList selection = sheetView->selectedIndexes();
 
-            if (selection.size() > 0) {
+            if (!selection.empty()) {
                 bool allItalic = true;
 
-                for (QModelIndexList::const_iterator it = selection.begin(); it != selection.end(); ++it) {
+                for (QModelIndexList::const_iterator it = selection.cbegin(); it != selection.cend(); ++it) {
                     const Cell * cell = sheet->getCell(CellAddress((*it).row(), (*it).column()));
 
                     if (cell) {
@@ -771,10 +760,10 @@ void CmdSpreadsheetStyleUnderline::activated(int iMsg)
             Sheet * sheet = sheetView->getSheet();
             QModelIndexList selection = sheetView->selectedIndexes();
 
-            if (selection.size() > 0) {
+            if (!selection.empty()) {
                 bool allUnderline = true;
 
-                for (QModelIndexList::const_iterator it = selection.begin(); it != selection.end(); ++it) {
+                for (QModelIndexList::const_iterator it = selection.cbegin(); it != selection.cend(); ++it) {
                     const Cell * cell = sheet->getCell(CellAddress((*it).row(), (*it).column()));
 
                     if (cell) {
