@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Eivind Kvedalen (eivind@kvedalen.name) 2015             *
+ *   Copyright (c) 2015 Eivind Kvedalen <eivind@kvedalen.name>             *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -21,37 +21,36 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
+
 #ifndef _PreComp_
-# include <QKeyEvent>
 # include <QAction>
-# include <QMenu>
 # include <QApplication>
 # include <QClipboard>
-# include <QMenu>
+# include <QKeyEvent>
 # include <QMessageBox>
+# include <QMenu>
 # include <QMimeData>
-# include <QTextStream>
 #endif
 # include <QTextTableCell>
 
 #include <App/Application.h>
 #include <App/AutoTransaction.h>
 #include <App/Document.h>
+#include <App/Range.h>
 #include <Base/Reader.h>
 #include <Base/Stream.h>
 #include <Base/Writer.h>
-#include <Gui/CommandT.h>
 #include <Gui/Application.h>
+#include <Gui/CommandT.h>
 #include <Gui/MainWindow.h>
-#include <boost_bind_bind.hpp>
-#include "../App/Utils.h"
-#include "../App/Cell.h"
-#include <App/Range.h>
+#include <Mod/Spreadsheet/App/Cell.h>
+
 #include "SheetTableView.h"
-#include "LineEdit.h"
-#include "PropertiesDialog.h"
 #include "DlgBindSheet.h"
 #include "DlgSheetConf.h"
+#include "LineEdit.h"
+#include "PropertiesDialog.h"
+
 
 using namespace SpreadsheetGui;
 using namespace Spreadsheet;
@@ -61,7 +60,7 @@ namespace bp = boost::placeholders;
 void SheetViewHeader::mouseReleaseEvent(QMouseEvent *event)
 {
     QHeaderView::mouseReleaseEvent(event);
-    resizeFinished();
+    Q_EMIT resizeFinished();
 }
 
 bool SheetViewHeader::viewportEvent(QEvent *e) {
@@ -127,18 +126,18 @@ SheetTableView::SheetTableView(QWidget *parent)
                 /*: This is shown in the context menu for the vertical header in a spreadsheet.
                     The number refers to how many lines are selected and will be inserted. */
                 auto insertBefore = menu.addAction(tr("Insert %n row(s) above", "", selection.size()));
-                connect(insertBefore, SIGNAL(triggered()), this, SLOT(insertRows()));
-    
+                connect(insertBefore, &QAction::triggered, this, &SheetTableView::insertRows);
+
                 if (max < model()->rowCount() - 1) {
                     auto insertAfter = menu.addAction(tr("Insert %n row(s) below", "", selection.size()));
-                    connect(insertAfter, SIGNAL(triggered()), this, SLOT(insertRowsAfter()));
+                    connect(insertAfter, &QAction::triggered, this, &SheetTableView::insertRowsAfter);
                 }
             } else {
                 auto insert = menu.addAction(tr("Insert %n non-contiguous rows", "", selection.size()));
-                connect(insert, SIGNAL(triggered()), this, SLOT(insertRows()));
+                connect(insert, &QAction::triggered, this, &SheetTableView::insertRows);
             }
             auto remove = menu.addAction(tr("Remove row(s)", "", selection.size()));
-            connect(remove, SIGNAL(triggered()), this, SLOT(removeRows()));
+            connect(remove, &QAction::triggered, this, &SheetTableView::removeRows);
             menu.exec(verticalHeader()->mapToGlobal(point));
        });
 
@@ -152,43 +151,43 @@ SheetTableView::SheetTableView(QWidget *parent)
                 /*: This is shown in the context menu for the horizontal header in a spreadsheet.
                     The number refers to how many lines are selected and will be inserted. */
                 auto insertAbove = menu.addAction(tr("Insert %n column(s) left", "", selection.size()));
-                connect(insertAbove, SIGNAL(triggered()), this, SLOT(insertColumns()));
+                connect(insertAbove, &QAction::triggered, this, &SheetTableView::insertColumns);
 
                 if (max < model()->columnCount() - 1) {
                     auto insertAfter = menu.addAction(tr("Insert %n column(s) right", "", selection.size()));
-                    connect(insertAfter, SIGNAL(triggered()), this, SLOT(insertColumnsAfter()));
+                    connect(insertAfter, &QAction::triggered, this, &SheetTableView::insertColumnsAfter);
                 }
             } else {
                 auto insert = menu.addAction(tr("Insert %n non-contiguous columns", "", selection.size()));
-                connect(insert, SIGNAL(triggered()), this, SLOT(insertColumns()));
+                connect(insert, &QAction::triggered, this, &SheetTableView::insertColumns);
             }
             auto remove = menu.addAction(tr("Remove column(s)", "", selection.size()));
-            connect(remove, SIGNAL(triggered()), this, SLOT(removeColumns()));
+            connect(remove, &QAction::triggered, this, &SheetTableView::removeColumns);
             menu.exec(horizontalHeader()->mapToGlobal(point));
        });
-       
+
     actionProperties = new QAction(tr("Properties..."), this);
     addAction(actionProperties);
-    
+
     horizontalHeader()->setContextMenuPolicy(Qt::CustomContextMenu);
     verticalHeader()->setContextMenuPolicy(Qt::CustomContextMenu);
 
     contextMenu = new QMenu(this);
 
     contextMenu->addAction(actionProperties);
-    connect(actionProperties, SIGNAL(triggered()), this, SLOT(cellProperties()));
+    connect(actionProperties, &QAction::triggered, this, &SheetTableView::cellProperties);
 
     contextMenu->addSeparator();
     actionRecompute = new QAction(tr("Recompute"),this);
-    connect(actionRecompute, SIGNAL(triggered()), this, SLOT(onRecompute()));
+    connect(actionRecompute, &QAction::triggered, this, &SheetTableView::onRecompute);
     contextMenu->addAction(actionRecompute);
 
     actionBind = new QAction(tr("Bind..."),this);
-    connect(actionBind, SIGNAL(triggered()), this, SLOT(onBind()));
+    connect(actionBind, &QAction::triggered, this, &SheetTableView::onBind);
     contextMenu->addAction(actionBind);
 
     actionConf = new QAction(tr("Configuration table..."),this);
-    connect(actionConf, SIGNAL(triggered()), this, SLOT(onConfSetup()));
+    connect(actionConf, &QAction::triggered, this, &SheetTableView::onConfSetup);
     contextMenu->addAction(actionConf);
 
     horizontalHeader()->addAction(actionBind);
@@ -196,21 +195,24 @@ SheetTableView::SheetTableView(QWidget *parent)
 
     contextMenu->addSeparator();
     actionMerge = contextMenu->addAction(tr("Merge cells"));
-    connect(actionMerge,SIGNAL(triggered()), this, SLOT(mergeCells()));
+    connect(actionMerge, &QAction::triggered, this, &SheetTableView::mergeCells);
     actionSplit = contextMenu->addAction(tr("Split cells"));
-    connect(actionSplit,SIGNAL(triggered()), this, SLOT(splitCell()));
+    connect(actionSplit, &QAction::triggered, this, &SheetTableView::splitCell);
 
     contextMenu->addSeparator();
     actionCut = contextMenu->addAction(tr("Cut"));
-    connect(actionCut,SIGNAL(triggered()), this, SLOT(cutSelection()));
+    connect(actionCut, &QAction::triggered, this, &SheetTableView::cutSelection);
     actionCopy = contextMenu->addAction(tr("Copy"));
-    connect(actionCopy,SIGNAL(triggered()), this, SLOT(copySelection()));
+    connect(actionCopy, &QAction::triggered, this, &SheetTableView::copySelection);
     actionPaste = contextMenu->addAction(tr("Paste"));
-    connect(actionPaste,SIGNAL(triggered()), this, SLOT(pasteClipboard()));
+    connect(actionPaste, &QAction::triggered, this, &SheetTableView::pasteClipboard);
     actionDel = contextMenu->addAction(tr("Delete"));
-    connect(actionDel,SIGNAL(triggered()), this, SLOT(deleteSelection()));
+    connect(actionDel, &QAction::triggered, this, &SheetTableView::deleteSelection);
 
     setTabKeyNavigation(false);
+
+    timer.setSingleShot(true);
+    QObject::connect(&timer, &QTimer::timeout, [this](){updateCellSpan();});
 }
 
 void SheetTableView::onRecompute() {
@@ -224,7 +226,7 @@ void SheetTableView::onRecompute() {
 
 void SheetTableView::onBind() {
     auto ranges = selectedRanges();
-    if(ranges.size()>=1 && ranges.size()<=2) {
+    if(!ranges.empty() && ranges.size()<=2) {
         DlgBindSheet dlg(sheet,ranges,this);
         dlg.exec();
     }
@@ -309,13 +311,13 @@ QModelIndexList SheetTableView::selectedIndexesRaw() const
 
 void SheetTableView::insertRows()
 {
-    assert(sheet != nullptr);
+    assert(sheet);
 
     QModelIndexList rows = selectionModel()->selectedRows();
     std::vector<int> sortedRows;
 
     /* Make sure rows are sorted in ascending order */
-    for (QModelIndexList::const_iterator it = rows.begin(); it != rows.end(); ++it)
+    for (QModelIndexList::const_iterator it = rows.cbegin(); it != rows.cend(); ++it)
         sortedRows.push_back(it->row());
     std::sort(sortedRows.begin(), sortedRows.end());
 
@@ -346,7 +348,7 @@ void SheetTableView::insertRows()
 
 void SheetTableView::insertRowsAfter()
 {
-    assert(sheet != nullptr);
+    assert(sheet);
     const auto rows = selectionModel()->selectedRows();
     const auto & [min, max] = selectedMinMaxRows(rows);
     assert(max - min == rows.size() - 1);
@@ -360,13 +362,13 @@ void SheetTableView::insertRowsAfter()
 
 void SheetTableView::removeRows()
 {
-    assert(sheet != nullptr);
+    assert(sheet);
 
     QModelIndexList rows = selectionModel()->selectedRows();
     std::vector<int> sortedRows;
 
     /* Make sure rows are sorted in descending order */
-    for (QModelIndexList::const_iterator it = rows.begin(); it != rows.end(); ++it)
+    for (QModelIndexList::const_iterator it = rows.cbegin(); it != rows.cend(); ++it)
         sortedRows.push_back(it->row());
     std::sort(sortedRows.begin(), sortedRows.end(), std::greater<int>());
 
@@ -381,13 +383,13 @@ void SheetTableView::removeRows()
 
 void SheetTableView::insertColumns()
 {
-    assert(sheet != nullptr);
+    assert(sheet);
 
     QModelIndexList cols = selectionModel()->selectedColumns();
     std::vector<int> sortedColumns;
 
     /* Make sure rows are sorted in ascending order */
-    for (QModelIndexList::const_iterator it = cols.begin(); it != cols.end(); ++it)
+    for (QModelIndexList::const_iterator it = cols.cbegin(); it != cols.cend(); ++it)
         sortedColumns.push_back(it->column());
     std::sort(sortedColumns.begin(), sortedColumns.end());
 
@@ -419,7 +421,7 @@ void SheetTableView::insertColumns()
 
 void SheetTableView::insertColumnsAfter()
 {
-    assert(sheet != nullptr);
+    assert(sheet);
     const auto columns = selectionModel()->selectedColumns();
     const auto& [min, max] = selectedMinMaxColumns(columns);
     assert(max - min == columns.size() - 1);
@@ -433,13 +435,13 @@ void SheetTableView::insertColumnsAfter()
 
 void SheetTableView::removeColumns()
 {
-    assert(sheet != nullptr);
+    assert(sheet);
 
     QModelIndexList cols = selectionModel()->selectedColumns();
     std::vector<int> sortedColumns;
 
     /* Make sure rows are sorted in descending order */
-    for (QModelIndexList::const_iterator it = cols.begin(); it != cols.end(); ++it)
+    for (QModelIndexList::const_iterator it = cols.cbegin(); it != cols.cend(); ++it)
         sortedColumns.push_back(it->column());
     std::sort(sortedColumns.begin(), sortedColumns.end(), std::greater<int>());
 
@@ -457,20 +459,31 @@ SheetTableView::~SheetTableView()
 
 }
 
-void SheetTableView::updateCellSpan(CellAddress address)
+void SheetTableView::updateCellSpan()
 {
     int rows, cols;
 
-    sheet->getSpans(address, rows, cols);
+    // Unspan first to avoid overlap
+    for (const auto &addr : spanChanges) {
+        if (rowSpan(addr.row(), addr.col()) > 1 || columnSpan(addr.row(), addr.col()) > 1)
+            setSpan(addr.row(), addr.col(), 1, 1);
+    }
 
-    if (rows != rowSpan(address.row(), address.col()) || cols != columnSpan(address.row(), address.col()))
-        setSpan(address.row(), address.col(), rows, cols);
+    for (const auto &addr : spanChanges) {
+        sheet->getSpans(addr, rows, cols);
+        if (rows > 1 || cols > 1)
+            setSpan(addr.row(), addr.col(), rows, cols);
+    }
+    spanChanges.clear();
 }
 
 void SheetTableView::setSheet(Sheet* _sheet)
 {
     sheet = _sheet;
-    cellSpanChangedConnection = sheet->cellSpanChanged.connect(bind(&SheetTableView::updateCellSpan, this, bp::_1));
+    cellSpanChangedConnection = sheet->cellSpanChanged.connect([&](const CellAddress &addr) {
+        spanChanges.insert(addr);
+        timer.start(10);
+    });
 
     // Update row and column spans
     std::vector<std::string> usedCells = sheet->getUsedCells();
@@ -478,8 +491,11 @@ void SheetTableView::setSheet(Sheet* _sheet)
     for (std::vector<std::string>::const_iterator i = usedCells.begin(); i != usedCells.end(); ++i) {
         CellAddress address(*i);
 
-        if (sheet->isMergedCell(address))
-            updateCellSpan(address);
+        if (sheet->isMergedCell(address)) {
+            int rows, cols;
+            sheet->getSpans(address, rows, cols);
+            setSpan(address.row(), address.col(), rows, cols);
+        }
     }
 
     // Update column widths and row height
@@ -593,7 +609,7 @@ bool SheetTableView::event(QEvent* event)
             kevent->accept();
         }
     }
-    else if (event->type() == QEvent::LanguageChange) {
+    else if (event && event->type() == QEvent::LanguageChange) {
         actionProperties->setText(tr("Properties..."));
         actionRecompute->setText(tr("Recompute"));
         actionConf->setText(tr("Configuration table..."));
@@ -612,7 +628,7 @@ void SheetTableView::deleteSelection()
 {
     QModelIndexList selection = selectionModel()->selectedIndexes();
 
-    if (selection.size() > 0) {
+    if (!selection.empty()) {
         Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Clear cell(s)"));
         std::vector<Range> ranges = selectedRanges();
         std::vector<Range>::const_iterator i = ranges.begin();
@@ -685,7 +701,7 @@ void SheetTableView::pasteClipboard()
             ranges = sheet->getCopyOrCutRange(copy);
         }
 
-        if(ranges.size())
+        if(!ranges.empty())
             _copySelection(ranges, copy);
 
         const QMimeData* mimeData = QApplication::clipboard()->mimeData();
@@ -693,7 +709,7 @@ void SheetTableView::pasteClipboard()
             return;
 
         if(!copy) {
-            for(auto range : ranges) {
+            for(auto &range : ranges) {
                 do {
                     sheet->clear(*range);
                 } while (range.next());
@@ -707,13 +723,13 @@ void SheetTableView::pasteClipboard()
         Range range = ranges.back();
         if (!mimeData->hasFormat(_SheetMime)) {
             CellAddress current = range.from();
-            QStringList cells;
             QString text = mimeData->text();
+            QStringList cells = text.split(QLatin1Char('\n'));
             int i=0;
-            for (auto it : text.split(QLatin1Char('\n'))) {
+            for (const auto& it : cells) {
                 QStringList cols = it.split(QLatin1Char('\t'));
                 int j=0;
-                for (auto jt : cols) {
+                for (const auto& jt : cols) {
                     QModelIndex index = model()->index(current.row()+i, current.col()+j);
                     model()->setData(index, jt);
                     j++;
@@ -798,7 +814,7 @@ void SheetTableView::finishEditWithMove(int keyPressed, Qt::KeyboardModifiers mo
 
     case Qt::Key_Home:
         // Home: row 1, same column
-        // Ctrl-Home: row 1, column 1 
+        // Ctrl-Home: row 1, column 1
         targetRow = 0;
         if (modifiers == Qt::ControlModifier)
             targetColumn = 0;
@@ -915,7 +931,7 @@ void SheetTableView::finishEditWithMove(int keyPressed, Qt::KeyboardModifiers mo
         // With shift down, this motion becomes a block selection command, rather than just simple motion:
         ModifyBlockSelection(targetRow, targetColumn);
     }
-        
+
 }
 
 void SheetTableView::ModifyBlockSelection(int targetRow, int targetCol)
@@ -973,7 +989,7 @@ void SheetTableView::splitCell() {
 }
 
 void SheetTableView::closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint)
-{ 
+{
     QTableView::closeEditor(editor, hint);
 }
 
@@ -1017,7 +1033,7 @@ void SheetTableView::contextMenuEvent(QContextMenuEvent *)
     }
 
     auto ranges = selectedRanges();
-    actionBind->setEnabled(ranges.size()>=1 && ranges.size()<=2);
+    actionBind->setEnabled(!ranges.empty() && ranges.size()<=2);
 
     contextMenu->exec(QCursor::pos());
 }
