@@ -21,45 +21,35 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
+
 #ifndef _PreComp_
-# include <QAction>
-# include <QApplication>
-# include <QMenu>
-# include <QMouseEvent>
+# include <cmath>
+# include <QPalette>
 # include <QPrinter>
 # include <QPrintDialog>
 # include <QPrintPreviewDialog>
-# include <QSlider>
-# include <QStatusBar>
-# include <QToolBar>
-# include <QTableWidgetItem>
 # include <QTextDocument>
-# include <QMessageBox>
-# include <QPalette>
-# include <cmath>
 #endif
 
 #include <App/DocumentObject.h>
-#include <App/PropertyStandard.h>
 #include <App/Range.h>
 #include <Base/Tools.h>
-#include <boost_bind_bind.hpp>
-#include <Gui/MainWindow.h>
 #include <Gui/Application.h>
 #include <Gui/Command.h>
 #include <Gui/CommandT.h>
 #include <Gui/Document.h>
-#include <Gui/ExpressionCompleter.h>
 #include <Gui/FileDialog.h>
-#include <LineEdit.h>
+#include <Gui/MainWindow.h>
+
 #include <Mod/Spreadsheet/App/Sheet.h>
 #include <Mod/Spreadsheet/App/SheetPy.h>
-#include <Mod/Spreadsheet/App/Utils.h>
-#include "qtcolorpicker.h"
 
 #include "SpreadsheetView.h"
-#include "SpreadsheetDelegate.h"
 #include "ui_Sheet.h"
+#include "LineEdit.h"
+#include "qtcolorpicker.h"
+#include "SpreadsheetDelegate.h"
+
 
 using namespace SpreadsheetGui;
 using namespace Spreadsheet;
@@ -90,28 +80,28 @@ SheetView::SheetView(Gui::Document *pcDocument, App::DocumentObject *docObj, QWi
     ui->cells->setSheet(sheet);
 
     // Connect signals
-    connect(ui->cells->selectionModel(), SIGNAL( currentChanged( QModelIndex, QModelIndex ) ),
-            this,        SLOT( currentChanged( QModelIndex, QModelIndex ) ) );
+    connect(ui->cells->selectionModel(), &QItemSelectionModel::currentChanged,
+            this, &SheetView::currentChanged);
 
-    connect(ui->cells->horizontalHeader(), SIGNAL(resizeFinished()),
-            this, SLOT(columnResizeFinished()));
-    connect(ui->cells->horizontalHeader(), SIGNAL(sectionResized ( int, int, int ) ),
-            this, SLOT(columnResized(int, int, int)));
+    connect(dynamic_cast<SheetViewHeader*>(ui->cells->horizontalHeader()), &SheetViewHeader::resizeFinished,
+            this, &SheetView::columnResizeFinished);
+    connect(ui->cells->horizontalHeader(), &QHeaderView::sectionResized,
+            this, &SheetView::columnResized);
 
-    connect(ui->cells->verticalHeader(), SIGNAL(resizeFinished()),
-            this, SLOT(rowResizeFinished()));
-    connect(ui->cells->verticalHeader(), SIGNAL(sectionResized ( int, int, int ) ),
-            this, SLOT(rowResized(int, int, int)));
+    connect(dynamic_cast<SheetViewHeader*>(ui->cells->verticalHeader()), &SheetViewHeader::resizeFinished,
+            this, &SheetView::rowResizeFinished);
+    connect(ui->cells->verticalHeader(), &QHeaderView::sectionResized,
+            this, &SheetView::rowResized);
 
     connect(delegate, &SpreadsheetDelegate::finishedWithKey, this, &SheetView::editingFinishedWithKey);
     connect(ui->cellContent, &ExpressionLineEdit::returnPressed, this, [this]() {confirmContentChanged(ui->cellContent->text()); });
-    connect(ui->cellAlias, &ExpressionLineEdit::returnPressed, this, [this]() {confirmAliasChanged(ui->cellAlias->text()); });
+    connect(ui->cellAlias, &ExpressionLineEdit::editingFinished, this, [this]() {confirmAliasChanged(ui->cellAlias->text()); });
     connect(ui->cellAlias, &LineEdit::textEdited, this, &SheetView::aliasChanged);
 
     columnWidthChangedConnection = sheet->columnWidthChanged.connect(bind(&SheetView::resizeColumn, this, bp::_1, bp::_2));
     rowHeightChangedConnection = sheet->rowHeightChanged.connect(bind(&SheetView::resizeRow, this, bp::_1, bp::_2));
 
-    connect( model, SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)), this, SLOT(modelUpdated(const QModelIndex &, const QModelIndex &)));
+    connect( model, &QAbstractItemModel::dataChanged, this, &SheetView::modelUpdated);
 
     QPalette palette = ui->cells->palette();
     palette.setColor(QPalette::Base, QColor(255, 255, 255));
@@ -119,11 +109,11 @@ SheetView::SheetView(Gui::Document *pcDocument, App::DocumentObject *docObj, QWi
     ui->cells->setPalette(palette);
 
     QList<QtColorPicker*> bgList = Gui::getMainWindow()->findChildren<QtColorPicker*>(QString::fromLatin1("Spreadsheet_BackgroundColor"));
-    if (bgList.size() > 0)
+    if (!bgList.empty())
         bgList[0]->setCurrentColor(palette.color(QPalette::Base));
 
     QList<QtColorPicker*> fgList = Gui::getMainWindow()->findChildren<QtColorPicker*>(QString::fromLatin1("Spreadsheet_ForegroundColor"));
-    if (fgList.size() > 0)
+    if (!fgList.empty())
         fgList[0]->setCurrentColor(palette.color(QPalette::Text));
 
     // Set document object to create auto completer
@@ -241,8 +231,8 @@ void SheetView::printPreview()
     QPrinter printer(QPrinter::ScreenResolution);
     printer.setPageOrientation(QPageLayout::Landscape);
     QPrintPreviewDialog dlg(&printer, this);
-    connect(&dlg, SIGNAL(paintRequested (QPrinter *)),
-            this, SLOT(print(QPrinter *)));
+    connect(&dlg, &QPrintPreviewDialog::paintRequested,
+            this, qOverload<QPrinter*>(&SheetView::print));
     dlg.exec();
 }
 
@@ -313,7 +303,7 @@ void SheetView::updateAliasLine()
 
 void SheetView::columnResizeFinished()
 {
-    if (newColumnSizes.size() == 0)
+    if (newColumnSizes.empty())
         return;
 
     blockSignals(true);
@@ -325,7 +315,7 @@ void SheetView::columnResizeFinished()
 
 void SheetView::rowResizeFinished()
 {
-    if (newRowSizes.size() == 0)
+    if (newRowSizes.empty())
         return;
 
     blockSignals(true);
@@ -584,7 +574,7 @@ Py::Object SheetViewPy::getattr(const char * attr)
     if (name == "__dict__" || name == "__class__") {
         Py::Dict dict_self(BaseType::getattr("__dict__"));
         Py::Dict dict_base(base.getattr("__dict__"));
-        for (auto it : dict_base) {
+        for (const auto& it : dict_base) {
             dict_self.setItem(it.first, it.second);
         }
         return dict_self;
