@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #***************************************************************************
 #*   Copyright (c) 2016 Ulrich Brammer <ulrich1a@users.sourceforge.net>    *
@@ -20,11 +20,10 @@
 #*   USA                                                                   *
 #***************************************************************************/
 
-from __future__ import print_function
 
 __title__  = "FreeCAD Spreadsheet Workbench - XLSX importer"
 __author__ = "Ulrich Brammer <ulrich1a@users.sourceforge.net>"
-__url__    = ["https://www.freecadweb.org"]
+__url__    = ["https://www.freecad.org"]
 
 '''
 This library imports an Excel-XLSX-file into FreeCAD.
@@ -56,7 +55,6 @@ known issues:
 import zipfile
 import xml.dom.minidom
 import FreeCAD as App
-import sys
 
 try: import FreeCADGui
 except ValueError: gui = False
@@ -322,10 +320,7 @@ def getText(nodelist):
   for node in nodelist:
     if node.nodeType == node.TEXT_NODE:
       rc.append(node.data)
-    if sys.version_info.major >= 3:
-      return ''.join(rc)
-    else:
-      return ''.join(rc).encode('utf8')
+    return ''.join(rc)
 
 
 def handleWorkSheet(theDom, actSheet, strList):
