@@ -4,212 +4,212 @@
   <context>
     <name>StartPage</name>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
+      <location filename="TranslationTexts.py" line="42"/>
       <source>Start</source>
       <translation>Mulai</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
+      <location filename="TranslationTexts.py" line="43"/>
       <source>Documents</source>
       <translation>Dokumen</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
+      <location filename="TranslationTexts.py" line="44"/>
       <source>Help</source>
       <translation>Bantuan</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
+      <location filename="TranslationTexts.py" line="45"/>
       <source>Activity</source>
       <translation>Aktifitas</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
+      <location filename="TranslationTexts.py" line="46"/>
       <source>Recent files</source>
       <translation>File terbaru</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
+      <location filename="TranslationTexts.py" line="47"/>
       <source>Tip</source>
       <translation>Petunjuk</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
+      <location filename="TranslationTexts.py" line="48"/>
       <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
       <translation>Sesuaikan jumlah file terbaru yang akan ditampilkan di sini di menu Edit -&gt; Preferensi -&gt; Umum -&gt; Ukuran daftar file terbaru</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
+      <location filename="TranslationTexts.py" line="49"/>
       <source>Examples</source>
       <translation>Contoh</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
+      <location filename="TranslationTexts.py" line="50"/>
       <source>General documentation</source>
       <translation>Dokumentasi umum</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
+      <location filename="TranslationTexts.py" line="51"/>
       <source>User hub</source>
       <translation type="unfinished">User hub</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
+      <location filename="TranslationTexts.py" line="52"/>
       <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
       <translation>Bagian ini berisi dokumentasi yang berguna untuk pengguna FreeCAD secara umum: daftar semua meja kerja, petunjuk terperinci tentang cara menginstal dan menggunakan aplikasi FreeCAD, tutorial, dan semua yang dibutuhkan untuk menggunakannya.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
+      <location filename="TranslationTexts.py" line="53"/>
       <source>Power users hub</source>
       <translation type="unfinished">Power users hub</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
+      <location filename="TranslationTexts.py" line="54"/>
       <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
       <translation>Bagian ini mengumpulkan dokumentasi untuk pengguna tingkat lanjutan dan mereka yang tertarik untuk membuat tulisan python. Anda juga akan menemukan ruang penyimpanan yang besar, instruksi tentang cara menginstal dan menggunakannya, dan informasi lebih lanjut tentang cara menyesuaikan FreeCAD dengan kebutuhan khusus Anda.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
+      <location filename="TranslationTexts.py" line="55"/>
       <source>Developers hub</source>
       <translation type="unfinished">Developers hub</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
+      <location filename="TranslationTexts.py" line="56"/>
       <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
       <translation type="unfinished">This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
+      <location filename="TranslationTexts.py" line="57"/>
       <source>Manual</source>
-      <translation type="unfinished">Manual</translation>
+      <translation>Manual</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
+      <location filename="TranslationTexts.py" line="58"/>
       <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</source>
       <translation type="unfinished">The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
+      <location filename="TranslationTexts.py" line="59"/>
       <source>Workbenches documentation</source>
       <translation type="unfinished">Workbenches documentation</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
+      <location filename="TranslationTexts.py" line="60"/>
       <source>These are the help pages of all the workbenches currently installed on this computer.</source>
       <translation type="unfinished">These are the help pages of all the workbenches currently installed on this computer.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
+      <location filename="TranslationTexts.py" line="61"/>
       <source>Getting help from the community</source>
-      <translation type="unfinished">Getting help from the community</translation>
+      <translation>Dapatkan bantuan dari komunitas</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
+      <location filename="TranslationTexts.py" line="62"/>
       <source>The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
       <translation type="unfinished">The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
+      <location filename="TranslationTexts.py" line="63"/>
       <source>If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</source>
       <translation type="unfinished">If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
+      <location filename="TranslationTexts.py" line="64"/>
       <source>FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</source>
       <translation type="unfinished">FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
+      <location filename="TranslationTexts.py" line="65"/>
       <source>Available addons</source>
       <translation type="unfinished">Available addons</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
+      <location filename="TranslationTexts.py" line="66"/>
       <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
       <translation type="unfinished">Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
+      <location filename="TranslationTexts.py" line="67"/>
       <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
       <translation type="unfinished">If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
+      <location filename="TranslationTexts.py" line="68"/>
       <source>Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
       <translation type="unfinished">Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
+      <location filename="TranslationTexts.py" line="69"/>
       <source>Recent commits</source>
       <translation type="unfinished">Recent commits</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
+      <location filename="TranslationTexts.py" line="70"/>
       <source>Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
       <translation type="unfinished">Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
+      <location filename="TranslationTexts.py" line="71"/>
       <source>See all commits on github</source>
       <translation type="unfinished">See all commits on github</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
+      <location filename="TranslationTexts.py" line="72"/>
       <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
       <translation type="unfinished">You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
+      <location filename="TranslationTexts.py" line="73"/>
       <source>version</source>
-      <translation type="unfinished">version</translation>
+      <translation>versi</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
+      <location filename="TranslationTexts.py" line="74"/>
       <source>build</source>
       <translation type="unfinished">build</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
+      <location filename="TranslationTexts.py" line="75"/>
       <source>Create new...</source>
-      <translation type="unfinished">Create new...</translation>
+      <translation>Buat baru...</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
+      <location filename="TranslationTexts.py" line="76"/>
       <source>Unknown</source>
       <translation type="unfinished">Unknown</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
+      <location filename="TranslationTexts.py" line="77"/>
       <source>Forum</source>
       <translation>Forum</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
+      <location filename="TranslationTexts.py" line="78"/>
       <source>The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</source>
       <translation type="unfinished">The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
+      <location filename="TranslationTexts.py" line="79"/>
       <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
       <translation type="unfinished">To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="80"/>
+      <location filename="TranslationTexts.py" line="80"/>
       <source>Creation date</source>
-      <translation type="unfinished">Creation date</translation>
+      <translation>Tanggal diciptakan</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
+      <location filename="TranslationTexts.py" line="81"/>
       <source>Last modification</source>
-      <translation type="unfinished">Last modification</translation>
+      <translation>Terakhir dimodifikasi</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
+      <location filename="TranslationTexts.py" line="82"/>
       <source>Notes</source>
-      <translation type="unfinished">Notes</translation>
+      <translation>Catatan</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
+      <location filename="TranslationTexts.py" line="83"/>
       <source>Open start page preferences</source>
       <translation type="unfinished">Open start page preferences</translation>
     </message>
@@ -217,8 +217,7 @@
   <context>
     <name>Workbench</name>
     <message>
-      <location filename="../../Command.cpp" line="58"/>
-      <location filename="../../Workbench.cpp" line="65"/>
+      <location filename="../../Workbench.cpp" line="75"/>
       <source>Start page</source>
       <translation type="unfinished">Start page</translation>
     </message>
@@ -226,17 +225,17 @@
   <context>
     <name>CmdStartPage</name>
     <message>
-      <location filename="../../Command.cpp" line="44"/>
+      <location filename="../../Command.cpp" line="45"/>
       <source>Start</source>
       <translation>Mulai</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="45"/>
+      <location filename="../../Command.cpp" line="46"/>
       <source>Start Page</source>
       <translation type="unfinished">Start Page</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="46"/>
+      <location filename="../../Command.cpp" line="47"/>
       <source>Displays the start page in a browser view</source>
       <translation type="unfinished">Displays the start page in a browser view</translation>
     </message>
@@ -266,7 +265,7 @@
     <message>
       <location filename="../../DlgStartPreferences.ui" line="48"/>
       <source>Show forum</source>
-      <translation type="unfinished">Show forum</translation>
+      <translation>Tampilkan forum</translation>
     </message>
     <message>
       <location filename="../../DlgStartPreferences.ui" line="55"/>
@@ -290,188 +289,210 @@
     </message>
     <message>
       <location filename="../../DlgStartPreferences.ui" line="110"/>
-      <source>An optional custom folder to be displayed at the bottom of the first page</source>
-      <translation type="unfinished">An optional custom folder to be displayed at the bottom of the first page</translation>
+      <source>An optional custom folder to be displayed at the bottom of the first page.
+By using ";;" to separate paths, you can add several folders here</source>
+      <translation type="unfinished">An optional custom folder to be displayed at the bottom of the first page.
+By using ";;" to separate paths, you can add several folders here</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="126"/>
+      <location filename="../../DlgStartPreferences.ui" line="127"/>
       <source>Show notepad</source>
       <translation type="unfinished">Show notepad</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="133"/>
-      <source>Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</source>
-      <translation type="unfinished">Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</translation>
+      <location filename="../../DlgStartPreferences.ui" line="134"/>
+      <source>Shows a notepad next to the file thumbnails, where you can keep notes across sessions</source>
+      <translation type="unfinished">Shows a notepad next to the file thumbnails, where you can keep notes across sessions</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="155"/>
+      <location filename="../../DlgStartPreferences.ui" line="153"/>
+      <source>Show tips</source>
+      <translation type="unfinished">Show tips</translation>
+    </message>
+    <message>
+      <location filename="../../DlgStartPreferences.ui" line="163"/>
+      <source>Displays help tips in the Start workbench Documents tab</source>
+      <translation type="unfinished">Displays help tips in the Start workbench Documents tab</translation>
+    </message>
+    <message>
+      <location filename="../../DlgStartPreferences.ui" line="185"/>
       <source>Fonts and colors</source>
-      <translation type="unfinished">Fonts and colors</translation>
+      <translation>Font dan warna</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="167"/>
+      <location filename="../../DlgStartPreferences.ui" line="197"/>
       <source>The background of the main start page area</source>
       <translation type="unfinished">The background of the main start page area</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="187"/>
+      <location filename="../../DlgStartPreferences.ui" line="217"/>
       <source>Background color</source>
       <translation>Warna latar belakang</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="199"/>
+      <location filename="../../DlgStartPreferences.ui" line="229"/>
       <source>in FreeCAD</source>
       <translation type="unfinished">in FreeCAD</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="218"/>
+      <location filename="../../DlgStartPreferences.ui" line="248"/>
       <source>In external browser</source>
       <translation type="unfinished">In external browser</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="236"/>
-      <source>Background color gradient down</source>
-      <translation type="unfinished">Background color gradient down</translation>
+      <location filename="../../DlgStartPreferences.ui" line="266"/>
+      <source>Background color down gradient</source>
+      <translation type="unfinished">Background color down gradient</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="249"/>
+      <location filename="../../DlgStartPreferences.ui" line="279"/>
       <source>The color of the version text</source>
       <translation type="unfinished">The color of the version text</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="269"/>
+      <location filename="../../DlgStartPreferences.ui" line="299"/>
       <source>Link color</source>
       <translation type="unfinished">Link color</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="276"/>
+      <location filename="../../DlgStartPreferences.ui" line="306"/>
       <source>An optional image to display as background</source>
       <translation type="unfinished">An optional image to display as background</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="289"/>
-      <source>If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</source>
-      <translation type="unfinished">If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</translation>
+      <location filename="../../DlgStartPreferences.ui" line="319"/>
+      <source>If this is checked and a style sheet is specified in General preferences, it will be used and override the colors below</source>
+      <translation type="unfinished">If this is checked and a style sheet is specified in General preferences, it will be used and override the colors below</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="308"/>
+      <location filename="../../DlgStartPreferences.ui" line="338"/>
       <source>Page background color</source>
       <translation type="unfinished">Page background color</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="321"/>
+      <location filename="../../DlgStartPreferences.ui" line="351"/>
       <source>The color of the text on the main pages</source>
       <translation type="unfinished">The color of the text on the main pages</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="341"/>
+      <location filename="../../DlgStartPreferences.ui" line="371"/>
       <source>Background image</source>
-      <translation type="unfinished">Background image</translation>
+      <translation>Gambar background</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="348"/>
+      <location filename="../../DlgStartPreferences.ui" line="378"/>
       <source>Page text color</source>
       <translation type="unfinished">Page text color</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="361"/>
+      <location filename="../../DlgStartPreferences.ui" line="391"/>
       <source>The color of the links</source>
       <translation type="unfinished">The color of the links</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="387"/>
+      <location filename="../../DlgStartPreferences.ui" line="417"/>
       <source>The background color of the boxes inside the pages</source>
       <translation type="unfinished">The background color of the boxes inside the pages</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="407"/>
+      <location filename="../../DlgStartPreferences.ui" line="437"/>
       <source>Box background color</source>
       <translation type="unfinished">Box background color</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="420"/>
+      <location filename="../../DlgStartPreferences.ui" line="450"/>
       <source>The background color behind the panels</source>
       <translation type="unfinished">The background color behind the panels</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="449"/>
+      <location filename="../../DlgStartPreferences.ui" line="479"/>
       <source>The down gradient for the background color (currently unsupported)</source>
       <translation type="unfinished">The down gradient for the background color (currently unsupported)</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="472"/>
+      <location filename="../../DlgStartPreferences.ui" line="502"/>
       <source>Open links</source>
       <translation type="unfinished">Open links</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="479"/>
+      <location filename="../../DlgStartPreferences.ui" line="509"/>
       <source>Background text color</source>
       <translation type="unfinished">Background text color</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="486"/>
+      <location filename="../../DlgStartPreferences.ui" line="516"/>
       <source>Use FreeCAD style sheet</source>
       <translation type="unfinished">Use FreeCAD style sheet</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="493"/>
+      <location filename="../../DlgStartPreferences.ui" line="523"/>
       <source>Font family</source>
       <translation>Keluarga font</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="502"/>
+      <location filename="../../DlgStartPreferences.ui" line="532"/>
       <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
       <translation type="unfinished">The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="508"/>
+      <location filename="../../DlgStartPreferences.ui" line="538"/>
       <source>Arial,Helvetica,sans</source>
       <translation type="unfinished">Arial,Helvetica,sans</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="521"/>
+      <location filename="../../DlgStartPreferences.ui" line="551"/>
       <source>The base font size to use for all texts of the Start page</source>
       <translation type="unfinished">The base font size to use for all texts of the Start page</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="524"/>
+      <location filename="../../DlgStartPreferences.ui" line="554"/>
       <source>px</source>
       <translation>px</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="542"/>
+      <location filename="../../DlgStartPreferences.ui" line="572"/>
       <source>Use gradient for New File icon</source>
       <translation type="unfinished">Use gradient for New File icon</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="568"/>
+      <location filename="../../DlgStartPreferences.ui" line="579"/>
+      <source>If this is selected, the 'New File' icon shows a gradient icon instead of the normal icon</source>
+      <translation type="unfinished">If this is selected, the 'New File' icon shows a gradient icon instead of the normal icon</translation>
+    </message>
+    <message>
+      <location filename="../../DlgStartPreferences.ui" line="601"/>
       <source>Options</source>
       <translation>Pilihan</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="577"/>
-      <source>Should the start page be closed after loading?</source>
-      <translation type="unfinished">Should the start page be closed after loading?</translation>
+      <location filename="../../DlgStartPreferences.ui" line="607"/>
+      <source>Choose which workbench to switch to after the program launches</source>
+      <translation type="unfinished">Choose which workbench to switch to after the program launches</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="596"/>
+      <location filename="../../DlgStartPreferences.ui" line="614"/>
+      <source>If checked, will automatically close the Start page when FreeCAD launches</source>
+      <translation type="unfinished">If checked, will automatically close the Start page when FreeCAD launches</translation>
+    </message>
+    <message>
+      <location filename="../../DlgStartPreferences.ui" line="633"/>
       <source>Switch workbench after loading</source>
       <translation type="unfinished">Switch workbench after loading</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="603"/>
+      <location filename="../../DlgStartPreferences.ui" line="640"/>
       <source>Close start page after loading</source>
       <translation type="unfinished">Close start page after loading</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="610"/>
-      <source>Close &amp; switch on file open</source>
-      <translation type="unfinished">Close &amp; switch on file open</translation>
+      <location filename="../../DlgStartPreferences.ui" line="647"/>
+      <source>Close and switch on opening file</source>
+      <translation type="unfinished">Close and switch on opening file</translation>
     </message>
     <message>
-      <location filename="../../DlgStartPreferences.ui" line="617"/>
-      <source>If FreeCAD is started by opening a file, apply the two settings above</source>
-      <translation type="unfinished">If FreeCAD is started by opening a file, apply the two settings above</translation>
+      <location filename="../../DlgStartPreferences.ui" line="654"/>
+      <source>If application is started by opening a file, apply the two settings above</source>
+      <translation type="unfinished">If application is started by opening a file, apply the two settings above</translation>
     </message>
   </context>
 </TS>
