@@ -32,10 +32,19 @@ import zipfile
 import re
 import FreeCAD
 import FreeCADGui
+import codecs
+import hashlib
 import urllib.parse
 from . import TranslationTexts
 from PySide import QtCore, QtGui
 
+try:
+    from addonmanager_macro import Macro as AM_Macro
+    has_am_macro = True
+except ImportError:
+    has_am_macro = False
+
+
 FreeCADGui.addLanguagePath(":/translations")
 FreeCADGui.updateLocale()
 
@@ -45,6 +54,42 @@ tempfolder = None   # store icons inside a subfolder in temp dir
 defaulticon = None  # store a default icon for problematic file types
 
 
+def getThumbnailDir():
+    parent_dir = FreeCAD.getUserCachePath()
+    return os.path.join(parent_dir, "FreeCADStartThumbnails")
+
+
+def createThumbnailDir():
+    path = getThumbnailDir()
+    if not os.path.exists(path):
+        os.mkdir(path)
+    return path
+
+
+def getSha1Hash(path, encode="utf-8"):
+    sha_hash = hashlib.sha1()
+    hashed = hashlib.sha1(path.encode(encode))
+    hex_digest = hashed.hexdigest().encode(encode)
+    sha_hash.update(hex_digest)
+    return sha_hash.hexdigest()
+
+
+def getUniquePNG(filename):
+    parent_dir = getThumbnailDir()
+    sha1 = getSha1Hash(filename) + ".png"
+    return os.path.join(parent_dir, sha1)
+
+
+def useCachedPNG(image, project):
+    if not os.path.exists(image):
+        return False
+    if not os.path.exists(project):
+        return False
+
+    stamp = os.path.getmtime
+    return stamp(image) > stamp(project)
+
+
 def gethexcolor(color):
 
     "returns a color hex value #000000"
@@ -144,7 +189,7 @@ def getInfo(filename):
             # check for meta-file if it's really a FreeCAD document
             if files[0] == "Document.xml":
                 try:
-                    doc = str(zfile.read(files[0]))
+                    doc = zfile.read(files[0]).decode('utf-8')
                 except OSError as e:
                     print ("Fail to load corrupted FCStd file: '{0}' with this error: {1}".format(filename, str(e)))
                     return None
@@ -165,41 +210,64 @@ def getInfo(filename):
                 if r:
                     descr = r[0]
                 if "thumbnails/Thumbnail.png" in files:
+                    image_png = getUniquePNG(filename)
                     if filename in iconbank:
                         image = iconbank[filename]
+                    elif useCachedPNG(image_png, filename):
+                        image = image_png
+                        iconbank[filename] = image
                     else:
                         imagedata=zfile.read("thumbnails/Thumbnail.png")
-                        image = tempfile.mkstemp(dir=tempfolder,suffix='.png')[1]
+                        image = image_png
                         thumb = open(image,"wb")
                         thumb.write(imagedata)
                         thumb.close()
                         iconbank[filename] = image
 
-        # use image itself as icon if it's an image file
-        if os.path.splitext(filename)[1].lower() in [".jpg",".jpeg",".png",".svg"]:
+        elif filename.lower().endswith(".fcmacro"):
+            # For FreeCAD macros, use the Macro Editor icon (but we have to have it in a file for
+            # the web view to load it)
+            image = os.path.join(tempfolder,"fcmacro_icon.svg")
+            if not os.path.exists(image):
+                f = QtCore.QFile(":/icons/MacroEditor.svg")
+                f.copy(image)
+            iconbank[filename] = image
+
+            if has_am_macro:
+                macro = AM_Macro(os.path.basename(filename))
+                macro.fill_details_from_file(filename)
+                author = macro.author
+
+        elif QtGui.QImageReader.imageFormat(filename):
+            # use image itself as icon if it's an image file
             image = filename
             iconbank[filename] = image
 
-        # use freedesktop thumbnail if available
-        fdthumb = getFreeDesktopThumbnail(filename)
-        if fdthumb:
-            image = fdthumb
-            iconbank[filename] = fdthumb
+        else:
+            # use freedesktop thumbnail if available
+            fdthumb = getFreeDesktopThumbnail(filename)
+            if fdthumb:
+                image = fdthumb
+                iconbank[filename] = fdthumb
 
         # retrieve default mime icon if needed
         if not image:
             i = QtCore.QFileInfo(filename)
             t = iconprovider.type(i)
+            filename_png = getUniquePNG(filename)
             if not t:
                 t = "Unknown"
             if t in iconbank:
                 image = iconbank[t]
+            elif os.path.exists(filename_png):
+                image = filename_png
+                iconbank[t] = image
             else:
                 icon = iconprovider.icon(i)
                 if icon.availableSizes():
                     preferred = icon.actualSize(QtCore.QSize(128,128))
                     px = icon.pixmap(preferred)
-                    image = tempfile.mkstemp(dir=tempfolder,suffix='.png')[1]
+                    image = filename_png
                     px.save(image)
                 else:
                     image = getDefaultIcon()
@@ -221,7 +289,7 @@ def getDefaultIcon():
         icon = iconprovider.icon(i)
         preferred = icon.actualSize(QtCore.QSize(128,128))
         px = icon.pixmap(preferred)
-        image = tempfile.mkstemp(dir=tempfolder,suffix='.png')[1]
+        image = getUniquePNG("default_icon")
         px.save(image)
         defaulticon = image
 
@@ -231,7 +299,7 @@ def getDefaultIcon():
 
 def buildCard(filename,method,arg=None):
 
-    """builds an html <li> element representing a file. 
+    """builds an html <li> element representing a file.
     method is a script + a keyword, for ex. url.py?key="""
 
     result = ""
@@ -277,7 +345,7 @@ def handle():
     if hasattr(Start,"tempfolder"):
         tempfolder = Start.tempfolder
     else:
-        tempfolder = tempfile.mkdtemp(prefix="FreeCADStartThumbnails")
+        tempfolder = createThumbnailDir()
 
     # build the html page skeleton
 
@@ -331,7 +399,7 @@ def handle():
                         ALTCSS = QtCore.QTextStream(f).readAll()
                         HTML = HTML.replace("<!--QSS-->","<style type=\"text/css\">"+ALTCSS+"</style>")
                 else:
-                    with open(path, 'r') as f:
+                    with codecs.open(path, encoding='utf-8') as f:
                         ALTCSS = f.read()
                         HTML = HTML.replace("<!--QSS-->","<style type=\"text/css\">"+ALTCSS+"</style>")
 
@@ -343,7 +411,7 @@ def handle():
     # get FreeCAD version
 
     v = FreeCAD.Version()
-    VERSIONSTRING = TranslationTexts.T_VERSION + " " + v[0] + "." + v[1] + " " + TranslationTexts.T_BUILD + " " + v[2]
+    VERSIONSTRING = TranslationTexts.T_VERSION + " " + v[0] + "." + v[1] + "." + v[2] +" " + TranslationTexts.T_BUILD + " " + v[3]
     HTML = HTML.replace("VERSIONSTRING",VERSIONSTRING)
 
     # translate texts
@@ -365,7 +433,7 @@ def handle():
         pa = QtGui.QPainter(i)
         pa.fillRect(i.rect(),gradient)
         pa.end()
-        createimg = tempfile.mkstemp(dir=tempfolder,suffix='.png')[1]
+        createimg = getUniquePNG("createimg")
         i.save(createimg)
         iconbank["createimg"] = createimg
 
@@ -492,7 +560,7 @@ def handle():
                         r = [s[:-1].strip('"') for s in re.findall("(?s){(.*?)};",xpm)[0].split("\n")[1:]]
                         p = QtGui.QPixmap(r)
                         p = p.scaled(24,24)
-                        img = tempfile.mkstemp(dir=tempfolder,suffix='.png')[1]
+                        img = getUniquePNG(wb)
                         p.save(img)
                     else:
                         img = xpm
@@ -501,7 +569,7 @@ def handle():
             iconbank[wb] = img
         UL_WORKBENCHES += '<li>'
         UL_WORKBENCHES += '<img src="file:///'+img.replace('\\','/')+'" alt="'+wn+'">&nbsp;'
-        UL_WORKBENCHES += '<a href="https://www.freecadweb.org/wiki/'+wn+'_Workbench">'+wn.replace("Reverse_Engineering","ReverseEng")+'</a>'
+        UL_WORKBENCHES += '<a href="https://www.freecad.org/wiki/'+wn+'_Workbench">'+wn.replace("Reverse_Engineering","ReverseEng")+'</a>'
         UL_WORKBENCHES += '</li>'
     UL_WORKBENCHES += '</ul>'
     HTML = HTML.replace("UL_WORKBENCHES", UL_WORKBENCHES)
@@ -541,6 +609,7 @@ def handle():
     BOXCOLOR  = gethexcolor(p.GetUnsigned("BoxColor",3722305023))
     TEXTCOLOR = gethexcolor(p.GetUnsigned("PageTextColor",255))
     BGTCOLOR = gethexcolor(p.GetUnsigned("BackgroundTextColor",4294703103))
+    OVERFLOW = "" if p.GetBool("ShowScrollBars",True) else "body::-webkit-scrollbar {display: none;}"
     SHADOW = "#888888"
     if QtGui.QColor(BASECOLOR).valueF() < 0.5: # dark page - we need to make darker shadows
         SHADOW = "#000000"
@@ -557,6 +626,7 @@ def handle():
     HTML = HTML.replace("SHADOW",SHADOW)
     HTML = HTML.replace("FONTFAMILY",FONTFAMILY)
     HTML = HTML.replace("FONTSIZE",str(FONTSIZE)+"px")
+    HTML = HTML.replace("OVERFLOW",OVERFLOW)
 
     # enable web access if permitted
 
@@ -580,15 +650,6 @@ def handle():
     Start.iconbank = iconbank
     Start.tempfolder = tempfolder
 
-    # make sure we are always returning unicode
-    # HTML should be a str-object and therefore:
-    # - for py2 HTML is a bytes object and has to be decoded to unicode
-    # - for py3 HTML is already a unicode object and the next 2 lines can be removed
-    #    once py2-support is removed.
-
-    if isinstance(HTML, bytes):
-        HTML = HTML.decode("utf8")
-
     return HTML
 
 
@@ -597,9 +658,13 @@ def exportTestFile():
 
     "Allow to check if everything is Ok"
 
-    f = open(os.path.expanduser("~")+os.sep+"freecad-startpage.html","w")
-    f.write(handle())
-    f.close()
+    with codecs.open(
+        os.path.expanduser("~") + os.sep + "freecad-startpage.html",
+        encoding="utf-8",
+        mode="w",
+    ) as f:
+        f.write(handle())
+        f.close()
 
 
 
