@@ -22,20 +22,11 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-#include <BRepBuilderAPI_MakeFace.hxx>
-#include <TopoDS.hxx>
-#include <TopoDS_Edge.hxx>
-#include <Precision.hxx>
+# include <TopoDS.hxx>
 #endif
 
 #include "FeatureCut.h"
-#include <BRepAlgoAPI_Cut.hxx>
-#include <TopExp_Explorer.hxx>
-#include <TopoDS_Builder.hxx>
-#include <BRep_Tool.hxx>
-#include <gp_Pnt.hxx>
-#include <Base/Tools.h>
-#include <Base/Exception.h>
+
 
 using namespace Surface;
 
@@ -56,7 +47,7 @@ short Cut::mustExecute() const
     return 0;
 }
 
-App::DocumentObjectExecReturn *Cut::execute(void)
+App::DocumentObjectExecReturn *Cut::execute()
 {
     //Perform error checking
 
