@@ -23,16 +23,22 @@
 #ifndef SURFACEGUI_TASKFILLING_H
 #define SURFACEGUI_TASKFILLING_H
 
+#include <App/DocumentObserver.h>
+#include <Gui/DocumentObserver.h>
 #include <Gui/TaskView/TaskDialog.h>
 #include <Gui/TaskView/TaskView.h>
-#include <Gui/SelectionFilter.h>
-#include <Gui/DocumentObserver.h>
-#include <Base/BoundBox.h>
 #include <Mod/Part/Gui/ViewProviderSpline.h>
 #include <Mod/Surface/App/FeatureFilling.h>
+#include <Mod/Surface/Gui/SelectionMode.h>
+
 
 class QListWidgetItem;
 
+namespace Gui
+{
+class ButtonGroup;
+}
+
 namespace SurfaceGui
 {
 
@@ -42,15 +48,15 @@ class Ui_TaskFilling;
 
 class ViewProviderFilling : public PartGui::ViewProviderSpline
 {
-    PROPERTY_HEADER(SurfaceGui::ViewProviderFilling);
-    typedef std::vector<App::PropertyLinkSubList::SubSet> References;
+    PROPERTY_HEADER_WITH_OVERRIDE(SurfaceGui::ViewProviderFilling);
+    using References = std::vector<App::PropertyLinkSubList::SubSet>;
 
 public:
     enum ShapeType {Vertex, Edge, Face};
-    virtual void setupContextMenu(QMenu*, QObject*, const char*);
-    virtual bool setEdit(int ModNum);
-    virtual void unsetEdit(int ModNum);
-    QIcon getIcon(void) const;
+    void setupContextMenu(QMenu*, QObject*, const char*) override;
+    bool setEdit(int ModNum) override;
+    void unsetEdit(int ModNum) override;
+    QIcon getIcon() const override;
     void highlightReferences(ShapeType type, const References& refs, bool on);
 };
 
@@ -62,9 +68,14 @@ class FillingPanel : public QWidget,
 
 protected:
     class ShapeSelection;
-    enum SelectionMode { None, InitFace, AppendEdge, RemoveEdge };
+    enum SelectionMode {
+        None = SurfaceGui::SelectionMode::None,
+        InitFace = SurfaceGui::SelectionMode::InitFace,
+        AppendEdge = SurfaceGui::SelectionMode::AppendEdge,
+        RemoveEdge = SurfaceGui::SelectionMode::RemoveEdge
+    };
     SelectionMode selectionMode;
-    Surface::Filling* editedObject;
+    App::WeakPtrT<Surface::Filling> editedObject;
     bool checkCommand;
 
 private:
@@ -73,36 +84,41 @@ private:
 
 public:
     FillingPanel(ViewProviderFilling* vp, Surface::Filling* obj);
-    ~FillingPanel();
+    ~FillingPanel() override;
 
     void open();
     void checkOpenCommand();
     bool accept();
     bool reject();
     void setEditedObject(Surface::Filling* obj);
+    void appendButtons(Gui::ButtonGroup *);
 
 protected:
-    void changeEvent(QEvent *e);
-    virtual void onSelectionChanged(const Gui::SelectionChanges& msg);
+    void changeEvent(QEvent *e) override;
+    void onSelectionChanged(const Gui::SelectionChanges& msg) override;
     /** Notifies on undo */
-    virtual void slotUndoDocument(const Gui::Document& Doc);
+    void slotUndoDocument(const Gui::Document& Doc) override;
     /** Notifies on redo */
-    virtual void slotRedoDocument(const Gui::Document& Doc);
+    void slotRedoDocument(const Gui::Document& Doc) override;
     /** Notifies when the object is about to be removed. */
-    virtual void slotDeletedObject(const Gui::ViewProviderDocumentObject& Obj);
+    void slotDeletedObject(const Gui::ViewProviderDocumentObject& Obj) override;
     void modifyBoundary(bool);
 
-private Q_SLOTS:
-    void on_buttonInitFace_clicked();
-    void on_buttonEdgeAdd_clicked();
-    void on_buttonEdgeRemove_clicked();
-    void on_lineInitFaceName_textChanged(const QString&);
-    void on_listBoundary_itemDoubleClicked(QListWidgetItem*);
-    void on_buttonAccept_clicked();
-    void on_buttonIgnore_clicked();
-    void onDeleteEdge(void);
+private:
+    void setupConnections();
+    void onButtonInitFaceClicked();
+    void onButtonEdgeAddToggled(bool checked);
+    void onButtonEdgeRemoveToggled(bool checked);
+    void onLineInitFaceNameTextChanged(const QString&);
+    void onListBoundaryItemDoubleClicked(QListWidgetItem*);
+    void onButtonAcceptClicked();
+    void onButtonIgnoreClicked();
+    void onDeleteEdge();
     void onIndexesMoved();
     void clearSelection();
+
+private:
+    void exitSelectionMode();
 };
 
 class TaskFilling : public Gui::TaskView::TaskDialog
@@ -111,19 +127,20 @@ class TaskFilling : public Gui::TaskView::TaskDialog
 
 public:
     TaskFilling(ViewProviderFilling* vp, Surface::Filling* obj);
-    ~TaskFilling();
+    ~TaskFilling() override;
     void setEditedObject(Surface::Filling* obj);
 
 public:
-    void open();
-    void closed();
-    bool accept();
-    bool reject();
+    void open() override;
+    void closed() override;
+    bool accept() override;
+    bool reject() override;
 
-    virtual QDialogButtonBox::StandardButtons getStandardButtons() const
+    QDialogButtonBox::StandardButtons getStandardButtons() const override
     { return QDialogButtonBox::Ok | QDialogButtonBox::Cancel; }
 
 private:
+    Gui::ButtonGroup* buttonGroup;
     FillingPanel* widget1;
     FillingEdgePanel* widget2;
     FillingVertexPanel* widget3;
