@@ -21,54 +21,48 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif  // #ifndef _PreComp_
-
-#include "CosmeticExtension.h"
 
 #include <Base/Console.h>
 
-#include <App/Application.h>
-#include <App/FeaturePythonPyImp.h>
-
+#include "CenterLine.h"
+#include "CosmeticExtension.h"
 #include "CosmeticExtensionPy.h"
-
 #include "Cosmetic.h"
 #include "DrawUtil.h"
 #include "DrawViewPart.h"
 
+
 using namespace TechDraw;
 using namespace std;
 
-
 EXTENSION_PROPERTY_SOURCE(TechDraw::CosmeticExtension, App::DocumentObjectExtension)
 
-CosmeticExtension::CosmeticExtension() 
+CosmeticExtension::CosmeticExtension()
 {
     static const char *cgroup = "Cosmetics";
 
     EXTENSION_ADD_PROPERTY_TYPE(CosmeticVertexes, (nullptr), cgroup, App::Prop_Output, "CosmeticVertex Save/Restore");
     EXTENSION_ADD_PROPERTY_TYPE(CosmeticEdges, (nullptr), cgroup, App::Prop_Output, "CosmeticEdge Save/Restore");
-    EXTENSION_ADD_PROPERTY_TYPE(CenterLines ,(nullptr),cgroup,App::Prop_Output,"Geometry format Save/Restore");
-    EXTENSION_ADD_PROPERTY_TYPE(GeomFormats ,(nullptr),cgroup,App::Prop_Output,"Geometry format Save/Restore");
+    EXTENSION_ADD_PROPERTY_TYPE(CenterLines ,(nullptr), cgroup, App::Prop_Output, "Geometry format Save/Restore");
+    EXTENSION_ADD_PROPERTY_TYPE(GeomFormats ,(nullptr), cgroup, App::Prop_Output, "Geometry format Save/Restore");
 
     initExtensionType(CosmeticExtension::getExtensionClassTypeId());
 }
 
-CosmeticExtension::~CosmeticExtension() 
+CosmeticExtension::~CosmeticExtension()
 {
 }
 
-//void CosmeticExtension::extHandleChangedPropertyName(Base::XMLReader &reader, 
-//                                                     const char* TypeName, 
+//void CosmeticExtension::extHandleChangedPropertyName(Base::XMLReader &reader,
+//                                                     const char* TypeName,
 //                                                     const char* PropName)
 //{
 //}
 
 //==============================================================================
-//CosmeticVertex x,y are stored as unscaled, but mirrored (inverted Y) values.
-//if you are creating a CV based on calculations of scaled geometry, you need to 
-//unscale x,y before creation.
+//CosmeticVertex x, y are stored as unscaled, but mirrored (inverted Y) values.
+//if you are creating a CV based on calculations of scaled geometry, you need to
+//unscale x, y before creation.
 //if you are creating a CV based on calculations of mirrored geometry, you need to
 //mirror again before creation.
 
@@ -91,41 +85,35 @@ std::string CosmeticExtension::addCosmeticVertex(Base::Vector3d pos)
 TechDraw::CosmeticVertex* CosmeticExtension::getCosmeticVertex(std::string tagString) const
 {
 //    Base::Console().Message("CEx::getCosmeticVertex(%s)\n", tagString.c_str());
-    CosmeticVertex* result = nullptr;
     const std::vector<TechDraw::CosmeticVertex*> verts = CosmeticVertexes.getValues();
     for (auto& cv: verts) {
         std::string cvTag = cv->getTagAsString();
         if (cvTag == tagString) {
-            result = cv;
-            break;
+            return cv;
         }
     }
-    return result;
+    return nullptr;
 }
 
 // find the cosmetic vertex corresponding to selection name (Vertex5)
 // used when selecting
 TechDraw::CosmeticVertex* CosmeticExtension::getCosmeticVertexBySelection(std::string name) const
 {
-//    Base::Console().Message("CEx::getCVBySelection(%s)\n",name.c_str());
-    CosmeticVertex* result = nullptr;
+//    Base::Console().Message("CEx::getCVBySelection(%s)\n", name.c_str());
     App::DocumentObject* extObj = const_cast<App::DocumentObject*> (getExtendedObject());
     TechDraw::DrawViewPart* dvp = dynamic_cast<TechDraw::DrawViewPart*>(extObj);
-    if (dvp == nullptr) {
-        return result;
+    if (!dvp) {
+        return nullptr;
     }
     int idx = DrawUtil::getIndexFromName(name);
     TechDraw::VertexPtr v = dvp->getProjVertexByIndex(idx);
-    if (v == nullptr) {
-        return result;
+    if (!v || v->getCosmeticTag().empty()) {
+        return nullptr;
     }
-    if (!v->cosmeticTag.empty()) {
-        result = getCosmeticVertex(v->cosmeticTag);
-    }
-    return result;
+    return getCosmeticVertex(v->getCosmeticTag());
 }
 
-//overload for index only 
+//overload for index only
 TechDraw::CosmeticVertex* CosmeticExtension::getCosmeticVertexBySelection(int i) const
 {
 //    Base::Console().Message("CEx::getCVBySelection(%d)\n", i);
@@ -155,14 +143,6 @@ void CosmeticExtension::removeCosmeticVertex(std::vector<std::string> delTags)
     }
 }
 
-bool CosmeticExtension::replaceCosmeticVertex(CosmeticVertex* newCV)
-{
-    (void) newCV;
-    Base::Console().Message("CX::replaceCosmeticVertex() - deprecated. do not use.\n");
-    bool result = false;
-    return result;
-}
-
 //********** Cosmetic Edge *****************************************************
 
 //returns unique CE id
@@ -170,13 +150,12 @@ bool CosmeticExtension::replaceCosmeticVertex(CosmeticVertex* newCV)
 std::string CosmeticExtension::addCosmeticEdge(Base::Vector3d start,
                                                Base::Vector3d end)
 {
-//    Base::Console().Message("CEx::addCosmeticEdge(s,e)\n");
+//    Base::Console().Message("CEx::addCosmeticEdge(s, e)\n");
     std::vector<CosmeticEdge*> edges = CosmeticEdges.getValues();
     TechDraw::CosmeticEdge* ce = new TechDraw::CosmeticEdge(start, end);
     edges.push_back(ce);
     CosmeticEdges.setValues(edges);
-    std::string result = ce->getTagAsString();
-    return result;
+    return ce->getTagAsString();
 }
 
 std::string CosmeticExtension::addCosmeticEdge(TechDraw::BaseGeomPtr bg)
@@ -186,62 +165,52 @@ std::string CosmeticExtension::addCosmeticEdge(TechDraw::BaseGeomPtr bg)
     TechDraw::CosmeticEdge* ce = new TechDraw::CosmeticEdge(bg);
     edges.push_back(ce);
     CosmeticEdges.setValues(edges);
-    std::string result = ce->getTagAsString();
-    return result;
+    return ce->getTagAsString();
 }
 
 //get CE by unique id
 TechDraw::CosmeticEdge* CosmeticExtension::getCosmeticEdge(std::string tagString) const
 {
 //    Base::Console().Message("CEx::getCosmeticEdge(%s)\n", tagString.c_str());
-    CosmeticEdge* result = nullptr;
-    bool found = false;
     const std::vector<TechDraw::CosmeticEdge*> edges = CosmeticEdges.getValues();
     for (auto& ce: edges) {
         std::string ceTag = ce->getTagAsString();
         if (ceTag == tagString) {
-            result = ce;
-            found = true;
-            break;
+            return ce;
         }
     }
-    if (!found) {
-        Base::Console().Message("CEx::getCosmeticEdge - CE for tag: %s not found.\n", tagString.c_str());
-    }
-    return result;
+
+    // None found
+    Base::Console().Message("CEx::getCosmeticEdge - CE for tag: %s not found.\n", tagString.c_str());
+    return nullptr;
 }
 
 // find the cosmetic edge corresponding to selection name (Edge5)
 // used when selecting
 TechDraw::CosmeticEdge* CosmeticExtension::getCosmeticEdgeBySelection(std::string name) const
 {
-//    Base::Console().Message("CEx::getCEBySelection(%s)\n",name.c_str());
-    CosmeticEdge* result = nullptr;
+//    Base::Console().Message("CEx::getCEBySelection(%s)\n", name.c_str());
     App::DocumentObject* extObj = const_cast<App::DocumentObject*> (getExtendedObject());
     TechDraw::DrawViewPart* dvp = dynamic_cast<TechDraw::DrawViewPart*>(extObj);
-    if (dvp == nullptr) {
-        return result;
+    if (!dvp) {
+        return nullptr;
     }
     int idx = DrawUtil::getIndexFromName(name);
     TechDraw::BaseGeomPtr base = dvp->getGeomByIndex(idx);
-    if (base == nullptr) {
-        return result;
+    if (!base || base->getCosmeticTag().empty()) {
+        return nullptr;
     }
-    
-    if (!base->getCosmeticTag().empty()) {
-        result = getCosmeticEdge(base->getCosmeticTag());
-    }
-    return result;
+
+    return getCosmeticEdge(base->getCosmeticTag());
 }
 
-//overload for index only 
+//overload for index only
 TechDraw::CosmeticEdge* CosmeticExtension::getCosmeticEdgeBySelection(int i) const
 {
 //    Base::Console().Message("CEx::getCEBySelection(%d)\n", i);
-    std::stringstream ss;
-    ss << "Edge" << i;
-    std::string eName = ss.str();
-    return getCosmeticEdgeBySelection(eName);
+    std::stringstream edgeName;
+    edgeName << "Edge" << i;
+    return getCosmeticEdgeBySelection(edgeName.str());
 }
 
 void CosmeticExtension::removeCosmeticEdge(std::string delTag)
@@ -264,15 +233,6 @@ void CosmeticExtension::removeCosmeticEdge(std::vector<std::string> delTags)
     }
 }
 
-
-bool CosmeticExtension::replaceCosmeticEdge(CosmeticEdge* newCE)
-{
-    (void) newCE;
-    Base::Console().Message("CX::replaceCosmeticEdge() - deprecated. do not use.\n");
-    bool result = false;
-    return result;
-}
-
 //********** Center Line *******************************************************
 
 //returns unique CL id
@@ -287,8 +247,7 @@ std::string CosmeticExtension::addCenterLine(Base::Vector3d start,
     TechDraw::CenterLine* cl = new TechDraw::CenterLine(start, end);
     cLines.push_back(cl);
     CenterLines.setValues(cLines);
-    std::string result = cl->getTagAsString();
-    return result;
+    return cl->getTagAsString();
 }
 
 std::string CosmeticExtension::addCenterLine(TechDraw::CenterLine* cl)
@@ -297,8 +256,7 @@ std::string CosmeticExtension::addCenterLine(TechDraw::CenterLine* cl)
     std::vector<CenterLine*> cLines = CenterLines.getValues();
     cLines.push_back(cl);
     CenterLines.setValues(cLines);
-    std::string result = cl->getTagAsString();
-    return result;
+    return cl->getTagAsString();
 }
 
 
@@ -309,8 +267,7 @@ std::string CosmeticExtension::addCenterLine(TechDraw::BaseGeomPtr bg)
     TechDraw::CenterLine* cl = new TechDraw::CenterLine(bg);
     cLines.push_back(cl);
     CenterLines.setValues(cLines);
-    std::string result = cl->getTagAsString();
-    return result;
+    return cl->getTagAsString();
 }
 
 
@@ -318,48 +275,41 @@ std::string CosmeticExtension::addCenterLine(TechDraw::BaseGeomPtr bg)
 TechDraw::CenterLine* CosmeticExtension::getCenterLine(std::string tagString) const
 {
 //    Base::Console().Message("CEx::getCenterLine(%s)\n", tagString.c_str());
-    CenterLine* result = nullptr;
     const std::vector<TechDraw::CenterLine*> cLines = CenterLines.getValues();
     for (auto& cl: cLines) {
         std::string clTag = cl->getTagAsString();
         if (clTag == tagString) {
-            result = cl;
-            break;
+            return cl;
         }
     }
-    return result;
+    return nullptr;
 }
 
 // find the center line corresponding to selection name (Edge5)
 // used when selecting
 TechDraw::CenterLine* CosmeticExtension::getCenterLineBySelection(std::string name) const
 {
-//    Base::Console().Message("CEx::getCLBySelection(%s)\n",name.c_str());
-    CenterLine* result = nullptr;
+//    Base::Console().Message("CEx::getCLBySelection(%s)\n", name.c_str());
     App::DocumentObject* extObj = const_cast<App::DocumentObject*> (getExtendedObject());
     TechDraw::DrawViewPart* dvp = dynamic_cast<TechDraw::DrawViewPart*>(extObj);
-    if (dvp == nullptr) {
-        return result;
+    if (!dvp) {
+        return nullptr;
     }
     int idx = DrawUtil::getIndexFromName(name);
     TechDraw::BaseGeomPtr base = dvp->getGeomByIndex(idx);
-    if (base == nullptr) {
-        return result;
+    if (!base || base->getCosmeticTag().empty()) {
+        return nullptr;
     }
-    if (!base->getCosmeticTag().empty()) {
-        result = getCenterLine(base->getCosmeticTag());
-    }
-    return result;
+    return getCenterLine(base->getCosmeticTag());
 }
 
-//overload for index only 
+//overload for index only
 TechDraw::CenterLine* CosmeticExtension::getCenterLineBySelection(int i) const
 {
 //    Base::Console().Message("CEx::getCLBySelection(%d)\n", i);
-    std::stringstream ss;
-    ss << "Edge" << i;
-    std::string eName = ss.str();
-    return getCenterLineBySelection(eName);
+    std::stringstream edgeName;
+    edgeName << "Edge" << i;
+    return getCenterLineBySelection(edgeName.str());
 }
 
 void CosmeticExtension::removeCenterLine(std::string delTag)
@@ -382,14 +332,6 @@ void CosmeticExtension::removeCenterLine(std::vector<std::string> delTags)
     }
 }
 
-bool CosmeticExtension::replaceCenterLine(CenterLine* newCL)
-{
-    (void) newCL;
-    Base::Console().Message("CX::replaceCenterLine() - deprecated. do not use.\n");
-    bool result = false;
-    return result;
-}
-
 
 //********** Geometry Formats **************************************************
 //returns unique GF id
@@ -401,8 +343,7 @@ std::string CosmeticExtension::addGeomFormat(TechDraw::GeomFormat* gf)
     TechDraw::GeomFormat* newGF = new TechDraw::GeomFormat(gf);
     formats.push_back(newGF);
     GeomFormats.setValues(formats);
-    std::string result = newGF->getTagAsString();
-    return result;
+    return newGF->getTagAsString();
 }
 
 
@@ -410,56 +351,47 @@ std::string CosmeticExtension::addGeomFormat(TechDraw::GeomFormat* gf)
 TechDraw::GeomFormat* CosmeticExtension::getGeomFormat(std::string tagString) const
 {
 //    Base::Console().Message("CEx::getGeomFormat(%s)\n", tagString.c_str());
-    GeomFormat* result = nullptr;
     const std::vector<TechDraw::GeomFormat*> formats = GeomFormats.getValues();
     for (auto& gf: formats) {
         std::string gfTag = gf->getTagAsString();
         if (gfTag == tagString) {
-            result = gf;
-            break;
+            return gf;
         }
     }
-    return result;
+
+    // Nothing found
+    return nullptr;
 }
 
 // find the cosmetic edge corresponding to selection name (Edge5)
 // used when selecting
 TechDraw::GeomFormat* CosmeticExtension::getGeomFormatBySelection(std::string name) const
 {
-//    Base::Console().Message("CEx::getCEBySelection(%s)\n",name.c_str());
-    GeomFormat* result = nullptr;
+//    Base::Console().Message("CEx::getCEBySelection(%s)\n", name.c_str());
     App::DocumentObject* extObj = const_cast<App::DocumentObject*> (getExtendedObject());
     TechDraw::DrawViewPart* dvp = dynamic_cast<TechDraw::DrawViewPart*>(extObj);
-    if (dvp == nullptr) {
-        return result;
+    if (!dvp) {
+        return nullptr;
     }
     int idx = DrawUtil::getIndexFromName(name);
     const std::vector<TechDraw::GeomFormat*> formats = GeomFormats.getValues();
     for (auto& gf: formats) {
         if (gf->m_geomIndex == idx) {
-            result = gf;
-            break;
+            return gf;
         }
     }
-    return result;
+
+    // Nothing found
+    return nullptr;
 }
 
-//overload for index only 
+//overload for index only
 TechDraw::GeomFormat* CosmeticExtension::getGeomFormatBySelection(int i) const
 {
 //    Base::Console().Message("CEx::getCEBySelection(%d)\n", i);
-    std::stringstream ss;
-    ss << "Edge" << i;
-    std::string eName = ss.str();
-    return getGeomFormatBySelection(eName);
-}
-
-bool CosmeticExtension::replaceGeomFormat(GeomFormat* newGF)
-{
-    (void) newGF;
-    Base::Console().Message("CX::replaceGeomFormat() - deprecated. do not use.\n");
-    bool result = false;
-    return result;
+    std::stringstream edgeName;
+    edgeName << "Edge" << i;
+    return getGeomFormatBySelection(edgeName.str());
 }
 
 void CosmeticExtension::removeGeomFormat(std::string delTag)
@@ -479,7 +411,7 @@ void CosmeticExtension::removeGeomFormat(std::string delTag)
 PyObject* CosmeticExtension::getExtensionPyObject(void) {
     if (ExtensionPythonObject.is(Py::_None())){
         // ref counter is set to 1
-        ExtensionPythonObject = Py::Object(new CosmeticExtensionPy(this),true);
+        ExtensionPythonObject = Py::Object(new CosmeticExtensionPy(this), true);
     }
     return Py::new_reference_to(ExtensionPythonObject);
 }
