@@ -26,25 +26,25 @@
 #include <App/DocumentObjectExtension.h>
 #include <App/ExtensionPython.h>
 #include <Base/Vector3D.h>
+#include <Mod/TechDraw/TechDrawGlobal.h>
 
+#include "Geometry.h"
 #include "PropertyCenterLineList.h"
 #include "PropertyCosmeticEdgeList.h"
 #include "PropertyCosmeticVertexList.h"
 #include "PropertyGeomFormatList.h"
 
-#include "Geometry.h"
-
 
 namespace TechDraw {
 class DrawViewPart;
 class GeometryObject;
 
 class TechDrawExport CosmeticExtension : public App::DocumentObjectExtension {
-    EXTENSION_PROPERTY_HEADER(TechDraw::CosmeticObject);
+    EXTENSION_PROPERTY_HEADER_WITH_OVERRIDE(TechDraw::CosmeticObject);
 
 public:
     CosmeticExtension();
-    virtual ~CosmeticExtension();
+    ~CosmeticExtension() override;
 
     TechDraw::PropertyCosmeticVertexList CosmeticVertexes;
     TechDraw::PropertyCosmeticEdgeList   CosmeticEdges;
@@ -55,7 +55,6 @@ public:
     virtual CosmeticVertex* getCosmeticVertexBySelection(std::string name) const;
     virtual CosmeticVertex* getCosmeticVertexBySelection(int i) const;
     virtual CosmeticVertex* getCosmeticVertex(std::string id) const;
-    virtual bool            replaceCosmeticVertex(CosmeticVertex* newVertex);
     virtual void            removeCosmeticVertex(std::string tag);
     virtual void            removeCosmeticVertex(std::vector<std::string> delTags);
 
@@ -64,7 +63,6 @@ public:
     virtual CosmeticEdge*   getCosmeticEdgeBySelection(std::string name) const;
     virtual CosmeticEdge*   getCosmeticEdgeBySelection(int i) const;
     virtual CosmeticEdge*   getCosmeticEdge(std::string id) const;
-    virtual bool            replaceCosmeticEdge(CosmeticEdge* newEdge);
     virtual void            removeCosmeticEdge(std::string tag);
     virtual void            removeCosmeticEdge(std::vector<std::string> delTags);
 
@@ -74,7 +72,6 @@ public:
     virtual CenterLine*     getCenterLineBySelection(std::string name) const;
     virtual CenterLine*     getCenterLineBySelection(int i) const;
     virtual CenterLine*     getCenterLine(std::string tag) const;
-    virtual bool            replaceCenterLine(CenterLine* newLine);
     virtual void            removeCenterLine(std::string tag);
     virtual void            removeCenterLine(std::vector<std::string> delTags);
 
@@ -82,11 +79,10 @@ public:
     virtual GeomFormat*     getGeomFormatBySelection(std::string name) const;
     virtual GeomFormat*     getGeomFormatBySelection(int i) const;
     virtual GeomFormat*     getGeomFormat(std::string id) const;
-    virtual bool            replaceGeomFormat(TechDraw::GeomFormat* gf);
     virtual void            removeGeomFormat(std::string tag);
 
 
-    PyObject* getExtensionPyObject(void);
+    PyObject* getExtensionPyObject() override;
 
 protected:
 /*    virtual void extHandleChangedPropertyName(Base::XMLReader &reader, */
@@ -97,7 +93,7 @@ private:
 
 };
 
-typedef App::ExtensionPythonT<CosmeticExtension> CosmeticExtensionPython;
+using CosmeticExtensionPython = App::ExtensionPythonT<CosmeticExtension>;
 
 } //end namespace TechDraw
 
