@@ -23,22 +23,22 @@
 #include "PreCompiled.h"
 
 #include "DrawSVGTemplate.h"
-
 // inclusion of the generated files (generated out of DrawSVGTemplatePy.xml)
 #include <Mod/TechDraw/App/DrawSVGTemplatePy.h>
 #include <Mod/TechDraw/App/DrawSVGTemplatePy.cpp>
 
+
 using namespace TechDraw;
 
 // returns a string which represents the object e.g. when printed in python
-std::string DrawSVGTemplatePy::representation(void) const
+std::string DrawSVGTemplatePy::representation() const
 {
     return std::string("<DrawSVGTemplate object>");
 }
 
 PyObject *DrawSVGTemplatePy::getCustomAttributes(const char* ) const
 {
-    return 0;
+    return nullptr;
 }
 
 int DrawSVGTemplatePy::setCustomAttributes(const char* attr, PyObject* obj)
@@ -63,39 +63,26 @@ int DrawSVGTemplatePy::setCustomAttributes(const char* attr, PyObject* obj)
 
 PyObject* DrawSVGTemplatePy::getEditFieldContent(PyObject* args)
 {
-    PyObject* result = nullptr;
     char* fieldName;
-    if (!PyArg_ParseTuple(args, "s",&fieldName)) {
-        Base::Console().Error("Error: DrawSVGTemplatePy::getEditFieldNames - Bad Arg\n");
+    if (!PyArg_ParseTuple(args, "s", &fieldName)) {
         return nullptr;
     }
     std::string content = getDrawSVGTemplatePtr()->EditableTexts[fieldName];
     if (!content.empty()) {
-#if PY_MAJOR_VERSION < 3
-        result = PyString_FromString(content.c_str());
-#else
-        result = PyUnicode_FromString(content.c_str());
-#endif
+        return PyUnicode_FromString(content.c_str());
     }
-    return result;
+    Py_Return;
 }
 
 PyObject* DrawSVGTemplatePy::setEditFieldContent(PyObject* args)
 {
-    PyObject* result = Py_True;
     char* fieldName;
     char* newContent;
-    if (!PyArg_ParseTuple(args, "ss", &fieldName,&newContent)) {
-        Base::Console().Error("Error: DrawSVGTemplatePy::getEditFieldNames - Bad Args\n");
-        result = Py_False;
-    } else {
-        try {
-            getDrawSVGTemplatePtr()->EditableTexts.setValue(fieldName, newContent);
-        }
-        catch (...) {
-            result = Py_False;
-        }
+    if (!PyArg_ParseTuple(args, "ss", &fieldName, &newContent)) {
+        return nullptr;
     }
 
-    return result;
+    getDrawSVGTemplatePtr()->EditableTexts.setValue(fieldName, newContent);
+
+    Py_Return;
 }
