@@ -20,25 +20,20 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <iomanip>
 # include <sstream>
 #endif
 
-#include <iomanip>
-
 #include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/FileInfo.h>
 #include <Base/Interpreter.h>
 
 #include "DrawViewArch.h"
 
-using namespace TechDraw;
-using namespace std;
 
+using namespace TechDraw;
 
 //===========================================================================
 // DrawViewArch
@@ -50,53 +45,50 @@ const char* DrawViewArch::RenderModeEnums[]= {"Wireframe",
                                               "Solid",
                                               "Coin",
                                               "Coin mono",
-                                              NULL};
+                                              nullptr};
 
-DrawViewArch::DrawViewArch(void)
+DrawViewArch::DrawViewArch()
 {
     static const char *group = "Arch view";
 
-    ADD_PROPERTY_TYPE(Source ,(0),group,App::Prop_None,"SectionPlane or BuildingPart object for this view");
+    ADD_PROPERTY_TYPE(Source ,(nullptr), group, App::Prop_None, "SectionPlane or BuildingPart object for this view");
     Source.setScope(App::LinkScope::Global);
-    ADD_PROPERTY_TYPE(AllOn ,(false),group,App::Prop_None,"If hidden objects must be shown or not");
+    ADD_PROPERTY_TYPE(AllOn ,(false), group, App::Prop_None, "If hidden objects must be shown or not");
     RenderMode.setEnums(RenderModeEnums);
-    ADD_PROPERTY_TYPE(RenderMode, ((long)0),group,App::Prop_None,"The render mode to use");
-    ADD_PROPERTY_TYPE(FillSpaces ,(false),group,App::Prop_None,"If True, Arch Spaces are shown as a colored area");
-    ADD_PROPERTY_TYPE(ShowHidden ,(false),group,App::Prop_None,"If the hidden geometry behind the section plane is shown or not");
-    ADD_PROPERTY_TYPE(ShowFill ,(false),group,App::Prop_None,"If cut areas must be filled with a hatch pattern or not");
-    ADD_PROPERTY_TYPE(LineWidth,(0.25),group,App::Prop_None,"Line width of this view");
-    ADD_PROPERTY_TYPE(FontSize,(12.0),group,App::Prop_None,"Text size for this view");
-    ADD_PROPERTY_TYPE(CutLineWidth,(0.50),group,App::Prop_None,"Width of cut lines of this view");
-    ADD_PROPERTY_TYPE(JoinArch ,(false),group,App::Prop_None,"If True, walls and structure will be fused by material");
+    ADD_PROPERTY_TYPE(RenderMode, ((long)0), group, App::Prop_None, "The render mode to use");
+    ADD_PROPERTY_TYPE(FillSpaces ,(false), group, App::Prop_None, "If True, Arch Spaces are shown as a colored area");
+    ADD_PROPERTY_TYPE(ShowHidden ,(false), group, App::Prop_None, "If the hidden geometry behind the section plane is shown or not");
+    ADD_PROPERTY_TYPE(ShowFill ,(false), group, App::Prop_None, "If cut areas must be filled with a hatch pattern or not");
+    ADD_PROPERTY_TYPE(LineWidth, (0.25), group, App::Prop_None, "Line width of this view");
+    ADD_PROPERTY_TYPE(FontSize, (12.0), group, App::Prop_None, "Text size for this view");
+    ADD_PROPERTY_TYPE(CutLineWidth, (0.50), group, App::Prop_None, "Width of cut lines of this view");
+    ADD_PROPERTY_TYPE(JoinArch ,(false), group, App::Prop_None, "If True, walls and structure will be fused by material");
     ScaleType.setValue("Custom");
 }
 
-DrawViewArch::~DrawViewArch()
-{
-}
-
+//NOTE: DocumentObject::mustExecute returns 1/0 and not true/false
 short DrawViewArch::mustExecute() const
 {
-    short result = 0;
     if (!isRestoring()) {
-        result = (Source.isTouched() ||
-                AllOn.isTouched() ||
-                RenderMode.isTouched() ||
-                ShowHidden.isTouched() ||
-                ShowFill.isTouched() ||
-                LineWidth.isTouched() ||
-                FontSize.isTouched() ||
-                CutLineWidth.isTouched() ||
-                JoinArch.isTouched());
-    }
-    if ((bool) result) {
-        return result;
+        if (
+            Source.isTouched() ||
+            AllOn.isTouched() ||
+            RenderMode.isTouched() ||
+            ShowHidden.isTouched() ||
+            ShowFill.isTouched() ||
+            LineWidth.isTouched() ||
+            FontSize.isTouched() ||
+            CutLineWidth.isTouched() ||
+            JoinArch.isTouched()
+        ) {
+            return 1;
+        }
     }
     return DrawViewSymbol::mustExecute();
 }
 
 
-App::DocumentObjectExecReturn *DrawViewArch::execute(void)
+App::DocumentObjectExecReturn *DrawViewArch::execute()
 {
     if (!keepUpdated()) {
         return App::DocumentObject::StdReturn;
@@ -106,7 +98,7 @@ App::DocumentObjectExecReturn *DrawViewArch::execute(void)
     if (sourceObj) {
         //if (sourceObj is not ArchSection) return
         App::Property* proxy = sourceObj->getPropertyByName("Proxy");
-        if (proxy == nullptr) {
+        if (!proxy) {
             Base::Console().Error("DVA::execute - %s is not an ArchSection\n", sourceObj->Label.getValue());
             //this is definitely not an ArchSection
             return DrawView::execute();
@@ -117,42 +109,40 @@ App::DocumentObjectExecReturn *DrawViewArch::execute(void)
         std::string svgTail = getSVGTail();
         std::string FeatName = getNameInDocument();
         std::string SourceName = sourceObj->getNameInDocument();
-        // ArchSectionPlane.getSVG(section,allOn=False,renderMode="Wireframe",showHidden=False,showFill=False,scale=1,linewidth=1,fontsize=1):
+        // ArchSectionPlane.getSVG(section, allOn=False, renderMode="Wireframe", showHidden=False, showFill=False, scale=1, linewidth=1, fontsize=1):
 
         std::stringstream paramStr;
-        paramStr << ",allOn=" << (AllOn.getValue() ? "True" : "False")
-                 << ",renderMode=" << RenderMode.getValue()
-                 << ",showHidden=" << (ShowHidden.getValue() ? "True" : "False")
-                 << ",showFill=" << (ShowFill.getValue() ? "True" : "False")
-                 << ",scale=" << getScale()
-                 << ",linewidth=" << LineWidth.getValue()
-                 << ",fontsize=" << FontSize.getValue()
-                 << ",techdraw=True"
-                 << ",rotation=" << Rotation.getValue()
-                 << ",fillSpaces=" << (FillSpaces.getValue() ? "True" : "False")
-                 << ",cutlinewidth=" << CutLineWidth.getValue()
-                 << ",joinArch=" << (JoinArch.getValue() ? "True" : "False");
+        paramStr << ", allOn=" << (AllOn.getValue() ? "True" : "False")
+                 << ", renderMode=" << RenderMode.getValue()
+                 << ", showHidden=" << (ShowHidden.getValue() ? "True" : "False")
+                 << ", showFill=" << (ShowFill.getValue() ? "True" : "False")
+                 << ", scale=" << getScale()
+                 << ", linewidth=" << LineWidth.getValue()
+                 << ", fontsize=" << FontSize.getValue()
+                 << ", techdraw=True"
+                 << ", rotation=" << Rotation.getValue()
+                 << ", fillSpaces=" << (FillSpaces.getValue() ? "True" : "False")
+                 << ", cutlinewidth=" << CutLineWidth.getValue()
+                 << ", joinArch=" << (JoinArch.getValue() ? "True" : "False");
 
         Base::Interpreter().runString("import ArchSectionPlane");
         Base::Interpreter().runStringArg("svgBody = ArchSectionPlane.getSVG(App.activeDocument().%s %s)",
-                                         SourceName.c_str(),paramStr.str().c_str());
+                                         SourceName.c_str(), paramStr.str().c_str());
         Base::Interpreter().runStringArg("App.activeDocument().%s.Symbol = '%s' + svgBody + '%s'",
-                                          FeatName.c_str(),svgHead.c_str(),svgTail.c_str());
+                                          FeatName.c_str(), svgHead.c_str(), svgTail.c_str());
     }
-//    requestPaint();
+    overrideKeepUpdated(false);
     return DrawView::execute();
 }
 
-std::string DrawViewArch::getSVGHead(void)
+std::string DrawViewArch::getSVGHead()
 {
-    std::string head = std::string("<svg\\n") +
-                       std::string("	xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"\\n") +
-                       std::string("	xmlns:freecad=\"http://www.freecadweb.org/wiki/index.php?title=Svg_Namespace\">\\n");
-    return head;
+    return std::string("<svg\\n") +
+           std::string("	xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"\\n") +
+           std::string("	xmlns:freecad=\"http://www.freecad.org/wiki/index.php?title=Svg_Namespace\">\\n");
 }
 
-std::string DrawViewArch::getSVGTail(void)
+std::string DrawViewArch::getSVGTail()
 {
-    std::string tail = "\\n</svg>";
-    return tail;
+    return "\\n</svg>";
 }
