@@ -20,25 +20,20 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <iomanip>
 # include <sstream>
 #endif
 
-#include <iomanip>
-
 #include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/FileInfo.h>
 #include <Base/Interpreter.h>
 
 #include "DrawViewDraft.h"
 
-using namespace TechDraw;
-using namespace std;
 
+using namespace TechDraw;
 
 //===========================================================================
 // DrawViewDraft
@@ -47,48 +42,42 @@ using namespace std;
 PROPERTY_SOURCE(TechDraw::DrawViewDraft, TechDraw::DrawViewSymbol)
 
 
-DrawViewDraft::DrawViewDraft(void)
+DrawViewDraft::DrawViewDraft()
 {
     static const char *group = "Draft view";
 
-    ADD_PROPERTY_TYPE(Source ,(nullptr),group,App::Prop_None,"Draft object for this view");
+    ADD_PROPERTY_TYPE(Source ,(nullptr), group, App::Prop_None, "Draft object for this view");
     Source.setScope(App::LinkScope::Global);
-    ADD_PROPERTY_TYPE(LineWidth,(0.35),group,App::Prop_None,"Line width of this view. If Override Style is false, this value multiplies the object line width");
-    ADD_PROPERTY_TYPE(FontSize,(12.0),group,App::Prop_None,"Text size for this view");
-    ADD_PROPERTY_TYPE(Direction ,(0,0,1.0),group,App::Prop_None,"Projection direction. The direction you are looking from.");
-    ADD_PROPERTY_TYPE(Color,(0.0f,0.0f,0.0f),group,App::Prop_None,"The default color of text and lines");
-    ADD_PROPERTY_TYPE(LineStyle,("Solid") ,group,App::Prop_None,"A line style to use for this view. Can be Solid, Dashed, Dashdot, Dot or a SVG pattern like 0.20,0.20");
-    ADD_PROPERTY_TYPE(LineSpacing,(1.0f),group,App::Prop_None,"The spacing between lines to use for multiline texts");
-    ADD_PROPERTY_TYPE(OverrideStyle,(false),group,App::Prop_None,"If True, line color, width and style of this view will override those of rendered objects");
+    ADD_PROPERTY_TYPE(LineWidth, (0.35), group, App::Prop_None, "Line width of this view. If Override Style is false, this value multiplies the object line width");
+    ADD_PROPERTY_TYPE(FontSize, (12.0), group, App::Prop_None, "Text size for this view");
+    ADD_PROPERTY_TYPE(Direction ,(0, 0,1.0), group, App::Prop_None, "Projection direction. The direction you are looking from.");
+    ADD_PROPERTY_TYPE(Color, (0.0f, 0.0f, 0.0f), group, App::Prop_None, "The default color of text and lines");
+    ADD_PROPERTY_TYPE(LineStyle, ("Solid") ,group, App::Prop_None, "A line style to use for this view. Can be Solid, Dashed, Dashdot, Dot or a SVG pattern like 0.20, 0.20");
+    ADD_PROPERTY_TYPE(LineSpacing, (1.0f), group, App::Prop_None, "The spacing between lines to use for multiline texts");
+    ADD_PROPERTY_TYPE(OverrideStyle, (false), group, App::Prop_None, "If True, line color, width and style of this view will override those of rendered objects");
     ScaleType.setValue("Custom");
 }
 
-DrawViewDraft::~DrawViewDraft()
-{
-}
-
 short DrawViewDraft::mustExecute() const
 {
-    short result = 0;
     if (!isRestoring()) {
-        result = Source.isTouched() ||
-                    LineWidth.isTouched() ||
-                    FontSize.isTouched() ||
-                    Direction.isTouched() ||
-                    Color.isTouched() ||
-                    LineStyle.isTouched() ||
-                    LineSpacing.isTouched() ||
-                    OverrideStyle.isTouched();
-    }
-    if ((bool) result) {
-        return result;
+        if(Source.isTouched() ||
+            LineWidth.isTouched() ||
+            FontSize.isTouched() ||
+            Direction.isTouched() ||
+            Color.isTouched() ||
+            LineStyle.isTouched() ||
+            LineSpacing.isTouched() ||
+            OverrideStyle.isTouched()) {
+            return true;
+        }
     }
     return DrawViewSymbol::mustExecute();
 }
 
 
 
-App::DocumentObjectExecReturn *DrawViewDraft::execute(void)
+App::DocumentObjectExecReturn *DrawViewDraft::execute()
 {
 //    Base::Console().Message("DVDr::execute() \n");
     if (!keepUpdated()) {
@@ -102,48 +91,47 @@ App::DocumentObjectExecReturn *DrawViewDraft::execute(void)
         std::string svgTail = getSVGTail();
         std::string FeatName = getNameInDocument();
         std::string SourceName = sourceObj->getNameInDocument();
-        // Draft.get_svg(obj,scale=1,linewidth=0.35,fontsize=12,fillstyle="shape color",direction=None,linestyle=None,color=None,linespacing=None,techdraw=False)
+        // Draft.get_svg(obj, scale=1, linewidth=0.35, fontsize=12, fillstyle="shape color", direction=None, linestyle=None, color=None, linespacing=None, techdraw=False)
 
         std::stringstream paramStr;
         App::Color col = Color.getValue();
-        paramStr << ",scale=" << getScale() 
-                 << ",linewidth=" << LineWidth.getValue() 
-                 << ",fontsize=" << FontSize.getValue()
+        paramStr << ", scale=" << getScale()
+                 << ", linewidth=" << LineWidth.getValue()
+                 << ", fontsize=" << FontSize.getValue()
                  // TODO treat fillstyle here
-                 << ",direction=FreeCAD.Vector(" << Direction.getValue().x << "," << Direction.getValue().y << "," << Direction.getValue().z << ")"
-                 << ",linestyle=\"" << LineStyle.getValue() << "\""
-                 << ",color=\"" << col.asCSSString() << "\""
-                 << ",linespacing=" << LineSpacing.getValue()
+                 << ", direction=FreeCAD.Vector(" << Direction.getValue().x << ", " << Direction.getValue().y << ", " << Direction.getValue().z << ")"
+                 << ", linestyle=\"" << LineStyle.getValue() << "\""
+                 << ", color=\"" << col.asHexString() << "\""
+                 << ", linespacing=" << LineSpacing.getValue()
                  // We must set techdraw to "true" becausea couple of things behave differently than in Drawing
-                 << ",techdraw=True"
-                 << ",override=" << (OverrideStyle.getValue() ? "True" : "False");
+                 << ", techdraw=True"
+                 << ", override=" << (OverrideStyle.getValue() ? "True" : "False");
 
 // this is ok for a starting point, but should eventually make dedicated Draft functions that build the svg for all the special cases
 // (Arch section, etc)
 // like Draft.makeDrawingView, but we don't need to create the actual document objects in Draft, just the svg.
         Base::Interpreter().runString("import Draft");
         Base::Interpreter().runStringArg("svgBody = Draft.get_svg(App.activeDocument().%s %s)",
-                                         SourceName.c_str(),paramStr.str().c_str());
+                                         SourceName.c_str(), paramStr.str().c_str());
 //        Base::Interpreter().runString("print svgBody");
         Base::Interpreter().runStringArg("App.activeDocument().%s.Symbol = '%s' + svgBody + '%s'",
-                                          FeatName.c_str(),svgHead.c_str(),svgTail.c_str());
+                                          FeatName.c_str(), svgHead.c_str(), svgTail.c_str());
         }
-//    requestPaint();
+
+    overrideKeepUpdated(false);
     return DrawView::execute();
 }
 
-std::string DrawViewDraft::getSVGHead(void)
+std::string DrawViewDraft::getSVGHead()
 {
-    std::string head = std::string("<svg\\n") +
-                       std::string("	xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"\\n") +
-                       std::string("	xmlns:freecad=\"http://www.freecadweb.org/wiki/index.php?title=Svg_Namespace\">\\n");
-    return head;
+    return std::string("<svg\\n") +
+           std::string("	xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"\\n") +
+           std::string("	xmlns:freecad=\"http://www.freecad.org/wiki/index.php?title=Svg_Namespace\">\\n");
 }
 
-std::string DrawViewDraft::getSVGTail(void)
+std::string DrawViewDraft::getSVGTail()
 {
-    std::string tail = "\\n</svg>";
-    return tail;
+    return "\\n</svg>";
 }
 
 // Python Drawing feature ---------------------------------------------------------
@@ -151,7 +139,7 @@ std::string DrawViewDraft::getSVGTail(void)
 namespace App {
 /// @cond DOXERR
 PROPERTY_SOURCE_TEMPLATE(TechDraw::DrawViewDraftPython, TechDraw::DrawViewDraft)
-template<> const char* TechDraw::DrawViewDraftPython::getViewProviderName(void) const {
+template<> const char* TechDraw::DrawViewDraftPython::getViewProviderName() const {
     return "TechDrawGui::ViewProviderDraft";
 }
 /// @endcond
