@@ -24,40 +24,32 @@
 
 #ifndef _PreComp_
 # include <sstream>
+# include <BRep_Builder.hxx>
+# include <BRepAlgoAPI_Fuse.hxx>
+# include <BRepTools.hxx>
+# include <TopoDS.hxx>
+# include <TopoDS_Iterator.hxx>
+# include <TopoDS_Vertex.hxx>
+# include <BRepBuilderAPI_Copy.hxx>
 #endif
 
-#include <BRepAlgoAPI_Fuse.hxx>
-#include <BRepTools.hxx>
-#include <BRepBuilderAPI_Copy.hxx>
-#include <TopExp.hxx>
-#include <TopExp_Explorer.hxx>
-#include <TopoDS_Vertex.hxx>
-#include <TopoDS.hxx>
-#include <TopoDS_Edge.hxx>
-
-#include <App/Application.h>
 #include <App/Document.h>
 #include <App/GroupExtension.h>
-#include <App/Part.h>
 #include <App/Link.h>
-
-#include <Base/BoundBox.h>
+#include <App/Part.h>
 #include <Base/Console.h>
-#include <Base/Exception.h>
-#include <Base/FileInfo.h>
 #include <Base/Parameter.h>
 #include <Base/Placement.h>
-
 #include <Mod/Part/App/PartFeature.h>
 #include <Mod/Part/App/PrimitiveFeature.h>
-#include <Mod/Part/App/FeaturePartCircle.h>
-#include <Mod/Part/App/TopoShape.h>
-#include <Mod/Part/App/PropertyTopoShape.h>
 
 #include "ShapeExtractor.h"
 #include "DrawUtil.h"
+#include "Preferences.h"
+
 
 using namespace TechDraw;
+using DU = DrawUtil;
 
 std::vector<TopoDS_Shape> ShapeExtractor::getShapes2d(const std::vector<App::DocumentObject*> links)
 {
@@ -69,7 +61,7 @@ std::vector<TopoDS_Shape> ShapeExtractor::getShapes2d(const std::vector<App::Doc
     }
     for (auto& l:links) {
         const App::GroupExtension* gex = dynamic_cast<const App::GroupExtension*>(l);
-        if (gex != nullptr) {
+        if (gex) {
             std::vector<App::DocumentObject*> objs = gex->Group.getValues();
             for (auto& d: objs) {
                 if (is2dObject(d)) {
@@ -101,7 +93,6 @@ std::vector<TopoDS_Shape> ShapeExtractor::getShapes2d(const std::vector<App::Doc
 TopoDS_Shape ShapeExtractor::getShapes(const std::vector<App::DocumentObject*> links)
 {
 //    Base::Console().Message("SE::getShapes() - links in: %d\n", links.size());
-    TopoDS_Shape result;
     std::vector<TopoDS_Shape> sourceShapes;
 
     for (auto& l:links) {
@@ -118,7 +109,7 @@ TopoDS_Shape ShapeExtractor::getShapes(const std::vector<App::DocumentObject*> l
                 sourceShapes.push_back(shape);
             } else {
                 std::vector<TopoDS_Shape> shapeList = getShapesFromObject(l);
-                sourceShapes.insert(sourceShapes.end(),shapeList.begin(),shapeList.end());
+                sourceShapes.insert(sourceShapes.end(), shapeList.begin(), shapeList.end());
             }
         }
     }
@@ -147,28 +138,28 @@ TopoDS_Shape ShapeExtractor::getShapes(const std::vector<App::DocumentObject*> l
     }
     //it appears that an empty compound is !IsNull(), so we need to check a different way
     //if we added anything to the compound.
-    if (!found) {
-        Base::Console().Error("ShapeExtractor failed to get shape.\n");
-    } else {
-        result = comp;
+    if (found) {
+//    BRepTools::Write(comp, "SEResult.brep");            //debug
+        return comp;
     }
-//    BRepTools::Write(result, "SEresult.brep");            //debug
-    return result;
+
+    Base::Console().Error("ShapeExtractor failed to get shape.\n");
+    return TopoDS_Shape();
 }
 
 std::vector<TopoDS_Shape> ShapeExtractor::getXShapes(const App::Link* xLink)
 {
-//    Base::Console().Message("SE::getXShapes(%X) - %s\n", xLink, xLink->getNameInDocument());
+//    Base::Console().Message("SE::getXShapes() - %s\n", xLink->getNameInDocument());
     std::vector<TopoDS_Shape> xSourceShapes;
-    if (xLink == nullptr) {
+    if (!xLink) {
         return xSourceShapes;
     }
 
     bool needsTransform = false;
     std::vector<App::DocumentObject*> children = xLink->getLinkedChildren();
-    Base::Placement linkPlm;  // default constructor is an identity placement, i.e. no rotation nor translation
+    Base::Placement xLinkPlacement;  // default constructor is an identity placement, i.e. no rotation nor translation
     if (xLink->hasPlacement()) {
-        linkPlm = xLink->getLinkPlacementProperty()->getValue();
+        xLinkPlacement = xLink->getLinkPlacementProperty()->getValue();
         needsTransform = true;
     }
     Base::Matrix4D linkScale;  // default constructor is an identity matrix, possibly scale it with link's scale
@@ -179,6 +170,7 @@ std::vector<TopoDS_Shape> ShapeExtractor::getXShapes(const App::Link* xLink)
 
     Base::Matrix4D netTransform;
     if (!children.empty()) {
+        // this link points to other links???
         for (auto& l:children) {
             bool childNeedsTransform = false;
             Base::Placement childPlm;
@@ -195,12 +187,16 @@ std::vector<TopoDS_Shape> ShapeExtractor::getXShapes(const App::Link* xLink)
                 }
             }
             auto shape = Part::Feature::getShape(l);
+            Part::TopoShape ts(shape);
+            if (ts.isInfinite()) {
+                shape = stripInfiniteShapes(shape);
+                ts = Part::TopoShape(shape);
+            }
             if(!shape.IsNull()) {
                 if (needsTransform || childNeedsTransform) {
                     // Multiplication is associative, but the braces show the idea of combining the two transforms:
                     // ( link placement and scale ) combined to ( child placement and scale )
-                    netTransform = (linkPlm.toMatrix() * linkScale) * (childPlm.toMatrix() * childScale);
-                    Part::TopoShape ts(shape);
+                    netTransform = (xLinkPlacement.toMatrix() * linkScale) * (childPlm.toMatrix() * childScale);
                     ts.transformGeometry(netTransform);
                     shape = ts.getShape();
                 }
@@ -210,25 +206,65 @@ std::vector<TopoDS_Shape> ShapeExtractor::getXShapes(const App::Link* xLink)
             }
         }
     } else {
-        int depth = 1;   //0 is default value, related to recursion of Links???
-        App::DocumentObject* link = xLink->getLink(depth);
-        if (link != nullptr) {
-            auto shape = Part::Feature::getShape(link);
-            if(!shape.IsNull()) {
-                if (needsTransform) {
-                    // Transform is just link placement and scale, no child objects
-                    netTransform = linkPlm.toMatrix() * linkScale;
-                    Part::TopoShape ts(shape);
-                    ts.transformGeometry(netTransform);
-                    shape = ts.getShape();
-                }
-                xSourceShapes.push_back(shape);
-            }
+        // link points to a regular object, not another link? no sublinks?
+        TopoDS_Shape xLinkShape = getShapeFromXLink(xLink);
+        if (!xLinkShape.IsNull()) {
+            // make the "located, oriented" version of the shape.
+            netTransform = xLinkPlacement.toMatrix() * linkScale;
+            // copying the shape prevents "non-orthogonal GTrsf" errors in some versions
+            // of OCC.  Something to do with triangulation of shape??
+            BRepBuilderAPI_Copy copier(xLinkShape);
+            auto ts = Part::TopoShape(copier.Shape());
+            ts.transformGeometry(netTransform);
+            xSourceShapes.push_back(ts.getShape());
         }
     }
     return xSourceShapes;
 }
 
+// get the shape for a single childless App::Link
+TopoDS_Shape ShapeExtractor::getShapeFromXLink(const App::Link* xLink)
+{
+    Base::Placement xLinkPlacement;
+    if (xLink->hasPlacement()) {
+        xLinkPlacement = xLink->getLinkPlacementProperty()->getValue();
+    }
+    Base::Matrix4D linkScale;  // default constructor is an identity matrix, possibly scale it with link's scale
+    if(xLink->getScaleProperty() || xLink->getScaleVectorProperty()) {
+        linkScale.scale(xLink->getScaleVector());
+    }
+    int depth = 0;   //0 is default value, related to recursion of Links???
+    App::DocumentObject* linkedObject = xLink->getLink(depth);
+    if (linkedObject) {
+        // have a linked object, get the shape
+        TopoDS_Shape shape = Part::Feature::getShape(linkedObject);
+        if (shape.IsNull()) {
+            // this is where we need to parse the target for objects with a shape??
+            Base::Console().Message("SE::getXShapes - link has no shape\n");
+            // std::vector<TopoDS_Shape> shapesFromObject = getShapesFromObject(linkedObject);  // getXShapes?
+            return TopoDS_Shape();
+        }
+        Part::TopoShape ts(shape);
+        if (ts.isInfinite()) {
+            shape = stripInfiniteShapes(shape);
+            // the shape must have a triangulation or it will cause a failure
+            // when later transforms are applied
+            ts = Part::TopoShape(shape);
+        }
+        //ts might be garbage now, better check
+        try {
+            if (!ts.isNull()) {
+                ts.setPlacement(xLinkPlacement);
+            }
+        }
+        catch (...) {
+            Base::Console().Error("ShapeExtractor failed to retrieve shape from %s\n", xLink->getNameInDocument());
+            return TopoDS_Shape();
+        }
+        return ts.getShape();
+    }
+    return TopoDS_Shape();
+}
 
 std::vector<TopoDS_Shape> ShapeExtractor::getShapesFromObject(const App::DocumentObject* docObj)
 {
@@ -258,37 +294,33 @@ std::vector<TopoDS_Shape> ShapeExtractor::getShapesFromObject(const App::Documen
             return result;
         }
 
-    } else if (gex != nullptr) {           //is a group extension
+    } else if (gex) {           //is a group extension
         std::vector<App::DocumentObject*> objs = gex->Group.getValues();
         std::vector<TopoDS_Shape> shapes;
         for (auto& d: objs) {
             shapes = getShapesFromObject(d);
             if (!shapes.empty()) {
-                result.insert(result.end(),shapes.begin(),shapes.end());
+                result.insert(result.end(), shapes.begin(), shapes.end());
             }
         }
     //the next 2 bits are mostly for Arch module objects
-    } else if (gProp != nullptr) {       //has a Group property
+    } else if (gProp) {       //has a Group property
         App::PropertyLinkList* list = dynamic_cast<App::PropertyLinkList*>(gProp);
-        if (list != nullptr) {
+        if (list) {
             std::vector<App::DocumentObject*> objs = list->getValues();
             std::vector<TopoDS_Shape> shapes;
             for (auto& d: objs) {
                 shapes = getShapesFromObject(d);
                 if (!shapes.empty()) {
-                    result.insert(result.end(),shapes.begin(),shapes.end());
+                    result.insert(result.end(), shapes.begin(), shapes.end());
                 }
             }
-        } else {
-                Base::Console().Log("SE::getShapesFromObject - Group is not a PropertyLinkList!\n");
         }
-    } else if (sProp != nullptr) {       //has a Shape property
+    } else if (sProp) {       //has a Shape property
         Part::PropertyPartShape* shape = dynamic_cast<Part::PropertyPartShape*>(sProp);
-        if (shape != nullptr) {
+        if (shape) {
             TopoDS_Shape occShape = shape->getValue();
             result.push_back(occShape);
-        } else {
-            Base::Console().Log("SE::getShapesFromObject - Shape is not a PropertyPartShape!\n");
         }
     }
     return result;
@@ -322,7 +354,7 @@ TopoDS_Shape ShapeExtractor::getShapesFused(const std::vector<App::DocumentObjec
 //Infinite shapes can not be projected, so they need to be removed.
 TopoDS_Shape ShapeExtractor::stripInfiniteShapes(TopoDS_Shape inShape)
 {
-//    Base::Console().Message("SE::stripInfiniteShapes() - shapeType: %d\n", inShape.ShapeType());
+//    Base::Console().Message("SE::stripInfiniteShapes()\n");
     BRep_Builder builder;
     TopoDS_Compound comp;
     builder.MakeCompound(comp);
@@ -373,66 +405,60 @@ bool ShapeExtractor::isEdgeType(App::DocumentObject* obj)
 bool ShapeExtractor::isPointType(App::DocumentObject* obj)
 {
 //    Base::Console().Message("SE::isPointType(%s)\n", obj->getNameInDocument());
-    bool result = false;
     if (obj) {
         Base::Type t = obj->getTypeId();
         if (t.isDerivedFrom(Part::Vertex::getClassTypeId())) {
-            result = true;
+            return true;
         } else if (isDraftPoint(obj)) {
-            result = true;
+            return true;
         }
     }
-    return result;
+    return false;
 }
 
 bool ShapeExtractor::isDraftPoint(App::DocumentObject* obj)
 {
 //    Base::Console().Message("SE::isDraftPoint()\n");
-    bool result = false;
     //if the docObj doesn't have a Proxy property, it definitely isn't a Draft point
     App::PropertyPythonObject* proxy = dynamic_cast<App::PropertyPythonObject*>(obj->getPropertyByName("Proxy"));
-    if (proxy != nullptr) {
+    if (proxy) {
         std::string  pp = proxy->toString();
 //        Base::Console().Message("SE::isDraftPoint - pp: %s\n", pp.c_str());
         if (pp.find("Point") != std::string::npos) {
-            result = true;
+            return true;
         }
     }
-    return result;
+    return false;
 }
 
 Base::Vector3d ShapeExtractor::getLocation3dFromFeat(App::DocumentObject* obj)
 {
 //    Base::Console().Message("SE::getLocation3dFromFeat()\n");
-    Base::Vector3d result(0.0, 0.0, 0.0);
     if (!isPointType(obj)) {
-        return result;
+        return Base::Vector3d(0.0, 0.0, 0.0);
     }
 //    if (isDraftPoint(obj) {
 //        //Draft Points are not necc. Part::PartFeature??
 //        //if Draft option "use part primitives" is not set are Draft points still PartFeature?
 
     Part::Feature* pf = dynamic_cast<Part::Feature*>(obj);
-    if (pf != nullptr) {
+    if (pf) {
         Part::TopoShape pts = pf->Shape.getShape();
         pts.setPlacement(pf->globalPlacement());
         TopoDS_Shape ts = pts.getShape();
         if (ts.ShapeType() == TopAbs_VERTEX)  {
             TopoDS_Vertex v = TopoDS::Vertex(ts);
-            result = DrawUtil::vertex2Vector(v);
+            return DrawUtil::vertex2Vector(v);
         }
     }
 
 //    Base::Console().Message("SE::getLocation3dFromFeat - returns: %s\n",
 //                            DrawUtil::formatVector(result).c_str());
-    return result;
+    return Base::Vector3d(0.0, 0.0, 0.0);
 }
 
-bool ShapeExtractor::prefAdd2d(void)
+bool ShapeExtractor::prefAdd2d()
 {
-    Base::Reference<ParameterGrp> hGrp = App::GetApplication().GetUserParameter()
-          .GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("Mod/TechDraw/General");
-    bool result = hGrp->GetBool("ShowLoose2d", false);
-    return result;
+    return Preferences::getPreferenceGroup("General")->GetBool("ShowLoose2d", false);
 }
 
