@@ -20,10 +20,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _ShapeExtractor_h_
-#define _ShapeExtractor_h_
-
-#include <Mod/TechDraw/TechDrawGlobal.h>
+#ifndef ShapeExtractor_h_
+#define ShapeExtractor_h_
 
 #include <TopoDS_Shape.hxx>
 
@@ -32,6 +30,8 @@
 #include <Base/Type.h>
 #include <Base/Vector3D.h>
 
+#include <Mod/TechDraw/TechDrawGlobal.h>
+
 
 namespace TechDraw
 {
@@ -44,13 +44,14 @@ public:
     static std::vector<TopoDS_Shape> getXShapes(const App::Link* xLink);
     static std::vector<TopoDS_Shape> getShapesFromObject(const App::DocumentObject* docObj);
     static TopoDS_Shape getShapesFused(const std::vector<App::DocumentObject*> links);
+    static TopoDS_Shape getShapeFromXLink(const App::Link* xLink);
 
     static bool is2dObject(App::DocumentObject* obj);
     static bool isEdgeType(App::DocumentObject* obj);
     static bool isPointType(App::DocumentObject* obj);
     static bool isDraftPoint(App::DocumentObject* obj);
     static Base::Vector3d getLocation3dFromFeat(App::DocumentObject* obj);
-    static bool prefAdd2d(void);
+    static bool prefAdd2d();
 
     static TopoDS_Shape stripInfiniteShapes(TopoDS_Shape inShape);
 
@@ -62,4 +63,4 @@ private:
 
 } //namespace TechDraw
 
-#endif  // #ifndef _ShapeExtractor_h_
+#endif  // #ifndef ShapeExtractor_h_
