@@ -22,12 +22,11 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #include "DlgPrefsTechDrawAdvancedImp.h"
-#include <Mod/TechDraw/Gui/ui_DlgPrefsTechDrawAdvanced.h>
-#include <Gui/PrefWidgets.h>
+#include "ui_DlgPrefsTechDrawAdvanced.h"
+
 
 using namespace TechDrawGui;
 
@@ -45,7 +44,7 @@ DlgPrefsTechDrawAdvancedImp::~DlgPrefsTechDrawAdvancedImp()
 
 void DlgPrefsTechDrawAdvancedImp::saveSettings()
 {
-    ui->cbDetectFaces->onSave(); 
+    ui->cbDetectFaces->onSave();
     ui->cbShowSectionEdges->onSave();
     ui->cbDebugSection->onSave();
     ui->cbDebugDetail->onSave();
@@ -57,6 +56,10 @@ void DlgPrefsTechDrawAdvancedImp::saveSettings()
     ui->cbEndCap->onSave();
     ui->sbMaxTiles->onSave();
     ui->sbMaxPat->onSave();
+    ui->cbReportProgress->onSave();
+    ui->cbAutoCorrectRefs->onSave();
+    ui->cbNewFaceFinder->onSave();
+    ui->sbScrubCount->onSave();
 }
 
 void DlgPrefsTechDrawAdvancedImp::loadSettings()
@@ -73,6 +76,10 @@ void DlgPrefsTechDrawAdvancedImp::loadSettings()
     ui->cbEndCap->onRestore();
     ui->sbMaxTiles->onRestore();
     ui->sbMaxPat->onRestore();
+    ui->cbReportProgress->onRestore();
+    ui->cbAutoCorrectRefs->onRestore();
+    ui->cbNewFaceFinder->onRestore();
+    ui->sbScrubCount->onRestore();
 }
 
 /**
