@@ -23,13 +23,14 @@
 #ifndef TECHDRAWGUI_QGIHIGHLIGHT_H
 #define TECHDRAWGUI_QGIHIGHLIGHT_H
 
+#include <Mod/TechDraw/TechDrawGlobal.h>
+
 #include <QColor>
 #include <QFont>
 #include <QGraphicsEllipseItem>
 #include <QGraphicsScene>
 #include <QPointF>
 
-#include "QGIArrow.h"
 #include "QGCustomText.h"
 #include "QGCustomRect.h"
 #include "QGIDecoration.h"
@@ -47,20 +48,22 @@ public:
     enum {Type = QGraphicsItem::UserType + 176};
     int type() const override { return Type;}
 
-    virtual void paint(QPainter * painter,
-                       const QStyleOptionGraphicsItem * option, 
-                       QWidget * widget = nullptr ) override;
+    void paint(QPainter * painter,
+               const QStyleOptionGraphicsItem * option,
+               QWidget * widget = nullptr ) override;
 
-    void setBounds(double x1,double y1,double x2,double y2);
-    void setReference(char* sym);
+    void setBounds(double x1, double y1, double x2, double y2);
+    void setReference(const char* sym);
     void setFont(QFont f, double fsize);
     virtual void draw() override;
     void setInteractive(bool state);
+    void setFeatureName(std::string name) { m_featureName = name; }
+    std::string getFeatureName() { return m_featureName; }
+    void setReferenceAngle(double angle) { m_referenceAngle = angle; }
+
+    void onDragFinished() override;
 
 protected:
-/*    virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value) override;*/
-/*    virtual void mousePressEvent(QGraphicsSceneMouseEvent *event) override;*/
-/*    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent *event) override;*/
     QColor getHighlightColor();
     Qt::PenStyle getHighlightStyle();
     void makeHighlight();
@@ -68,10 +71,8 @@ protected:
     void setTools();
     int getHoleStyle(void);
 
-/*    bool m_dragging;*/
-
 private:
-    char* m_refText;
+    QString            m_refText;
     QGraphicsEllipseItem* m_circle;
     QGCustomRect*      m_rect;
     QGCustomText*      m_reference;
@@ -80,6 +81,8 @@ private:
     double             m_refSize;
     QPointF            m_start;
     QPointF            m_end;
+    std::string        m_featureName;
+    double             m_referenceAngle;
 };
 
 }
