@@ -26,13 +26,15 @@
 #include <Base/Vector3D.h>
 #include <Gui/TaskView/TaskDialog.h>
 #include <Gui/TaskView/TaskView.h>
+#include <Mod/TechDraw/TechDrawGlobal.h>
 
 
 //TODO: make this a proper enum
-#define TRACKERPICK 0
-#define TRACKEREDIT 1
-#define TRACKERCANCEL 2
-#define TRACKERCANCELEDIT 3
+static constexpr int TRACKERPICK(0);
+static constexpr int TRACKEREDIT(1);
+static constexpr int TRACKERCANCEL(2);
+static constexpr int TRACKERCANCELEDIT(3);
+
 
 namespace TechDraw
 {
@@ -44,14 +46,13 @@ class DrawViewPart;
 
 namespace TechDrawGui
 {
-class QGVPage;
+class QGSPage;
 class QGIView;
 class QGIPrimPath;
-class MDIViewPage;
 class QGEPath;
 class QGIDetail;
 class QGIGhostHighlight;
-class ViewProviderLeader;
+class ViewProviderPage;
 class Ui_TaskDetail;
 
 class TaskDetail : public QWidget
@@ -59,41 +60,40 @@ class TaskDetail : public QWidget
     Q_OBJECT
 
 public:
-    TaskDetail(TechDraw::DrawViewPart* baseFeat);
-    TaskDetail(TechDraw::DrawViewDetail* detailFeat);
-    ~TaskDetail();
+    explicit TaskDetail(TechDraw::DrawViewPart* baseFeat);
+    explicit TaskDetail(TechDraw::DrawViewDetail* detailFeat);
+    ~TaskDetail() = default;
 
-public Q_SLOTS:
-    void onDraggerClicked(bool b);
-    void onHighlightMoved(QPointF newPos);
-    void onXEdit();
-    void onYEdit();
-    void onRadiusEdit();
-    void onScaleTypeEdit();
-    void onScaleEdit();
-    void onReferenceEdit();
-
-public:
     virtual bool accept();
     virtual bool reject();
     void updateTask();
     void saveButtons(QPushButton* btnOK,
                      QPushButton* btnCancel);
-    void enableTaskButtons(bool b);
-    
+    void enableTaskButtons(bool button);
+
+public Q_SLOTS:
+        void onDraggerClicked(bool clicked);
+        void onHighlightMoved(QPointF dragEnd);
+        void onXEdit();
+        void onYEdit();
+        void onRadiusEdit();
+        void onScaleTypeEdit();
+        void onScaleEdit();
+        void onReferenceEdit();
+
 protected:
-    void changeEvent(QEvent *e);
-    void startDragger(void);
+    void changeEvent(QEvent *event) override;
+    void startDragger();
 
     void createDetail();
     void updateDetail();
-    
+
     void editByHighlight();
 
-    void blockButtons(bool b);
-    void setUiFromFeat(void);
-    void updateUi(QPointF p);
-    void enableInputFields(bool b);
+    void blockButtons(bool isBlocked);
+    void setUiFromFeat();
+    void updateUi(QPointF pos);
+    void enableInputFields(bool isEnabled);
 
     void saveDetailState();
     void restoreDetailState();
@@ -108,9 +108,7 @@ private:
 
     QGIGhostHighlight* m_ghost;
 
-    MDIViewPage* m_mdi;
-    QGraphicsScene* m_scene;
-    QGVPage* m_view;
+    ViewProviderPage* m_vpp;
     TechDraw::DrawViewDetail* m_detailFeat;
     TechDraw::DrawViewPart* m_baseFeat;
     TechDraw::DrawPage* m_basePage;
@@ -141,28 +139,24 @@ class TaskDlgDetail : public Gui::TaskView::TaskDialog
     Q_OBJECT
 
 public:
-    TaskDlgDetail(TechDraw::DrawViewPart* baseFeat);
-    TaskDlgDetail(TechDraw::DrawViewDetail* detailFeat);
-    ~TaskDlgDetail();
+    explicit TaskDlgDetail(TechDraw::DrawViewPart* baseFeat);
+    explicit TaskDlgDetail(TechDraw::DrawViewDetail* detailFeat);
+    ~TaskDlgDetail() override;
 
-public:
     /// is called the TaskView when the dialog is opened
-    virtual void open();
+    void open() override;
     /// is called by the framework if an button is clicked which has no accept or reject role
-    virtual void clicked(int);
+    void clicked(int) override;
     /// is called by the framework if the dialog is accepted (Ok)
-    virtual bool accept();
+    bool accept() override;
     /// is called by the framework if the dialog is rejected (Cancel)
-    virtual bool reject();
+    bool reject() override;
     /// is called by the framework if the user presses the help button
-    virtual void helpRequested() { return;}
-    virtual bool isAllowedAlterDocument(void) const
+    bool isAllowedAlterDocument() const override
                         { return false; }
     void update();
 
-    void modifyStandardButtons(QDialogButtonBox* box);
-
-protected:
+    void modifyStandardButtons(QDialogButtonBox* box) override;
 
 private:
     TaskDetail * widget;
