@@ -22,35 +22,28 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
-#include <cmath>
+# include <cmath>
 #endif // #ifndef _PreComp_
 
+#include <App/Document.h>
+#include <App/DocumentObject.h>
 #include <Base/Console.h>
 #include <Base/Tools.h>
 #include <Base/Vector3D.h>
-
 #include <Gui/Application.h>
 #include <Gui/BitmapFactory.h>
 #include <Gui/Command.h>
 #include <Gui/Document.h>
-#include <Gui/Selection.h>
 #include <Gui/ViewProvider.h>
-
-#include <App/Application.h>
-#include <App/Document.h>
-#include <App/DocumentObject.h>
-
 #include <Mod/TechDraw/App/DrawHatch.h>
-#include <Mod/TechDraw/App/DrawView.h>
-#include <Mod/TechDraw/App/DrawViewPart.h>
 #include <Mod/TechDraw/App/DrawUtil.h>
+#include <Mod/TechDraw/App/DrawViewPart.h>
 
-#include "PreferencesGui.h"
-#include "ViewProviderHatch.h"
 #include "TaskHatch.h"
-#include <Mod/TechDraw/Gui/ui_TaskHatch.h>
+#include "ui_TaskHatch.h"
+#include "ViewProviderHatch.h"
+
 
 using namespace Gui;
 using namespace TechDraw;
@@ -65,10 +58,12 @@ TaskHatch::TaskHatch(TechDraw::DrawViewPart* inDvp, std::vector<std::string> sub
 {
     ui->setupUi(this);
 
-    connect(ui->fcFile, SIGNAL(fileNameSelected(QString)), this, SLOT(onFileChanged()));
-    connect(ui->sbScale, SIGNAL(valueChanged(double)), this, SLOT(onScaleChanged()));
-    connect(ui->ccColor, SIGNAL(changed()), this, SLOT(onColorChanged()));
-
+    connect(ui->fcFile, &FileChooser::fileNameSelected, this, &TaskHatch::onFileChanged);
+    connect(ui->sbScale, qOverload<double>(&QuantitySpinBox::valueChanged), this, &TaskHatch::onScaleChanged);
+    connect(ui->ccColor, &ColorButton::changed, this, &TaskHatch::onColorChanged);
+    connect(ui->dsbRotation, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &TaskHatch::onRotationChanged);
+    connect(ui->dsbOffsetX, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &TaskHatch::onOffsetChanged);
+    connect(ui->dsbOffsetY, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &TaskHatch::onOffsetChanged);
     setUiPrimary();
 }
 
@@ -83,9 +78,12 @@ TaskHatch::TaskHatch(TechDrawGui::ViewProviderHatch* inVp) :
     App::DocumentObject* obj = m_hatch->Source.getValue();
     m_dvp = static_cast<TechDraw::DrawViewPart*>(obj);
 
-    connect(ui->fcFile, SIGNAL(fileNameSelected(QString)), this, SLOT(onFileChanged()));
-    connect(ui->sbScale, SIGNAL(valueChanged(double)), this, SLOT(onScaleChanged()));
-    connect(ui->ccColor, SIGNAL(changed()), this, SLOT(onColorChanged()));
+    connect(ui->fcFile, &FileChooser::fileNameSelected, this, &TaskHatch::onFileChanged);
+    connect(ui->sbScale, qOverload<double>(&QuantitySpinBox::valueChanged), this, &TaskHatch::onScaleChanged);
+    connect(ui->ccColor, &ColorButton::changed, this, &TaskHatch::onColorChanged);
+    connect(ui->dsbRotation, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &TaskHatch::onRotationChanged);
+    connect(ui->dsbOffsetX, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &TaskHatch::onOffsetChanged);
+    connect(ui->dsbOffsetY, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &TaskHatch::onOffsetChanged);
 
     saveHatchState();
     setUiEdit();
@@ -103,6 +101,7 @@ void TaskHatch::setUiPrimary()
     ui->sbScale->setValue(1.0);
     ui->sbScale->setSingleStep(0.1);
     ui->ccColor->setColor(TechDraw::DrawHatch::prefSvgHatchColor().asValue<QColor>());
+    ui->dsbRotation->setValue(0.0);
 }
 
 void TaskHatch::setUiEdit()
@@ -114,6 +113,9 @@ void TaskHatch::setUiEdit()
     ui->sbScale->setValue(m_saveScale);
     ui->sbScale->setSingleStep(0.1);
     ui->ccColor->setColor(m_saveColor.asValue<QColor>());
+    ui->dsbRotation->setValue(m_saveRotation);
+    ui->dsbOffsetX->setValue(m_saveOffset.x);
+    ui->dsbOffsetY->setValue(m_saveOffset.y);
 }
 
 void TaskHatch::saveHatchState()
@@ -121,20 +123,25 @@ void TaskHatch::saveHatchState()
     m_saveFile = m_hatch->HatchPattern.getValue();
     m_saveScale = m_vp->HatchScale.getValue();
     m_saveColor = m_vp->HatchColor.getValue();
+    m_saveRotation = m_vp->HatchRotation.getValue();
+    m_saveOffset = m_vp->HatchOffset.getValue();
+
 }
 
 //restore the start conditions
 void TaskHatch::restoreHatchState()
 {
 //    Base::Console().Message("TH::restoreHatchState()\n");
-    if (m_hatch != nullptr) {
+    if (m_hatch) {
         m_hatch->HatchPattern.setValue(m_saveFile);
         m_vp->HatchScale.setValue(m_saveScale);
         m_vp->HatchColor.setValue(m_saveColor);
+        m_vp->HatchRotation.setValue(m_saveRotation);
+        m_vp->HatchOffset.setValue(m_saveOffset);
     }
 }
 
-void TaskHatch::onFileChanged(void)
+void TaskHatch::onFileChanged()
 {
     m_file = Base::Tools::toStdString(ui->fcFile->fileName());
     apply();
@@ -152,18 +159,31 @@ void TaskHatch::onColorChanged()
     apply();
 }
 
+void TaskHatch::onRotationChanged()
+{
+    m_rotation = ui->dsbRotation->value();
+    apply();
+}
+
+void TaskHatch::onOffsetChanged()
+{
+    m_offset.x = ui->dsbOffsetX->value();
+    m_offset.y = ui->dsbOffsetY->value();
+    apply();
+}
+
 void TaskHatch::apply(bool forceUpdate)
 {
     Q_UNUSED(forceUpdate)
 //    Base::Console().Message("TH::apply() - m_hatch: %X\n", m_hatch);
-    if (m_hatch == nullptr) {
+    if (!m_hatch) {
         createHatch();
     }
-    if (m_hatch != nullptr) {
+    if (m_hatch) {
         updateHatch();
     }
 
-    if (m_dvp != nullptr) {
+    if (m_dvp) {
         //only need requestPaint to hatch the face
 //        m_dvp->requestPaint();
         //need a recompute in order to claimChildren in tree
@@ -182,13 +202,13 @@ void TaskHatch::createHatch()
 
     Command::openCommand(QT_TRANSLATE_NOOP("Command", "Create Hatch"));
 
-    Command::doCommand(Command::Doc,"App.activeDocument().addObject('TechDraw::DrawHatch','%s')",FeatName.c_str());
-    Command::doCommand(Command::Doc,"App.activeDocument().%s.Label = '%s'",FeatName.c_str(),featLabel.str().c_str());
+    Command::doCommand(Command::Doc, "App.activeDocument().addObject('TechDraw::DrawHatch', '%s')", FeatName.c_str());
+    Command::doCommand(Command::Doc, "App.activeDocument().%s.Label = '%s'", FeatName.c_str(), featLabel.str().c_str());
 
     m_hatch = static_cast<TechDraw::DrawHatch *>(doc->getObject(FeatName.c_str()));
     m_hatch->Source.setValue(m_dvp, m_subs);
 
-    Command::doCommand(Command::Doc,"App.activeDocument().%s.HatchPattern = '%s'",
+    Command::doCommand(Command::Doc, "App.activeDocument().%s.HatchPattern = '%s'",
                        FeatName.c_str(),
                        Base::Tools::toStdString(ui->fcFile->fileName()).c_str());
 
@@ -200,6 +220,9 @@ void TaskHatch::createHatch()
         ac.setValue<QColor>(ui->ccColor->color());
         m_vp->HatchColor.setValue(ac);
         m_vp->HatchScale.setValue(ui->sbScale->value().getValue());
+        m_vp->HatchRotation.setValue(ui->dsbRotation->value());
+        Base::Vector3d offset(ui->dsbOffsetX->value(), ui->dsbOffsetY->value(), 0.0);
+        m_vp->HatchOffset.setValue(offset);
     } else {
         Base::Console().Error("TaskHatch - Hatch has no ViewProvider\n");
     }
@@ -213,7 +236,7 @@ void TaskHatch::updateHatch()
 
     Command::openCommand(QT_TRANSLATE_NOOP("Command", "Update Hatch"));
 
-    Command::doCommand(Command::Doc,"App.activeDocument().%s.HatchPattern = '%s'",
+    Command::doCommand(Command::Doc, "App.activeDocument().%s.HatchPattern = '%s'",
                        FeatName.c_str(),
                        Base::Tools::toStdString(ui->fcFile->fileName()).c_str());
 
@@ -221,6 +244,9 @@ void TaskHatch::updateHatch()
     ac.setValue<QColor>(ui->ccColor->color());
     m_vp->HatchColor.setValue(ac);
     m_vp->HatchScale.setValue(ui->sbScale->value().getValue());
+    m_vp->HatchRotation.setValue(ui->dsbRotation->value());
+    Base::Vector3d offset(ui->dsbOffsetX->value(), ui->dsbOffsetY->value(), 0.0);
+    m_vp->HatchOffset.setValue(offset);
     Command::commitCommand();
 }
 
