@@ -24,11 +24,11 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-# include <QMessageBox>
-# include <QTextStream>
-# ifdef FC_OS_WIN32
-#  include <windows.h>
-# endif
+#include <QMessageBox>
+#include <QTextStream>
+#ifdef FC_OS_WIN32
+#include <windows.h>
+#endif
 #endif
 
 #include <App/DocumentObject.h>
@@ -37,13 +37,14 @@
 #include <Gui/MainWindow.h>
 
 #include <Mod/TechDraw/App/DrawPage.h>
-#include <Mod/TechDraw/App/DrawTemplate.h>
 #include <Mod/TechDraw/App/DrawSVGTemplate.h>
+#include <Mod/TechDraw/App/DrawTemplate.h>
 
-#include "QGITemplate.h"
-#include "QGISVGTemplate.h"
-#include "QGVPage.h"
 #include "MDIViewPage.h"
+#include "QGISVGTemplate.h"
+#include "QGITemplate.h"
+#include "QGSPage.h"
+#include "QGVPage.h"
 #include "TemplateTextField.h"
 #include "ViewProviderPage.h"
 #include "ViewProviderTemplate.h"
@@ -55,52 +56,57 @@ PROPERTY_SOURCE(TechDrawGui::ViewProviderTemplate, Gui::ViewProviderDocumentObje
 //**************************************************************************
 // Construction/Destruction
 
-ViewProviderTemplate::ViewProviderTemplate()
+ViewProviderTemplate::ViewProviderTemplate() : m_myName(std::string())
 {
+    initExtension(this);
+
     sPixmap = "TechDraw_TreePageTemplate";
 
-    DisplayMode.setStatus(App::Property::Hidden,true);
+    // Do not show in property editor   why? wf  WF: because DisplayMode applies only to coin and we
+    // don't use coin.
+    DisplayMode.setStatus(App::Property::Hidden, true);
 }
 
-ViewProviderTemplate::~ViewProviderTemplate()
+void ViewProviderTemplate::attach(App::DocumentObject* pcFeat)
 {
-}
-
-void ViewProviderTemplate::attach(App::DocumentObject *pcFeat)
-{
-    // call parent attach method
+    //    Base::Console().Message("VPT::attach(%s)\n", pcFeat->getNameInDocument());
     ViewProviderDocumentObject::attach(pcFeat);
-}
 
-void ViewProviderTemplate::setDisplayMode(const char* ModeName)
-{
-    ViewProviderDocumentObject::setDisplayMode(ModeName);
-}
-
-std::vector<std::string> ViewProviderTemplate::getDisplayModes(void) const
-{
-    // get the modes of the father
-    std::vector<std::string> StrList = ViewProviderDocumentObject::getDisplayModes();
-
-    return StrList;
+    auto feature = getTemplate();
+    if (feature) {
+        m_myName = feature->getNameInDocument();
+    }
 }
 
 void ViewProviderTemplate::updateData(const App::Property* prop)
 {
+    //This doesn't belong here.  Should be in a ViewProviderSvgTemplate?
     if (getTemplate()->isDerivedFrom(TechDraw::DrawSVGTemplate::getClassTypeId())) {
         auto t = static_cast<TechDraw::DrawSVGTemplate*>(getTemplate());
         if (prop == &(t->Template)) {
-            MDIViewPage* mdi = getMDIViewPage();
-            if (mdi != nullptr) {
-                mdi->attachTemplate(t);
-                mdi->viewAll();
+            auto page = t->getParentPage();
+            Gui::ViewProvider* vp =
+                Gui::Application::Instance->getDocument(t->getDocument())->getViewProvider(page);
+            TechDrawGui::ViewProviderPage* vpp = dynamic_cast<TechDrawGui::ViewProviderPage*>(vp);
+            if (vpp) {
+                vpp->getQGSPage()->attachTemplate(t);
+                vpp->getQGSPage()->matchSceneRectToTemplate();
             }
-       }
+        }
     }
+
+    if (prop == &(getTemplate()->EditableTexts)) {
+        QGITemplate* qgiv = getQTemplate();
+        if (qgiv) {
+            qgiv->updateView(true);
+        }
+    }
+
+
     Gui::ViewProviderDocumentObject::updateData(prop);
 }
 
-void ViewProviderTemplate::onChanged(const App::Property *prop)
+void ViewProviderTemplate::onChanged(const App::Property* prop)
 {
     App::DocumentObject* obj = getObject();
     if (!obj || obj->isRestoring()) {
@@ -111,63 +117,63 @@ void ViewProviderTemplate::onChanged(const App::Property *prop)
     if (prop == &Visibility) {
         if (Visibility.getValue()) {
             show();
-        } else {
+        }
+        else {
             hide();
         }
     }
-    
+
     Gui::ViewProviderDocumentObject::onChanged(prop);
 }
 
-void ViewProviderTemplate::show(void)
+void ViewProviderTemplate::show()
 {
     QGITemplate* qTemplate = getQTemplate();
-    if (qTemplate != nullptr) {
+    if (qTemplate) {
         qTemplate->show();
     }
 
     ViewProviderDocumentObject::show();
 }
 
-void ViewProviderTemplate::hide(void)
+void ViewProviderTemplate::hide()
 {
     QGITemplate* qTemplate = getQTemplate();
-    if (qTemplate != nullptr) {
+    if (qTemplate) {
         qTemplate->hide();
     }
-    
+
     ViewProviderDocumentObject::hide();
 }
 
-bool ViewProviderTemplate::isShow(void) const
-{
-    return Visibility.getValue();
-}
+bool ViewProviderTemplate::isShow() const { return Visibility.getValue(); }
 
-QGITemplate* ViewProviderTemplate::getQTemplate(void)
+QGITemplate* ViewProviderTemplate::getQTemplate()
 {
-    QGITemplate *result = nullptr;
     TechDraw::DrawTemplate* dt = getTemplate();
     if (dt) {
-        MDIViewPage* mdi = getMDIViewPage();
-        if (mdi != nullptr) {
-            result = mdi->getQGVPage()->getTemplate();
-        }
+        auto page = dt->getParentPage();
+        Gui::ViewProvider* vp =
+            Gui::Application::Instance->getDocument(dt->getDocument())->getViewProvider(page);
+        TechDrawGui::ViewProviderPage* vpp = dynamic_cast<TechDrawGui::ViewProviderPage*>(vp);
+        if (vpp)
+            return vpp->getQGSPage()->getTemplate();
     }
-    return result;
+    return nullptr;
 }
 
 void ViewProviderTemplate::setMarkers(bool state)
 {
-//    Base::Console().Message("VPT::setMarkers(%d)\n",state);
+    //    Base::Console().Message("VPT::setMarkers(%d)\n", state);
     QGITemplate* qTemplate = getQTemplate();
-    QGISVGTemplate* qSvgTemplate = dynamic_cast<QGISVGTemplate*> (qTemplate);
-    if (qSvgTemplate != nullptr) {
-        std::vector<TemplateTextField *> textFields = qSvgTemplate->getTextFields();
-        for (auto& t:textFields) {
+    QGISVGTemplate* qSvgTemplate = dynamic_cast<QGISVGTemplate*>(qTemplate);
+    if (qSvgTemplate) {
+        std::vector<TemplateTextField*> textFields = qSvgTemplate->getTextFields();
+        for (auto& t : textFields) {
             if (state) {
                 t->show();
-            } else {
+            }
+            else {
                 t->hide();
             }
         }
@@ -175,7 +181,7 @@ void ViewProviderTemplate::setMarkers(bool state)
     }
 }
 
-bool ViewProviderTemplate::onDelete(const std::vector<std::string> &)
+bool ViewProviderTemplate::onDelete(const std::vector<std::string>&)
 {
     // deleting the template will break the page view, thus warn the user
 
@@ -190,39 +196,38 @@ bool ViewProviderTemplate::onDelete(const std::vector<std::string> &)
     QString bodyMessage;
     QTextStream bodyMessageStream(&bodyMessage);
     bodyMessageStream << qApp->translate("Std_Delete",
-        "The following referencing object might break:");
+                                         "The following referencing object might break:");
     bodyMessageStream << "\n\n" << QString::fromUtf8(page->Label.getValue());
     bodyMessageStream << "\n\n" << QObject::tr("Are you sure you want to continue?");
 
     // show and evaluate dialog
     int DialogResult = QMessageBox::warning(Gui::getMainWindow(),
-        qApp->translate("Std_Delete", "Object dependencies"), bodyMessage,
-        QMessageBox::Yes, QMessageBox::No);
+                                            qApp->translate("Std_Delete", "Object dependencies"),
+                                            bodyMessage, QMessageBox::Yes, QMessageBox::No);
     if (DialogResult == QMessageBox::Yes)
         return true;
     else
         return false;
 }
 
-MDIViewPage* ViewProviderTemplate::getMDIViewPage(void) const
+MDIViewPage* ViewProviderTemplate::getMDIViewPage() const
 {
-    MDIViewPage* myMdi = nullptr;
     auto t = getTemplate();
     auto page = t->getParentPage();
-    Gui::ViewProvider* vp = Gui::Application::Instance->getDocument(t->getDocument())->getViewProvider(page);
+    Gui::ViewProvider* vp =
+        Gui::Application::Instance->getDocument(t->getDocument())->getViewProvider(page);
     TechDrawGui::ViewProviderPage* dvp = dynamic_cast<TechDrawGui::ViewProviderPage*>(vp);
     if (dvp) {
-        myMdi = dvp->getMDIViewPage();
+        return dvp->getMDIViewPage();
     }
-    return myMdi;
+    return nullptr;
 }
 
-Gui::MDIView *ViewProviderTemplate::getMDIView() const
-{
-    return getMDIViewPage();
-}
+Gui::MDIView* ViewProviderTemplate::getMDIView() const { return getMDIViewPage(); }
 
 TechDraw::DrawTemplate* ViewProviderTemplate::getTemplate() const
 {
     return dynamic_cast<TechDraw::DrawTemplate*>(pcObject);
 }
+
+const char* ViewProviderTemplate::whoAmI() const { return m_myName.c_str(); }
