@@ -22,6 +22,7 @@
 #***************************************************************************/
 
 import FreeCAD, os, unittest, tempfile, math
+from FreeCAD import Base
 
 class ConsoleTestCase(unittest.TestCase):
     def setUp(self):
@@ -101,6 +102,11 @@ class ConsoleTestCase(unittest.TestCase):
     def tearDown(self):
         pass
 
+    def testILoggerBlocker(self):
+        if FreeCAD.GuiUp:
+            import QtUnitGui
+            QtUnitGui.testILoggerBlocker()
+
 class ParameterTestCase(unittest.TestCase):
     def setUp(self):
         self.TestPar = FreeCAD.ParamGet("System parameter:Test")
@@ -247,6 +253,35 @@ class AlgebraTestCase(unittest.TestCase):
         self.assertEqual(m2, m3*m4   , "Wrong multiplication order")
         self.assertNotEqual(m2, m4*m3, "Wrong multiplication order")
 
+
+    def testRotationFromMatrix(self):
+        m1 = FreeCAD.Matrix()
+        m1.rotateZ(.2)
+        m1.scale(0.5)
+        m1.rotateY(.2)
+        m1.scale(3)
+        m1.move(10,5,-3)
+        r1 = FreeCAD.Rotation(m1)
+        m2 = FreeCAD.Matrix()
+        m2.rotateZ(.2)
+        m2.rotateY(.2)
+        m2.move(10,5,-3)
+        r2 = FreeCAD.Rotation(m2)  
+        self.assertTrue(r1.isSame(r2, 1e-7), 'Scale on matrix influenced rotation')
+        m3 = FreeCAD.Matrix()
+        m3.scale(-1)
+        r3 = FreeCAD.Rotation(m3)
+        r0 = FreeCAD.Rotation()
+        self.assertTrue(r3.isSame(r0, 1e-7), 'Scale on matrix influenced rotation')
+        m4 = FreeCAD.Matrix()
+        m4.scale(1.25,1.0,0.25)
+        m4.move(4,5,6)
+        r24 = FreeCAD.Rotation(m2*m4)
+        r42 = FreeCAD.Rotation(m4*m2)
+        self.assertTrue(r2.isSame(r24, 1e-7), 'Scale on matrix influenced rotation')
+        self.assertTrue(r2.isSame(r42, 1e-7), 'Scale on matrix influenced rotation')
+
+        
     def testRotation(self):
         r=FreeCAD.Rotation(1,0,0,0) # 180 deg around (1,0,0)
         self.assertEqual(r.Axis, FreeCAD.Vector(1,0,0))
@@ -329,6 +364,25 @@ class AlgebraTestCase(unittest.TestCase):
         p.Rotation.Angle = math.pi / 2
         self.assertEqual(abs(p.inverse().Rotation.Angle), p.Rotation.Angle)
 
+    def testMatrixToRotationFailure(self):
+        mat = FreeCAD.Matrix()
+        mat.A21 = 1.0
+        with self.assertRaises(ValueError):
+            FreeCAD.Placement(mat)
+        with self.assertRaises(ValueError):
+            FreeCAD.Rotation(mat)
+        with self.assertRaises(ValueError):
+            FreeCAD.Rotation(*mat.A)
+        with self.assertRaises(ValueError):
+            FreeCAD.Rotation(1, 1, 0, 0, 1, 0, 0, 0, 1)
+        with self.assertRaises(ValueError):
+            rot = FreeCAD.Rotation()
+            rot.Matrix = FreeCAD.Matrix(1, 1, 0, 0, 1, 0, 0, 0, 1)
+        with self.assertRaises(ValueError):
+            plm = FreeCAD.Placement()
+            rot.Matrix = FreeCAD.Matrix(1, 1, 0, 0, 1, 0, 0, 0, 1)
+
+
     def testYawPitchRoll(self):
         def getYPR1(yaw, pitch, roll):
             r = FreeCAD.Rotation()
@@ -376,6 +430,27 @@ class AlgebraTestCase(unittest.TestCase):
         self.assertFalse(b.intersected(FreeCAD.BoundBox(4,4,4,6,6,6)).isValid(),"Bbox should not intersect with Bbox outside")
         self.assertEqual(b.intersected(FreeCAD.BoundBox(-2,-2,-2,2,2,2)).Center, b.Center,"Bbox is not a full subset")
 
+    def testMultLeftOrRight(self):
+        doc = FreeCAD.newDocument()
+        obj = doc.addObject("App::FeatureTestPlacement")
+
+        p1 = Base.Placement()
+        p1.Base = Base.Vector(10, 10, 10)
+
+        p2 = Base.Placement()
+        p2.Rotation.Angle = math.radians(90)
+
+        obj.Input1 = p1
+        obj.Input2 = p2
+        doc.recompute()
+
+        self.assertTrue(obj.MultRight.isSame(p1 * p2))
+        self.assertFalse(obj.MultRight.isSame(p2 * p1))
+        self.assertTrue(obj.MultLeft.isSame(p2 * p1))
+        self.assertFalse(obj.MultLeft.isSame(p1 * p2))
+
+        FreeCAD.closeDocument(doc.Name)
+
 class MatrixTestCase(unittest.TestCase):
     def setUp(self):
         self.mat = FreeCAD.Matrix()
@@ -431,7 +506,7 @@ class MatrixTestCase(unittest.TestCase):
         self.assertEqual(type(res), FreeCAD.Matrix)
 
     def testMatrixPlacementMatrix(self):
-        # Example taken from https://forum.freecadweb.org/viewtopic.php?f=3&t=61000
+        # Example taken from https://forum.freecad.org/viewtopic.php?f=3&t=61000
         mat = FreeCAD.Matrix(-0.470847778020266,
                              0.8150598976807029,
                              0.3376088628746235,
@@ -499,6 +574,11 @@ class MatrixTestCase(unittest.TestCase):
         self.mat.setRow(1, FreeCAD.Vector(1,2,3))
         self.mat.setRow(2, FreeCAD.Vector(1,2,3))
         self.assertEqual(self.mat.hasScale(), FreeCAD.ScaleType.Other)
+        self.mat.unity()
+        self.mat.scale(-1.)
+        self.assertEqual(self.mat.hasScale(), FreeCAD.ScaleType.Uniform)
+        self.mat.scale(-2.)
+        self.assertEqual(self.mat.hasScale(), FreeCAD.ScaleType.Uniform)
 
     def testShearing(self):
         self.mat.setRow(1, FreeCAD.Vector(0,1,1))
