@@ -41,7 +41,7 @@
     <message>
       <location filename="../../UnitTest.ui" line="141"/>
       <source>&amp;About</source>
-      <translation>&amp;Tietoja ohjelmasta</translation>
+      <translation>&amp;Tietoja</translation>
     </message>
     <message>
       <location filename="../../UnitTest.ui" line="144"/>
@@ -102,12 +102,12 @@
   <context>
     <name>TestGui::UnitTestDialog</name>
     <message>
-      <location filename="../../UnitTestImp.cpp" line="155"/>
+      <location filename="../../UnitTestImp.cpp" line="166"/>
       <source>Help</source>
       <translation>Helppi</translation>
     </message>
     <message>
-      <location filename="../../UnitTestImp.cpp" line="155"/>
+      <location filename="../../UnitTestImp.cpp" line="166"/>
       <source>Enter the name of a callable object which, when called, will return a TestCase.
 Click 'start', and the test thus produced will be run.
 
@@ -118,12 +118,12 @@ Napsauta 'alkaa', ja näin tuotettu testi suoritetaan.
 Kaksoisnapsauta puunäkymässä olevaa virhettä nähdäksesi lisää tietoa siitä, mukaan lukien pinottu jälki.</translation>
     </message>
     <message>
-      <location filename="../../UnitTestImp.cpp" line="167"/>
+      <location filename="../../UnitTestImp.cpp" line="178"/>
       <source>About FreeCAD UnitTest</source>
-      <translation>Tietoja FreeCAD toiminnan testauksesta</translation>
+      <translation>Tietoja FreeCAD-yksikkötestauksesta</translation>
     </message>
     <message>
-      <location filename="../../UnitTestImp.cpp" line="167"/>
+      <location filename="../../UnitTestImp.cpp" line="178"/>
       <source>Copyright (c) Werner Mayer
 
 FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
