@@ -20,24 +20,20 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <QMessageBox>
-# include <QStyleFactory>
 #endif
 
-#include <Base/PyObjectBase.h>
 #include <Base/Interpreter.h>
 #include <Gui/MainWindow.h>
+
 #include "UnitTestImp.h"
 #include "ui_UnitTest.h"
-#include "UnitTestPy.h"
 
 
 using namespace TestGui;
 
-
 /* TRANSLATOR TestGui::UnitTestDialog */
 
 UnitTestDialog* UnitTestDialog::_instance=nullptr;
@@ -58,7 +54,7 @@ UnitTestDialog* UnitTestDialog::instance()
  */
 void UnitTestDialog::destruct ()
 {
-    if (_instance != nullptr) {
+    if (_instance) {
         UnitTestDialog *pTmp = _instance;
         _instance = nullptr;
         delete pTmp;
@@ -85,6 +81,8 @@ UnitTestDialog::UnitTestDialog(QWidget* parent, Qt::WindowFlags f)
   , ui(new Ui_UnitTest)
 {
     ui->setupUi(this);
+    setupConnections();
+
     setProgressColor(QColor(40,210,43)); // a darker green
     ui->progressBar->setAlignment(Qt::AlignCenter);
 
@@ -101,6 +99,19 @@ UnitTestDialog::~UnitTestDialog()
 {
 }
 
+void UnitTestDialog::setupConnections()
+{
+    connect(ui->treeViewFailure, &QTreeWidget::itemDoubleClicked,
+            this, &UnitTestDialog::onTreeViewFailureItemDoubleClicked);
+    connect(ui->helpButton, &QPushButton::clicked,
+            this, &UnitTestDialog::onHelpButtonClicked);
+    connect(ui->aboutButton, &QPushButton::clicked,
+            this, &UnitTestDialog::onAboutButtonClicked);
+    connect(ui->startButton, &QPushButton::clicked,
+            this, &UnitTestDialog::onStartButtonClicked);
+
+}
+
 /**
  * Sets the color to the progressbar to \a col.
  */
@@ -122,7 +133,7 @@ void UnitTestDialog::setProgressColor(const QColor& col)
 /**
  * Opens a dialog to display a detailed description about the error.
  */
-void UnitTestDialog::on_treeViewFailure_itemDoubleClicked(QTreeWidgetItem * item, int column)
+void UnitTestDialog::onTreeViewFailureItemDoubleClicked(QTreeWidgetItem * item, int column)
 {
     Q_UNUSED(column);
 
@@ -150,7 +161,7 @@ void UnitTestDialog::on_treeViewFailure_itemDoubleClicked(QTreeWidgetItem * item
 /**
  * Shows the help dialog.
  */
-void UnitTestDialog::on_helpButton_clicked()
+void UnitTestDialog::onHelpButtonClicked()
 {
     QMessageBox::information(this, tr("Help"), tr(
         "Enter the name of a callable object which, when called, will return a TestCase.\n"
@@ -162,7 +173,7 @@ void UnitTestDialog::on_helpButton_clicked()
 /**
  * Shows the about dialog.
  */
-void UnitTestDialog::on_aboutButton_clicked()
+void UnitTestDialog::onAboutButtonClicked()
 {
     QMessageBox::information(this, tr("About FreeCAD UnitTest"), tr(
         "Copyright (c) Werner Mayer\n\n"
@@ -173,7 +184,7 @@ void UnitTestDialog::on_aboutButton_clicked()
 /**
  * Runs the unit tests.
  */
-void UnitTestDialog::on_startButton_clicked()
+void UnitTestDialog::onStartButtonClicked()
 {
     reset();
     setProgressColor(QColor(40,210,43)); // a darker green
@@ -278,6 +289,19 @@ QString UnitTestDialog::getUnitTest() const
     return ui->comboTests->currentText();
 }
 
+/**
+ * Runs the currently selected test and closes the dialog afterwards.
+ * It returns true if all tests have passed and false otherwise.
+ */
+bool UnitTestDialog::runCurrentTest()
+{
+    clearErrorList();
+    onStartButtonClicked();
+    int count = ui->treeViewFailure->topLevelItemCount();
+    reject();
+    return (count == 0);
+}
+
 /**
  * Sets the text in the status bar.
  */
