@@ -22,8 +22,8 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <stdexcept>
 # include <memory>
+# include <stdexcept>
 # include <QCoreApplication>
 # include <QTcpSocket>
 #endif
@@ -127,16 +127,16 @@ AppServer::AppServer( bool direct, QObject* parent)
 
 void AppServer::incomingConnection(qintptr socket)
 {
-    QTcpSocket* s = new QTcpSocket(this);
-    connect(s, SIGNAL(readyRead()), this, SLOT(readClient()));
-    connect(s, SIGNAL(disconnected()), this, SLOT(discardClient()));
-    s->setSocketDescriptor(socket);
-    addPendingConnection(s);
+    QTcpSocket* tcpSocket = new QTcpSocket(this);
+    connect(tcpSocket, &QTcpSocket::readyRead, this, &AppServer::readClient);
+    connect(tcpSocket, &QTcpSocket::disconnected, this, &AppServer::discardClient);
+    tcpSocket->setSocketDescriptor(socket);
+    addPendingConnection(tcpSocket);
 }
 
 void AppServer::readClient()
 {
-    QTcpSocket* socket = (QTcpSocket*)sender();
+    QTcpSocket* socket = static_cast<QTcpSocket*>(sender());
     if (socket->bytesAvailable() > 0) {
         QByteArray request = socket->readAll();
         std::unique_ptr<ServerEvent> event(std::make_unique<ServerEvent>(socket, request));
@@ -155,7 +155,7 @@ void AppServer::readClient()
 
 void AppServer::discardClient()
 {
-    QTcpSocket* socket = (QTcpSocket*)sender();
+    QTcpSocket* socket = static_cast<QTcpSocket*>(sender());
     socket->deleteLater();
 }
 
