@@ -22,10 +22,17 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <string>
+# include <QAbstractNativeEventFilter>
+# include <QApplication>
 # include <QIcon>
 # include <QUrl>
 #endif
 
+#ifdef Q_OS_WIN32
+#include <Windows.h>
+#endif
+
 #include <Base/Console.h>
 #include <Base/Interpreter.h>
 #include <Base/PyObjectBase.h>
@@ -38,12 +45,13 @@
 
 
 // use a different name to CreateCommand()
-void CreateWebCommands(void);
+void CreateWebCommands();
 
 void loadWebResource()
 {
     // add resources and reloads the translators
     Q_INIT_RESOURCE(Web);
+    Q_INIT_RESOURCE(Web_translation);
     Gui::Translator::instance()->refresh();
 }
 
@@ -70,7 +78,7 @@ public:
         initialize("This module is the WebGui module."); // register with Python
     }
 
-    virtual ~Module() {}
+    ~Module() override {}
 
 private:
     Py::Object openBrowser(const Py::Tuple& args)
@@ -150,6 +158,32 @@ PyObject* initModule()
     return Base::Interpreter().addModule(new Module);
 }
 
+class NativeEventFilter : public QAbstractNativeEventFilter
+{
+public:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    bool nativeEventFilter(const QByteArray& eventType, void* message, qintptr* result) override
+#else
+    bool nativeEventFilter(const QByteArray& eventType, void* message, long* result) override
+#endif
+    {
+        Q_UNUSED(eventType)
+        Q_UNUSED(result)
+
+        // Fixes bug #9364: WM_INPUTLANGCHANGEREQUEST seems to freeze FreeCAD
+#ifdef Q_OS_WIN32
+        MSG* msg = (MSG*)(message);
+        if (msg->message == WM_INPUTLANGCHANGEREQUEST) {
+            Base::Console().Log("Ignore WM_INPUTLANGCHANGEREQUEST\n");
+            return true;
+        }
+#else
+        Q_UNUSED(message)
+#endif
+        return false;
+    }
+};
+
 } // namespace WebGui
 
 
@@ -169,6 +203,10 @@ PyMOD_INIT_FUNC(WebGui)
     WebGui::BrowserView::init();
     WebGui::Workbench::init();
 
+#ifdef Q_OS_WIN32
+    qApp->installNativeEventFilter(new WebGui::NativeEventFilter);
+#endif
+
      // add resources and reloads the translators
     loadWebResource();
 
