@@ -21,8 +21,9 @@
  ***************************************************************************/
 
 #include "PreCompiled.h"
-
 #ifndef _PreComp_
+# include <vector>
+
 # include <QApplication>
 # include <QDesktopServices>
 # include <QFileInfo>
@@ -32,14 +33,18 @@
 # include <QMessageBox>
 # include <QMouseEvent>
 # include <QNetworkRequest>
-# include <QRegExp>
-# include <QScreen>
+# include <QRegularExpression>
+# include <QRegularExpressionMatch>
 # include <QSignalMapper>
 # include <QStatusBar>
 #endif
 
 #if defined(QTWEBENGINE)
-# include <QWebEngineContextMenuData>
+# if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+#  include <QWebEngineContextMenuData>
+# else
+#  include <QWebEngineContextMenuRequest>
+# endif
 # include <QWebEnginePage>
 # include <QWebEngineProfile>
 # include <QWebEngineSettings>
@@ -85,23 +90,24 @@ enum WebAction {
 class WebEngineUrlRequestInterceptor : public QWebEngineUrlRequestInterceptor
 {
 public:
-    WebEngineUrlRequestInterceptor(BrowserView *parent) :
+    explicit WebEngineUrlRequestInterceptor(BrowserView *parent) :
         QWebEngineUrlRequestInterceptor(parent),
         m_parent(parent)
     {
     }
 
-    void interceptRequest(QWebEngineUrlRequestInfo &info)
+    void interceptRequest(QWebEngineUrlRequestInfo &info) override
     {
         // do something with this resource, click or get img for example
         if (info.navigationType() == QWebEngineUrlRequestInfo::NavigationTypeLink) {
             // wash out windows file:///C:/something ->file://C:/something
             QUrl url = info.requestUrl();
-            QRegExp re(QLatin1String("^/([a-zA-Z]\\:.*)")); // match & catch drive letter forward
+            QRegularExpression re(QLatin1String("^/([a-zA-Z]\\:.*)")); // match & catch drive letter forward
+            QRegularExpressionMatch match = re.match(url.path());
 
-            if (url.host().isEmpty() && url.isLocalFile() && re.exactMatch(url.path()))
+            if (url.host().isEmpty() && url.isLocalFile() && match.hasMatch())
                 // clip / in file urs ie /C:/something -> C:/something
-                url.setPath(re.cap(1));
+                url.setPath(match.captured(1));
 
             // invoke thread safe.
             QMetaObject::invokeMethod(m_parent, "urlFilter", Q_ARG(QUrl, url));
@@ -156,11 +162,11 @@ public:
     using BaseType = Py::PythonExtension<BrowserViewPy>;
     static void init_type();    // announce properties and methods
 
-    BrowserViewPy(BrowserView* view);
-    ~BrowserViewPy();
+    explicit BrowserViewPy(BrowserView* view);
+    ~BrowserViewPy() override;
 
-    Py::Object repr();
-    Py::Object getattr(const char *);
+    Py::Object repr() override;
+    Py::Object getattr(const char *) override;
     Py::Object cast_to_base(const Py::Tuple&);
 
     Py::Object setHtml(const Py::Tuple&);
@@ -231,7 +237,7 @@ Py::Object BrowserViewPy::getattr(const char * attr)
     if (name == "__dict__" || name == "__class__") {
         Py::Dict dict_self(BaseType::getattr("__dict__"));
         Py::Dict dict_base(base.getattr("__dict__"));
-        for (auto it : dict_base) {
+        for (const auto& it : dict_base) {
             dict_self.setItem(it.first, it.second);
         }
         return dict_self;
@@ -335,27 +341,38 @@ void WebView::wheelEvent(QWheelEvent *event)
 void WebView::contextMenuEvent(QContextMenuEvent *event)
 {
 #ifdef QTWEBENGINE
+# if QT_VERSION < QT_VERSION_CHECK(6,0,0)
     const QWebEngineContextMenuData r = page()->contextMenuData();
+    QUrl linkUrl = r.linkUrl();
+# else
+    const QWebEngineContextMenuRequest* r = this->lastContextMenuRequest();
+    QUrl linkUrl = r->linkUrl();
+# endif
 #else
     QWebHitTestResult r = page()->mainFrame()->hitTestContent(event->pos());
+    QUrl linkUrl = r.linkUrl();
 #endif
-    if (!r.linkUrl().isEmpty()) {
+    if (!linkUrl.isEmpty()) {
         QMenu menu(this);
 
         // building a custom signal for external browser action
         QSignalMapper* signalMapper = new QSignalMapper (&menu);
-        signalMapper->setProperty("url", QVariant(r.linkUrl()));
-        connect(signalMapper, SIGNAL(mapped(int)),
-                this, SLOT(triggerContextMenuAction(int)));
+        signalMapper->setProperty("url", QVariant(linkUrl));
 
         QAction* extAction = menu.addAction(tr("Open in External Browser"));
-        connect (extAction, SIGNAL(triggered()), signalMapper, SLOT(map()));
         signalMapper->setMapping(extAction, WebAction::OpenLink);
 
         QAction* newAction = menu.addAction(tr("Open in new window"));
-        connect (newAction, SIGNAL(triggered()), signalMapper, SLOT(map()));
         signalMapper->setMapping(newAction, WebAction::OpenLinkInNewWindow);
 
+#if QT_VERSION < QT_VERSION_CHECK(5,15,0)
+        connect(signalMapper, qOverload<int>(&QSignalMapper::mapped), this, &WebView::triggerContextMenuAction);
+#else
+        connect(signalMapper, &QSignalMapper::mappedInt, this, &WebView::triggerContextMenuAction);
+#endif
+        connect(extAction, &QAction::triggered, signalMapper, qOverload<>(&QSignalMapper::map));
+        connect(newAction, &QAction::triggered, signalMapper, qOverload<>(&QSignalMapper::map));
+
         menu.addAction(pageAction(QWebEnginePage::DownloadLinkToDisk));
         menu.addAction(pageAction(QWebEnginePage::CopyLinkToClipboard));
         menu.exec(mapToGlobal(event->pos()));
@@ -367,16 +384,23 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
         static bool firstRun = true;
         if (firstRun) {
             firstRun = false;
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
             QMenu *menu = page()->createStandardContextMenu();
+#else
+            QMenu *menu = this->createStandardContextMenu();
+#endif
             QList<QAction *> actions = menu->actions();
             for(QAction *ac : actions) {
                 if (ac->data().toInt() == WebAction::ViewSource) {
                     QSignalMapper* signalMapper = new QSignalMapper (this);
-                    signalMapper->setProperty("url", QVariant(r.linkUrl()));
+                    signalMapper->setProperty("url", QVariant(linkUrl));
                     signalMapper->setMapping(ac, WebAction::ViewSource);
-                    connect(signalMapper, SIGNAL(mapped(int)),
-                            this, SLOT(triggerContextMenuAction(int)));
-                    connect (ac, SIGNAL(triggered()), signalMapper, SLOT(map()));
+#if QT_VERSION < QT_VERSION_CHECK(5,15,0)
+                    connect(signalMapper, qOverload<int>(&QSignalMapper::mapped), this, &WebView::triggerContextMenuAction);
+#else
+                    connect(signalMapper, &QSignalMapper::mappedInt, this, &WebView::triggerContextMenuAction);
+#endif
+                    connect(ac, &QAction::triggered, signalMapper, qOverload<>(&QSignalMapper::map));
                 }
             }
         }
@@ -387,7 +411,7 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
         QAction *ac = menu->addAction(tr("View source"));
         ac->setData(WebAction::ViewSource);
         QSignalMapper* signalMapper = new QSignalMapper (this);
-        signalMapper->setProperty("url", QVariant(r.linkUrl()));
+        signalMapper->setProperty("url", QVariant(linkUrl));
         signalMapper->setMapping(ac, WebAction::ViewSource);
         connect(signalMapper, SIGNAL(mapped(int)),
                 this, SLOT(triggerContextMenuAction(int)));
@@ -405,10 +429,10 @@ void WebView::triggerContextMenuAction(int id)
 
     switch (id) {
     case WebAction::OpenLink:
-        openLinkInExternalBrowser(url);
+        Q_EMIT openLinkInExternalBrowser(url);
         break;
     case WebAction::OpenLinkInNewWindow:
-        openLinkInNewWindow(url);
+        Q_EMIT openLinkInNewWindow(url);
         break;
     case WebAction::ViewSource:
         Q_EMIT viewSource(url);
@@ -492,29 +516,29 @@ BrowserView::BrowserView(QWidget* parent)
     view->settings()->setAttribute(QWebEngineSettings::AutoLoadIconsForPage, true);
     view->settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled,false);
 
-    connect(view->page()->profile(), SIGNAL(downloadRequested(QWebEngineDownloadItem*)),
-            this, SLOT(onDownloadRequested(QWebEngineDownloadItem*)));
-    connect(view->page(), SIGNAL(iconChanged(const QIcon &)),
-            this, SLOT(setWindowIcon(const QIcon &)));
-    connect(view->page(), SIGNAL(linkHovered(const QString &)),
-            this, SLOT(onLinkHovered(const QString &)));
+    connect(view->page()->profile(), &QWebEngineProfile::downloadRequested,
+            this, &BrowserView::onDownloadRequested);
+    connect(view->page(), &QWebEnginePage::iconChanged,
+            this, &BrowserView::setWindowIcon);
+    connect(view->page(), &QWebEnginePage::linkHovered,
+            this, &BrowserView::onLinkHovered);
 #endif
-    connect(view, SIGNAL(viewSource(const QUrl&)),
-            this, SLOT(onViewSource(const QUrl&)));
-    connect(view, SIGNAL(loadStarted()),
-            this, SLOT(onLoadStarted()));
-    connect(view, SIGNAL(loadProgress(int)),
-            this, SLOT(onLoadProgress(int)));
-    connect(view, SIGNAL(loadFinished(bool)),
-            this, SLOT(onLoadFinished(bool)));
-    connect(view, SIGNAL(openLinkInExternalBrowser(const QUrl &)),
-            this, SLOT(onOpenLinkInExternalBrowser(const QUrl &)));
-    connect(view, SIGNAL(openLinkInNewWindow(const QUrl &)),
-            this, SLOT(onOpenLinkInNewWindow(const QUrl &)));
-    connect(view, SIGNAL(loadStarted()),
-            this, SLOT(onUpdateBrowserActions()));
-    connect(view, SIGNAL(loadFinished(bool)),
-            this, SLOT(onUpdateBrowserActions()));
+    connect(view, &WebView::viewSource,
+            this, &BrowserView::onViewSource);
+    connect(view, &WebView::loadStarted,
+            this, &BrowserView::onLoadStarted);
+    connect(view, &WebView::loadProgress,
+            this, &BrowserView::onLoadProgress);
+    connect(view, &WebView::loadFinished,
+            this, &BrowserView::onLoadFinished);
+    connect(view, &WebView::openLinkInExternalBrowser,
+            this, &BrowserView::onOpenLinkInExternalBrowser);
+    connect(view, &WebView::openLinkInNewWindow,
+            this, &BrowserView::onOpenLinkInNewWindow);
+    connect(view, &WebView::loadStarted,
+            this, &BrowserView::onUpdateBrowserActions);
+    connect(view, &WebView::loadFinished,
+            this, &BrowserView::onUpdateBrowserActions);
 }
 
 /** Destroys the object and frees any allocated resources */
@@ -533,8 +557,7 @@ void BrowserView::urlFilter(const QUrl & url)
     //QString username = url.userName();
 
     // path handling
-    QString path     = url.path();
-    QFileInfo fi(path);
+    QString path = url.path();
     QUrl exturl(url);
 
     // query
@@ -579,7 +602,10 @@ void BrowserView::urlFilter(const QUrl & url)
                     }
                     // Gui::Command::doCommand(Gui::Command::Gui,"execfile('%s')",(const char*) fi.absoluteFilePath().	toLocal8Bit());
                     QString filename = Base::Tools::escapeEncodeFilename(fi.absoluteFilePath());
+                    // Set flag indicating that this load/restore has been initiated by the user (not by a macro)
+                    Gui::Application::Instance->setStatus(Gui::Application::UserInitiatedOpenDocument, true);
                     Gui::Command::doCommand(Gui::Command::Gui,"with open('%s') as file:\n\texec(file.read())",(const char*) filename.toUtf8());
+                    Gui::Application::Instance->setStatus(Gui::Application::UserInitiatedOpenDocument, false);
                 }
                 catch (const Base::Exception& e) {
                     QMessageBox::critical(this, tr("Error"), QString::fromUtf8(e.what()));
@@ -607,7 +633,11 @@ bool BrowserView::chckHostAllowed(const QString& host)
 }
 
 #ifdef QTWEBENGINE
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 void BrowserView::onDownloadRequested(QWebEngineDownloadItem *request)
+#else
+void BrowserView::onDownloadRequested(QWebEngineDownloadRequest *request)
+#endif
 {
     QUrl url = request->url();
     if (!url.isLocalFile()) {
@@ -735,7 +765,7 @@ void BrowserView::setHtml(const QString& HtmlCode,const QUrl & BaseUrl)
 #endif
 }
 
-void BrowserView::stop(void)
+void BrowserView::stop()
 {
     view->stop();
 }
@@ -868,12 +898,12 @@ bool BrowserView::onHasMsg(const char* pMsg) const
 }
 
 /** Checking on close state. */
-bool BrowserView::canClose(void)
+bool BrowserView::canClose()
 {
     return true;
 }
 
-PyObject* BrowserView::getPyObject(void)
+PyObject* BrowserView::getPyObject()
 {
     static bool init = false;
     if (!init) {
