@@ -23,26 +23,24 @@
 #ifndef WEBGUI_BROWSERVIEW_H
 #define WEBGUI_BROWSERVIEW_H
 
+#include <QLineEdit>
+#include <QPointer>
+#if defined(QTWEBENGINE)
+# include <QWebEngineView>
+namespace WebGui {
+ class WebEngineUrlRequestInterceptor;
+}
+#elif defined(QTWEBKIT)
+# include <QWebView>
+#endif
 
 #include <Gui/MDIView.h>
 #include <Gui/Window.h>
 #include <Mod/Web/WebGlobal.h>
-#include <QLineEdit>
-#include <QPointer>
 
-#if defined(QTWEBENGINE)
-#include <QWebEngineView>
-
-namespace WebGui {
-class WebEngineUrlRequestInterceptor;
-}
-#elif defined(QTWEBKIT)
-#include <QWebView>
-#endif
-
-class QUrl;
-class QNetworkRequest;
 class QNetworkReply;
+class QNetworkRequest;
+class QUrl;
 
 namespace WebGui {
 class UrlWidget;
@@ -56,12 +54,12 @@ class WebGuiExport WebView : public QWebView
     Q_OBJECT
 
 public:
-    WebView(QWidget *parent = nullptr);
+    explicit WebView(QWidget *parent = nullptr);
 
 protected:
-    void mousePressEvent(QMouseEvent *event);
-    void wheelEvent(QWheelEvent *event);
-    void contextMenuEvent(QContextMenuEvent *event);
+    void mousePressEvent(QMouseEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
+    void contextMenuEvent(QContextMenuEvent *event) override;
 
 private Q_SLOTS:
     void triggerContextMenuAction(int);
@@ -81,27 +79,27 @@ class WebGuiExport BrowserView : public Gui::MDIView,
 {
     Q_OBJECT
 
-    TYPESYSTEM_HEADER();
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
-    BrowserView(QWidget* parent);
-    ~BrowserView();
+    explicit BrowserView(QWidget* parent);
+    ~BrowserView() override;
 
     void load(const char* URL);
     void load(const QUrl & url);
     void setHtml(const QString& HtmlCode,const QUrl & BaseUrl);
-    void stop(void);
+    void stop();
     QUrl url() const;
 
-    void OnChange(Base::Subject<const char*> &rCaller,const char* rcReason);
+    void OnChange(Base::Subject<const char*> &rCaller,const char* rcReason) override;
 
-    const char *getName(void) const {return "BrowserView";}
-    virtual PyObject *getPyObject(void);
+    const char *getName() const override {return "BrowserView";}
+    PyObject *getPyObject() override;
 
-    bool onMsg(const char* pMsg,const char** ppReturn);
-    bool onHasMsg(const char* pMsg) const;
+    bool onMsg(const char* pMsg,const char** ppReturn) override;
+    bool onHasMsg(const char* pMsg) const override;
 
-    bool canClose (void);
+    bool canClose () override;
 
 #ifdef QTWEBENGINE
 public Q_SLOTS:
@@ -115,7 +113,11 @@ protected Q_SLOTS:
     bool chckHostAllowed(const QString& host);
     void urlFilter(const QUrl &url);
 #ifdef QTWEBENGINE
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
     void onDownloadRequested(QWebEngineDownloadItem *request);
+#else
+    void onDownloadRequested(QWebEngineDownloadRequest *request);
+#endif
     void onLinkHovered(const QString& url);
 #else
     void onDownloadRequested(const QNetworkRequest& request);
@@ -145,10 +147,10 @@ class UrlWidget : public QLineEdit
     BrowserView *m_view;
 public:
     explicit UrlWidget(BrowserView *view);
-    ~UrlWidget();
+    ~UrlWidget() override;
     void display();
 protected:
-    void keyPressEvent(QKeyEvent *keyEvt);
+    void keyPressEvent(QKeyEvent *keyEvt) override;
 };
 
 } // namespace WebGui
