@@ -4,14 +4,17 @@
   <context>
     <name>CmdWebBrowserBack</name>
     <message>
+      <location filename="../../Command.cpp" line="72"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="73"/>
       <source>Previous page</source>
       <translation>Predošlá stránka</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="74"/>
       <source>Go back to the previous page</source>
       <translation>Choď naspäť na predošlú stránku</translation>
     </message>
@@ -19,14 +22,17 @@
   <context>
     <name>CmdWebBrowserNext</name>
     <message>
+      <location filename="../../Command.cpp" line="101"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="102"/>
       <source>Next page</source>
       <translation>Ďalšia stránka</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="103"/>
       <source>Go to the next page</source>
       <translation>Choď na ďalšiu stránku</translation>
     </message>
@@ -34,10 +40,13 @@
   <context>
     <name>CmdWebBrowserRefresh</name>
     <message>
+      <location filename="../../Command.cpp" line="130"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="131"/>
+      <location filename="../../Command.cpp" line="132"/>
       <source>Refresh web page</source>
       <translation>Obnoviť internetovú stránku</translation>
     </message>
@@ -45,10 +54,13 @@
   <context>
     <name>CmdWebBrowserSetURL</name>
     <message>
+      <location filename="../../Command.cpp" line="246"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="247"/>
+      <location filename="../../Command.cpp" line="248"/>
       <source>Set URL</source>
       <translation>Nastaviť URL</translation>
     </message>
@@ -56,10 +68,13 @@
   <context>
     <name>CmdWebBrowserStop</name>
     <message>
+      <location filename="../../Command.cpp" line="158"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="159"/>
+      <location filename="../../Command.cpp" line="160"/>
       <source>Stop loading</source>
       <translation>Zastaviť načítanie</translation>
     </message>
@@ -67,10 +82,13 @@
   <context>
     <name>CmdWebBrowserZoomIn</name>
     <message>
+      <location filename="../../Command.cpp" line="188"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="189"/>
+      <location filename="../../Command.cpp" line="190"/>
       <source>Zoom in</source>
       <translation>Priblížiť</translation>
     </message>
@@ -78,10 +96,13 @@
   <context>
     <name>CmdWebBrowserZoomOut</name>
     <message>
+      <location filename="../../Command.cpp" line="217"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="218"/>
+      <location filename="../../Command.cpp" line="219"/>
       <source>Zoom out</source>
       <translation>Vzdialiť</translation>
     </message>
@@ -89,14 +110,17 @@
   <context>
     <name>CmdWebOpenWebsite</name>
     <message>
+      <location filename="../../Command.cpp" line="46"/>
       <source>Web</source>
       <translation>Web</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="47"/>
       <source>Open website...</source>
       <translation>Otvoriť internetové stránky...</translation>
     </message>
     <message>
+      <location filename="../../Command.cpp" line="48"/>
       <source>Opens a website in FreeCAD</source>
       <translation>Otvorí internetové stránky vo FreeCAD</translation>
     </message>
@@ -104,10 +128,13 @@
   <context>
     <name>QObject</name>
     <message>
+      <location filename="../../AppWebGui.cpp" line="86"/>
+      <location filename="../../BrowserView.cpp" line="805"/>
       <source>Browser</source>
       <translation>Prehliadač</translation>
     </message>
     <message>
+      <location filename="../../BrowserView.cpp" line="613"/>
       <source>File does not exist!</source>
       <translation>Súbor neexistuje!</translation>
     </message>
@@ -115,18 +142,24 @@
   <context>
     <name>WebGui::BrowserView</name>
     <message>
+      <location filename="../../BrowserView.cpp" line="601"/>
+      <location filename="../../BrowserView.cpp" line="606"/>
+      <location filename="../../BrowserView.cpp" line="609"/>
       <source>Error</source>
       <translation>Chyba</translation>
     </message>
     <message>
+      <location filename="../../BrowserView.cpp" line="606"/>
       <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
       <translation>Pri načítaní súboru nastala chyba. Niektoré dáta mohli byť zmenené, alebo sa vôbec neobnovili. Pozrite si zobrazenie výpisu, v ktorom nájdete detailnejšie informácie o objektoch, ktorých sa to týka.</translation>
     </message>
     <message>
+      <location filename="../../BrowserView.cpp" line="609"/>
       <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
       <translation type="unfinished">There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</translation>
     </message>
     <message>
+      <location filename="../../BrowserView.cpp" line="773"/>
       <source>Loading %1...</source>
       <translation>Načítanie %1...</translation>
     </message>
@@ -134,14 +167,17 @@
   <context>
     <name>WebGui::WebView</name>
     <message>
+      <location filename="../../BrowserView.cpp" line="364"/>
       <source>Open in External Browser</source>
       <translation>Otvoriť v externom prehliadači</translation>
     </message>
     <message>
+      <location filename="../../BrowserView.cpp" line="368"/>
       <source>Open in new window</source>
       <translation>Otvoriť v novom okne</translation>
     </message>
     <message>
+      <location filename="../../BrowserView.cpp" line="404"/>
       <source>View source</source>
       <translation>Zobraziť zdroj</translation>
     </message>
@@ -149,6 +185,7 @@
   <context>
     <name>Workbench</name>
     <message>
+      <location filename="../../Workbench.cpp" line="36"/>
       <source>Navigation</source>
       <translation>Navigácia</translation>
     </message>
