@@ -22,14 +22,13 @@
 
 #include "PreCompiled.h"
 
-#include "Workbench.h"
-
 #include <Gui/Application.h>
 #include <Gui/Command.h>
-#include <Gui/MenuManager.h>
 #include <Gui/Selection.h>
 #include <Gui/ToolBarManager.h>
 
+#include "Workbench.h"
+
 
 using namespace WebGui;
 
@@ -231,17 +230,6 @@ Gui::MenuItem* Workbench::setupMenuBar() const
 //        << "Drawing_ExportPage"
 //    ;
 //
-//    // Raytracing ****************************************************************************************************
-//
-//    Gui::MenuItem* raytracing = new Gui::MenuItem(menuBar);
-//
-//    raytracing->setCommand("&Raytracing");
-//    *raytracing
-//        << "Raytracing_WriteView"
-//        << "Raytracing_WriteCamera"
-//        << "Raytracing_WritePart";
-//    ;
-//
 //    // Drafting ****************************************************************************************************
 //#   ifdef WEB_USE_DRAFTING
 //    if (mgr.getCommandByName("Draft_Line")) {
@@ -278,8 +266,8 @@ Gui::MenuItem* Workbench::setupMenuBar() const
 //    Gui::MenuItem* wnd = new Gui::MenuItem( menuBar );
 //    wnd->setCommand("&Windows");
 //    *wnd << "Std_ActivateNextWindow" << "Std_ActivatePrevWindow" << "Separator"
-//         << "Std_TileWindows" << "Std_CascadeWindows"
-//         << "Std_ArrangeIcons" << "Separator" << "Std_WindowsMenu" << "Std_Windows";
+//         << "Std_TileWindows" << "Std_CascadeWindows" << "Separator"
+//         << "Std_WindowsMenu" << "Std_Windows";
 //
 //    // help ****************************************************************************************************
 //    // Separator
